package com.hand.hap.db.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.jdbc.core.JdbcTemplate;

/**
 * @Description:
 * @Author: wty
 * @Date: Created in 15:20 2018/1/29
 */
class SysCodeTemplateUtils {

    private String jdbcUrl = System.getProperty("db.url");

    private JdbcTemplate jdbcTemplate = null;

    private static SysCodeTemplateUtils sysCodeTemplateUtils;

    private static Logger logger = LoggerFactory.getLogger(SysCodeTemplateUtils.class);

    private SysCodeTemplateUtils() {
        JdbcTemplateUtils jdbcTemplateUtils = JdbcTemplateUtils.getInstance();
        this.jdbcTemplate = jdbcTemplateUtils.getJdbcTemplate();
    }

    public static SysCodeTemplateUtils getInstance() {
        logger.info("===================== start init SysCodeTemplateUtils ========================");
        if (sysCodeTemplateUtils == null) {
            synchronized (SysCodeTemplateUtils.class) {
                if (sysCodeTemplateUtils == null) {
                    logger.info("===================== Create new SysCodeTemplateUtils Start========================");
                    sysCodeTemplateUtils = new SysCodeTemplateUtils();
                    logger.info("===================== Create new SysCodeTemplateUtils end========================");
                }
            }
        }
        return sysCodeTemplateUtils;
    }


    public void sysCodeLoad(String code, String description, String type, String parentCode) {
        String sqlHead = "insert into sys_code_b ";
        String columns = "(enabled_flag,";
        String values = "values ('Y',";
        if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:oracle")) {
            columns = "(code_id,enabled_flag,";
            values = "values (sys_code_b_s.nextval,'Y',";
        } else if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:mysql")) {
            columns = "(enabled_flag,";
            values = "values ('Y',";
        }
        if (code != null) {
            columns += "code,";
            values += "'" + code + "',";
        }
        if (description != null) {
            columns += "description,";
            values += "'" + description + "',";
        }
        if (type != null) {
            columns += "type,";
            values += "'" + type + "',";
        }
        if (parentCode != null) {
            String selectParentCodeId = "(select scb.code_id from sys_code_b scb where scb.code = '" + parentCode + "')";
            columns += "parent_code_id,";
            values += selectParentCodeId + ",";
        }
        String sql = sqlHead + columns.substring(0, columns.length() - 1) + ") " + values.substring(0, values.length() - 1) + ")";
        jdbcTemplate.update(sql);
    }

    public void sysCodeTlLoad(String code, String description, String lang) {
        String selectSysCodeId = "(select scb.code_id from sys_code_b scb where scb.code = '" + code + "')";
        String sql = "insert into sys_code_tl (code_id,lang,description) values (" +
                selectSysCodeId + ",'" + lang + "','" + description + "')";
        try {
            jdbcTemplate.update(sql);
        } catch (Exception e) {
            logger.error("insertError   : ", e);
        }
    }

    public void sysCodeValueLoad(String code, String value, String meaning, String description, Integer orderSeq, String parentCode, String parentCodeValue) {
        String sqlHead = "insert into sys_code_value_b ";
        String columns = null;
        String values =  null;
        if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:oracle")) {
            columns = "(code_value_id,enabled_flag,";
            values = "values (sys_code_value_b_s.nextval,'Y',";
            if (value != null) {
                columns += "value,";
                values += "'" + value + "',";
            }
        } else if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:mysql")) {
            columns = "(enabled_flag,";
            values = " values ('Y',";
            if (value != null) {
                columns += "`value`,";
                values += "'" + value + "',";
            }
        }
        String selectSysCodeId = "(select scb.code_id from sys_code_b scb where scb.code = '" + code + "')";
        if (code != null) {
            columns += "code_id,";
            values += selectSysCodeId + ",";
        }
        if (meaning != null) {
            columns += "meaning,";
            values += "'" + meaning + "',";
        }
        if (description != null) {
            columns += "description,";
            values += "'" + description + "',";
        }
        if (orderSeq != null) {
            columns += "order_seq,";
            values += orderSeq.toString() + ",";
        }
        if (parentCode != null && parentCodeValue != null) {
            columns += "parent_code_value_id,";
            String selectSysValueCodeId = "(select scb.code_id from sys_code_b scb where scb.code = '" + parentCode + "')";
            String selectParentCodeValueId = "(select s.code_value_id from sys_code_value_b s where s.code_id=" + selectSysValueCodeId + " and s.value = '" + parentCodeValue + "')";
            values += selectParentCodeValueId + ",";
        }
        String sql = sqlHead + columns.substring(0, columns.length() - 1) + ")" +
                values.substring(0, values.length() - 1) + ")";
        jdbcTemplate.update(sql);
    }

    public void sysCodeValueTlLoad(String code, String value, String meaning, String description, String lang) {
        String selectSysCodeId = "(select scb.code_id from sys_code_b scb where scb.code = '" + code + "')";
        String selectSysValueCodeId = "(select scvb.code_value_id from sys_code_value_b scvb where scvb.value = '" +
                value + "' and scvb.code_id = " + selectSysCodeId + ")";
        String sql = "insert into sys_code_value_tl (code_value_id,lang,meaning,description) values (" +
                selectSysValueCodeId + ",'" + lang + "','" + meaning + "','" + description + "')";
        jdbcTemplate.update(sql);
    }

    public void deleteSysCode(String code) {
        String selectSysCodeId = "(select scb.code_id from sys_code_b scb where scb.code = '" + code + "')";
        String selectCodeValueId = "(select code_value_id from sys_code_value_b where code_id = " + selectSysCodeId + ")";
        String deleteSysCodeValueSql = "delete from sys_code_value_b where code_id = " + selectSysCodeId;
        String deleteSysCodeValueTlSql = "delete from sys_code_value_tl where code_value_id in ( " + selectCodeValueId + " )";
        String deleteSysCodeTlSql = "delete from sys_code_tl where code_id = " + selectSysCodeId;
        String deleteSysCodeSql = "delete from sys_code_b where code = '" + code + "'";
        jdbcTemplate.update(deleteSysCodeValueTlSql);
        jdbcTemplate.update(deleteSysCodeValueSql);
        jdbcTemplate.update(deleteSysCodeTlSql);
        jdbcTemplate.update(deleteSysCodeSql);
    }

}
