package com.hand.hap.db.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.jdbc.core.JdbcTemplate;

/**
 * @Description:
 * @Author: wty
 * @Date: Created in 15:33 2018/1/29
 */
class SysLovTemplateUtils {

    private static Logger logger = LoggerFactory.getLogger(SysLovTemplateUtils.class);

    private JdbcTemplate jdbcTemplate = null;

    private static SysLovTemplateUtils sysLovTemplateUtils;

    private String jdbcUrl = System.getProperty("db.url");

    private SysLovTemplateUtils() {
        JdbcTemplateUtils jdbcTemplateUtils = JdbcTemplateUtils.getInstance();
        this.jdbcTemplate = jdbcTemplateUtils.getJdbcTemplate();
    }

    public static SysLovTemplateUtils getInstance() {
        logger.info("===================== start init SysLovTemplateUtils ========================");
        if (sysLovTemplateUtils == null) {
            synchronized (SysLovTemplateUtils.class) {
                if (sysLovTemplateUtils == null) {
                    logger.info("===================== Create new SysLovTemplateUtils Start========================");
                    sysLovTemplateUtils = new SysLovTemplateUtils();
                    logger.info("===================== Create new SysLovTemplateUtils end========================");
                }
            }
        }
        return sysLovTemplateUtils;
    }

    public void sysLovLoad(String code, String description, String sqlId, String title, String textField, String valueField, String placeHolder, String customSql, String customUrl, String editable, Integer queryColumns, Integer width, Integer height) {
        String headOfSql = "insert into sys_lov";
        String columns = null;
        String values = null;
        if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:oracle")) {
            columns = "(lov_id,delay_load,need_query_param,can_popup,";
            values = " values (sys_lov_s.nextval,'N','N','Y',";
        } else if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:mysql")) {
            columns = "(delay_load,need_query_param,can_popup,";
            values = " values ('N','N','Y',";
        }
        if (code != null) {
            columns += "code,";
            values += "'" + code + "',";
        }
        if (description != null) {
            columns += "description,";
            values += "'" + description + "',";
        }
        if (sqlId != null) {
            columns += "sql_id,";
            values += "'" + sqlId + "',";
        }
        if (title != null) {
            columns += "title,";
            values += "'" + title + "',";
        }
        if (textField != null) {
            columns += "text_field,";
            values += "'" + textField + "',";
        }
        if (valueField != null) {
            columns += "value_field,";
            values += "'" + valueField + "',";
        }
        if (placeHolder != null) {
            columns += "placeholder,";
            values += "'" + placeHolder + "',";
        }
        if (customSql != null) {
            columns += "custom_sql,";
            values += "'" + customSql + "',";
        }
        if (customUrl != null) {
            columns += "custom_url,";
            values += "'" + customUrl + "',";
        }
        if (width != null) {
            columns += "width,";
            values += width.toString() + ",";
        }
        if (height != null) {
            columns += "height,";
            values += height.toString() + ",";
        }
        if (editable != null) {
            columns += "editable,";
            values += "'" + editable + "',";
        } else {
            columns += "editable,";
            values += "'N',";
        }
        if (queryColumns != null) {
            columns += "query_columns,";
            values += queryColumns.toString() + ",";
        }
        String sql = headOfSql + columns.substring(0, columns.length() - 1) + ")" +
                values.substring(0, values.length() - 1) + ")";
        jdbcTemplate.update(sql);
    }

    public void sysLovItemLoad(String code, String display, String gridFieldName, String gridFieldAlign, Integer gridFieldWidth, Integer gridFieldSequence, String gridField, String conditionField, String conditionFieldType, String conditionFieldName, String conditionFieldSelectCode, String conditionFieldLovCode, String conditionFieldTextfield, String conditionFieldSelectUrl, String conditionFieldSelectTf, String conditionFieldSelectVf, Integer conditionFieldLabelWidth, Integer conditionFieldWidth, Integer conditionFieldSequence) {
        String headOfSql = "insert into sys_lov_item ";
        String columns = null;
        String values = null;
        if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:oracle")) {
            columns = "(lov_item_id,is_autocomplete,condition_field_newline,autocomplete_field,";
            values = " values (sys_lov_item_s.nextval,'N','N','Y',";
        } else if (jdbcUrl != null && jdbcUrl.startsWith("jdbc:mysql")) {
            columns = "(is_autocomplete,condition_field_newline,autocomplete_field,";
            values = " values ('N','N','Y',";
        }
        if (code != null) {
            String selectLovId = "(select lov_id from sys_lov where code = '" + code + "')";
            columns += "lov_id,";
            values += selectLovId + ",";
        }
        if (display != null) {
            columns += "display,";
            values += "'" + display + "',";
        }
        if (gridFieldName != null) {
            columns += "grid_field_name,";
            values += "'" + gridFieldName + "',";
        }
        if (gridFieldAlign != null) {
            columns += "grid_field_align,";
            values += "'" + gridFieldAlign + "',";
        }
        if (gridFieldWidth != null) {
            columns += "grid_field_width,";
            values += gridFieldWidth.toString() + ",";
        }
        if (gridFieldSequence != null) {
            columns += "grid_field_sequence,";
            values += gridFieldSequence.toString() + ",";
        }
        if (gridField != null) {
            columns += "grid_field,";
            values += "'" + gridField + "',";
        }
        if (conditionField != null) {
            columns += "condition_field,";
            values += "'" + conditionField + "',";
        }
        if (conditionFieldType != null) {
            columns += "condition_field_type,";
            values += "'" + conditionFieldType + "',";
        }
        if (conditionFieldName != null) {
            columns += "condition_field_name,";
            values += "'" + conditionFieldName + "',";
        }
        if (conditionFieldSelectCode != null) {
            columns += "condition_field_select_code,";
            values += "'" + conditionFieldSelectCode + "',";
        }
        if (conditionFieldLovCode != null) {
            columns += "condition_field_lov_code,";
            values += "'" + conditionFieldLovCode + "',";
        }
        if (conditionFieldTextfield != null) {
            columns += "condition_field_textfield,";
            values += "'" + conditionFieldTextfield + "',";
        }
        if (conditionFieldSelectUrl != null) {
            columns += "condition_field_select_url,";
            values += "'" + conditionFieldSelectUrl + "',";
        }
        if (conditionFieldSelectTf != null) {
            columns += "condition_field_select_tf,";
            values += "'" + conditionFieldSelectTf + "',";
        }
        if (conditionFieldSelectVf != null) {
            columns += "condition_field_select_vf,";
            values += "'" + conditionFieldSelectVf + "',";
        }
        if (conditionFieldLabelWidth != null) {
            columns += "condition_field_label_width,";
            values += conditionFieldLabelWidth.toString() + ",";
        }
        if (conditionFieldWidth != null) {
            columns += "condition_field_width,";
            values += conditionFieldWidth.toString() + ",";
        }
        if (conditionFieldSequence != null) {
            columns += "condition_field_sequence,";
            values += conditionFieldSequence.toString() + ",";
        }
        String sql = headOfSql + columns.substring(0, columns.length() - 1) + ")" +
                values.substring(0, values.length() - 1) + ")";
        jdbcTemplate.update(sql);
    }

    public void deleteSysLov(String code) {
        String selectLovId = "(select lov_id from sys_lov where code = '" + code + "')";
        String deleteLovItemSql = "delete from sys_lov_item where lov_id = " + selectLovId;
        String deleteLovSql = "delete from sys_lov where code = '" + code + "'";
        jdbcTemplate.update(deleteLovItemSql);
        jdbcTemplate.update(deleteLovSql);
    }
}