package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
dbType = mhi.dbType()
databaseChangeLog(logicalFilePath: "2017-10-09-init-table-migration.groovy") {
    changeSet(author: "neil", id: "-GLD_JE_RULE_ENGINE_EXTEND") {
        createTable(tableName: "GLD_JE_RULE_ENGINE_EXTEND", remarks: "凭证规则树_扩展") {
            column(name: "RULE_ENGINE_EXTEND_ID", type: "bigint(20)", remarks: "凭证规则树节点扩展ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_RULE_ENGINE_EXTEND_PK")
            }
            column(name: "ROUTE_ID", type: "bigint(20)", remarks: "规则树节点ID") { constraints(nullable: "false") }
            column(name: "JE_HD_TEMPLATE_ID", type: "bigint(20)", remarks: "凭证模板头ID")
            column(name: "JE_HD_RULE_USER_COLUMN_1", type: "varchar(100)", remarks: "凭证头汇总规则_自定义字段1")
            column(name: "JE_HD_RULE_USER_COLUMN_2", type: "varchar(100)", remarks: "凭证头汇总规则_自定义字段2")
            column(name: "JE_HD_RULE_USER_COLUMN_3", type: "varchar(100)", remarks: "凭证头汇总规则_自定义字段3")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_JE_RULE_ENGINE_EXTEND", columnNames: "ROUTE_ID", constraintName: "GLD_JE_RULE_ENGINE_EXTEND_U1")


    }
    changeSet(author: "neil", id: "-GLD_JE_HD_TEMPLATE") {
        createTable(tableName: "GLD_JE_HD_TEMPLATE", remarks: "凭证模板头") {
            column(name: "JE_HD_TEMPLATE_ID", type: "bigint(20)", remarks: "凭证模板头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_HD_TEMPLATE_PK")
            }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "JE_TEMPLATE_NAME", type: "varchar(255)", remarks: "凭证模板说明") {
                constraints(nullable: "false")
            }
            column(name: "DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "单据类别") { constraints(nullable: "false") }
            column(name: "DOCUMENT_TYPE", type: "varchar(100)", remarks: "单据类型") { constraints(nullable: "false") }
            column(name: "BUSINESS_TYPE", type: "varchar(100)", remarks: "业务类型") { constraints(nullable: "false") }
            column(name: "JE_HD_DESCRIPTION", type: "varchar(100)", remarks: "凭证头摘要") { constraints(nullable: "false") }
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志")
            column(name: "JE_HD_RULE_FLAG", type: "varchar(1)", remarks: "凭证头汇总标志", defaultValue: "N")
            column(name: "JE_HD_RULE", type: "varchar(1000)", remarks: "凭证头汇总规则")
            column(name: "JE_HD_RULE_USER_1_FLAG", type: "varchar(1)", remarks: "凭证头汇总规则_自定义1启用", defaultValue: "N")
            column(name: "JE_HD_RULE_USER_2_FLAG", type: "varchar(1)", remarks: "凭证头汇总规则_自定义2启用", defaultValue: "N")
            column(name: "JE_HD_RULE_USER_3_FLAG", type: "varchar(1)", remarks: "凭证头汇总规则_自定义3启用", defaultValue: "N")
            column(name: "JE_HD_RULE_USER_1", type: "varchar(100)", remarks: "凭证头汇总规则_自定义1")
            column(name: "JE_HD_RULE_USER_2", type: "varchar(100)", remarks: "凭证头汇总规则_自定义2")
            column(name: "JE_HD_RULE_USER_3", type: "varchar(100)", remarks: "凭证头汇总规则_自定义3")
            column(name: "JE_REVERSE_RULE", type: "varchar(100)", remarks: "凭证行反冲规则（SYSCODE:GLD.JE_REVERSE_RULE）(行/头/头+回退)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "GLD_JE_HD_TEMPLATE", indexName: "GLD_JE_HD_TEMPLATE_N1") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_TEMPLATE_NAME", type: "varchar(255)")
        }

    }
}




