package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
dbType = mhi.dbType()

databaseChangeLog(logicalFilePath: "hls/support/core/db/HLS_DB_SCRIPT_2017-9-20-init-table-migration") {
    changeSet(author: "weck", id: "20171023-weck-1") {
        createTable(tableName: "con_floating_rate_req",remarks: "合同调息申请头表") {
            column(name: "flt_req_id", type: "bigint(20)", remarks: "申请头ID", autoIncrement: "true", startWith: "10") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "status", type: "varchar(100)", remarks: "状态")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "flt_req_date", type: "DATETIME", remarks: "申请日期")
            column(name: "flt_req_user_id", type: "bigint(20)", remarks: "申请人ID")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式")
            column(name: "flt_req_number", type: "varchar(100)", remarks: "申请单号")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "con_floating_rate_req", indexName: "CON_FLOATING_RATE_REQ_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "con_floating_rate_req", indexName: "CON_FLOATING_RATE_REQ_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }
    }

    changeSet(author: "weck", id: "20171023-weck-2") {
        createTable(tableName: "con_floating_rate_req_ln",remarks: "合同调息申请行表") {
            column(name: "flt_req_ln_id", type: "bigint(20)", remarks: "申请行ID", autoIncrement: "true", startWith: "10") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "flt_req_id", type: "bigint(20)", remarks: "申请头ID") { constraints(nullable: "false") }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "base_rate_type", type: "varchar(100)", remarks: "基准利率类型")
            column(name: "old_base_rate", type: "double", remarks: "原基准利率")
            column(name: "new_base_rate", type: "double", remarks: "新基准利率")
            column(name: "floating_range_method", type: "varchar(100)", remarks: "合同调息范围（次期/次年/...）")
            column(name: "floating_calc_method", type: "varchar(100)", remarks: "合同调息计算规则（单位日调整额）缺省值UNIT_AMT_PER_DAY")
            column(name: "unit_adj_amount", type: "double", remarks: "单位调整金额")
            column(name: "base_rate_adj_range", type: "double", remarks: "基准利率调整幅度")
            column(name: "status", type: "varchar(100)", remarks: "计算状态（syscode：CON.FLOATING_REQ_LN_STATUS）")
            column(name: "interest_adj_amount", type: "double", remarks: "利息调整金额")
            column(name: "document_version_id", type: "bigint(20)", remarks: "单据历史ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "con_floating_rate_req_ln", columnNames: "flt_req_id,contract_id", constraintName: "CON_FLOATING_RATE_REQ_LN_U1")
    }

    changeSet(author: "weck", id: "20171023-weck-3") {
        createTable(tableName: "acr_receipt_hd",remarks: "收据头表") {
            column(name: "receipt_hd_id", type: "bigint(20)", remarks: "收据头ID", autoIncrement: "true", startWith: "10") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "document_number", type: "varchar(100)", remarks: "收据编号")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "total_amount", type: "double", remarks: "金额")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "receipt_date", type: "datetime", remarks: "发票日期")
            column(name: "receipt_status", type: "varchar(100)", remarks: "发票状态")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "acr_receipt_hd", indexName: "ACR_RECEIPT_HD_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "document_number", type: "varchar(100)")
        }
        createIndex(tableName: "acr_receipt_hd", indexName: "ACR_RECEIPT_HD_N2") {
            column(name: "bp_id", type: "bigint(20)")
        }
    }

    changeSet(author: "weck", id: "20171023-weck-4") {
        createTable(tableName: "acr_receipt_ln",remarks: "收据行表") {
            column(name: "receipt_ln_id", type: "bigint(20)", remarks: "收据行ID", autoIncrement: "true", startWith: "10") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "receipt_hd_id", type: "bigint(20)", remarks: "receipt_hd_id") { constraints(nullable: "false") }
            column(name: "source_type", type: "varchar(100)", remarks: "来源类型(CASHFLOW_PRINCIPAL/CSH_RECEIPT)")
            column(name: "source_id", type: "bigint(20)", remarks: "来源ID（现金流ID/收款ID）")
            column(name: "amount", type: "varchar(100)", remarks: "金额")
            column(name: "description", type: "varchar(2000)", remarks: "行备注/行摘要")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "acr_receipt_ln", indexName: "ACR_RECEIPT_LN_N1") {
            column(name: "receipt_hd_id", type: "bigint(20)")
        }
        createIndex(tableName: "acr_receipt_ln", indexName: "ACR_RECEIPT_LN_N2") {
            column(name: "source_type", type: "varchar(100)")
            column(name: "source_id", type: "bigint(20)")
        }
    }
}