package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
dbType = mhi.dbType()
databaseChangeLog(logicalFilePath: "hls/support/core/db/HLS_DB_SCRIPT_2017-9-20-init-table-migration") {
    changeSet(author: "xuju", id: "20171027-xuju-1") {
        createTable(tableName: "HLS_CREDIT_LINE_GUARANTOR") {
            column(name: "credit_line_guarantor_id", type: "bigint(20)", autoIncrement: "true", startWith: "1", remarks: "额度ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "credit_line_id", type: "bigint(20)", remarks: "额度编号") {
                constraints(nullable: "false")
            }
            column(name: "guarantor_bp_id", type: "bigint(20)", remarks: "担保人商业伙伴ID")
            column(name: "guarantee_type", type: "varchar(100)", remarks: "担保人角色")
            column(name: "guarantee_method", type: "varchar(100)", remarks: "担保类型（syscode：HLS.MORTGAGE_TYPE）")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "HLS_CREDIT_LINE_GUARANTOR", indexName: "HLS_CREDIT_LINE_GUARANTOR_N1") {
            column(name: "credit_line_id", type: "bigint(20)")
        }
    }
    changeSet(author: "huangtianyang", id: "20171027-huangtianyang-1") {
        createTable(tableName: "HLS_CREDIT_CONTRACT"){
            column(name: "credit_contract_id", type: "bigint(20)", autoIncrement: "true", startWith: "1",remarks: "融资授信合同ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name:"company_id",type:"bigint(20)",remarks: "公司ID"){
                constraints(nullable: "true")
            }
            column(name:"document_type",type:"varchar(100)",remarks: "单据类型")
            column(name:"document_category",type:"varchar(100)",remarks: "单据类别")
            column(name:"business_type",type:"varchar(100)",remarks: "业务类型")
            column(name:"credit_contract_number",type:"varchar(255)",remarks: "融资授信合同编号")
            column(name:"credit_contract_name",type:"varchar(500)",remarks: "融资授信合同名称")
            column(name:"credit_contract_status",type:"varchar(100)",remarks: "融资授信合同状态")
            column(name:"credit_line_id",type:"bigint(20)",remarks: "额度ID")
            column(name:"currency",type:"varchar(100)",remarks: "币种")
            column(name:"credit_bp_id",type:"bigint(20)",remarks: "授信机构ID")
            column(name:"description",type:"varchar(500)",remarks: "说明")
            column(name:"OBJECT_VERSION_NUMBER",type:"bigint(20)",defaultValue:"1")
            column(name:"REQUEST_ID",type:"bigint(20)")
            column(name:"PROGRAM_ID",type:"bigint(20)")
            column(name:"CREATION_DATE",type:"datetime")
            column(name:"LAST_UPDATED_BY",type:"bigint(20)")
            column(name:"LAST_UPDATE_DATE",type:"datetime")
            column(name:"LAST_UPDATE_LOGIN",type:"bigint(20)")
        }
        createIndex(tableName: "HLS_CREDIT_CONTRACT", indexName: "HLS_CREDIT_CONTRACT_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "credit_contract_number", type: "varchar(255)")
        }
        createIndex(tableName: "HLS_CREDIT_CONTRACT", indexName: "HLS_CREDIT_CONTRACT_N3") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "credit_contract_status", type: "varchar(100)")
        }
        createIndex(tableName: "HLS_CREDIT_CONTRACT", indexName: "HLS_CREDIT_CONTRACT_N4") {
            column(name: "credit_line_id", type: "bigint(20)")
        }
        createIndex(tableName: "HLS_CREDIT_CONTRACT", indexName: "HLS_CREDIT_CONTRACT_N5") {
            column(name: "credit_bp_id", type: "bigint(20)")
        }
    }
    changeSet(author: "huangtianyang", id: "20171027-huangtianyang-2") {
        createTable(tableName: "HLS_CREDIT_LINE_ATTACHMENT"){
            column(name: "credit_line_attachment_id", type: "bigint(20)", autoIncrement: "true", startWith: "1",remarks: "额度附件ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name:"credit_line_id",type:"bigint(20)",remarks: "额度ID"){
                constraints(nullable: "false")
            }
            column(name:"source_type",type:"varchar(100)",remarks: "附件类别")
            column(name:"source_id",type:"bigint(20)",remarks: "如来源DOC_FLIE,则记录原始模板id")
            column(name:"bp_category",type:"varchar(100)",remarks: "文档签约对象类别")
            column(name:"bp_id",type:"bigint(20)",remarks: "文档签约对象ID")
            column(name:"document_name",type:"varchar(2000)",remarks: "文档名称")
            column(name:"description",type:"varchar(2000)",remarks: "说明备注")
            column(name:"OBJECT_VERSION_NUMBER",type:"bigint(20)",defaultValue:"1")
            column(name:"REQUEST_ID",type:"bigint(20)")
            column(name:"PROGRAM_ID",type:"bigint(20)")
            column(name:"CREATION_DATE",type:"datetime")
            column(name:"LAST_UPDATED_BY",type:"bigint(20)")
            column(name:"LAST_UPDATE_DATE",type:"datetime")
            column(name:"LAST_UPDATE_LOGIN",type:"bigint(20)")
        }
        createIndex(tableName: "HLS_CREDIT_LINE_ATTACHMENT", indexName: "HLS_CREDIT_LINE_ATTACHMENT_N1") {
            column(name: "credit_line_id", type: "bigint(20)")
            column(name: "source_type", type: "varchar(100)")
            column(name: "source_id", type: "bigint(20)")
        }
        createIndex(tableName: "HLS_CREDIT_LINE_ATTACHMENT", indexName: "HLS_CREDIT_LINE_ATTACHMENT_N2") {
            column(name: "bp_category", type: "varchar(100)")
            column(name: "bp_id", type: "bigint(20)")
        }

        addColumn(tableName: "csh_bank_account") {
            column(name: "FINANCING_LOAN_FLAG", type: "varchar(1)")
        }

        addColumn(tableName: "csh_bank") {
            column(name: "BANK_SHORT_NAME", type: "varchar(100)", remarks: "银行简称")
        }

        addColumn(tableName: "csh_bank") {
            column(name: "ORG_TYPE", type: "varchar(100)", remarks: "机构分类")
        }

        addColumn(tableName: "csh_bank") {
            column(name: "START_ACTIVE_DATE", type: "datetime", remarks: "有效日期从")
        }

        addColumn(tableName: "csh_bank") {
            column(name: "END_ACTIVE_DATE", type: "datetime", remarks: "有效日期到")
        }

        addColumn(tableName: "csh_bank") {
            column(name: "BP_ID", type: "bigint(20)", remarks: "商业伙伴ID")
        }

        addColumn(tableName: "csh_bank") {
            column(name: "BANK_TYPE", type: "varchar(100)", remarks: "银行类型")
        }
    }

    changeSet(author: "chenhao", id: "20171027-chenhao-2") {
        createTable(tableName: "act_process_cond_expression"){
            column(name: "EXPRESSION_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1",remarks: "表达式ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name:"PROCESS_ID",type:"bigint(20)",remarks: "流程ID"){
                constraints(nullable: "false")
            }
            column(name:"SOURCE_TYPE",type:"varchar(100)",remarks: "来源类型"){
                constraints(nullable: "false")
            }
            column(name:"SOURCE_ID",type:"varchar(100)",remarks: "来源ID"){
                constraints(nullable: "false")
            }
            column(name:"SEQ_NUM",type:"bigint(20)",remarks: "顺序号")
            column(name:"LEFT_BRACKET",type:"varchar(10)",remarks: "左括号")
            column(name:"VARIABLE_NAME",type:"varchar(100)",remarks: "变量名")
            column(name:"COMPARISON_OPERATOR",type:"varchar(30)",remarks: "预算比较符号")
            column(name:"CONSTANT_VALUE",type:"varchar(100)",remarks: "常量值")
            column(name:"RIGHT_BRACKET",type:"varchar(10)",remarks: "右括号")
            column(name:"CONNECTOR_OPERATOR",type:"varchar(10)",remarks: "连接符")
            column(name:"OBJECT_VERSION_NUMBER",type:"bigint(20)",defaultValue:"1")
            column(name:"REQUEST_ID",type:"bigint(20)")
            column(name:"PROGRAM_ID",type:"bigint(20)")
            column(name:"CREATION_DATE",type:"datetime")
            column(name:"LAST_UPDATED_BY",type:"bigint(20)")
            column(name:"LAST_UPDATE_DATE",type:"datetime")
            column(name:"LAST_UPDATE_LOGIN",type:"bigint(20)")
        }

        createTable(tableName: "act_process_variable"){
            column(name: "variable_id", type: "bigint(20)", autoIncrement: "true", startWith: "1",remarks: "变量ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name:"key",type:"varchar(100)",remarks: "流程ID"){
                constraints(nullable: "false")
            }
            column(name:"variable_name",type:"varchar(100)",remarks: "变量名"){
                constraints(nullable: "false")
            }
            column(name:"description",type:"varchar(500)",remarks: "说明")
            column(name:"OBJECT_VERSION_NUMBER",type:"bigint(20)",defaultValue:"1")
            column(name:"REQUEST_ID",type:"bigint(20)",defaultValue : "-1")
            column(name:"PROGRAM_ID",type:"bigint(20)",defaultValue : "-1")
            column(name:"CREATION_DATE",type:"datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name:"LAST_UPDATED_BY",type:"bigint(20)", defaultValue : "-1")
            column(name:"LAST_UPDATE_DATE",type:"datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name:"LAST_UPDATE_LOGIN",type:"bigint(20)", defaultValue : "-1")
        }

        addUniqueConstraint(tableName: "act_process_variable", columnNames: "process_id,variable_name", constraintName: "U1")

        createTable(tableName: "act_process_method"){
            column(name: "method_id", type: "bigint(20)", autoIncrement: "true", startWith: "1",remarks: "程序ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name:"key",type:"varchar(100)",remarks: "流程ID"){
                constraints(nullable: "false")
            }
            column(name:"method_name",type:"varchar(100)",remarks: "程序名"){
                constraints(nullable: "false")
            }
            column(name:"description",type:"varchar(500)",remarks: "说明")
            column(name:"OBJECT_VERSION_NUMBER",type:"bigint(20)",defaultValue:"1")
            column(name:"REQUEST_ID",type:"bigint(20)",defaultValue : "-1")
            column(name:"PROGRAM_ID",type:"bigint(20)",defaultValue : "-1")
            column(name:"CREATION_DATE",type:"datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name:"LAST_UPDATED_BY",type:"bigint(20)", defaultValue : "-1")
            column(name:"LAST_UPDATE_DATE",type:"datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name:"LAST_UPDATE_LOGIN",type:"bigint(20)", defaultValue : "-1")
        }

        addUniqueConstraint(tableName: "act_process_method", columnNames: "process_id,method_name", constraintName: "U1")

    }

    }