package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
dbType = mhi.dbType()
databaseChangeLog(logicalFilePath: "2018-01-04-init-table-migration.groovy") {

    changeSet(author: "neil", id: "-CSH_PAYMENT_REQ_DT") {
        createTable(tableName: "CSH_PAYMENT_REQ_DT", remarks: "付款申请行抵扣表") {
            column(name: "payment_req_dt_id", type: "bigint(20)", remarks: "付款申请抵扣ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_PAYMENT_REQ_DT_PK")
            }
            column(name: "payment_req_ln_id", type: "bigint(20)", remarks: "付款申请行ID") {
                constraints(nullable: "false")
            }
            column(name: "source_doc_category", type: "varchar(100)", remarks: "付款来源单据类别")
            column(name: "source_doc_id", type: "bigint(20)", remarks: "付款来源单据ID")
            column(name: "source_doc_line_id", type: "bigint(20)", remarks: "付款来源单据行ID")
            column(name: "deduct_amount", type: "double(20,2)", remarks: "抵扣金额")
            column(name: "deduct_principal", type: "double(20,2)", remarks: "抵扣本金")
            column(name: "deduct_interest", type: "double(20,2)", remarks: "抵扣利息")
            column(name: "description", type: "varchar(2000)", remarks: "抵扣行说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CSH_PAYMENT_REQ_DT", indexName: "CSH_PAYMENT_REQ_DT_N1") {
            column(name: "payment_req_ln_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_DT", indexName: "CSH_PAYMENT_REQ_DT_N2") {
            column(name: "source_doc_category", type: "varchar(100)")
            column(name: "source_doc_id", type: "bigint(20)")
            column(name: "source_doc_line_id", type: "bigint(20)")
        }
    }

    changeSet(author: "neil", id: "-SYS_USER_VISIT_HISTORY") {
        createTable(tableName: "SYS_USER_VISIT_HISTORY", remarks: "用户最近访问") {
            column(name: "history_id", type: "bigint(20)", remarks: "访问历史id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_VISIT_HISTORY_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "访问用户id") { constraints(nullable: "false") }
            column(name: "user_allocation_id", type: "bigint(20)", remarks: "访问用户分配id")
            column(name: "visit_type", type: "varchar(30)", remarks: "访问类型(syscode:SYS.USER_VISIT_HISTORY_TYPE)")
            column(name: "visit_url", type: "varchar(1000)", remarks: "访问地址")
            column(name: "visit_title", type: "varchar(500)", remarks: "标题")
            column(name: "visit_datetime", type: "datetime", remarks: "访问时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "SYS_USER_VISIT_HISTORY", indexName: "SYS_USER_VISIT_HISTORY_N1") {
            column(name: "user_id", type: "bigint(20)")
            column(name: "user_allocation_id", type: "bigint(20)")
            column(name: "visit_type", type: "varchar(30)")
        }
    }
}

