package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
dbType = mhi.dbType()
databaseChangeLog(logicalFilePath: "2018-01-10-init-table-migration.groovy") {
    changeSet(author: "xuju", id: "20180110-xuju-1") {
        createTable(tableName: "FCT_CONTRACT_TERMINATION") {
            column(name: "contract_termination_id", type: "bigint(20)", autoIncrement: "true", startWith: "1", remarks: "合同结束ID") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") {
                constraints(nullable: "false")
            }
            column(name: "status", type: "varchar(100)", remarks: "合同结束状态(syscode：FCT.CONTRACT_PROCESS_STATUS)")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "termination_date", type: "datetime", remarks: "结束日期")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "FCT_CONTRACT_TERMINATION", indexName: "FCT_CONTRACT_TERMINATION_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "FCT_CONTRACT_TERMINATION", indexName: "FCT_CONTRACT_TERMINATION_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }
    }
    changeSet(author: "wangchao", id: "-FND_COUNTRY"){
        createTable(tableName: "FND_COUNTRY" ,remarks:"国家地区"){
            column(name:"country",type:"varchar(100)",remarks:"国家"){constraints(nullable: "false",primaryKey: "true",primaryKeyName:"FND_COUNTRY_PK")}
            column(name:"country_name",type:"varchar(500)",remarks:"中文名")
            column(name:"two_character_code",type:"varchar(2)",remarks:"两字符简码")
            column(name:"three_character_code",type:"varchar(3)",remarks:"三字符简码")
            column(name:"digital_code",type:"varchar(3)",remarks:"数字代码")
            column(name:"description",type:"varchar(500)",remarks:"中文和英文全称")
            column(name:"continent",type:"varchar(50)",remarks:"所在洲际(syscode:FND.CONTINENT)")
            column(name:"continent_area",type:"varchar(50)",remarks:"洲际所属大区(syscode:FND.CONTINENT_AREA)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }

        addUniqueConstraint(tableName:"FND_COUNTRY",columnNames:"two_character_code", constraintName:"FND_COUNTRY_U1")
        addUniqueConstraint(tableName:"FND_COUNTRY",columnNames:"three_character_code", constraintName:"FND_COUNTRY_U2")
        addUniqueConstraint(tableName:"FND_COUNTRY",columnNames:"digital_code", constraintName:"FND_COUNTRY_U3")

    }
}