package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
databaseChangeLog(logicalFilePath: "2018-01-15-init-table-migration.groovy") {
    changeSet(id: '1516006251870-1', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'FND_COMPANY_B_S')
        }
        createTable(tableName: 'fnd_company_b') {
            column(name: 'company_id', type: 'BIGINT', autoIncrement: true) {
                constraints(primaryKey: true)
            }
            column(name: 'company_code', type: 'VARCHAR(30)', remarks: '公司编码') {
                constraints(nullable: false)
            }
            column(name: 'company_type', type: 'VARCHAR(30)', remarks: '公司类型')
            column(name: 'address', type: 'VARCHAR(2000)', remarks: '地址')
            column(name: 'company_level_id', type: 'BIGINT')
            column(name: 'parent_company_id', type: 'BIGINT')
            column(name: 'chief_position_id', type: 'BIGINT')
            column(name: 'start_date_active', type: 'datetime(6)')
            column(name: 'end_date_active', type: 'datetime(6)')
            column(name: 'company_short_name', type: 'VARCHAR(2000)', remarks: '公司简称')
            column(name: 'company_full_name', type: 'VARCHAR(2000)', remarks: '公司全称')
            column(name: 'zipcode', type: 'VARCHAR(100)')
            column(name: 'fax', type: 'VARCHAR(100)')
            column(name: 'phone', type: 'VARCHAR(100)')
            column(name: 'contact_person', type: 'VARCHAR(100)')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-2', author: 'yang') {
        createTable(tableName: 'fnd_uom_code_copy') {
            column(name: 'uom_code', type: 'VARCHAR(100)', remarks: '计量单位') {
                constraints(nullable: false)
            }
            column(name: 'uom_type', type: 'VARCHAR(100)', remarks: '计量单位类型') {
                constraints(nullable: false)
            }
            column(name: 'description', type: 'VARCHAR(200)', remarks: '描述')
            column(name: 'enabled_flag', type: 'VARCHAR(1)', remarks: '启用标志')
            column(name: 'system_flag', type: 'VARCHAR(1)', remarks: '系统标志')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-3', author: 'yang') {
        createTable(tableName: 'fnd_work_calendar') {
            column(name: 'calendar_day', type: 'date', remarks: '日期') {
                constraints(nullable: false)
            }
            column(name: 'off_day_flag', type: 'VARCHAR(1)', defaultValue: 'N', remarks: '是否休息日')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-4', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'HLS_BP_MASTER_COPY_S')
        }
        createTable(tableName: 'hls_bp_master_copy') {
            column(name: 'bp_id', type: 'BIGINT', autoIncrement: true, remarks: '商业伙伴ID') {
                constraints(primaryKey: true)
            }
            column(name: 'bp_code', type: 'VARCHAR(200)', remarks: '商业伙伴代码') {
                constraints(nullable: false)
            }
            column(name: 'bp_name', type: 'VARCHAR(200)', remarks: '商业伙伴名称') {
                constraints(nullable: false)
            }
            column(name: 'bp_class', type: 'VARCHAR(200)', remarks: '分类（org/法人、np/自然人）') {
                constraints(nullable: false)
            }
            column(name: 'extra_nam', type: 'VARCHAR(200)', remarks: '附加名称')
            column(name: 'external_bp_code', type: 'VARCHAR(200)', remarks: '商业伙伴外部编码')
            column(name: 'enabled_flag', type: 'VARCHAR(1)', remarks: '是否启用') {
                constraints(nullable: false)
            }
            column(name: 'enterprise_scale', type: 'VARCHAR(200)', remarks: '企业规模')
            column(name: 'INDUSTRY', type: 'VARCHAR(200)')
            column(name: 'legal_form', type: 'VARCHAR(200)', remarks: '企业性质')
            column(name: 'Legal_representative', type: 'VARCHAR(200)', remarks: '法人代表')
            column(name: 'Actual_controller', type: 'VARCHAR(200)', remarks: '实际控制人')
            column(name: 'registered_place', type: 'VARCHAR(200)', remarks: '注册地点')
            column(name: 'registered_date', type: 'datetime(6)', remarks: '注册时间')
            column(name: 'registered_capital', type: 'VARCHAR(200)', remarks: '注册资本')
            column(name: 'paid_in_capital', type: 'VARCHAR(200)', remarks: '实收资本')
            column(name: 'Enterprise_unified_credit_code', type: 'VARCHAR(200)', remarks: '统一社会信用代码')
            column(name: 'founded_date', type: 'datetime(6)', remarks: '成立时间')
            column(name: 'business_license_num', type: 'VARCHAR(200)', remarks: '工商营业执照号')
            column(name: 'organization_code', type: 'VARCHAR(200)', remarks: '组织机构代码')
            column(name: 'tax_registry_num', type: 'VARCHAR(200)', remarks: '税务登记证号')
            column(name: 'loan_card_num', type: 'VARCHAR(200)', remarks: '贷款卡号')
            column(name: 'loan_card_password', type: 'VARCHAR(200)', remarks: '贷款卡密码')
            column(name: 'primary_business', type: 'VARCHAR(2000)', remarks: '主营业务')
            column(name: 'main_products', type: 'VARCHAR(2000)', remarks: '经营范围')
            column(name: 'company_Information', type: 'VARCHAR(2000)', remarks: '企业介绍')
            column(name: 'taxpayer_type', type: 'VARCHAR(200)', remarks: '纳税人类别')
            column(name: 'invoice_title', type: 'VARCHAR(200)', remarks: '发票抬头')
            column(name: 'invoice_bp_address_phone_num', type: 'VARCHAR(200)', remarks: '发票地址及电话')
            column(name: 'invoice_bp_bank_account', type: 'VARCHAR(200)', remarks: '发票开户行及账号')
            column(name: 'nationality', type: 'VARCHAR(200)', remarks: '国籍')
            column(name: 'date_of_birth', type: 'datetime(6)', remarks: '出生日期')
            column(name: 'native_place', type: 'VARCHAR(200)', remarks: '籍贯')
            column(name: 'id_type', type: 'VARCHAR(200)', remarks: '证件类型')
            column(name: 'id_card_no', type: 'VARCHAR(200)', remarks: '证件号')
            column(name: 'marital_status', type: 'VARCHAR(20)', remarks: '婚姻状况')
            column(name: 'academic_background', type: 'VARCHAR(200)', remarks: '学历')
            column(name: 'age', type: 'BIGINT', remarks: '年龄')
            column(name: 'gender', type: 'VARCHAR(20)', remarks: '性别')
            column(name: 'annual_income', type: 'DECIMAL(20, 2)', remarks: '年收入(万元)')
            column(name: 'working_company', type: 'VARCHAR(200)', remarks: '工作单位')
            column(name: 'company_industry', type: 'VARCHAR(200)', remarks: '公司行业')
            column(name: 'business_job', type: 'VARCHAR(200)', remarks: '职务')
            column(name: 'working_years', type: 'BIGINT', remarks: '从业年限')
            column(name: 'phone', type: 'VARCHAR(20)', remarks: '电话')
            column(name: 'cell_phone', type: 'VARCHAR(20)', remarks: '手机')
            column(name: 'email', type: 'VARCHAR(200)', remarks: '邮箱')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
            column(name: 'primaryiness', type: 'VARCHAR(255)')
            column(name: 'authority_Rule_String', type: 'VARCHAR(255)', remarks: '权限字段')
        }
    }

    changeSet(id: '1516006251870-5', author: 'yang') {
        createTable(tableName: 'hls_business_type_copy') {
            column(name: 'document_category', type: 'VARCHAR(50)', remarks: '单据类别') {
                constraints(nullable: false)
            }
            column(name: 'business_type', type: 'VARCHAR(50)', remarks: '业务模式') {
                constraints(nullable: false)
            }
            column(name: 'description', type: 'VARCHAR(2000)', remarks: '描述') {
                constraints(nullable: false)
            }
            column(name: 'enabled_flag', type: 'VARCHAR(1)', remarks: '是否启用') {
                constraints(nullable: false)
            }
            column(name: 'system_flag', type: 'VARCHAR(1)', remarks: '系统标志') {
                constraints(nullable: false)
            }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-6', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'HLS_CREDIT_LINE_APPROVAL_S')
        }
        createTable(tableName: 'hls_credit_line_approval') {
            column(name: 'approval_id', type: 'BIGINT', autoIncrement: true, remarks: '审批ID') {
                constraints(primaryKey: true)
            }
            column(name: 'credit_line_id', type: 'BIGINT', remarks: '额度ID') {
                constraints(nullable: false)
            }
            column(name: 'status', type: 'VARCHAR(30)', remarks: '状态')
            column(name: 'description', type: 'VARCHAR(1000)', remarks: '说明备注')
            column(name: 'process_instance_id', type: 'BIGINT', remarks: '工作流实例ID')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-7', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'HLS_CREDIT_LINE_TRX_S')
        }
        createTable(tableName: 'hls_credit_line_trx') {
            column(name: 'trx_id', type: 'BIGINT', autoIncrement: true, remarks: '事务id') {
                constraints(primaryKey: true)
            }
            column(name: 'company_id', type: 'BIGINT', remarks: '公司id')
            column(name: 'credit_line_id', type: 'BIGINT', remarks: '额度id')
            column(name: 'trx_date', type: 'datetime(6)', remarks: '事务日期')
            column(name: 'trx_code', type: 'VARCHAR(100)', remarks: '事务代码')
            column(name: 'trx_amount', type: 'DOUBLE(20, 2)', remarks: '额度金额')
            column(name: 'source_document_category', type: 'VARCHAR(100)', remarks: '来源单据类别')
            column(name: 'source_document_id', type: 'BIGINT', remarks: '来源单据id')
            column(name: 'description', type: 'VARCHAR(1000)', remarks: '说明')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-8', author: 'yang') {
        createTable(tableName: 'hls_credit_line_trx_master') {
            column(name: 'trx_code', type: 'VARCHAR(100)', remarks: '事务代码') {
                constraints(nullable: false)
            }
            column(name: 'trx_name', type: 'VARCHAR(1000)', remarks: '事务说明')
            column(name: 'trx_type', type: 'VARCHAR(100)', remarks: '事务类型')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-9', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'SYS_DOCUMENT_LIST_S')
        }
        createTable(tableName: 'sys_document_list') {
            column(name: 'DOCUMENT_ID', type: 'BIGINT', autoIncrement: true, remarks: '单据ID') {
                constraints(primaryKey: true)
            }
            column(name: 'DOCUMENT_TYPE', type: 'VARCHAR(200)', remarks: '文件类型')
            column(name: 'DOCUMENT_CATEGORY', type: 'VARCHAR(200)', remarks: '文件类型')
            column(name: 'DOCUMENT_LIST_NAME', type: 'VARCHAR(2000)', remarks: '文件名称')
            column(name: 'ENABLED_FLAG', type: 'VARCHAR(1)', remarks: '文件名称')
            column(name: 'SYSTEM_FLAG', type: 'VARCHAR(1)', remarks: '文件名称')
            column(name: 'NECESSARY_UPLOAD_FLAG', type: 'VARCHAR(1)', remarks: '必须上传')
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-10', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'SYS_LAYOUT_S')
        }
        createTable(tableName: 'sys_layout') {
            column(name: 'layout_id', type: 'BIGINT', autoIncrement: true) {
                constraints(primaryKey: true)
            }
            column(name: 'layout_code', type: 'VARCHAR(150)', remarks: '布局编码')
            column(name: 'layout_name', type: 'VARCHAR(150)', remarks: '布局名称')
            column(name: 'layout_html', type: 'LONGTEXT', remarks: '布局页面')
            column(name: 'enabled_flag', type: 'VARCHAR(1)', remarks: '是否启用') {
                constraints(nullable: false)
            }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-11', author: 'yang') {
        createTable(tableName: 'sys_layout_role_module') {
            column(name: 'role_id', type: 'BIGINT', remarks: '页面布局code') {
                constraints(nullable: false)
            }
            column(name: 'module_code', type: 'VARCHAR(100)', remarks: '页面布局name') {
                constraints(nullable: false)
            }
            column(name: 'layout_code', type: 'VARCHAR(100)', remarks: '页面布局html') {
                constraints(nullable: false)
            }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-12', author: 'yang') {
        createTable(tableName: 'sys_layout_user_role_module') {
            column(name: 'user_id', type: 'BIGINT', remarks: '用户id') {
                constraints(nullable: false)
            }
            column(name: 'role_id', type: 'BIGINT', remarks: '角色id') {
                constraints(nullable: false)
            }
            column(name: 'module_code', type: 'VARCHAR(100)', remarks: '模块code') {
                constraints(nullable: false)
            }
            column(name: 'layout_code', type: 'VARCHAR(100)', remarks: '页面布局code') {
                constraints(nullable: false)
            }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-13', author: 'yang') {
        if (mhi.isDbType('oracle')) {
            createSequence(sequenceName: 'SYS_PROCESS_INSTANCE_S')
        }
        createTable(tableName: 'sys_process_instance') {
            column(name: 'process_instance_id', type: 'BIGINT', autoIncrement: true) {
                constraints(primaryKey: true)
            }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-14', author: 'yang') {
        createTable(tableName: 'sys_role_module_exclude_func') {
            column(name: 'role_id', type: 'BIGINT', remarks: '角色ID') {
                constraints(nullable: false)
            }
            column(name: 'module_code', type: 'VARCHAR(100)', remarks: '模块代码') {
                constraints(nullable: false)
            }
            column(name: 'function_id', type: 'BIGINT', remarks: '功能ID') {
                constraints(nullable: false)
            }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue : "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue : "-1")
        }
    }

    changeSet(id: '1516006251870-15', author: 'yang') {
        addPrimaryKey(columnNames: 'uom_code', constraintName: 'fnd_uom_code_copy_pk', tableName: 'fnd_uom_code_copy')
    }

    changeSet(id: '1516006251870-16', author: 'yang') {
        addPrimaryKey(columnNames: 'calendar_day', constraintName: 'fnd_work_calendar_pk', tableName: 'fnd_work_calendar')
    }

    changeSet(id: '1516006251870-17', author: 'yang') {
        addPrimaryKey(columnNames: 'document_category, business_type', constraintName: 'hls_business_type_copy_pk', tableName: 'hls_business_type_copy')
    }

    changeSet(id: '1516006251870-18', author: 'yang') {
        addPrimaryKey(columnNames: 'trx_code', constraintName: 'hls_credit_line_trx_master_pk', tableName: 'hls_credit_line_trx_master')
    }

    changeSet(id: '1516006251870-19', author: 'yang') {
        addPrimaryKey(columnNames: 'role_id, module_code', constraintName: 'sys_layout_role_module_pk', tableName: 'sys_layout_role_module')
    }

    changeSet(id: '1516006251870-20', author: 'yang') {
        addPrimaryKey(columnNames: 'user_id, role_id, module_code', constraintName: 'sys_layout_user_role_module_pk', tableName: 'sys_layout_user_role_module')
    }

    changeSet(id: '1516006251870-21', author: 'yang') {
        addPrimaryKey(columnNames: 'role_id, module_code, function_id', constraintName: 'sys_role_module_exclude_func_pk', tableName: 'sys_role_module_exclude_func')
    }

    changeSet(id: '1516006251870-22', author: 'yang') {
        addUniqueConstraint(columnNames: 'company_code', constraintName: 'FND_COMPANY_B_U1', tableName: 'fnd_company_b')
    }

    changeSet(id: '1516006251870-23', author: 'yang') {
        addUniqueConstraint(columnNames: 'bp_code', constraintName: 'hls_bp_master_copy_U1', tableName: 'hls_bp_master_copy')
    }

    changeSet(id: '1516006251870-24', author: 'yang') {
        addUniqueConstraint(columnNames: 'layout_code', constraintName: 'sys_layout_U1', tableName: 'sys_layout')
    }

    changeSet(id: '1516006251870-25', author: 'yang') {
        createIndex(indexName: 'HLS_CREDIT_LINE_TRX_N1', tableName: 'hls_credit_line_trx') {
            column(name: 'company_id')
        }
    }

    changeSet(id: '1516006251870-26', author: 'yang') {
        createIndex(indexName: 'HLS_CREDIT_LINE_TRX_N2', tableName: 'hls_credit_line_trx') {
            column(name: 'credit_line_id')
        }
    }

    changeSet(id: '1516006251870-27', author: 'yang') {
        createIndex(indexName: 'HLS_CREDIT_LINE_TRX_N3', tableName: 'hls_credit_line_trx') {
            column(name: 'trx_date')
        }
    }

    changeSet(id: '1516006251870-28', author: 'yang') {
        createIndex(indexName: 'HLS_CREDIT_LINE_TRX_N4', tableName: 'hls_credit_line_trx') {
            column(name: 'trx_code')
        }
    }

    changeSet(id: '1516006251870-29', author: 'yang') {
        createIndex(indexName: 'HLS_CREDIT_LINE_TRX_N5', tableName: 'hls_credit_line_trx') {
            column(name: 'source_document_category')
            column(name: 'source_document_id')
        }
    }
}