package hls.core.db

import com.hand.hap.liquibase.MigrationHelper

def mhi = MigrationHelper.getInstance()
dbType = mhi.dbType()
databaseChangeLog(logicalFilePath: "hls/support/core/db/HLS_DB_SCRIPT_2017-9-20-init-table-migration") {

    changeSet(author: "neil", id: "20160926-activiti.create.engine-1") {
        sqlFile(path: MigrationHelper.getInstance().dataPath("hls/core/db/data/" + dbType + "/tables/activiti.create.engine.sql"), encoding: "UTF-8")
    }

    changeSet(author: "neil", id: "20160926-activiti.create.history-1") {
        sqlFile(path: MigrationHelper.getInstance().dataPath("hls/core/db/data/" + dbType + "/tables/activiti.create.history.sql"), encoding: "UTF-8")
    }

    changeSet(author: "neil", id: "20160926-activiti.create.identity-1") {
        sqlFile(path: MigrationHelper.getInstance().dataPath("hls/core/db/data/" + dbType + "/tables/activiti.create.identity.sql"), encoding: "UTF-8")
    }

    changeSet(author: "neil", id: "20160609-hailor-1") {
        sqlFile(path: MigrationHelper.getInstance().dataPath("hls/core/db/data/" + dbType + "/tables/quartz_2.2.3.sql"), encoding: "UTF-8")
    }
    changeSet(author: "neil", id: "20171009-neil-1") {
        createTable(tableName: "reportform") {
            column(name: "ID", type: "bigint(20)", autoIncrement: "true", startWith: "10") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "reportform_code", type: "varchar(255)", remarks: "报表编码") { constraints(nullable: "false") }
            column(name: "reportform_name", type: "varchar(255)", remarks: "报表名称")
            column(name: "reportform_file", type: "varchar(255)", remarks: "报表文件") { constraints(nullable: "false") }
            column(name: "reportform_description", type: "varchar(255)", remarks: "报表描述") {
                constraints(nullable: "false")
            }
            column(name: "reportform_attribute", type: "varchar(255)", remarks: "报表参数url")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }
    changeSet(author: "neil", id: "20171009-neil-2") {
        createTable(tableName: "reportform_attr") {
            column(name: "ID", type: "bigint(20)", autoIncrement: "true", startWith: "18") {
                constraints(nullable: "false", primaryKey: "true")
            }
            column(name: "lov", type: "varchar(50)", remarks: "lov") { constraints(nullable: "false") }
            column(name: "lov_description", type: "varchar(50)", remarks: "lov描述")
            column(name: "LOV_NAME", type: "varchar(50)", remarks: "lov名称")
            column(name: "LOV_PARAMETER", type: "varchar(50)", remarks: "字段描述")
            column(name: "REPORT_ID", type: "varchar(255)", remarks: "报表文件")
            column(name: "DISPLAY", type: "varchar(255)", remarks: "报表描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_MODULE") {
        createTable(tableName: "SYS_MODULE", remarks: "模块定义表") {
            column(name: "module_icon_color", type: "varchar(100)", remarks: "模块图标")
            column(name: "module_serial_number", type: "varchar(100)", remarks: "")
            column(name: "module_code", type: "varchar(100)", remarks: "模块代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MODULE_PK")
            }
            column(name: "module_description", type: "varchar(2000)", remarks: "模块描述")
            column(name: "module_name", type: "varchar(2000)", remarks: "模块名称"){ constraints(nullable: "false") }
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "homepage_resource_id", type: "bigint(20)", remarks: "模块首页页面id")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "MODULE_ICON", type: "varchar(100)", remarks: "")
            column(name: "background_color", type: "varchar(100)", remarks: "")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_FUNCTION_B") {
        createTable(tableName: "SYS_FUNCTION_B", remarks: "功能定义表") {
            column(name: "FUNCTION_ID", type: "bigint(20)", remarks: "主键ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_FUNCTION_B_PK")
            }
            column(name: "MODULE_CODE", type: "varchar(100)", remarks: "模块编码")
            column(name: "FUNCTION_ICON", type: "varchar(2000)", remarks: "功能图标")
            column(name: "FUNCTION_CODE", type: "varchar(100)", remarks: "功能编码")
            column(name: "FUNCTION_NAME", type: "varchar(2000)", remarks: "功能名称")
            column(name: "FUNCTION_DESCRIPTION", type: "varchar(2000)", remarks: "描述")
            column(name: "RESOURCE_ID", type: "bigint(20)", remarks: "功能入口")
            column(name: "TYPE", type: "varchar(100)", remarks: "功能类型")
            column(name: "PARENT_FUNCTION_ID", type: "bigint(20)", remarks: "父功能")
            column(name: "FUNCTION_TYPE", type: "varchar(100)", remarks: "功能类型（syscode：SYS.FUNCTION_TYPE)")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "是否启用")
            column(name: "FUNCTION_SEQUENCE", type: "bigint", remarks: "排序号")
            column(name: "width", type: "bigint(20)", remarks: "窗口宽度")
            column(name: "height", type: "bigint(20)", remarks: "窗口高度")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "homepage_resource_id", type: "bigint(20)", remarks: "")
            column(name: "MODULE_ICON", type: "varchar(100)", remarks: "")
            column(name: "MODULE_DESCRIPTION", type: "varchar(240)", remarks: "")
            column(name: "toolbar_flag", type: "varchar(1)", remarks: "")
        }

        addUniqueConstraint(tableName: "SYS_FUNCTION_B", columnNames: "FUNCTION_CODE", constraintName: "SYS_FUNCTION_B_U1")

        createIndex(tableName: "SYS_FUNCTION_B", indexName: "SYS_FUNCTION_B_N1") {
            column(name: "PARENT_FUNCTION_ID", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_USER") {
        if(mhi.isDbType('oracle') || mhi.isDbType('hana')){
            createSequence(sequenceName: 'HR_EMPLOYEE_S', startValue:"10001")
        }

        createTable(tableName: "SYS_USER"){
            column(name:"USER_ID",type:"bigint",autoIncrement: "true", startWith:"10001",remarks: "表ID，主键"){
                constraints(nullable: "false", primaryKey: "true",primaryKeyName: "SYS_USER_PK")
            }
            column(name:"USER_TYPE",type:"varchar(30)",remarks: "用户类型")
            column(name:"USER_NAME",type:"varchar(40)",remarks: "用户名"){ constraints(nullable: "false") }
            column(name:"PASSWORD_ENCRYPTED",type:"varchar(80)",remarks: "加密过的密码")
            column(name:"EMAIL",type:"varchar(150)",remarks: "邮箱地址")
            column(name:"PHONE",type:"varchar(40)",remarks: "电话号码")
            column(name:"START_ACTIVE_DATE",type:"datetime",remarks: "有效期从")
            column(name:"END_ACTIVE_DATE",type:"datetime",remarks: "有效期至")
            column(name:"STATUS",type:"varchar(30)",remarks: "状态")
            column(name:"OBJECT_VERSION_NUMBER",type:"BIGINT",defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "bigint", defaultValue : "-1")
            column(name: "CREATED_BY", type: "bigint", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint", defaultValue : "-1")
            column(name:"ATTRIBUTE_CATEGORY",type:"varchar(30)")
            column(name:"ATTRIBUTE1",type:"varchar(240)")
            column(name:"ATTRIBUTE2",type:"varchar(240)")
            column(name:"ATTRIBUTE3",type:"varchar(240)")
            column(name:"ATTRIBUTE4",type:"varchar(240)")
            column(name:"ATTRIBUTE5",type:"varchar(240)")
            column(name:"ATTRIBUTE6",type:"varchar(240)")
            column(name:"ATTRIBUTE7",type:"varchar(240)")
            column(name:"ATTRIBUTE8",type:"varchar(240)")
            column(name:"ATTRIBUTE9",type:"varchar(240)")
            column(name:"ATTRIBUTE10",type:"varchar(240)")
            column(name:"ATTRIBUTE11",type:"varchar(240)")
            column(name:"ATTRIBUTE12",type:"varchar(240)")
            column(name:"ATTRIBUTE13",type:"varchar(240)")
            column(name:"ATTRIBUTE14",type:"varchar(240)")
            column(name:"ATTRIBUTE15",type:"varchar(240)")
            column(name:"LAST_LOGIN_DATE",type: "datetime")
            column(name:"LAST_PASSWORD_UPDATE_DATE",type:"datetime")
            column(name:"frozen_flag",type:"varchar(2)")
            column(name:"frozen_date",type:"datetime")
            column(name:"password_lifespan_type",type:"varchar(100)")
            column(name:"password_lifespan_days",type:"bigint(20)")
            column(name:"password_lifespan_times",type:"bigint(20)")
            column(name:"DESCRIPTION",type:"varchar(255)")
            column(name:"EMPLOYEE_ID",type:"bigint(20)")
            column(name:"CUSTOMER_ID",type:"bigint(20)")
            column(name:"SUPPLIER_ID",type:"bigint(20)")
            column(name:"FIRST_LOGIN",type:"varchar(1)")

        }

        addUniqueConstraint(tableName: "SYS_USER", columnNames: "USER_NAME", constraintName: "SYS_USER_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_ROLE_MODULE") {
        createTable(tableName: "SYS_ROLE_MODULE", remarks: "角色模块分配表") {
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_MODULE_PK")
            }
            column(name: "module_code", type: "varchar(100)", remarks: "模块代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_MODULE_PK")
            }
            column(name: "sequence", type: "bigint(20)", remarks: "显示顺序")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_ROLE_B") {
        createTable(tableName: "SYS_ROLE_B", remarks: "角色定义表") {
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_B_PK")
            }
            column(name: "role_code", type: "varchar(100)", remarks: "角色代码") { constraints(nullable: "false") }
            column(name: "role_name", type: "varchar(150)", remarks: "角色名称"){ constraints(nullable: "false") }
            column(name: "role_description", type: "varchar(240)", remarks: "角色描述")
            column(name: "START_ACTIVE_DATE", type: "datetime", remarks: "有效日期从")
            column(name: "END_ACTIVE_DATE", type: "datetime", remarks: "有效日期到")
            column(name: "ENABLE_FLAG", type: "varchar(1)", remarks: "启动标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_ROLE_B", columnNames: "role_code", constraintName: "SYS_ROLE_B_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_USER_ALLOCATION") {
        createTable(tableName: "SYS_USER_ALLOCATION", remarks: "用户分配表") {
            column(name: "allocation_id", type: "bigint(20)", remarks: "分配ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_ALLOCATION_PK")
            }
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID")
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID")
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID")
            column(name: "employee_assign_id", type: "bigint(20)", remarks: "员工分配ID")
            column(name: "Valid_date_from", type: "datetime", remarks: "有效日期从")
            column(name: "Valid_date_to", type: "datetime", remarks: "有效日期到")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "SYS_USER_ALLOCATION", columnNames: "role_id,user_id,company_id,employee_assign_id", constraintName: "SYS_USER_ALLOCATION_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_USER_AUTHORITY_RULE") {
        createTable(tableName: "SYS_USER_AUTHORITY_RULE", remarks: "用户单据授权表") {
            column(name: "authority_rule_id", type: "bigint(20)", remarks: "授权规则ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_AUTHORITY_RULE_PK")
            }
            column(name: "allocation_id", type: "bigint(20)", remarks: "用户分配ID")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "authority_rule_string", type: "varchar(2000)", remarks: "授权规则字符串")
            column(name: "company_rule", type: "varchar(1000)", remarks: "权限-公司段")
            column(name: "org_unit_rule", type: "varchar(1000)", remarks: "权限-部门段")
            column(name: "district_rule", type: "varchar(1000)", remarks: "权限-地区段")
            column(name: "doc_type_rule", type: "varchar(1000)", remarks: "权限-单据类型段")
            column(name: "biz_type_rule", type: "varchar(1000)", remarks: "权限-业务模式段")
            column(name: "division_rule", type: "varchar(1000)", remarks: "权限-产品线段")
            column(name: "employee_rule", type: "varchar(1000)", remarks: "权限-员工段")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "SYS_USER_AUTHORITY_RULE", indexName: "SYS_USER_AUTHORITY_RULE_N1") {
            column(name: "allocation_id", type: "bigint(20)")
            column(name: "document_category", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_COMPANY") {
        createTable(tableName: "FND_COMPANY", remarks: "公司表") {
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_COMPANY_PK")
            }
            column(name: "company_code", type: "varchar(100)", remarks: "公司代码") { constraints(nullable: "false") }
            column(name: "company_short_name", type: "varchar(2000)", remarks: "公司简称")
            column(name: "company_full_name", type: "varchar(2000)", remarks: "公司全称")
            column(name: "company_type", type: "varchar(100)", remarks: "公司类型(syscode：FND.COMPANY_TYPE)")
            column(name: "parent_company_id", type: "varchar(100)", remarks: "上级公司ID")
            column(name: "address", type: "varchar(255)", remarks: "地址")
            column(name: "business_scope", type: "varchar(200)", remarks: "")
            column(name: "zipcode", type: "varchar(255)", remarks: "邮编")
            column(name: "fax", type: "varchar(255)", remarks: "传真")
            column(name: "phone", type: "varchar(255)", remarks: "电话")
            column(name: "contact_person", type: "varchar(255)", remarks: "联系人")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "Enterprise_unified_credit_code", type: "varchar(255)", remarks: "统一社会信用代码")
            column(name: "registered_capital", type: "varchar(255)", remarks: "注册资本")
            column(name: "Legal_representative", type: "varchar(255)", remarks: "法定代表人")
            column(name: "establishment_date", type: "datetime", remarks: "成立日期")
            column(name: "Operating_period_from", type: "datetime", remarks: "经营期限从")
            column(name: "Operating_period_to", type: "datetime", remarks: "经营期限到")
            column(name: "Basic_account_bank", type: "varchar(255)", remarks: "基本账户开户行")
            column(name: "Basic_account_number", type: "varchar(255)", remarks: "基本账户号")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_COMPANY", columnNames: "company_code", constraintName: "FND_COMPANY_U1")

        createIndex(tableName: "FND_COMPANY", indexName: "FND_COMPANY_N1") {
            column(name: "parent_company_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_ORG_UNIT") {
        createTable(tableName: "FND_ORG_UNIT", remarks: "部门表") {
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "unit_id", type: "bigint(20)", remarks: "部门ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_ORG_UNIT_PK")
            }
            column(name: "unit_code", type: "varchar(100)", remarks: "部门代码") { constraints(nullable: "false") }
            column(name: "unit_name", type: "varchar(2000)", remarks: "部门名称")
            column(name: "unit_type", type: "varchar(100)", remarks: "部门类型(syscode：FND.UNIT_TYPE)")
            column(name: "parent_unit_id", type: "bigint(20)", remarks: "上级部门ID")
            column(name: "chief_position_id", type: "bigint(20)", remarks: "主管岗位")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_ORG_UNIT", columnNames: "company_id,unit_code", constraintName: "FND_ORG_UNIT_U1")

        createIndex(tableName: "FND_ORG_UNIT", indexName: "FND_ORG_UNIT_N1") {
            column(name: "parent_unit_id", type: "bigint(20)")
        }
        createIndex(tableName: "FND_ORG_UNIT", indexName: "FND_ORG_UNIT_N2") {
            column(name: "chief_position_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_ORG_POSITION") {
        createTable(tableName: "FND_ORG_POSITION", remarks: "岗位表") {
            column(name: "unit_id", type: "bigint(20)", remarks: "部门ID") { constraints(nullable: "false") }
            column(name: "position_id", type: "bigint(20)", remarks: "岗位ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_ORG_POSITION_PK")
            }
            column(name: "position_code", type: "varchar(100)", remarks: "岗位代码") { constraints(nullable: "false") }
            column(name: "position_name", type: "varchar(2000)", remarks: "岗位名称")
            column(name: "position_type", type: "varchar(100)", remarks: "岗位类型(syscode：FND.POSITION_TYPE)")
            column(name: "parent_position_id", type: "bigint(20)", remarks: "上级岗位ID")
            column(name: "chief_position_flag", type: "varchar(1)", remarks: "", defaultValue: "Y")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_ORG_POSITION", columnNames: "unit_id,position_code", constraintName: "FND_ORG_POSITION_U1")

        createIndex(tableName: "FND_ORG_POSITION", indexName: "FND_ORG_POSITION_N1") {
            column(name: "parent_position_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_EMPLOYEE") {
        createTable(tableName: "FND_EMPLOYEE", remarks: "员工表") {
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "employee_id", type: "bigint(20)", remarks: "员工ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_EMPLOYEE_PK")
            }
            column(name: "employee_code", type: "varchar(100)", remarks: "员工代码") { constraints(nullable: "false") }
            column(name: "name", type: "varchar(2000)", remarks: "姓名")
            column(name: "email", type: "varchar(2000)", remarks: "电子邮件")
            column(name: "mobil", type: "varchar(2000)", remarks: "手机")
            column(name: "phone", type: "varchar(2000)", remarks: "电话")
            column(name: "id_type", type: "varchar(100)", remarks: "证件类型(syscode：FND.EMPLOYEE_ID_TYPE)")
            column(name: "id_card_no", type: "varchar(100)", remarks: "证件号")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_EMPLOYEE", columnNames: "company_id,employee_code", constraintName: "FND_EMPLOYEE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_EMPLOYEE_ASSIGNS") {
        createTable(tableName: "FND_EMPLOYEE_ASSIGNS", remarks: "员工分配表") {
            column(name: "employee_assign_id", type: "bigint(20)", remarks: "员工分配ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_EMPLOYEE_ASSIGNS_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID")
            column(name: "employee_id", type: "bigint(20)", remarks: "员工ID")
            column(name: "unit_id", type: "bigint(20)", remarks: "部门ID")
            column(name: "position_id", type: "bigint(20)", remarks: "岗位ID")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_EMPLOYEE_ASSIGNS", columnNames: "company_id,employee_id,unit_id,position_id", constraintName: "FND_EMPLOYEE_ASSIGNS_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOCUMENT_CATEGORY") {
        createTable(tableName: "HLS_DOCUMENT_CATEGORY", remarks: "单据类别") {
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_CATEGORY_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BUSINESS_TYPE") {
        createTable(tableName: "HLS_BUSINESS_TYPE", remarks: "业务模式") {
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BUSINESS_TYPE_PK")
            }
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BUSINESS_TYPE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOCUMENT_TYPE") {
        createTable(tableName: "HLS_DOCUMENT_TYPE", remarks: "单据类型") {
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_TYPE_PK")
            }
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_TYPE_PK")
            }
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_TYPE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "coding_rule_type", type: "varchar(100)", remarks: "编码方式（syscode：FND.CODING_RULE_TYPE)")
            column(name: "coding_rule_id", type: "bigint(20)", remarks: "编码规则ID")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOCUMENT_STATUS") {
        createTable(tableName: "HLS_DOCUMENT_STATUS", remarks: "单据状态") {
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_STATUS_PK")
            }
            column(name: "status_code", type: "varchar(100)", remarks: "状态代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_STATUS_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    /* changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-SYS_USER_AUTHORITY_RULE") {
         createTable(tableName: "SYS_USER_AUTHORITY_RULE", remarks: "单据授权规则") {
             column(name: "authority_rule_id", type: "bigint(20)", remarks: "授权规则ID", autoIncrement: "true", startWith: "10001") {
                 constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_AUTHORITY_RULE_PK")
             }
             column(name: "allocation_id", type: "bigint(20)", remarks: "用户分配ID") { constraints(nullable: "false") }
             column(name: "document_category", type: "varchar(100)", remarks: "单据类别") { constraints(nullable: "false") }
             column(name: "authority_rule_string", type: "varchar(2000)", remarks: "授权规则字符串")
             column(name: "company_rule", type: "varchar(1000)", remarks: "权限-公司段")
             column(name: "org_unit_rule", type: "varchar(1000)", remarks: "权限-部门段")
             column(name: "district_rule", type: "varchar(1000)", remarks: "权限-地区段")
             column(name: "doc_type_rule", type: "varchar(1000)", remarks: "权限-单据类型段")
             column(name: "biz_type_rule", type: "varchar(1000)", remarks: "权限-业务模式段")
             column(name: "division_rule", type: "varchar(1000)", remarks: "权限-产品线段")
             column(name: "employee_rule", type: "varchar(1000)", remarks: "权限-员工段")
             column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
             column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
             column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
             column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
             column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
             column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
             column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
             column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
             column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
         }


         createIndex(tableName: "SYS_USER_AUTHORITY_RULE", indexName: "SYS_USER_AUTHORITY_RULE_N1") {
             column(name: "allocation_id", type: "bigint(20)")
             column(name: "document_category", type: "varchar(100)")
         }


     }*/

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_CASHFLOW_TYPE") {
        createTable(tableName: "HLS_CASHFLOW_TYPE", remarks: "现金流类型") {
            column(name: "cf_type", type: "varchar(100)", remarks: "现金流类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CASHFLOW_TYPE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "cf_direction", type: "varchar(2000)", remarks: "现金流方向(syscode：HLS.CASHFLOW_DIRECTION)")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_CASHFLOW_ITEM") {
        createTable(tableName: "HLS_CASHFLOW_ITEM", remarks: "现金流项目") {
            column(name: "cf_item", type: "varchar(100)", remarks: "现金流项目") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CASHFLOW_ITEM_PK")
            }
            column(name: "cf_type", type: "varchar(100)", remarks: "现金流类型") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "cf_direction", type: "varchar(2000)", remarks: "现金流方向(syscode：HLS.CASHFLOW_DIRECTION)")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "billing_desc", type: "varchar(2000)")
            column(name: "calc_penalty", type: "varchar(1)")
            column(name: "fin_income_profile", type: "varchar(100)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_CASHFLOW_ITEM", columnNames: "cf_item,cf_type", constraintName: "HLS_CASHFLOW_ITEM_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_CASHFLOW_ITEM_COMPANY") {
        createTable(tableName: "HLS_CASHFLOW_ITEM_COMPANY", remarks: "公司现金流") {
            column(name: "cf_item", type: "varchar(100)", remarks: "现金流项目") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CASHFLOW_ITEM_COMPANY_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CASHFLOW_ITEM_COMPANY_PK")
            }
            column(name: "fin_income_profile", type: "varchar(100)", remarks: "收入确认方案(syscode：HLS.FIN_INCOME_PROFILE)")
            column(name: "billing_desc", type: "varchar(2000)", remarks: "开票说明")
            column(name: "calc_penalty", type: "varchar(100)", remarks: "罚息计算")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_PENALTY_PROFILE") {
        createTable(tableName: "HLS_PENALTY_PROFILE", remarks: "延迟履行金规则") {
            column(name: "penalty_profile", type: "varchar(100)", remarks: "规则方案ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_PENALTY_PROFILE_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_PENALTY_PROFILE", indexName: "HLS_PENALTY_PROFILE_N1") {
            column(name: "company_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_PENALTY_PROFILE_DTL") {
        createTable(tableName: "HLS_PENALTY_PROFILE_DTL", remarks: "延迟履行金规则明细") {
            column(name: "penalty_profile", type: "varchar(100)", remarks: "规则方案ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_PENALTY_PROFILE_DTL_PK")
            }
            column(name: "cf_item", type: "varchar(100)", remarks: "现金流项目") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_PENALTY_PROFILE_DTL_PK")
            }
            column(name: "penalty_rate", type: "double", remarks: "罚息利率")
            column(name: "grace_period", type: "bigint(20)", remarks: "豁免期天数")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-VAT_INVOICE_PROFILE") {
        createTable(tableName: "VAT_INVOICE_PROFILE", remarks: "开票规则") {
            column(name: "invoice_profile", type: "varchar(100)", remarks: "规则方案ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "VAT_INVOICE_PROFILE_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "VAT_INVOICE_PROFILE", indexName: "VAT_INVOICE_PROFILE_N1") {
            column(name: "company_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-VAT_INVOICE_PROFILE_DTL") {
        createTable(tableName: "VAT_INVOICE_PROFILE_DTL", remarks: "开票规则明细") {
            column(name: "invoice_profile", type: "varchar(100)", remarks: "规则方案ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "VAT_INVOICE_PROFILE_DTL_PK")
            }
            column(name: "cf_item", type: "varchar(100)", remarks: "现金流项目") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "VAT_INVOICE_PROFILE_DTL_PK")
            }
            column(name: "merge_rental_flag", type: "varchar(1)", remarks: "合并租金项")
            column(name: "taxable_service_name", type: "varchar(2000)", remarks: "应税劳务名称")
            column(name: "tax_type_code", type: "varchar(100)", remarks: "适用税率")
            column(name: "invoice_kind", type: "varchar(100)", remarks: "发票类型")
            column(name: "rental_flag", type: "varchar(1)", remarks: "是否租金标志", defaultValue: "N")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DIVISION") {
        createTable(tableName: "HLS_DIVISION", remarks: "产品线") {
            column(name: "division", type: "varchar(100)", remarks: "产品线代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DIVISION_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DIVISION_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_LEASE_CHANNEL") {
        createTable(tableName: "HLS_LEASE_CHANNEL", remarks: "商业模式") {
            column(name: "lease_channel", type: "varchar(100)", remarks: "商业模式代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_LEASE_CHANNEL_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_LEASE_CHANNEL_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_TAX_TYPE_CODE") {
        createTable(tableName: "FND_TAX_TYPE_CODE", remarks: "税种") {
            column(name: "tax_type_code", type: "varchar(100)", remarks: "税种") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_TAX_TYPE_CODE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "tax_type_rate", type: "double", remarks: "税率")
            column(name: "tax_category", type: "varchar(100)", remarks: "类型（syscode:FND.TAX_CATEGORY)")
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_TAX_TYPE_CODE_PK")
            }
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_UOM_TYPE") {
        createTable(tableName: "FND_UOM_TYPE", remarks: "计量单位类型") {
            column(name: "uom_type", type: "varchar(100)", remarks: "计量单位类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_UOM_TYPE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_UOM_CODE") {
        createTable(tableName: "FND_UOM_CODE", remarks: "计量单位") {
            column(name: "uom_code", type: "varchar(100)", remarks: "计量单位") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_UOM_CODE_PK")
            }
            column(name: "uom_type", type: "varchar(100)", remarks: "计量单位类型") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_UOM_CODE", columnNames: "uom_code,uom_type", constraintName: "FND_UOM_CODE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_CURRENCY") {
        createTable(tableName: "FND_CURRENCY", remarks: "币种") {
            column(name: "currency_code", type: "varchar(100)", remarks: "币种代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_CURRENCY_PK")
            }
            column(name: "currency_name", type: "varchar(2000)", remarks: "币种名称")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "finance_precision", type: "bigint(20)", remarks: "精度")
            column(name: "currency_symbol", type: "varchar(100)", remarks: "符号")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_PROVINCE") {
        createTable(tableName: "FND_PROVINCE", remarks: "省") {
            column(name: "province", type: "varchar(100)", remarks: "省代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_PROVINCE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_CITY") {
        createTable(tableName: "FND_CITY", remarks: "市") {
            column(name: "province", type: "varchar(100)", remarks: "省代码") { constraints(nullable: "false") }
            column(name: "city", type: "varchar(100)", remarks: "市代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_CITY_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "FND_CITY", indexName: "FND_CITY_N1") {
            column(name: "province", type: "varchar(100)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_DISTRICT") {
        createTable(tableName: "FND_DISTRICT", remarks: "区县") {
            column(name: "province", type: "varchar(100)", remarks: "省代码") { constraints(nullable: "false") }
            column(name: "city", type: "varchar(100)", remarks: "市代码") { constraints(nullable: "false") }
            column(name: "district", type: "varchar(100)", remarks: "区县代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_DISTRICT_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "FND_DISTRICT", indexName: "FND_DISTRICT_N1") {
            column(name: "province", type: "varchar(100)")
            column(name: "city", type: "varchar(100)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-VAT_INVOICE_ATTRIBUTE") {
        createTable(tableName: "VAT_INVOICE_ATTRIBUTE", remarks: "公司税务属性表") {
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "VAT_INVOICE_ATTRIBUTE_PK")
            }
            column(name: "special_invoice_limit", type: "double", remarks: "增值税专票限额")
            column(name: "normal_invoice_limit", type: "double", remarks: "增值税普票限额")
            column(name: "line_limit", type: "double", remarks: "最大发票行数")
            column(name: "invoice_title", type: "varchar(2000)", remarks: "开票公司名称")
            column(name: "tax_registry_num", type: "varchar(2000)", remarks: "纳税人识别号")
            column(name: "invoice_address", type: "varchar(2000)", remarks: "地址")
            column(name: "invoice_phone", type: "varchar(2000)", remarks: "电话")
            column(name: "invoice_bank", type: "varchar(2000)", remarks: "开户行")
            column(name: "invoice_bank_account", type: "varchar(2000)", remarks: "银行账号")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_BASE_RATE_SET") {
        createTable(tableName: "FND_BASE_RATE_SET", remarks: "基准利率") {
            column(name: "base_rate_set", type: "varchar(100)", remarks: "基准利率代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_BASE_RATE_SET_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "base_rate_type", type: "varchar(100)", remarks: "基准利率类型（syscode:FND.BASE_RATE_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "valid_from", type: "datetime", remarks: "有效期从")
            column(name: "valid_to", type: "datetime", remarks: "有效期到")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_BASE_RATE") {
        createTable(tableName: "FND_BASE_RATE", remarks: "基准利率明细") {
            column(name: "base_rate_id", type: "bigint(20)", remarks: "基准利率值ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_BASE_RATE_PK")
            }
            column(name: "base_rate_set", type: "varchar(100)", remarks: "基准利率代码") { constraints(nullable: "false") }
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "base_rate", type: "double", remarks: "基准利率值")
            column(name: "months_from", type: "bigint(20)", remarks: "月数从")
            column(name: "months_to", type: "bigint(20)", remarks: "月数到（含）")
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "FND_BASE_RATE", indexName: "FND_BASE_RATE_N1") {
            column(name: "base_rate_set", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_CODING_RULES") {
        createTable(tableName: "FND_CODING_RULES", remarks: "编码规则") {
            column(name: "coding_rule_id", type: "bigint(20)", remarks: "编码规则ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_CODING_RULES_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "coding_rule_code", type: "varchar(100)", remarks: "编码规则代码") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "reset_frequence", type: "varchar(100)", remarks: "重置频率（syscode：FND.CODING_RULE_RESET_FREQUENCY）")
            column(name: "document_category", type: "varchar(50)", remarks: "单据类别")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_CODING_RULES", columnNames: "company_id,coding_rule_code", constraintName: "FND_CODING_RULES_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_CODING_RULE_DETAILS") {
        createTable(tableName: "FND_CODING_RULE_DETAILS", remarks: "编码规则明细") {
            column(name: "coding_rule_line_id", type: "bigint(20)", remarks: "编码规则明细ID",autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_CODING_RULE_DETAILS_PK")
            }
            column(name: "coding_rule_id", type: "bigint(20)", remarks: "编码规则ID") { constraints(nullable: "false") }
            column(name: "sequence", type: "bigint(20)", remarks: ""){ constraints(nullable: "false") }
            column(name: "segment_type", type: "varchar(100)", remarks: "段值类型"){ constraints(nullable: "false") }
            column(name: "segment_value", type: "varchar(100)", remarks: "段值")
            column(name: "note", type: "varchar(100)", remarks: "说明")
            column(name: "date_format", type: "varchar(100)", remarks: "日期格式")
            column(name: "length", type: "bigint(20)", remarks: "长度")
            column(name: "incremental", type: "bigint(20)", remarks: "增量")
            column(name: "start_value", type: "bigint(20)", remarks: "起始值")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_CODING_RULE_DETAILS", columnNames: "coding_rule_id,sequence", constraintName: "FND_CODING_RULE_DETAILS_U1")
        addUniqueConstraint(tableName: "FND_CODING_RULE_DETAILS", columnNames: "coding_rule_id,segment_type", constraintName: "FND_CODING_RULE_DETAILS_U2")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_CODING_RULE_VALUES") {
        createTable(tableName: "FND_CODING_RULE_VALUES", remarks: "编码规则值表") {
            column(name: "coding_rule_id", type: "bigint(20)", remarks: "编码规则ID") { constraints(nullable: "false") }
            column(name: "year", type: "bigint(20)", remarks: "年")
            column(name: "month", type: "varchar(100)", remarks: "月")
            column(name: "current_value", type: "bigint(20)", remarks: "当前值")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_CODING_RULE_VALUES", columnNames: "coding_rule_id,year,month", constraintName: "FND_CODING_RULE_VALUES_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SCORE_TARGET") {
        createTable(tableName: "HLS_SCORE_TARGET", remarks: "评分指标") {
            column(name: "score_target_id", type: "bigint(20)", remarks: "指标ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SCORE_TARGET_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "score_target_code", type: "varchar(100)", remarks: "指标代码")
            column(name: "score_target_name", type: "varchar(2000)", remarks: "指标名称")
            column(name: "target_value_type", type: "varchar(100)", remarks: "指标值类型（syscode:HLS.SCORE_TARGET_VALUE_TYPE)")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_SCORE_TARGET", columnNames: "company_id,score_target_code", constraintName: "HLS_SCORE_TARGET_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SCORE_TARGET_VALUE") {
        createTable(tableName: "HLS_SCORE_TARGET_VALUE", remarks: "评分指标") {
            column(name: "score_target_value_id", type: "bigint(20)", remarks: "指标值ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SCORE_TARGET_VALUE_PK")
            }
            column(name: "score_target_id", type: "bigint(20)", remarks: "指标ID") { constraints(nullable: "false") }
            column(name: "line_number", type: "bigint(20)", remarks: "行序号")
            column(name: "left_bracket", type: "varchar(100)", remarks: "左边界（syscode:FND.SCORE_TEMPLATE_LEFT_BRACKET)")
            column(name: "from_value", type: "varchar(100)", remarks: "起始值")
            column(name: "to_value", type: "varchar(100)", remarks: "结束值")
            column(name: "right_bracket", type: "varchar(100)", remarks: "右边界（syscode:FND.SCORE_TEMPLATE_RIGHT_BRACKET)")
            column(name: "fixed_target_value", type: "varchar(1000)", remarks: "固定值")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_SCORE_TARGET_VALUE", columnNames: "score_target_id,line_number", constraintName: "HLS_SCORE_TARGET_VALUE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_TEMPLATE_TYPE") {
        createTable(tableName: "FND_SCORE_TEMPLATE_TYPE", remarks: "评分指标模板类型") {
            column(name: "score_template_type_id", type: "bigint(20)", remarks: "评分指标模型类型ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_TEMPLATE_TYPE_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "score_template_type_code", type: "varchar(100)", remarks: "评分指标模型类型代码") {
                constraints(nullable: "false")
            }
            column(name: "score_template_type_name", type: "varchar(2000)", remarks: "评分指标模型类型名称")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_SCORE_TEMPLATE_TYPE", columnNames: "company_id,score_template_type_code", constraintName: "FND_SCORE_TEMPLATE_TYPE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_TEMPLATE_HD") {
        createTable(tableName: "FND_SCORE_TEMPLATE_HD", remarks: "评分指标模板头") {
            column(name: "score_template_hd_id", type: "bigint(20)", remarks: "评分指标模板头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_TEMPLATE_HD_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "score_template_hd_code", type: "varchar(100)", remarks: "评分指标模板头代码") {
                constraints(nullable: "false")
            }
            column(name: "score_template_hd_name", type: "varchar(2000)", remarks: "评分指标模板头名称")
            column(name: "score_template_type_id", type: "bigint(20)", remarks: "评分指标模型类型ID")
            column(name: "calc_method", type: "varchar(100)", remarks: "计算方式(syscode:HLS.SCORE_TEMPLATE_CALC_METHOD)")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_SCORE_TEMPLATE_HD", columnNames: "company_id,score_template_hd_code", constraintName: "FND_SCORE_TEMPLATE_HD_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_TEMPLATE_LN") {
        createTable(tableName: "FND_SCORE_TEMPLATE_LN", remarks: "评分指标模板行") {
            column(name: "score_template_ln_id", type: "bigint(20)", remarks: "评分指标模板行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_TEMPLATE_LN_PK")
            }
            column(name: "score_template_hd_id", type: "bigint(20)", remarks: "评分指标模板头ID") {
                constraints(nullable: "false")
            }
            column(name: "line_seq", type: "bigint(20)", remarks: "顺序号") { constraints(nullable: "false") }
            column(name: "summary_flag", type: "varchar(1)", remarks: "汇总标志")
            column(name: "description", type: "varchar(2000)", remarks: "评分指标模板行说明")
            column(name: "score_target_id", type: "bigint(20)", remarks: "指标ID")
            column(name: "data_source_column_id", type: "bigint(20)", remarks: "数据源取值字段ID")
            column(name: "weigth_value", type: "double", remarks: "权重")
            column(name: "parent_ln_id", type: "bigint(20)", remarks: "上级_评分指标模板行ID")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "FND_SCORE_TEMPLATE_LN", indexName: "FND_SCORE_TEMPLATE_LN_N1") {
            column(name: "score_template_hd_id", type: "bigint(20)")
        }
        createIndex(tableName: "FND_SCORE_TEMPLATE_LN", indexName: "FND_SCORE_TEMPLATE_LN_N2") {
            column(name: "parent_ln_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_TEMPLATE_LN_VALUE") {
        createTable(tableName: "FND_SCORE_TEMPLATE_LN_VALUE", remarks: "评分指标模板行值") {
            column(name: "score_template_ln_value_id", type: "bigint(20)", remarks: "评分指标模板行值ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_TEMPLATE_LN_VALUE_PK")
            }
            column(name: "score_template_ln_id", type: "bigint(20)", remarks: "评分指标模板行ID") {
                constraints(nullable: "false")
            }
            column(name: "score_target_value_id", type: "bigint(20)", remarks: "指标值ID") {
                constraints(nullable: "false")
            }
            column(name: "score_value", type: "double", remarks: "分值")
            column(name: "score_grade", type: "varchar(2000)", remarks: "评级")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_SCORE_TEMPLATE_LN_VALUE", columnNames: "score_template_ln_id,score_target_value_id", constraintName: "FND_SCORE_TEMPLATE_LN_VALUE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_TEMPLATE_HD_VALUE") {
        createTable(tableName: "FND_SCORE_TEMPLATE_HD_VALUE", remarks: "评分指标模板头值") {
            column(name: "score_template_hd_value_id", type: "bigint(20)", remarks: "评分指标模板头值ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_TEMPLATE_HD_VALUE_PK")
            }
            column(name: "score_template_hd_id", type: "bigint(20)", remarks: "评分指标模板头ID") {
                constraints(nullable: "false")
            }
            column(name: "line_number", type: "bigint(20)", remarks: "行序号")
            column(name: "left_bracket", type: "varchar(100)", remarks: "左边界（syscode:FND.SCORE_TEMPLATE_LEFT_BRACKET)")
            column(name: "from_value", type: "varchar(100)", remarks: "起始值")
            column(name: "to_value", type: "varchar(100)", remarks: "结束值")
            column(name: "right_bracket", type: "varchar(100)", remarks: "右边界（syscode:FND.SCORE_TEMPLATE_RIGHT_BRACKET)")
            column(name: "score_grade", type: "double(100)", remarks: "评级")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_SCORE_TEMPLATE_HD_VALUE", columnNames: "score_template_hd_id,line_number", constraintName: "FND_SCORE_TEMPLATE_HD_VALUE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_TPLT_DB_SOURCE") {
        createTable(tableName: "FND_SCORE_TPLT_DB_SOURCE", remarks: "评分指标模板数据源") {
            column(name: "score_template_db_source_id", type: "bigint(20)", remarks: "评分模板数据源ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_TPLT_DB_SOURCE_PK")
            }
            column(name: "score_template_hd_id", type: "bigint(20)", remarks: "评分指标模板头ID") {
                constraints(nullable: "false")
            }
            column(name: "db_data_source_id", type: "bigint(20)", remarks: "数据源ID")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "FND_SCORE_TPLT_DB_SOURCE", columnNames: "score_template_hd_id,db_data_source_id", constraintName: "FND_SCORE_TPLT_DB_SOURCE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_RESULT") {
        createTable(tableName: "FND_SCORE_RESULT", remarks: "评分结果") {
            column(name: "score_result_id", type: "bigint(20)", remarks: "评分结果ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_RESULT_PK")
            }
            column(name: "score_value", type: "double", remarks: "分数值")
            column(name: "score_grade", type: "varchar(100)", remarks: "分数评级")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "score_template_hd_id", type: "bigint(20)", remarks: "评分模块ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_RESULT_DTL") {
        createTable(tableName: "FND_SCORE_RESULT_DTL", remarks: "评分结果明细") {
            column(name: "score_result_dtl_id", type: "bigint(20)", remarks: "评分结果明细ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_RESULT_DTL_PK")
            }
            column(name: "score_result_id", type: "bigint(20)", remarks: "评分结果ID") { constraints(nullable: "false") }
            column(name: "parent_result_dtl_id", type: "bigint(20)", remarks: "上级_评分结果明细ID")
            column(name: "summary_flag", type: "varchar(1)", remarks: "汇总标志")
            column(name: "score_template_ln_id", type: "bigint(20)", remarks: "评分指标模板行ID")
            column(name: "score_target_id", type: "bigint(20)", remarks: "指标ID")
            column(name: "score_target_value_id", type: "bigint(20)", remarks: "指标值ID")
            column(name: "weigth_value", type: "double", remarks: "指标权重")
            column(name: "target_value", type: "varchar(1000)", remarks: "指标值")
            column(name: "target_score", type: "double", remarks: "指标得分")
            column(name: "target_score_original", type: "double", remarks: "指标得分_原始")
            column(name: "target_score_grade", type: "varchar(1000)", remarks: "指标评级")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_SCORE_RESULT_JSON") {
        createTable(tableName: "FND_SCORE_RESULT_JSON", remarks: "评分结果输入值") {
            column(name: "score_result_json_id", type: "bigint(20)", remarks: "评分数据jsonID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_SCORE_RESULT_JSON_PK")
            }
            column(name: "score_result_id", type: "bigint(20)", remarks: "评分结果ID") { constraints(nullable: "false") }
            column(name: "json_data", type: "text", remarks: "json数据源")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "FND_SCORE_RESULT_JSON", indexName: "FND_SCORE_RESULT_JSON_N1") {
            column(name: "score_result_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SCORE_CALCULATION") {
        createTable(tableName: "HLS_SCORE_CALCULATION", remarks: "评分计算表") {
            column(name: "score_id", type: "bigint(20)", remarks: "评分ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SCORE_CALCULATION_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "object_type", type: "varchar(100)", remarks: "评分对象类型") { constraints(nullable: "false") }
            column(name: "object_id", type: "bigint(20)", remarks: "评分对象ID") { constraints(nullable: "false") }
            column(name: "fiscal_year", type: "bigint(20)", remarks: "财务年度") { constraints(nullable: "false") }
            column(name: "fiscal_month", type: "bigint(20)", remarks: "财务月度") { constraints(nullable: "false") }
            column(name: "score_date", type: "datetime", remarks: "评分日期")
            column(name: "score_user_id", type: "bigint(20)", remarks: "评分用户ID")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "score_template_hd_id", type: "bigint(20)", remarks: "评分模块ID")
            column(name: "score_result_id", type: "bigint(20)", remarks: "评分结果ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_SCORE_CALCULATION", columnNames: "company_id,object_type,object_id,fiscal_year,fiscal_month", constraintName: "HLS_SCORE_CALCULATION_U1")

        createIndex(tableName: "HLS_SCORE_CALCULATION", indexName: "HLS_SCORE_CALCULATION_N1") {
            column(name: "score_date", type: "datetime")
            column(name: "score_user_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_CATEGORY") {
        createTable(tableName: "HLS_BP_CATEGORY", remarks: "商业伙伴类别") {
            column(name: "bp_category", type: "varchar(100)", remarks: "商业伙伴类别") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_CATEGORY_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_TYPE") {
        createTable(tableName: "HLS_BP_TYPE", remarks: "商业伙伴类型") {
            column(name: "bp_type", type: "varchar(100)", remarks: "商业伙伴类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_TYPE_PK")
            }
            column(name: "bp_category", type: "varchar(100)", remarks: "描述") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_BP_TYPE", columnNames: "bp_type,bp_category", constraintName: "HLS_BP_TYPE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_RELATION") {
        createTable(tableName: "HLS_BP_RELATION", remarks: "商业伙伴关系") {
            column(name: "bp_relation_type", type: "varchar(100)", remarks: "商业伙伴关系") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_RELATION_PK")
            }
            column(name: "bp_relation_type_Opposite", type: "varchar(100)", remarks: "商业伙伴关系（反向）") {
                constraints(nullable: "false")
            }
            column(name: "bp_class", type: "varchar(100)", remarks: "分类(syscode：FND.BP_CLASS)")
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "-HLS_BP_MASTER") {
        createTable(tableName: "HLS_BP_MASTER", remarks: "商业伙伴") {
            column(name: "bp_id", type: "bigint(100)", remarks: "商业伙伴ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_PK")
            }
            column(name: "bp_code", type: "varchar(100)", remarks: "商业伙伴代码") { constraints(nullable: "false") }
            column(name: "bp_name", type: "varchar(2000)", remarks: "商业伙伴名称")
            column(name: "bp_class", type: "varchar(100)", remarks: "分类(syscode：FND.BP_CLASS)")
            column(name: "extra_nam", type: "varchar(2000)", remarks: "附加名称")
            column(name: "external_bp_code", type: "varchar(100)", remarks: "商业伙伴外部编码")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "enterprise_scale", type: "varchar(100)", remarks: "企业规模(syscode:FND.ENTERPRISE_SCALE_TYPE)")
            column(name: "legal_form", type: "varchar(100)", remarks: "企业性质(syscode:FND.ENTERPRISE_LEGAL_FORM)")
            column(name: "INDUSTRY", type: "varchar(100)", remarks: "所属行业(syscode:FND.INDUSTRY)")
            column(name: "Legal_representative", type: "varchar(255)", remarks: "法人代表")
            column(name: "Actual_controller", type: "varchar(255)", remarks: "实际控制人")
            column(name: "registered_place", type: "varchar(255)", remarks: "注册地点")
            column(name: "registered_date", type: "datetime", remarks: "注册时间")
            column(name: "registered_capital", type: "varchar(255)", remarks: "注册资本")
            column(name: "paid_in_capital", type: "varchar(255)", remarks: "实收资本")
            column(name: "Enterprise_unified_credit_code", type: "varchar(255)", remarks: "统一社会信用代码")
            column(name: "founded_date", type: "datetime", remarks: "成立时间")
            column(name: "business_license_num", type: "varchar(255)", remarks: "工商营业执照号")
            column(name: "organization_code", type: "varchar(255)", remarks: "组织机构代码")
            column(name: "tax_registry_num", type: "varchar(255)", remarks: "税务登记证号")
            column(name: "loan_card_num", type: "varchar(255)", remarks: "贷款卡号")
            column(name: "loan_card_password", type: "varchar(255)", remarks: "贷款卡密码")
            column(name: "primary_business", type: "varchar(2000)", remarks: "主营业务")
            column(name: "main_products", type: "varchar(2000)", remarks: "经营范围")
            column(name: "Company_Information", type: "varchar(2000)", remarks: "企业介绍")
            column(name: "taxpayer_type", type: "varchar(100)", remarks: "纳税人类别(syscode:FND.TAXPAYER_TYPE)")
            column(name: "invoice_title", type: "varchar(255)", remarks: "发票抬头")
            column(name: "invoice_bp_address_phone_num", type: "varchar(255)", remarks: "发票地址及电话")
            column(name: "invoice_bp_bank_account", type: "varchar(255)", remarks: "发票开户行及账号")
            column(name: "nationality", type: "varchar(255)", remarks: "国籍")
            column(name: "date_of_birth", type: "datetime", remarks: "出生日期")
            column(name: "native_place", type: "varchar(100)", remarks: "籍贯")
            column(name: "id_type", type: "varchar(100)", remarks: "证件类型(syscode：FND.EMPLOYEE_ID_TYPE)")
            column(name: "id_card_no", type: "varchar(100)", remarks: "证件号")
            column(name: "marital_status", type: "varchar(100)", remarks: "婚姻状况(syscode：FND.MARITAL_STATUS)")
            column(name: "academic_background", type: "varchar(100)", remarks: "学历(syscode：FND.ACADEMIC_BACKGROUND)")
            column(name: "age", type: "double", remarks: "年龄")
            column(name: "gender", type: "varchar(100)", remarks: "性别(syscode：FND.GENDER)")
            column(name: "annual_income", type: "double", remarks: "年收入(万元)")
            column(name: "working_company", type: "varchar(255)", remarks: "工作单位")
            column(name: "company_industry", type: "varchar(2000)", remarks: "公司行业")
            column(name: "business_job", type: "varchar(255)", remarks: "职务")
            column(name: "working_years", type: "double", remarks: "从业年限")
            column(name: "phone", type: "varchar(255)", remarks: "电话")
            column(name: "cell_phone", type: "varchar(255)", remarks: "手机")
            column(name: "email", type: "varchar(255)", remarks: "邮箱")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_BP_MASTER", columnNames: "bp_code", constraintName: "HLS_BP_MASTER_U1")


    }



    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_ROLE") {
        createTable(tableName: "HLS_BP_MASTER_ROLE", remarks: "商业伙伴角色") {
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_ROLE_PK")
            }
            column(name: "bp_type", type: "varchar(100)", remarks: "商业伙伴类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_ROLE_PK")
            }
            column(name: "bp_category", type: "varchar(100)", remarks: "商业伙伴类别")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_COMPANY") {
        createTable(tableName: "HLS_BP_MASTER_COMPANY", remarks: "商业伙伴公司") {
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_COMPANY_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_COMPANY_PK")
            }
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_ADDRESS") {
        createTable(tableName: "HLS_BP_MASTER_ADDRESS", remarks: "商业伙伴地址") {
            column(name: "address_id", type: "bigint(20)", remarks: "地址id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_ADDRESS_PK")
            }
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") { constraints(nullable: "false") }
            column(name: "address_type", type: "varchar(100)", remarks: "地址类型(syscode：FND.ADDRESS_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "country", type: "varchar(100)", remarks: "国家")
            column(name: "province", type: "varchar(100)", remarks: "省")
            column(name: "city", type: "varchar(100)", remarks: "市")
            column(name: "district", type: "varchar(100)", remarks: "区/县")
            column(name: "street", type: "varchar(2000)", remarks: "街道")
            column(name: "address", type: "varchar(2000)", remarks: "地址")
            column(name: "zipcode", type: "varchar(2000)", remarks: "邮编")
            column(name: "contact_person", type: "varchar(2000)", remarks: "联系人")
            column(name: "position", type: "varchar(2000)", remarks: "职位")
            column(name: "phone", type: "varchar(2000)", remarks: "电话")
            column(name: "fax", type: "varchar(2000)", remarks: "传真")
            column(name: "cell_phone ", type: "varchar(2000)", remarks: "手机")
            column(name: "email", type: "varchar(2000)", remarks: "邮箱")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_BP_MASTER_ADDRESS", columnNames: "bp_id,address_type", constraintName: "HLS_BP_MASTER_ADDRESS_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_CONTACT_INFO") {
        createTable(tableName: "HLS_BP_MASTER_CONTACT_INFO", remarks: "商业伙伴联系人") {
            column(name: "contact_info_id", type: "bigint(20)", remarks: "联系人id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_CONTACT_INFO_PK")
            }
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") { constraints(nullable: "false") }
            column(name: "emergency_contact", type: "varchar(2000)", remarks: "紧急联系人")
            column(name: "contact_person", type: "varchar(2000)", remarks: "联系人")
            column(name: "position", type: "varchar(2000)", remarks: "职位/关系")
            column(name: "cell_phone", type: "varchar(2000)", remarks: "手机")
            column(name: "phone", type: "varchar(2000)", remarks: "电话")
            column(name: "fax", type: "varchar(2000)", remarks: "传真")
            column(name: "email", type: "varchar(2000)", remarks: "邮箱")
            column(name: "contact_address", type: "varchar(2000)", remarks: "联系地址")
            column(name: "id_type", type: "varchar(100)", remarks: "证件类型(syscode：FND.EMPLOYEE_ID_TYPE)")
            column(name: "id_card_no", type: "varchar(100)", remarks: "证件号")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_BP_MASTER_CONTACT_INFO", columnNames: "bp_id", constraintName: "HLS_BP_MASTER_CONTACT_INFO_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_BANK_ACCOUNT") {
        createTable(tableName: "HLS_BP_MASTER_BANK_ACCOUNT", remarks: "商业伙伴账户信息") {
            column(name: "bank_account_id", type: "bigint(20)", remarks: "账户信息id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_BANK_ACCOUNT_PK")
            }
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") { constraints(nullable: "false") }
            column(name: "bank_account_num", type: "varchar(2000)", remarks: "银行账户")
            column(name: "bank_account_name", type: "varchar(2000)", remarks: "账户名称")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "bank_full_name", type: "varchar(2000)", remarks: "开户银行")
            column(name: "bank_branch_name", type: "varchar(2000)", remarks: "开户支行")
            column(name: "country", type: "varchar(100)", remarks: "国家")
            column(name: "province", type: "varchar(100)", remarks: "省")
            column(name: "city", type: "varchar(100)", remarks: "市")
            column(name: "district", type: "varchar(100)", remarks: "县")
            column(name: "debt_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "debt_bank_id", type: "bigint(10)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "HLS_BP_MASTER_BANK_ACCOUNT", indexName: "HLS_BP_MASTER_BANK_ACCOUNT_N1") {
            column(name: "bp_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_RELATION") {
        createTable(tableName: "HLS_BP_MASTER_RELATION", remarks: "商业伙伴关联关系") {
            column(name: "bp_id", type: "bigint(20)", remarks: "关系原BP") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_RELATION_PK")
            }
            column(name: "relation_bp_id", type: "bigint(20)", remarks: "关系对象BP") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_RELATION_PK")
            }
            column(name: "bp_relation_type", type: "varchar(100)", remarks: "子女/配偶/家属/ 上下级公司")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_FIN_STATEMENT_TMPLT_HD") {
        createTable(tableName: "HLS_FIN_STATEMENT_TMPLT_HD", remarks: "财务报表模板头") {
            column(name: "fin_statement_templet_hd_id", type: "bigint(20)", remarks: "财务报表模板ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_FIN_STATEMENT_TMPLT_HD_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "fin_statement_templet_code", type: "varchar(100)", remarks: "财务报表模板代码")
            column(name: "fin_statement_templet_name", type: "varchar(2000)", remarks: "财务报表模板名称")
            column(name: "currency_code", type: "varchar(100)", remarks: "币种")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_FIN_STATEMENT_TMPLT_HD", columnNames: "company_id,fin_statement_templet_code", constraintName: "HLS_FIN_STATEMENT_TMPLT_HD_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_FIN_STATEMENT_TMPLT_LN") {
        createTable(tableName: "HLS_FIN_STATEMENT_TMPLT_LN", remarks: "财务报表模板行") {
            column(name: "fin_statement_templet_ln_id", type: "bigint(20)", remarks: "财务报表模板行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_FIN_STATEMENT_TMPLT_LN_PK")
            }
            column(name: "fin_statement_templet_hd_id", type: "bigint(20)", remarks: "财务报表模板ID") {
                constraints(nullable: "false")
            }
            column(name: "line_type", type: "varchar(100)", remarks: "模板行类别(SYSCODE:HLS.FIN_STATEMENT_TMPLT_LINE_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "line_seq_number", type: "bigint(20)", remarks: "模板行顺序号") { constraints(nullable: "false") }
            column(name: "fin_statement_item_name", type: "varchar(2000)", remarks: "报表项名称")
            column(name: "fin_statement_item_type", type: "varchar(100)", remarks: "报表项类型(SYSCODE:HLS.FIN_STATEMENT_TMPLT_ITEM_TYPE)")
            column(name: "formula_priority", type: "bigint(20)", remarks: "公式优先级")
            column(name: "formula_text", type: "varchar(2000)", remarks: "公式字符串，可写如[1]+[2] 表示模板行第1行+第2行")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_FIN_STATEMENT_TMPLT_LN", columnNames: "fin_statement_templet_hd_id,line_type,line_seq_number", constraintName: "HLS_FIN_STATEMENT_TMPLT_LN_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_FIN_STATEMENT_HD") {
        createTable(tableName: "HLS_FIN_STATEMENT_HD", remarks: "财务报表头") {
            column(name: "fin_statement_hd_id", type: "bigint(20)", remarks: "财务报表头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_FIN_STATEMENT_HD_PK")
            }
            column(name: "fin_statement_templet_hd_id", type: "bigint(20)", remarks: "财务报表模板ID") {
                constraints(nullable: "false")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID")
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID")
            column(name: "fiscal_year", type: "bigint(20)", remarks: "财务年度")
            column(name: "fiscal_month", type: "bigint(20)", remarks: "财务月度")
            column(name: "currency_code", type: "varchar(100)", remarks: "币种")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_FIN_STATEMENT_HD", columnNames: "company_id,bp_id,fiscal_year,fiscal_month", constraintName: "HLS_FIN_STATEMENT_HD_U1")

        createIndex(tableName: "HLS_FIN_STATEMENT_HD", indexName: "HLS_FIN_STATEMENT_HD_N1") {
            column(name: "fin_statement_templet_hd_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_FIN_STATEMENT_LN") {
        createTable(tableName: "HLS_FIN_STATEMENT_LN", remarks: "财务报表行") {
            column(name: "fin_statement_ln_id", type: "bigint(20)", remarks: "财务报表行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_FIN_STATEMENT_LN_PK")
            }
            column(name: "fin_statement_hd_id", type: "bigint(20)", remarks: "财务报表头ID") {
                constraints(nullable: "false")
            }
            column(name: "line_type", type: "varchar(100)", remarks: "模板行类别(SYSCODE:HLS.FIN_STATEMENT_TMPLT_LINE_TYPE)")
            column(name: "line_seq_number", type: "bigint(20)", remarks: "模板行顺序号")
            column(name: "fin_statement_item_name", type: "varchar(2000)", remarks: "报表项名称")
            column(name: "fin_statement_item_type", type: "varchar(100)", remarks: "报表项类型(SYSCODE:HLS.FIN_STATEMENT_TMPLT_ITEM_TYPE)")
            column(name: "amount", type: "double", remarks: "原始金额")
            column(name: "adj_amount", type: "double", remarks: "调整金额")
            column(name: "adj_reason", type: "varchar(2000)", remarks: "调整原因")
            column(name: "final_amount", type: "double", remarks: "最终金额")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_FIN_STATEMENT_LN", indexName: "HLS_FIN_STATEMENT_LN_N1") {
            column(name: "fin_statement_hd_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT") {
        createTable(tableName: "PRJ_PROJECT", remarks: "租赁项目表") {
            column(name: "project_id", type: "bigint(20)", remarks: "发票头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "project_number", type: "varchar(255)", remarks: "项目编号")
            column(name: "project_name", type: "varchar(255)", remarks: "项目名称")
            column(name: "project_status", type: "varchar(100)", remarks: "项目状态")
            column(name: "lease_item_type", type: "varchar(100)", remarks: "租赁物类型")
            column(name: "lease_channel", type: "varchar(100)", remarks: "商业模式")
            column(name: "division", type: "varchar(100)", remarks: "产品线")
            column(name: "employee_id", type: "bigint(20)", remarks: "业务员（用户id）")
            column(name: "unit_id", type: "bigint(20)", remarks: "部门id")
            column(name: "finance_amount", type: "double", remarks: "融资额")
            column(name: "lease_start_date", type: "datetime", remarks: "租赁期开始日")
            column(name: "financing_purpose", type: "varchar(2000)", remarks: "融资目的")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "authority_rule_string", type: "varchar(1000)", remarks: "授权规则字符串")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "comprehensive_opinion", type: "varchar(4000)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_PROJECT", columnNames: "company_id,project_number", constraintName: "PRJ_PROJECT_U1")

        createIndex(tableName: "PRJ_PROJECT", indexName: "PRJ_PROJECT_N3") {
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
        }
        createIndex(tableName: "PRJ_PROJECT", indexName: "PRJ_PROJECT_N1") {
            column(name: "project_name", type: "varchar(255)")
        }
        createIndex(tableName: "PRJ_PROJECT", indexName: "PRJ_PROJECT_N2") {
            column(name: "project_status", type: "varchar(100)")
        }
        createIndex(tableName: "PRJ_PROJECT", indexName: "PRJ_PROJECT_N5") {
            column(name: "lease_channel", type: "varchar(100)")
            column(name: "division", type: "varchar(100)")
        }
        createIndex(tableName: "PRJ_PROJECT", indexName: "PRJ_PROJECT_N4") {
            column(name: "employee_id", type: "bigint(20)")
            column(name: "unit_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_QUOTATION") {
        createTable(tableName: "PRJ_QUOTATION", remarks: "报价表") {
            column(name: "quotation_id", type: "bigint(20)", remarks: "报价id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_PK")
            }
            column(name: "quotation_coding", type: "double(20)", remarks: "来源单据类别")
            column(name: "source_document_category", type: "double(20)", remarks: "来源单据类别")
            column(name: "source_document_id", type: "bigint(20)", remarks: "来源单据id")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "status", type: "varchar(100)", remarks: "状态")
            column(name: "price_list", type: "varchar(100)", remarks: "报价方案")
            column(name: "penalty_profile", type: "varchar(100)", remarks: "延迟履行金规则")
            column(name: "lease_start_date", type: "datetime", remarks: "租赁期开始日")
            column(name: "lease_times", type: "bigint(20)", remarks: "租赁期数")
            column(name: "annual_pay_times", type: "bigint(20)", remarks: "支付频率（年）")
            column(name: "lease_term", type: "bigint(20)", remarks: "租赁期限")
            column(name: "pay_type", type: "bigint(20)", remarks: "支付类型（1/先付;0/后付）")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "tax_type_id", type: "bigint(20)", remarks: "税种id")
            column(name: "vat_flag", type: "varchar(1)", remarks: "增值税标志")
            column(name: "vat_rate", type: "double", remarks: "增值税率")
            column(name: "lease_item_amount", type: "double", remarks: "租赁资产总价款")
            column(name: "vat_input", type: "double", remarks: "进项增值税额")
            column(name: "vat_input_tax_type_id", type: "bigint(20)", remarks: "进项税税种")
            column(name: "vat_input_tax_type_rate", type: "double", remarks: "进项税税率")
            column(name: "down_payment_ratio", type: "double", remarks: "首期租金比例/首付比例")
            column(name: "down_payment", type: "double", remarks: "首期租金/首付金额")
            column(name: "net_down_payment", type: "double", remarks: "不含税首付金额")
            column(name: "vat_down_payment", type: "double", remarks: "首付款税额")
            column(name: "finance_amount", type: "double", remarks: "融资额 （租赁资产总价款 - 首付款，即租赁本金）")
            column(name: "net_finance_amount", type: "double", remarks: "不含税融资额")
            column(name: "vat_finance_amount", type: "double", remarks: "融资额增值税")
            column(name: "total_rental", type: "double", remarks: "租金总额")
            column(name: "net_total_rental", type: "double", remarks: "不含税租金")
            column(name: "vat_total_rental", type: "double", remarks: "租金增值税额")
            column(name: "total_interest", type: "double", remarks: "利息总额")
            column(name: "net_total_interest", type: "double", remarks: "不含税利息")
            column(name: "vat_total_interest", type: "double", remarks: "利息增值税额")
            column(name: "lease_charge_ratio", type: "double", remarks: "手续费比例")
            column(name: "lease_charge", type: "double", remarks: "手续费")
            column(name: "net_lease_charge", type: "double", remarks: "不含税手续费")
            column(name: "vat_lease_charge", type: "double", remarks: "手续费税额")
            column(name: "lease_mgt_fee_ratio", type: "double", remarks: "管理费比例")
            column(name: "lease_mgt_fee", type: "double", remarks: "管理费")
            column(name: "net_lease_mgt_fee", type: "double", remarks: "不含税管理费")
            column(name: "vat_lease_mgt_fee", type: "double", remarks: "管理费税额")
            column(name: "lease_mgt_fee_rule", type: "varchar(100)", remarks: "管理费计算方式")
            column(name: "deposit_ratio", type: "double", remarks: "保证金比例")
            column(name: "deposit", type: "double", remarks: "保证金")
            column(name: "deposit_deduction", type: "varchar(100)", remarks: "保证金抵扣方式")
            column(name: "residual_ratio", type: "double", remarks: "留购价款比例")
            column(name: "residual_value", type: "double", remarks: "留购价款")
            column(name: "net_residual_value", type: "double", remarks: "不含税留购金")
            column(name: "vat_residual_value", type: "double", remarks: "留购金税额")
            column(name: "balloon_ratio", type: "double", remarks: "末期租金比例")
            column(name: "balloon", type: "double", remarks: "末期租金")
            column(name: "net_balloon", type: "double", remarks: "不含税末期租金")
            column(name: "vat_balloon", type: "double", remarks: "末期租金税额")
            column(name: "base_rate_type", type: "varchar(100)", remarks: " 基准利率类别：pboc央行基准、libor伦敦同业")
            column(name: "base_rate", type: "double", remarks: "基准利率")
            column(name: "int_rate", type: "double", remarks: "租赁利率")
            column(name: "int_rate_implicit", type: "double", remarks: "租赁利率（实际）")
            column(name: "int_rate_type", type: "varchar(100)", remarks: "利率类型：浮动/floating; 固定/fixed(syscode:CON.INT_RATE_TYPE)")
            column(name: "irr", type: "double", remarks: "内部收益率")
            column(name: "irr_after_tax", type: "double", remarks: "税后内部收益率")
            column(name: "pmt", type: "double", remarks: "等额本息租金")
            column(name: "pmt_first", type: "double", remarks: "等额本息租金（首期）")
            column(name: "billing_profile", type: "varchar(30)", remarks: "")
           // column(name: "penalty_profile", type: "varchar(30)", remarks: "")
            column(name: "annual_mean_rate", type: "double", remarks: "表面利率、平息率")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_QUOTATION", indexName: "PRJ_QUOTATION_N1") {
            column(name: "source_document_category", type: "double(20)")
            column(name: "source_document_id", type: "bigint(20)")
        }
        createIndex(tableName: "PRJ_QUOTATION", indexName: "PRJ_QUOTATION_N2") {
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "PRJ_QUOTATION", indexName: "PRJ_QUOTATION_N3") {
            column(name: "price_list", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_QUOTATION_CASHFLOW") {
        createTable(tableName: "PRJ_QUOTATION_CASHFLOW", remarks: "项目报价现金流表") {
            column(name: "quotation_cashflow_id", type: "bigint(20)", remarks: "现金流ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_CASHFLOW_PK")
            }
            column(name: "quotation_id", type: "bigint(20)", remarks: "项目报价ID") { constraints(nullable: "false") }
            column(name: "cf_item", type: "varchar(100)", remarks: "现金流项目")
            column(name: "cf_type", type: "varchar(100)", remarks: "现金流类型")
            column(name: "cf_direction", type: "varchar(100)", remarks: "现金流方向（INFLOW/OUTFLOW）")
            column(name: "cf_status", type: "varchar(100)", remarks: "现金流状态（BLOCK/冻结 、RELEASE/下达、CANCEL/取消） （syscode：HLS.CASHFLOW_STATUS）")
            column(name: "times", type: "bigint(20)", remarks: "期数")
            column(name: "due_date", type: "datetime", remarks: "支付日/到期日")
            column(name: "fin_income_date", type: "datetime", remarks: "收入确认日")
            column(name: "due_amount", type: "double", remarks: "应收金额")
            column(name: "net_due_amount", type: "double", remarks: "不含税应收金额")
            column(name: "vat_due_amount", type: "double", remarks: "增值税额")
            column(name: "principal", type: "double", remarks: "应收本金")
            column(name: "net_principal", type: "double", remarks: "不含税应收本金")
            column(name: "vat_principal", type: "double", remarks: "本金增值税额")
            column(name: "interest", type: "double", remarks: "应收利息")
            column(name: "net_interest", type: "double", remarks: "不含税应收利息")
            column(name: "vat_interest", type: "double", remarks: "利息增值税额")
            column(name: "outstanding_rental", type: "double", remarks: "当期剩余租金")
            column(name: "outstanding_principal", type: "double", remarks: "当期剩余本金")
            column(name: "outstanding_interest", type: "double", remarks: "当期剩余利息")
            column(name: "interest_accrual_balance", type: "double", remarks: "当期计息余额")
            column(name: "accumulated_unpaid_interest", type: "double", remarks: "累计未偿还利息")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "PRJ_QUOTATION_CASHFLOW", indexName: "PRJ_QUOTATION_CASHFLOW_N1") {
            column(name: "quotation_id", type: "bigint(20)")
            column(name: "cf_item", type: "varchar(100)")
            column(name: "cf_type", type: "varchar(100)")
            column(name: "times", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_TENANT") {
        createTable(tableName: "PRJ_PROJECT_TENANT", remarks: "项目承租人表") {
            column(name: "project_tenant_id", type: "bigint(20)", remarks: "项目承租人ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_TENANT_PK")
            }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "tenant_bp_id", type: "bigint(20)", remarks: "承租人商业伙伴ID")
            column(name: "tenant_bp_type", type: "varchar(100)", remarks: "承租人商业伙伴类型")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "description_stock_stru", type: "varchar(2000)", remarks: "承租人与主要股东、下属控股公司等关联企业关联交易情况简介")
            column(name: "investment_situation", type: "varchar(2000)", remarks: "承租人对外投资情况简介")
            column(name: "industry_status", type: "varchar(2000)", remarks: "行业现状(简要)")
            column(name: "product_supply_demand", type: "varchar(2000)", remarks: "承租人产品及其上、下游市场供需状况")
            column(name: "market_competition_analysis", type: "varchar(2000)", remarks: "承租人的市场竞争能力分析")
            column(name: "profit_model", type: "varchar(2000)", remarks: "承租人盈利模式(或经营特点)及上下游客户")
            column(name: "environmental_status", type: "varchar(2000)", remarks: "承租人经营情况-承租人的环保状况")
            column(name: "development_resource", type: "varchar(2000)", remarks: "企业可持续发展的资源因素")
            column(name: "research_development_ability", type: "varchar(2000)", remarks: "承租人经营情况-企业的研发能力和可持续发展能力")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_PROJECT_TENANT", columnNames: "project_id,tenant_bp_id", constraintName: "PRJ_PROJECT_TENANT_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_GUARANTOR") {
        createTable(tableName: "PRJ_PROJECT_GUARANTOR", remarks: "项目担保人表") {
            column(name: "project_guarantor_id", type: "bigint(20)", remarks: "项目担保人ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_GUARANTOR_PK")
            }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "guarantor_bp_id", type: "bigint(20)", remarks: "担保人商业伙伴ID")
            column(name: "guarantee_type", type: "varchar(100)", remarks: "担保类型")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_PROJECT_GUARANTOR", columnNames: "project_id,guarantor_bp_id", constraintName: "PRJ_PROJECT_GUARANTOR_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_LEASE_ITEM") {
        createTable(tableName: "PRJ_PROJECT_LEASE_ITEM", remarks: "项目租赁物表") {
            column(name: "project_lease_item_id", type: "bigint(20)", remarks: "项目租赁物ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_LEASE_ITEM_PK")
            }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "seq_number", type: "bigint(20)", remarks: "项目租赁物序号") { constraints(nullable: "false") }
            column(name: "lease_item_name", type: "varchar(2000)", remarks: "租赁物名称")
            column(name: "serial_number", type: "varchar(2000)", remarks: "租赁物序列号")
            column(name: "pattern", type: "varchar(2000)", remarks: "型号")
            column(name: "specification", type: "varchar(2000)", remarks: "规格")
            column(name: "colour", type: "varchar(2000)", remarks: "颜色")
            column(name: "quantity", type: "double", remarks: "数量")
            column(name: "uom", type: "varchar(100)", remarks: "单位")
            column(name: "price", type: "double", remarks: "单价")
            column(name: "lease_item_amount", type: "double", remarks: "租赁物金额")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "vender_bp_id", type: "bigint(20)", remarks: "供应商商业伙伴ID")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_PROJECT_LEASE_ITEM", columnNames: "project_id,seq_number", constraintName: "PRJ_PROJECT_LEASE_ITEM_U1")

        createIndex(tableName: "PRJ_PROJECT_LEASE_ITEM", indexName: "PRJ_PROJECT_LEASE_ITEM_N1") {
            column(name: "project_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_MORTGAGE") {
        createTable(tableName: "PRJ_PROJECT_MORTGAGE", remarks: "项目抵质押表") {
            column(name: "project_mortgage_id", type: "bigint(20)", remarks: "项目抵质押ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MORTGAGE_PK")
            }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "seq_number", type: "bigint(20)", remarks: "项目抵质押物序号") { constraints(nullable: "false") }
            column(name: "mortgage_name", type: "varchar(2000)", remarks: "抵押物名称")
            column(name: "mortgage_type", type: "varchar(100)", remarks: "抵押类型（抵押mortgage /质押 pledge）（syscode：HLS.MORTGAGE_TYPE）")
            column(name: "mortgage_ast_classfication", type: "varchar(100)", remarks: "抵押物分类（动产（质押）/动产（抵押）/权利/不动产）（syscode：HLS.MORTGAGE_AST_CLASSFICATION)")
            column(name: "mortgage_ast_detail", type: "varchar(2000)", remarks: "明细分类（汇票/债券/基金份额/股权/一般动产/特殊动产-车辆/特殊动产-船舶/特殊动产-航天器/土地/房屋） (syscode:HLS.MORTGAGE_AST_DETAIL)")
            column(name: "mortgage_contract_no", type: "varchar(2000)", remarks: "抵押合同编号 ")
            column(name: "mortgage_register_no", type: "varchar(2000)", remarks: "抵押物登记证号")
            column(name: "mortgage_registed_dept", type: "varchar(2000)", remarks: "抵押登记部门")
            column(name: "mortgagor_bp_id", type: "bigint(20)", remarks: "抵押人商业伙伴ID")
            column(name: "mortgage_value", type: "double", remarks: "抵押物价值")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "uom", type: "varchar(100)", remarks: "单位")
            column(name: "quantity", type: "double", remarks: "数量")
            column(name: "start_date", type: "datetime", remarks: "抵押开始日期")
            column(name: "end_date", type: "datetime", remarks: "抵押结束日期")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_PROJECT_MORTGAGE", columnNames: "project_id,seq_number", constraintName: "PRJ_PROJECT_MORTGAGE_U1")

        createIndex(tableName: "PRJ_PROJECT_MORTGAGE", indexName: "PRJ_PROJECT_MORTGAGE_N1") {
            column(name: "project_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_ATTACHMENT") {
        createTable(tableName: "PRJ_PROJECT_ATTACHMENT", remarks: "项目附件表") {
            column(name: "project_attachment_id", type: "bigint(20)", remarks: "项目附件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_ATTACHMENT_PK")
            }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "source_type", type: "varchar(100)", remarks: "合同附件类别(syscode:CON.CONTRACT_ATTACHMENT_SOURCE_TYPE)（DOC_FILE/MANUAL）")
            column(name: "source_id", type: "bigint(20)", remarks: "如来源DOC_FLIE,则记录原始模板id")
            column(name: "bp_category", type: "varchar(100)", remarks: "文档签约对象类别")
            column(name: "bp_id", type: "bigint(20)", remarks: "文档签约对象ID")
            column(name: "document_name", type: "varchar(2000)", remarks: "文档名称")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_PROJECT_ATTACHMENT", indexName: "PRJ_PROJECT_ATTACHMENT_N1") {
            column(name: "project_id", type: "bigint(20)")
            column(name: "source_type", type: "varchar(100)")
            column(name: "source_id", type: "bigint(20)")
        }
        createIndex(tableName: "PRJ_PROJECT_ATTACHMENT", indexName: "PRJ_PROJECT_ATTACHMENT_N2") {
            column(name: "bp_category", type: "varchar(100)")
            column(name: "bp_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_REPORT") {
        createTable(tableName: "HLS_BP_REPORT", remarks: "商业伙伴调查报告表") {
            column(name: "bp_report_id", type: "bigint(20)", remarks: "BP报告ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_REPORT_PK")
            }
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") { constraints(nullable: "false") }
            column(name: "report_number", type: "varchar(100)", remarks: "报告编号")
            column(name: "report_name", type: "varchar(2000)", remarks: "报告名称")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "source_document_category", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "source_document_id", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "status", type: "varchar(100)", remarks: "状态")
            column(name: "report_by", type: "bigint(20)", remarks: "报告人")
            column(name: "report_date", type: "datetime", remarks: "报告时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_BP_REPORT", columnNames: "bp_id,report_number", constraintName: "HLS_BP_REPORT_U1")

        createIndex(tableName: "HLS_BP_REPORT", indexName: "HLS_BP_REPORT_N3") {
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
        }
        createIndex(tableName: "HLS_BP_REPORT", indexName: "HLS_BP_REPORT_N2") {
            column(name: "source_document_category", type: "varchar(100)")
            column(name: "source_document_id", type: "bigint(20)")
        }
        createIndex(tableName: "HLS_BP_REPORT", indexName: "HLS_BP_REPORT_N4") {
            column(name: "report_by", type: "bigint(20)")
            column(name: "report_date", type: "datetime")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_MEETING_JUDGE") {
        createTable(tableName: "PRJ_MEETING_JUDGE", remarks: "上会评委定义表") {
            column(name: "judge_id", type: "bigint(20)", remarks: "评委ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_MEETING_JUDGE_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "judge_type", type: "varchar(100)", remarks: "用户分配ID（syscode：PRJ.MEETING_JUDGE_TYPE）（固定/随机)")
            column(name: "judge_user_allocation_id", type: "bigint(20)", remarks: "评委用户分配ID")
            column(name: "judge_user_id", type: "bigint(20)", remarks: "评委用户ID")
            column(name: "director_flag", type: "varchar(1)", remarks: "主任标志")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_MEETING_JUDGE", indexName: "PRJ_MEETING_JUDGE_N1") {
            column(name: "company_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_MEETING") {
        createTable(tableName: "PRJ_PROJECT_MEETING", remarks: "项目上会表") {
            column(name: "project_meeting_id", type: "bigint(20)", remarks: "项目上会ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MEETING_PK")
            }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "meeting_name", type: "varchar(200)", remarks: "会议名称")
            column(name: "meeting_location", type: "varchar(2000)", remarks: "会议地点")
            column(name: "meeting_date", type: "datetime", remarks: "会议时间")
            column(name: "meeting_status", type: "varchar(100)", remarks: "状态（syscode：PRJ.PROJECT_MEETING_STATUS）（新建/进行中/完成)")
            column(name: "meeting_result", type: "varchar(100)", remarks: "会议结论（syscode：PRJ.PROJECT_MEETING_RESULT）（通过/拒绝/待定)")
            column(name: "meeting_comments", type: "varchar(2000)", remarks: "会议摘要")
            column(name: "number_of_judges", type: "bigint(20)", remarks: "评审人数")
            column(name: "anonymous_flag", type: "varchar(1)", remarks: "是否匿名模式")
            column(name: "meeting_times", type: "bigint(20)", remarks: "第几次上会")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_PROJECT_MEETING", indexName: "PRJ_PROJECT_MEETING_N1") {
            column(name: "project_id", type: "bigint(20)")
            column(name: "meeting_name", type: "varchar(200)")
        }
        createIndex(tableName: "PRJ_PROJECT_MEETING", indexName: "PRJ_PROJECT_MEETING_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_PROJECT_MEETING_JUDGE") {
        createTable(tableName: "PRJ_PROJECT_MEETING_JUDGE", remarks: "项目上会评委意见表") {
            column(name: "project_meeting_Judge_id", type: "bigint(20)", remarks: "项目上会评审ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MEETING_JUDGE_PK")
            }
            column(name: "project_meeting_id", type: "bigint(20)", remarks: "项目上会ID") { constraints(nullable: "false") }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID") { constraints(nullable: "false") }
            column(name: "judge_user_allocation_id", type: "bigint(20)", remarks: "评委用户分配ID") {
                constraints(nullable: "false")
            }
            column(name: "judge_user_id", type: "bigint(20)", remarks: "评委用户ID") { constraints(nullable: "false") }
            column(name: "director_flag", type: "varchar(1)", remarks: "主任标志")
            column(name: "Judge_approve_result", type: "varchar(100)", remarks: "评委结论（syscode：PRJ.PROJECT_JUDGE_APPROVE_RESULT）（通过/拒绝/保留)")
            column(name: "Judge_approve_comments", type: "varchar(2000)", remarks: "评委意见摘要")
            column(name: "absence_flag", type: "varchar(1)", remarks: "是否缺席")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_PROJECT_MEETING_JUDGE", columnNames: "project_meeting_id,project_id,judge_user_allocation_id", constraintName: "PRJ_PROJECT_MEETING_JUDGE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_CREDIT_LINE") {
        createTable(tableName: "HLS_CREDIT_LINE", remarks: "客户额度表") {
            column(name: "credit_line_id", type: "bigint(20)", remarks: "额度ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CREDIT_LINE_PK")
            }
            column(name: "credit_line_NUMBER", type: "varchar(100)", remarks: "额度编号")
            column(name: "credit_line_name", type: "varchar(2000)", remarks: "额度名称")
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID") { constraints(nullable: "false") }
            column(name: "company_id ", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "source_document_category", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "source_document_id", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "credit_line_status", type: "varchar(100)", remarks: "额度状态")
            column(name: "currency_code", type: "varchar(100)", remarks: "币种")
            column(name: "credit_line_amt ", type: "double", remarks: "额度金额")
            column(name: "credit_exposure_amt  ", type: "double", remarks: "已占用金额")
            column(name: "credit_line_qty", type: "bigint(20)", remarks: "额度次数")
            column(name: "credit_exposure_qty ", type: "bigint(20)", remarks: "已占用次数")
            column(name: "valid_from ", type: "datetime", remarks: "有效期从")
            column(name: "valid_to ", type: "datetime", remarks: "有效期到")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_CREDIT_LINE", columnNames: "credit_line_NUMBER,bp_id  ,company_id ", constraintName: "HLS_CREDIT_LINE_U1")

        createIndex(tableName: "HLS_CREDIT_LINE", indexName: "HLS_CREDIT_LINE_N2") {
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
        }
        createIndex(tableName: "HLS_CREDIT_LINE", indexName: "HLS_CREDIT_LINE_N3") {
            column(name: "source_document_category", type: "varchar(100)")
            column(name: "source_document_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_HIST_EVOLUTION") {
        createTable(tableName: "PRJ_TENANT_HIST_EVOLUTION", remarks: "承租人历史沿革") {
            column(name: "evolution_id", type: "bigint(20)", remarks: "沿革id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_HIST_EVOLUTION_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "项目承租人表id") { constraints(nullable: "false") }
            column(name: "evolution_seq", type: "bigint(20)", remarks: "序号")
            column(name: "change_date", type: "datetime", remarks: "变更日期")
            column(name: "change_affairs", type: "varchar(2000)", remarks: "变更事宜")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_TENANT_HIST_EVOLUTION", columnNames: "bp_report_id,evolution_seq", constraintName: "PRJ_TENANT_HIST_EVOLUTION_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_STOCK_STRUCTURE") {
        createTable(tableName: "PRJ_TENANT_STOCK_STRUCTURE", remarks: "承租人股权结构-主要股东") {
            column(name: "structure_id", type: "bigint(20)", remarks: "股东ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_STOCK_STRUCTURE_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "项目承租人表id")
            column(name: "structure_name", type: "varchar(2000)", remarks: "股东名称")
            column(name: "industry", type: "varchar(2000)", remarks: "所属行业")
            column(name: "capital_contribution", type: "double", remarks: "出资金额（万元）")
            column(name: "stockholding_type", type: "varchar(2000)", remarks: "出资方式")
            column(name: "stockholding_ratio", type: "double", remarks: "股权比例（%）")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_TENANT_STOCK_STRUCTURE", indexName: "PRJ_TENANT_STOCK_STRUCTURE_N1") {
            column(name: "bp_report_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_STOCK_HOLDING") {
        createTable(tableName: "PRJ_TENANT_STOCK_HOLDING", remarks: "承租人股权结构-控股情况") {
            column(name: "holding_id", type: "bigint(20)", remarks: "控股ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_STOCK_HOLDING_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "项目承租人表id")
            column(name: "holding company", type: "varchar(2000)", remarks: "控股公司名称")
            column(name: "industry", type: "varchar(2000)", remarks: "所属行业")
            column(name: "registered_capital", type: "double", remarks: "注册资本（万元）")
            column(name: "stockholding_ratio", type: "double", remarks: "承租人控股比例（%）")
            column(name: "asset_size", type: "double", remarks: "最近年度资产规模（万元）")
            column(name: "total_profit", type: "double", remarks: "利润总额（万元）")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_TENANT_STOCK_HOLDING", indexName: "PRJ_TENANT_STOCK_HOLDING_N1") {
            column(name: "bp_report_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_SUPPLIER") {
        createTable(tableName: "PRJ_TENANT_SUPPLIER", remarks: "承租人经营情况-前五大供应商") {
            column(name: "supplier_id", type: "bigint(20)", remarks: "供应商ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_SUPPLIER_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "项目承租人表id")
            column(name: "vender_name", type: "varchar(2000)", remarks: "供应商名称")
            column(name: "purchase_amount", type: "double", remarks: "采购量（万元）")
            column(name: "purchase_percentage", type: "double", remarks: "占总采购量比例%")
            column(name: "payment_way", type: "varchar(2000)", remarks: "结算方式")
            column(name: "relation", type: "varchar(2000)", remarks: "关联关系")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_TENANT_SUPPLIER", indexName: "PRJ_TENANT_SUPPLIER_N1") {
            column(name: "bp_report_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_SALES_CUSTOMER") {
        createTable(tableName: "PRJ_TENANT_SALES_CUSTOMER", remarks: "承租人经营情况-前五大销售客户") {
            column(name: "customer_id", type: "bigint(20)", remarks: "客户ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_SALES_CUSTOMER_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "项目承租人表id")
            column(name: "sale_customer_name", type: "varchar(2000)", remarks: "销售客户名称")
            column(name: "sale_quantity", type: "double", remarks: "销售量（万元）")
            column(name: "sale_percentage", type: "double", remarks: "占总销售量比例%")
            column(name: "sale_payment_way", type: "varchar(2000)", remarks: "结算方式")
            column(name: "sale_relation", type: "varchar(2000)", remarks: "关联关系")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "PRJ_TENANT_SALES_CUSTOMER", indexName: "PRJ_TENANT_SALES_CUSTOMER_N1") {
            column(name: "bp_report_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_PRICE_LIST_CONFIG_HD") {
        createTable(tableName: "HLS_PRICE_LIST_CONFIG_HD", remarks: "价目表配置头") {
            column(name: "CONFIG_HD_ID", type: "bigint(20)", remarks: "配置头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_PRICE_LIST_CONFIG_HD_PK")
            }
            column(name: "PRICE_LIST", type: "varchar(100)", remarks: "价目表ID") { constraints(nullable: "false") }
            column(name: "TABLE_NAME", type: "varchar(100)", remarks: "保存到数据库表名") { constraints(nullable: "false") }
            column(name: "TABLE_TYPE", type: "varchar(100)", remarks: "保存到数据库表类型(single/multi-line)（syscode：HLS.PRICE_LIST_DB_TABLE_TYPE)")
            column(name: "MULTI_LINE_FROM", type: "bigint(20)", remarks: "多行范围从")
            column(name: "MULTI_LINE_TO", type: "bigint(20)", remarks: "多行范围到")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_PRICE_LIST_CONFIG_HD", columnNames: "PRICE_LIST,TABLE_NAME", constraintName: "HLS_PRICE_LIST_CONFIG_HD_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_PRICE_LIST_CONFIG_LN") {
        createTable(tableName: "HLS_PRICE_LIST_CONFIG_LN", remarks: "价目表配置行") {
            column(name: "CONFIG_LN_ID", type: "bigint(20)", remarks: "配置行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_PRICE_LIST_CONFIG_LN_PK")
            }
            column(name: "CONFIG_HD_ID", type: "double(20)", remarks: "配置头ID") { constraints(nullable: "false") }
            column(name: "COLUMN_NAME", type: "varchar(100)", remarks: "保存到数据库字段名") { constraints(nullable: "false") }
            column(name: "COLUMN_CODE", type: "varchar(100)", remarks: "Excel中的字段编号（单行的需写全行和列，例C10；多行的只需写列，例C）")
            column(name: "COLUMN_TYPE", type: "varchar(100)", remarks: "保存到数据库字段类型(syscode：SYS.DB_COLUMN_TYPE)")
            column(name: "VALIDATE_TYPE", type: "varchar(100)", remarks: "验证方式(syscode：HLS.PRICE_LIST_COLUMN_VALIDATE_TYPE)")
            column(name: "VALIDATE_SQL", type: "varchar(2000)", remarks: "验证sql")
            column(name: "CASHFLOW_ITEM", type: "varchar(100)", remarks: "对应现金流项目")
            column(name: "prompt", type: "varchar(2000)", remarks: "字段描述")
            column(name: "precisions", type: "bigint(20)", remarks: "精度")
            column(name: "net_column_code", type: "varchar(100)", remarks: "现金流不含税对应excelExcel中的字段编号（单行的需写全行和列，例C10；多行的只需写列，例C）")
            column(name: "vat_column_code", type: "varchar(100)", remarks: "现金流税额对应excelExcel中的字段编号（单行的需写全行和列，例C10；多行的只需写列，例C）")
            column(name: "formula_no_check_flag", type: "varchar(1)", remarks: "忽略公式修改校验标志，默认为N", defaultValue: "N")
            column(name: "hide_column_flag", type: "varchar(1)", remarks: "行隐藏", defaultValue: "N")
            column(name: "hide_row_flag", type: "varchar(1)", remarks: "列隐藏", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_PRICE_LIST_CONFIG_LN", columnNames: "CONFIG_HD_ID,COLUMN_NAME", constraintName: "HLS_PRICE_LIST_CONFIG_LN_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT") {
        createTable(tableName: "CON_CONTRACT", remarks: "租赁合同表") {
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID")
            column(name: "quotation_id", type: "bigint(20)", remarks: "报价ID")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式")
            column(name: "contract_number", type: "varchar(100)", remarks: "合同编号")
            column(name: "contract_name", type: "varchar(500)", remarks: "合同名称")
            column(name: "contract_status", type: "varchar(100)", remarks: "合同状态")
            column(name: "lease_channel", type: "varchar(100)", remarks: "商业模式")
            column(name: "division", type: "varchar(100)", remarks: "产品线")
            column(name: "authority_rule_string", type: "varchar(255)", remarks: "授权规则字符串")
            column(name: "sign_date", type: "datetime", remarks: "签约日")
            column(name: "inception_of_lease", type: "datetime", remarks: "起租日")
            column(name: "employee_id", type: "datetime(20)", remarks: "业务员（用户id）")
            column(name: "unit_id", type: "datetime(20)", remarks: "部门id")
            column(name: "lease_start_date", type: "datetime", remarks: "租赁期开始日")
            column(name: "first_pay_date", type: "datetime", remarks: "首次支付日")
            column(name: "last_pay_date", type: "datetime", remarks: "末次支付日")
            column(name: "lease_end_date", type: "datetime", remarks: "租赁到期日（租赁期结束日）")
            column(name: "original_recall_date", type: "datetime", remarks: "合同正本回收日")
            column(name: "lease_card_recall_date", type: "datetime", remarks: "承租证回收日")
            column(name: "early_termination_date", type: "datetime", remarks: "提起结清日")
            column(name: "termination_date", type: "datetime", remarks: "合同结清日")
            column(name: "assignment_date", type: "datetime", remarks: "所有权转让日")
            column(name: "lease_times", type: "bigint(20)", remarks: "租赁期数")
            column(name: "annual_pay_times", type: "bigint(20)", remarks: "支付频率（年）")
            column(name: "lease_term", type: "double", remarks: "租赁期限")
            column(name: "pay_type", type: "bigint(20)", remarks: "支付类型（1/先付;0/后付）")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "tax_type_id", type: "bigint(20)", remarks: "税种id")
            column(name: "vat_flag", type: "varchar(1)", remarks: "增值税标志")
            column(name: "vat_rate", type: "double", remarks: "增值税率")
            column(name: "lease_item_amount", type: "double", remarks: "租赁资产总价款")
            column(name: "vat_input", type: "double", remarks: "进项增值税额")
            column(name: "vat_input_tax_type_id", type: "bigint(20)", remarks: "进项税税种")
            column(name: "vat_input_tax_type_rate", type: "double", remarks: "进项税税率")
            column(name: "down_payment_ratio", type: "double", remarks: "首期租金比例/首付比例")
            column(name: "down_payment", type: "double", remarks: "首期租金/首付金额")
            column(name: "net_down_payment", type: "double", remarks: "不含税首付金额")
            column(name: "vat_down_payment", type: "double", remarks: "首付款税额")
            column(name: "finance_amount", type: "double", remarks: "融资额 （租赁资产总价款 - 首付款，即租赁本金）")
            column(name: "net_finance_amount", type: "double", remarks: "不含税融资额")
            column(name: "vat_finance_amount", type: "double", remarks: "融资额增值税")
            column(name: "total_rental", type: "double", remarks: "租金总额")
            column(name: "net_total_rental", type: "double", remarks: "不含税租金")
            column(name: "vat_total_rental", type: "double", remarks: "租金增值税额")
            column(name: "total_interest", type: "double", remarks: "利息总额")
            column(name: "net_total_interest", type: "double", remarks: "不含税利息")
            column(name: "vat_total_interest", type: "double", remarks: "利息增值税额")
            column(name: "lease_charge_ratio", type: "double", remarks: "手续费比例")
            column(name: "lease_charge", type: "double", remarks: "手续费")
            column(name: "net_lease_charge", type: "double", remarks: "不含税手续费")
            column(name: "vat_lease_charge", type: "double", remarks: "手续费税额")
            column(name: "lease_mgt_fee_ratio", type: "double", remarks: "管理费比例")
            column(name: "lease_mgt_fee", type: "double", remarks: "管理费")
            column(name: "net_lease_mgt_fee", type: "double", remarks: "不含税管理费")
            column(name: "vat_lease_mgt_fee", type: "double", remarks: "管理费税额")
            column(name: "lease_mgt_fee_rule", type: "varchar(100)", remarks: "管理费计算方式")
            column(name: "deposit_ratio", type: "double", remarks: "保证金比例")
            column(name: "deposit", type: "double", remarks: "保证金")
            column(name: "deposit_deduction", type: "varchar(100)", remarks: "保证金抵扣方式")
            column(name: "residual_ratio", type: "double", remarks: "留购价款")
            column(name: "residual_value", type: "double", remarks: "留购价款")
            column(name: "net_residual_value", type: "double", remarks: "不含税留购金")
            column(name: "vat_residual_value", type: "double", remarks: "留购金税额")
            column(name: "balloon_ratio", type: "double", remarks: "末期租金比例")
            column(name: "balloon", type: "double", remarks: "末期租金")
            column(name: "net_balloon", type: "double", remarks: "不含税末期租金")
            column(name: "vat_balloon", type: "double", remarks: "末期租金税额")
            column(name: "base_rate_type", type: "varchar(100)", remarks: " 基准利率类别：pboc央行基准、libor伦敦同业")
            column(name: "base_rate", type: "double", remarks: "基准利率")
            column(name: "int_rate", type: "double", remarks: "租赁利率")
            column(name: "int_rate_implicit", type: "double", remarks: "租赁利率（实际）")
            column(name: "int_rate_type", type: "double", remarks: "利率类型：浮动/floating; 固定/fixed(syscode:CON.INT_RATE_TYPE)")
            column(name: "irr", type: "double", remarks: "内部收益率")
            column(name: "irr_after_tax", type: "double", remarks: "税后内部收益率")
            column(name: "pmt", type: "double", remarks: "等额本息租金")
            column(name: "pmt_first", type: "double", remarks: "等额本息租金（首期）")
            column(name: "annual_mean_rate", type: "double", remarks: "表面利率、平息率")
            column(name: "received_status", type: "varchar(100)", remarks: "回款状态（not/partial/full）（syscode:CON.CONTRACT_RECEIVED_STATUS)")
            column(name: "overdue_status", type: "varchar(100)", remarks: "逾期状态（n 未逾期、y 已逾期）（syscode：CON.CONTRACT_OVERDUE_STATUS）")
            column(name: "billing_method", type: "varchar(100)", remarks: "开票方式")
            column(name: "billing_status", type: "varchar(100)", remarks: "开票状态（not/partial/full）（syscode：CON.CONTRACT_BILLING_STATUS）")
            column(name: "biz_day_convention", type: "varchar(100)", remarks: "非工作日调整")
            column(name: "penalty_profile", type: "varchar(100)", remarks: "迟延履行金规则")
            column(name: "bp_account_id", type: "bigint(20)", remarks: "商业伙伴扣款id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT", indexName: "CON_CONTRACT_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "project_id", type: "bigint(20)")
            column(name: "quotation_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_CONTRACT", indexName: "CON_CONTRACT_N2") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "contract_number", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT", indexName: "CON_CONTRACT_N3") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "contract_status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT", indexName: "CON_CONTRACT_N5") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "authority_rule_string", type: "varchar(255)")
        }
        createIndex(tableName: "CON_CONTRACT", indexName: "CON_CONTRACT_N6") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "employee_id", type: "datetime(20)")
            column(name: "unit_id", type: "datetime(20)")
        }
        createIndex(tableName: "CON_CONTRACT", indexName: "CON_CONTRACT_N4") {
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
            column(name: "lease_channel", type: "varchar(100)")
            column(name: "division", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_CASHFLOW") {
        createTable(tableName: "CON_CONTRACT_CASHFLOW", remarks: "合同现金流表") {
            column(name: "cashflow_id", type: "bigint(20)", remarks: "现金流ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_CASHFLOW_PK")
            }
            column(name: "contract_id", type: "double(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "cf_item", type: "varchar(100)", remarks: "现金流项目") { constraints(nullable: "false") }
            column(name: "cf_type", type: "varchar(100)", remarks: "现金流类型")
            column(name: "cf_direction", type: "varchar(100)", remarks: "现金流方向（INFLOW/OUTFLOW）")
            column(name: "cf_status", type: "varchar(100)", remarks: "现金流状态（BLOCK/冻结 、RELEASE/下达、CANCEL/取消） （syscode：HLS.CASHFLOW_STATUS）")
            column(name: "times", type: "bigint(20)", remarks: "期数")
            column(name: "due_date", type: "datetime", remarks: "支付日/到期日")
            column(name: "fin_income_date", type: "datetime", remarks: "收入确认日")
            column(name: "due_amount", type: "double", remarks: "应收金额")
            column(name: "net_due_amount", type: "double", remarks: "不含税应收金额")
            column(name: "vat_due_amount", type: "double", remarks: "增值税额")
            column(name: "principal", type: "double", remarks: "应收本金")
            column(name: "net_principal", type: "double", remarks: "不含税应收本金")
            column(name: "vat_principal", type: "double", remarks: "本金增值税额")
            column(name: "interest", type: "double", remarks: "应收利息")
            column(name: "net_interest", type: "double", remarks: "不含税应收利息")
            column(name: "vat_interest", type: "double", remarks: "利息增值税额")
            column(name: "write_off_flag", type: "double", remarks: "核销标志（NOT/PARTIAL/FULL/NA）(syscode:CON.CASHFLOW_WRITE_OFF_FLAG) ")
            column(name: "received_amount", type: "double", remarks: "已收金额")
            column(name: "received_principal", type: "double", remarks: "已收本金")
            column(name: "received_interest", type: "double", remarks: "已收利息")
            column(name: "outstanding_rental", type: "double", remarks: "当期剩余租金")
            column(name: "outstanding_principal", type: "double", remarks: "当期剩余本金")
            column(name: "outstanding_interest", type: "double", remarks: "当期剩余利息")
            column(name: "interest_accrual_balance", type: "double", remarks: "当期计息余额")
            column(name: "accumulated_unpaid_interest", type: "double", remarks: "累计未偿还利息")
            column(name: "last_received_date", type: "datetime", remarks: "最后收款日")
            column(name: "full_write_off_date", type: "datetime", remarks: "完全核销日")
            column(name: "penalty_process_status", type: "varchar(100)", remarks: "罚金处理状态（NORMAL 正常/SUSPEND 暂停计算/EXEMPT 豁免） （syscode：CON.PENALTY_PROCESS_STATUS）")
            column(name: "billing_status", type: "varchar(100)", remarks: "开票状态（NOT/PARTIAL/FULL） (SYSCODE:CON.CONTRACT_BILLING_STATUS)")
            column(name: "billing_amount", type: "double", remarks: "开票金额")
            column(name: "billing_principal", type: "double", remarks: "开票本金")
            column(name: "billing_interest", type: "double", remarks: "开票利息")
            column(name: "payment_bp_id", type: "bigint(20)", remarks: "付款商业伙伴ID")
            column(name: "overdue_status", type: "varchar(100)", remarks: "逾期状态（n 未逾期、y 已逾期）（syscode：CON.CONTRACT_OVERDUE_STATUS）")
            column(name: "generated_source", type: "varchar(100)", remarks: "创建来源")
            column(name: "generated_source_doc_id", type: "bigint(20)", remarks: "来源单据id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_CASHFLOW", indexName: "CON_CONTRACT_CASHFLOW_N1") {
            column(name: "contract_id", type: "double(20)")
            column(name: "cf_item", type: "varchar(100)")
            column(name: "cf_type", type: "varchar(100)")
            column(name: "cf_status", type: "varchar(100)")
            column(name: "times", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_TENANT") {
        createTable(tableName: "CON_CONTRACT_TENANT", remarks: "合同承租人表") {
            column(name: "contract_tenant_id", type: "bigint(20)", remarks: "合同承租人ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_TENANT_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "tenant_bp_id", type: "bigint(20)", remarks: "承租人商业伙伴ID") { constraints(nullable: "false") }
            column(name: "tenant_bp_type", type: "varchar(100)", remarks: "承租人商业伙伴类型")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_TENANT", columnNames: "contract_id,tenant_bp_id", constraintName: "CON_CONTRACT_TENANT_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_GUARANTOR") {
        createTable(tableName: "CON_CONTRACT_GUARANTOR", remarks: "合同担保人表") {
            column(name: "contract_guarantor_id", type: "bigint(20)", remarks: "合同担保人ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_GUARANTOR_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "guarantor_bp_id", type: "bigint(20)", remarks: "担保人商业伙伴ID") { constraints(nullable: "false") }
            column(name: "guarantee_type", type: "varchar(100)", remarks: "担保类型")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_GUARANTOR", columnNames: "contract_id,guarantor_bp_id", constraintName: "CON_CONTRACT_GUARANTOR_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_LEASE_ITEM") {
        createTable(tableName: "CON_CONTRACT_LEASE_ITEM", remarks: "合同租赁物表") {
            column(name: "contract_lease_item_id", type: "bigint(20)", remarks: "合同租赁物ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_LEASE_ITEM_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "seq_number", type: "bigint(20)", remarks: "合同租赁物序号") { constraints(nullable: "false") }
            column(name: "lease_item_name", type: "varchar(2000)", remarks: "租赁物名称")
            column(name: "serial_number", type: "varchar(2000)", remarks: "租赁物序列号")
            column(name: "pattern", type: "varchar(2000)", remarks: "型号")
            column(name: "specification", type: "varchar(2000)", remarks: "规格")
            column(name: "colour", type: "varchar(2000)", remarks: "颜色")
            column(name: "quantity", type: "double", remarks: "数量")
            column(name: "uom", type: "varchar(100)", remarks: "单位")
            column(name: "price", type: "varchar(2000)", remarks: "单价")
            column(name: "lease_item_amount", type: "double", remarks: "租赁物金额")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "vender_bp_id", type: "bigint(20)", remarks: "供应商商业伙伴ID")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_LEASE_ITEM", columnNames: "contract_id,seq_number", constraintName: "CON_CONTRACT_LEASE_ITEM_U1")

        createIndex(tableName: "CON_CONTRACT_LEASE_ITEM", indexName: "CON_CONTRACT_LEASE_ITEM_N1") {
            column(name: "contract_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_MORTGAGE") {
        createTable(tableName: "CON_CONTRACT_MORTGAGE", remarks: "合同抵质押表") {
            column(name: "contract_mortgage_id", type: "bigint(20)", remarks: "合同抵质押ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_MORTGAGE_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "seq_number", type: "bigint(20)", remarks: "合同抵质押物序号") { constraints(nullable: "false") }
            column(name: "mortgage_name", type: "varchar(2000)", remarks: "抵押物名称")
            column(name: "mortgage_type", type: "varchar(100)", remarks: "抵押类型（抵押mortgage /质押 pledge）（syscode：HLS.MORTGAGE_TYPE）")
            column(name: "mortgage_ast_classfication", type: "varchar(100)", remarks: "抵押物分类（动产（质押）/动产（抵押）/权利/不动产）（syscode：HLS.MORTGAGE_AST_CLASSFICATION)")
            column(name: "mortgage_ast_detail", type: "varchar(100)", remarks: "明细分类（汇票/债券/基金份额/股权/一般动产/特殊动产-车辆/特殊动产-船舶/特殊动产-航天器/土地/房屋） (syscode:HLS.MORTGAGE_AST_DETAIL)")
            column(name: "mortgage_contract_no", type: "varchar(2000)", remarks: "抵押合同编号 ")
            column(name: "mortgage_register_no", type: "varchar(2000)", remarks: "抵押物登记证号")
            column(name: "mortgage_registed_dept", type: "varchar(2000)", remarks: "抵押登记部门")
            column(name: "mortgagor_bp_id", type: "bigint(20)", remarks: "抵押人商业伙伴ID")
            column(name: "mortgage_value", type: "double", remarks: "抵押物价值")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "uom", type: "varchar(100)", remarks: "单位")
            column(name: "quantity", type: "double", remarks: "数量")
            column(name: "start_date", type: "datetime", remarks: "抵押开始日期")
            column(name: "end_date", type: "datetime", remarks: "抵押结束日期")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_MORTGAGE", columnNames: "contract_id,seq_number", constraintName: "CON_CONTRACT_MORTGAGE_U1")

        createIndex(tableName: "CON_CONTRACT_MORTGAGE", indexName: "CON_CONTRACT_MORTGAGE_N1") {
            column(name: "contract_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_SIGN") {
        createTable(tableName: "CON_CONTRACT_SIGN", remarks: "合同签约表") {
            column(name: "contract_sign_id", type: "bigint(20)", remarks: "合同签约ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_SIGN_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "status", type: "varchar(100)", remarks: "状态(SYSCODE:CON.CONTRACT_PROCESS_STATUS)")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "sign_date", type: "datetime", remarks: "签约日")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_SIGN", indexName: "CON_CONTRACT_SIGN_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_SIGN", indexName: "CON_CONTRACT_SIGN_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_INCEPT") {
        createTable(tableName: "CON_CONTRACT_INCEPT", remarks: "合同起租表") {
            column(name: "contract_incept_id", type: "bigint(20)", remarks: "合同起租ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_INCEPT_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "status", type: "varchar(100)", remarks: "状态(SYSCODE:CON.CONTRACT_PROCESS_STATUS)")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "inception_of_lease", type: "datetime", remarks: "起租日")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_INCEPT", indexName: "CON_CONTRACT_INCEPT_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_INCEPT", indexName: "CON_CONTRACT_INCEPT_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_CHANGE_REQ") {
        createTable(tableName: "CON_CONTRACT_CHANGE_REQ", remarks: "合同变更表") {
            column(name: "change_req_id", type: "bigint(20)", remarks: "合同变更ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_CHANGE_REQ_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "status", type: "varchar(100)", remarks: "状态(SYSCODE:CON.CONTRACT_PROCESS_STATUS)")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "change_req_date", type: "datetime", remarks: "申请日期")
            column(name: "change_req_user_id", type: "bigint(20)", remarks: "申请人ID")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式")
            column(name: "change_req_number", type: "varchar(100)", remarks: "申请单号")
            column(name: "early_termination_flag", type: "varchar(1)", remarks: "变更-提前结清", defaultValue: "N")
            column(name: "change_cashflow_flag", type: "varchar(1)", remarks: "变更-还款计划", defaultValue: "N")
            column(name: "change_tenant_flag", type: "varchar(1)", remarks: "变更-承租人", defaultValue: "N")
            column(name: "change_guarantor_flag", type: "varchar(1)", remarks: "变更-担保人", defaultValue: "N")
            column(name: "change_lease_item_flag", type: "varchar(1)", remarks: "变更-租赁物", defaultValue: "N")
            column(name: "change_contract_text_flag", type: "varchar(1)", remarks: "变更-合同文件", defaultValue: "N")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_CHANGE_REQ", indexName: "CON_CONTRACT_CHANGE_REQ_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_CHANGE_REQ", indexName: "CON_CONTRACT_CHANGE_REQ_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_CANCEL") {
        createTable(tableName: "CON_CONTRACT_CANCEL", remarks: "合同撤销表") {
            column(name: "contract_cancel_id", type: "bigint(20)", remarks: "合同撤销ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_CANCEL_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "status", type: "varchar(100)", remarks: "状态(SYSCODE:CON.CONTRACT_PROCESS_STATUS)")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "cancel_date", type: "datetime", remarks: "撤销日")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_CANCEL", indexName: "CON_CONTRACT_CANCEL_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_CANCEL", indexName: "CON_CONTRACT_CANCEL_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_TERMINATION") {
        createTable(tableName: "CON_CONTRACT_TERMINATION", remarks: "合同结清表") {
            column(name: "contract_termination_id", type: "bigint(20)", remarks: "合同起租ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_TERMINATION_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "status", type: "varchar(100)", remarks: "状态(SYSCODE:CON.CONTRACT_PROCESS_STATUS)")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "termination_date", type: "datetime", remarks: "结清日")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_TERMINATION", indexName: "CON_CONTRACT_TERMINATION_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_TERMINATION", indexName: "CON_CONTRACT_TERMINATION_N2") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_ATTACHMENT") {
        createTable(tableName: "CON_CONTRACT_ATTACHMENT", remarks: "合同附件表") {
            column(name: "contract_attachment_id", type: "bigint(20)", remarks: "合同附件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_ATTACHMENT_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "source_type", type: "varchar(100)", remarks: "合同附件类别(syscode:CON.CONTRACT_ATTACHMENT_SOURCE_TYPE)（DOC_FILE/MANUAL）")
            column(name: "source_id", type: "bigint(20)", remarks: "如来源DOC_FLIE,则记录原始模板id")
            column(name: "bp_category", type: "varchar(100)", remarks: "文档签约对象类别")
            column(name: "bp_id", type: "bigint(20)", remarks: "文档签约对象ID")
            column(name: "document_name", type: "varchar(2000)", remarks: "文档名称")
            column(name: "description", type: "varchar(2000)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_ATTACHMENT", indexName: "CON_CONTRACT_ATTACHMENT_N1") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "source_type", type: "varchar(100)")
            column(name: "source_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_CONTRACT_ATTACHMENT", indexName: "CON_CONTRACT_ATTACHMENT_N2") {
            column(name: "bp_category", type: "varchar(100)")
            column(name: "bp_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_COLLECTION") {
        createTable(tableName: "CON_CONTRACT_COLLECTION", remarks: "合同催收表") {
            column(name: "contract_collection_id", type: "bigint(20)", remarks: "催收记录ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_COLLECTION_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "collection_date", type: "datetime", remarks: "催收日期")
            column(name: "collection_type", type: "varchar(100)", remarks: "催收方式(syscode:CON.CONTRACT_COLLECTION_TYPE)")
            column(name: "collection_result", type: "varchar(2000)", remarks: "催收结果")
            column(name: "collection_user_id", type: "bigint(20)", remarks: "催收人")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_CONTRACT_COLLECTION", indexName: "CON_CONTRACT_COLLECTION_N1") {
            column(name: "contract_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_CONTRACT_COLLECTION", indexName: "CON_CONTRACT_COLLECTION_N3") {
            column(name: "collection_date", type: "datetime")
        }
        createIndex(tableName: "CON_CONTRACT_COLLECTION", indexName: "CON_CONTRACT_COLLECTION_N2") {
            column(name: "collection_user_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_ET") {
        createTable(tableName: "CON_CONTRACT_ET", remarks: "合同提前结清表") {
            column(name: "contract_et_id", type: "bigint(20)", remarks: "合同提前结清ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_ET_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID")
            column(name: "change_req_id", type: "bigint(20)", remarks: "变更申请ID")
            column(name: "et_date", type: "datetime", remarks: "提前结清日")
            column(name: "et_description", type: "varchar(2000)", remarks: "提前结清说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_ET", columnNames: "change_req_id", constraintName: "CON_CONTRACT_ET_U1")

        createIndex(tableName: "CON_CONTRACT_ET", indexName: "CON_CONTRACT_ET_N1") {
            column(name: "contract_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_DEBT_EXEMPTION_REQ") {
        createTable(tableName: "CON_DEBT_EXEMPTION_REQ", remarks: "债务减免申请头表") {
            column(name: "change_req_id", type: "bigint(20)", remarks: "债务免除申请ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_DEBT_EXEMPTION_REQ_PK")
            }
            column(name: "change_req_number", type: "varchar(100)", remarks: "债务免除申请编号")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类别")
            column(name: "company_id", type: "bigint(20)", remarks: "公司id")
            column(name: "req_status", type: "varchar(100)", remarks: "申请状态", defaultValue: "NEW")
            column(name: "req_date", type: "datetime", remarks: "申请日期")
            column(name: "req_user_id", type: "bigint(20)", remarks: "申请人ID")
            column(name: "description", type: "varchar(2000)", remarks: "申请原因")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CON_DEBT_EXEMPTION_REQ", indexName: "CON_DEBT_EXEMPTION_REQ_N1") {
            column(name: "change_req_number", type: "varchar(100)")
            column(name: "company_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_DEBT_EXEMPTION_REQ", indexName: "CON_DEBT_EXEMPTION_REQ_N2") {
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
        }
        createIndex(tableName: "CON_DEBT_EXEMPTION_REQ", indexName: "CON_DEBT_EXEMPTION_REQ_N3") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "req_status", type: "varchar(100)")
            column(name: "req_date", type: "datetime")
            column(name: "req_user_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_DEBT_EXEMPTION_REQ", indexName: "CON_DEBT_EXEMPTION_REQ_N4") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_DEBT_EXEMPTION_REQ_CF") {
        createTable(tableName: "CON_DEBT_EXEMPTION_REQ_CF", remarks: "债务减免申请行表") {
            column(name: "change_req_cf_id", type: "bigint(20)", remarks: "债务免除申请行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_DEBT_EXEMPTION_REQ_CF_PK")
            }
            column(name: "change_req_id", type: "bigint(20)", remarks: "债务免除申请ID") { constraints(nullable: "false") }
            column(name: "cashflow_id", type: "bigint(20)", remarks: "需减免的现金流ID")
            column(name: "contract_id", type: "bigint(20)", remarks: "需减免的合同ID")
            column(name: "cf_item", type: "varchar(100)", remarks: "需减免的现金流项目")
            column(name: "cf_type", type: "varchar(100)", remarks: "需减免的现金流类型")
            column(name: "cf_direction", type: "varchar(100)", remarks: "需减免的现金流方向")
            column(name: "cf_status", type: "varchar(100)", remarks: "需减免的现金流状态")
            column(name: "times", type: "bigint(20)", remarks: "需减免的现金流期数")
            column(name: "due_date", type: "datetime", remarks: "需减免的现金流应收日期")
            column(name: "due_amount", type: "double", remarks: "需减免的现金流金额")
            column(name: "principal", type: "double", remarks: "需减免的现金流本金")
            column(name: "interest", type: "double", remarks: "需减免的现金流利息")
            column(name: "exemption_amount", type: "double", remarks: "减免金额")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_DEBT_EXEMPTION_REQ_CF", columnNames: "change_req_id,cashflow_id", constraintName: "CON_DEBT_EXEMPTION_REQ_CF_U1")

        createIndex(tableName: "CON_DEBT_EXEMPTION_REQ_CF", indexName: "CON_DEBT_EXEMPTION_REQ_CF_N1") {
            column(name: "change_req_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_DEBT_EXEMPTION_REQ_CF", indexName: "CON_DEBT_EXEMPTION_REQ_CF_N2") {
            column(name: "cashflow_id", type: "bigint(20)")
            column(name: "contract_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_BANK") {
        createTable(tableName: "CSH_BANK", remarks: "银行表") {
            column(name: "bank_id", type: "bigint(20)", remarks: "银行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_BANK_PK")
            }
            column(name: "bank_code", type: "varchar(100)", remarks: "银行代码") { constraints(nullable: "false") }
            column(name: "bank_name", type: "varchar(2000)", remarks: "银行名称")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CSH_BANK", columnNames: "bank_code", constraintName: "CSH_BANK_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_BANK_ACCOUNT") {
        createTable(tableName: "CSH_BANK_ACCOUNT", remarks: "银行账户表") {
            column(name: "bank_account_id", type: "bigint(20)", remarks: "银行账户ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_BANK_ACCOUNT_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "bank_id", type: "bigint(20)", remarks: "银行ID") { constraints(nullable: "false") }
            column(name: "bank_branch_name", type: "varchar(2000)", remarks: "分行名称")
            column(name: "bank_account_num", type: "varchar(100)", remarks: "账户号")
            column(name: "bank_account_name", type: "varchar(2000)", remarks: "账户名")
            column(name: "bank_account_type", type: "varchar(100)", remarks: "账户类型(syscode：CSH.BANK_ACCOUNT_TYPE)")
            column(name: "gld_account_code", type: "varchar(100)", remarks: "银行科目代码")
            column(name: "currency", type: "varchar(100)", remarks: "账户币种")
            column(name: "bank_color", type: "varchar(100)", remarks: "")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CSH_BANK_ACCOUNT", columnNames: "company_id,bank_id,bank_account_num", constraintName: "CSH_BANK_ACCOUNT_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_TRANSACTION") {
        createTable(tableName: "CSH_TRANSACTION", remarks: "现金事务表") {
            column(name: "transaction_id", type: "bigint(20)", remarks: "现金事务ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_TRANSACTION_PK")
            }
            column(name: "transaction_num", type: "varchar(100)", remarks: "现金事务编号")
            column(name: "transaction_category", type: "varchar(100)", remarks: "现金事务类别,即DOCUMENT_CATEGORY，固定插入CSH_TRANSACTION")
            column(name: "transaction_type", type: "varchar(100)", remarks: "现金事务类型,即DOCUMENT_TYPE")
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式(RECEIPT，PAYMENT，ADVANCE_RECEIPT，PREPAYMENT，DEDUCTION，DEPOSIT）")
            column(name: "transaction_date", type: "datetime", remarks: "事务日期")
            column(name: "penalty_calc_date", type: "datetime", remarks: "罚息计算日（缺省同transaction_date)")
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "transaction_amount", type: "double", remarks: "事务金额")
            column(name: "currency_code", type: "varchar(100)", remarks: "币种")
            column(name: "payment_method", type: "varchar(100)", remarks: "付款方式(syscode:CSH.PAYMENT_METHOD)")
            column(name: "bank_slip_num", type: "varchar(100)", remarks: "银行流水单号")
            column(name: "bank_account_id", type: "bigint(20)", remarks: "本方银行账户ID")
            column(name: "bp_id", type: "bigint(20)", remarks: "对方商业伙伴ID")
            column(name: "bp_bank_account_id", type: "bigint(20)", remarks: "对方银行账户ID")
            column(name: "bp_bank_name", type: "varchar(255)", remarks: "对方银行")
            column(name: "bp_bank_branch_name", type: "varchar(255)", remarks: "对方银行分行名")
            column(name: "bp_bank_account_num", type: "varchar(100)", remarks: "对方银行账户号")
            column(name: "bp_bank_account_name", type: "varchar(100)", remarks: "对方银行账户名")
            column(name: "reversed_flag", type: "varchar(1)", remarks: "反冲标志（N 未反冲/W 被反冲/R 反冲交易） ")
            column(name: "reversed_trx_id", type: "bigint(20)", remarks: "反冲的现金事务事务id（互记） ")
            column(name: "reversed_date", type: "datetime", remarks: "反冲日期")
            column(name: "posted_flag", type: "varchar(1)", remarks: "已确认标志")
            column(name: "contract_id", type: "bigint(20)", remarks: "租赁合同ID")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "handling_charge", type: "double", remarks: "手续费")
            column(name: "write_off_flag", type: "varchar(100)", remarks: "核销标志（NA/NOT/PARTIAL/FULL） ")
            column(name: "write_off_amount", type: "double", remarks: "核销金额")
            column(name: "full_write_off_date", type: "datetime", remarks: "完全核销日期")
            column(name: "source_doc_category", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "source_doc_id", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "source_doc_line_id", type: "bigint(20)", remarks: "来源单据行ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CSH_TRANSACTION", indexName: "CSH_TRANSACTION_N1") {
            column(name: "transaction_num", type: "varchar(100)")
        }
        createIndex(tableName: "CSH_TRANSACTION", indexName: "CSH_TRANSACTION_N2") {
            column(name: "transaction_category", type: "varchar(100)")
            column(name: "transaction_type", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
            column(name: "company_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_TRANSACTION", indexName: "CSH_TRANSACTION_N3") {
            column(name: "transaction_date", type: "datetime")
            column(name: "company_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_TRANSACTION", indexName: "CSH_TRANSACTION_N5") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "bp_id", type: "bigint(20)")
            column(name: "bp_bank_account_id", type: "bigint(20)")
            column(name: "bp_bank_name", type: "varchar(2000)")
            column(name: "bp_bank_branch_name", type: "varchar(2000)")
            column(name: "bp_bank_account_num", type: "varchar(2000)")
            column(name: "bp_bank_account_name", type: "varchar(2000)")
        }
        createIndex(tableName: "CSH_TRANSACTION", indexName: "CSH_TRANSACTION_N4") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "bank_slip_num", type: "varchar(100)")
            column(name: "bank_account_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_WRITE_OFF") {
        createTable(tableName: "CSH_WRITE_OFF", remarks: "核销表") {
            column(name: "write_off_id", type: "bigint(20)", remarks: "核销ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_WRITE_OFF_PK")
            }
            column(name: "write_off_type", type: "varchar(100)", remarks: "核销类型（syscode：CSH.WRITE_OFF_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "write_off_date", type: "datetime", remarks: "核销日期") { constraints(nullable: "false") }
            column(name: "csh_transaction_id", type: "bigint(20)", remarks: "现金事务ID") { constraints(nullable: "false") }
            column(name: "csh_write_off_amount", type: "double", remarks: "现金事务核销金额")
            column(name: "subsequent_csh_trx_id", type: "bigint(20)", remarks: "后续现金事务ID")
            column(name: "subseq_csh_write_off_amount", type: "double", remarks: "后续现金事务核销金额")
            column(name: "reversed_flag", type: "varchar(1)", remarks: "反冲标志（N 未反冲/W 被反冲/R 反冲交易） ")
            column(name: "reversed_write_off_id", type: "bigint(20)", remarks: "反冲的核销事务id（互记） ")
            column(name: "reversed_date", type: "datetime", remarks: "反冲日期")
            column(name: "cashflow_id", type: "bigint(20)", remarks: "合同现金流ID")
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID")
            column(name: "times", type: "bigint(20)", remarks: "合同期数")
            column(name: "cf_item", type: "varchar(100)", remarks: "合同现金流项目")
            column(name: "cf_type", type: "varchar(100)", remarks: "合同现金流类型")
            column(name: "write_off_due_amount", type: "double", remarks: "核销金额")
            column(name: "write_off_principal", type: "double", remarks: "核销本金")
            column(name: "write_off_interest", type: "double", remarks: "核销利息")
            column(name: "payment_req_line_id", type: "bigint(20)", remarks: "付款申请行ID")
            column(name: "payment_req_id", type: "bigint(20)", remarks: "付款申请头ID")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CSH_WRITE_OFF", indexName: "CSH_WRITE_OFF_N1") {
            column(name: "csh_transaction_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_WRITE_OFF", indexName: "CSH_WRITE_OFF_N2") {
            column(name: "subsequent_csh_trx_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_WRITE_OFF", indexName: "CSH_WRITE_OFF_N3") {
            column(name: "reversed_write_off_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_WRITE_OFF", indexName: "CSH_WRITE_OFF_N4") {
            column(name: "cashflow_id", type: "bigint(20)")
            column(name: "contract_id", type: "bigint(20)")
            column(name: "times", type: "bigint(20)")
            column(name: "cf_item", type: "varchar(100)")
            column(name: "cf_type", type: "varchar(100)")
        }
        createIndex(tableName: "CSH_WRITE_OFF", indexName: "CSH_WRITE_OFF_N5") {
            column(name: "payment_req_line_id", type: "bigint(20)")
            column(name: "payment_req_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_PAYMENT_REQ_HD") {
        createTable(tableName: "CSH_PAYMENT_REQ_HD", remarks: "付款申请头表") {
            column(name: "payment_req_id", type: "bigint(20)", remarks: "付款申请头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_PAYMENT_REQ_HD_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单独类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式")
            column(name: "payment_req_number", type: "varchar(100)", remarks: "付款申请编号")
            column(name: "payment_req_date", type: "datetime", remarks: "付款申请日期")
            column(name: "payment_req_status", type: "varchar(100)", remarks: "付款申请状态（syscode:CSH.PAYMENT_REQ_STATUS)")
            column(name: "apply_pay_date", type: "datetime", remarks: "申请支付日期")
            column(name: "amount", type: "double", remarks: "申请总金额(自动汇总行金额)")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "process_instance_id", type: "bigint(20)", remarks: "工作流实例ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CSH_PAYMENT_REQ_HD", indexName: "CSH_PAYMENT_REQ_HD_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
            column(name: "business_type", type: "varchar(100)")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_HD", indexName: "CSH_PAYMENT_REQ_HD_N2") {
            column(name: "payment_req_number", type: "varchar(100)")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_HD", indexName: "CSH_PAYMENT_REQ_HD_N3") {
            column(name: "payment_req_date", type: "datetime")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_HD", indexName: "CSH_PAYMENT_REQ_HD_N4") {
            column(name: "payment_req_status", type: "varchar(100)")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_HD", indexName: "CSH_PAYMENT_REQ_HD_N5") {
            column(name: "apply_pay_date", type: "datetime")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_HD", indexName: "CSH_PAYMENT_REQ_HD_N6") {
            column(name: "process_instance_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_PAYMENT_REQ_LN") {
        createTable(tableName: "CSH_PAYMENT_REQ_LN", remarks: "付款申请行表") {
            column(name: "payment_req_ln_id", type: "bigint(20)", remarks: "付款申请行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_PAYMENT_REQ_LN_PK")
            }
            column(name: "payment_req_id", type: "bigint(20)", remarks: "付款申请头ID") { constraints(nullable: "false") }
            column(name: "source_doc_category", type: "varchar(100)", remarks: "付款来源单据类别")
            column(name: "source_doc_id", type: "bigint(20)", remarks: "付款来源单据ID")
            column(name: "source_doc_line_id", type: "bigint(20)", remarks: "付款来源单据行ID")
            column(name: "amount", type: "double", remarks: "申请金额")
            column(name: "amount_paid", type: "double", remarks: "已支付金额")
            column(name: "description", type: "varchar(2000)", remarks: "申请行说明")
            column(name: "payment_flag", type: "varchar(100)", remarks: "支付状态(syscode:CSH.PAYMENT_FLAG)")
            column(name: "payment_completed_date", type: "datetime", remarks: "完成支付时间")
            column(name: "payment_method", type: "varchar(100)", remarks: "付款方式(syscode:CSH.PAYMENT_METHOD)")
            column(name: "bp_id", type: "bigint(20)", remarks: "对方商业伙伴ID")
            column(name: "bp_bank_account_id", type: "bigint(20)", remarks: "对方银行账户ID")
            column(name: "bp_bank_name", type: "varchar(2000)", remarks: "对方银行")
            column(name: "bp_bank_branch_name", type: "varchar(2000)", remarks: "对方银行分行名")
            column(name: "bp_bank_account_num", type: "varchar(2000)", remarks: "对方银行账户号")
            column(name: "bp_bank_account_name", type: "varchar(2000)", remarks: "对方银行账户名")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "CSH_PAYMENT_REQ_LN", indexName: "CSH_PAYMENT_REQ_LN_N1") {
            column(name: "payment_req_id", type: "bigint(20)")
        }
        createIndex(tableName: "CSH_PAYMENT_REQ_LN", indexName: "CSH_PAYMENT_REQ_LN_N2") {
            column(name: "source_doc_category", type: "varchar(100)")
            column(name: "source_doc_id", type: "bigint(20)")
            column(name: "source_doc_line_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CSH_BANK_ACCOUNT_BALANCE") {
        createTable(tableName: "CSH_BANK_ACCOUNT_BALANCE", remarks: "银行账户余额表") {
            column(name: "bank_account_id", type: "bigint(20)", remarks: "银行账户ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_BANK_ACCOUNT_BALANCE_PK")
            }
            column(name: "period_year", type: "bigint(20)", remarks: "年度") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_BANK_ACCOUNT_BALANCE_PK")
            }
            column(name: "period_month", type: "bigint(20)", remarks: "月份") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CSH_BANK_ACCOUNT_BALANCE_PK")
            }
            column(name: "opening_balance", type: "double", remarks: "期初")
            column(name: "period_income", type: "double", remarks: "本月收入")
            column(name: "period_expense", type: "double", remarks: "本月支出")
            column(name: "balance", type: "double", remarks: "余额")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACR_INVOICE_HD") {
        createTable(tableName: "ACR_INVOICE_HD", remarks: "销项发票头表") {
            column(name: "invoice_hd_id", type: "bigint(20)", remarks: "发票头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACR_INVOICE_HD_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "document_number", type: "varchar(100)", remarks: "系统发票编号")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "billing_method", type: "varchar(100)", remarks: "开票方式")
            column(name: "invoice_kind", type: "varchar(100)", remarks: "发票种类（0-专用增票 / 2-普通增票 / RECEIPT-收据）（syscode：VAT.INVOICE_KIND)")
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴")
            column(name: "bp_name", type: "varchar(255)", remarks: "发票抬头/伙伴名称")
            column(name: "bp_tax_registry_num", type: "varchar(100)", remarks: "纳税人登记号")
            column(name: "bp_address_phone_num", type: "varchar(255)", remarks: "地址及电话")
            column(name: "bp_bank_account", type: "varchar(100)", remarks: "开户行及账号 ")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "total_amount", type: "double", remarks: "价税合计")
            column(name: "net_amount", type: "double", remarks: "不含税金额")
            column(name: "tax_amount", type: "double", remarks: "税金")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "invoice_date", type: "datetime", remarks: "发票日期")
            column(name: "invoice_number", type: "varchar(100)", remarks: "发票号")
            column(name: "invoice_status", type: "varchar(100)", remarks: "发票状态")
            column(name: "reversed_flag", type: "varchar(1)", remarks: "反冲标志")
            column(name: "reverse_date", type: "datetime", remarks: "反冲日期")
            column(name: "source_invoice_header_id", type: "bigint(20)", remarks: "来源发票头ID")
            column(name: "confirmed_date", type: "datetime", remarks: "复核日期")
            column(name: "confirmed_by", type: "bigint(20)", remarks: "复核人ID")
            column(name: "posted_date", type: "datetime", remarks: "确认日期")
            column(name: "posted_by", type: "bigint(20)", remarks: "确认人ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "ACR_INVOICE_HD", indexName: "ACR_INVOICE_HD_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "document_number", type: "varchar(100)")
        }
        createIndex(tableName: "ACR_INVOICE_HD", indexName: "ACR_INVOICE_HD_N3") {
            column(name: "billing_method", type: "varchar(100)")
        }
        createIndex(tableName: "ACR_INVOICE_HD", indexName: "ACR_INVOICE_HD_N2") {
            column(name: "invoice_kind", type: "varchar(100)")
            column(name: "bp_id", type: "bigint(20)")
            column(name: "bp_name", type: "varchar(255)")
            column(name: "bp_tax_registry_num", type: "varchar(100)")
            column(name: "bp_address_phone_num", type: "varchar(255)")
            column(name: "bp_bank_account", type: "varchar(100)")
        }
        createIndex(tableName: "ACR_INVOICE_HD", indexName: "ACR_INVOICE_HD_N4") {
            column(name: "invoice_date", type: "datetime")
        }
        createIndex(tableName: "ACR_INVOICE_HD", indexName: "ACR_INVOICE_HD_N5") {
            column(name: "invoice_number", type: "varchar(100)")
        }
        createIndex(tableName: "ACR_INVOICE_HD", indexName: "ACR_INVOICE_HD_N6") {
            column(name: "invoice_status", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACR_INVOICE_LN") {
        createTable(tableName: "ACR_INVOICE_LN", remarks: "销项发票行表") {
            column(name: "invoice_ln_id", type: "bigint(20)", remarks: "发票行id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACR_INVOICE_LN_PK")
            }
            column(name: "invoice_hd_id", type: "bigint(20)", remarks: "发票头id") { constraints(nullable: "false") }
            column(name: "line_type", type: "varchar(100)", remarks: "行类型（syscode：VAT.INVOICE_LINE_TYPE）")
            column(name: "line_number", type: "bigint(20)", remarks: "行号")
            column(name: "product_name", type: "varchar(2000)", remarks: "商品名称")
            column(name: "specification", type: "varchar(2000)", remarks: "规格型号")
            column(name: "quantity", type: "double", remarks: "数量")
            column(name: "uom", type: "varchar(100)", remarks: "计量单位")
            column(name: "price", type: "double", remarks: "单价")
            column(name: "net_price", type: "double", remarks: "税前单价")
            column(name: "tax_type_rate", type: "double", remarks: "税率")
            column(name: "tax_included_flag", type: "varchar(1)", remarks: "含税标志")
            column(name: "tax_amount", type: "double", remarks: "税额")
            column(name: "net_amount", type: "double", remarks: "税前金额")
            column(name: "total_amount", type: "double", remarks: "含税金额")
            column(name: "description", type: "varchar(2000)", remarks: "行备注/行摘要")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "ACR_INVOICE_LN", indexName: "ACR_INVOICE_LN_N1") {
            column(name: "invoice_hd_id", type: "bigint(20)")
        }
        createIndex(tableName: "ACR_INVOICE_LN", indexName: "ACR_INVOICE_LN_N3") {
            column(name: "line_type", type: "varchar(100)")
            column(name: "line_number", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACR_INVOICE_RELATIONSHIP") {
        createTable(tableName: "ACR_INVOICE_RELATIONSHIP", remarks: "销项发票行表") {
            column(name: "invoice_relation_id", type: "bigint(20)", remarks: "发票关系id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACR_INVOICE_RELATIONSHIP_PK")
            }
            column(name: "invoice_ln_id", type: "bigint(20)", remarks: "发票行id")
            column(name: "source_document_type", type: "varchar(100)", remarks: "开票来源单据（缺省CON_CONTRACT_CASHFLOW)")
            column(name: "source_document_id", type: "bigint(20)", remarks: "开票来源单据ID（缺省合同现金流ID)")
            column(name: "billing_amount", type: "double", remarks: "开票金额")
            column(name: "tax_type_rate", type: "double", remarks: "税率")
            column(name: "tax_included_flag", type: "varchar(1)", remarks: "含税标志")
            column(name: "tax_amount", type: "double", remarks: "税额")
            column(name: "net_amount", type: "double", remarks: "税前金额")
            column(name: "description", type: "varchar(200)", remarks: "行备注/行摘要")
            column(name: "invoice_kind", type: "varchar(100)", remarks: "发票种类（0-专用增票 / 2-普通增票 / RECEIPT-收据）（syscode：VAT.INVOICE_KIND)")
            column(name: "bp_id", type: "bigint(20)", remarks: "开票对象（商业伙伴ID）")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "ACR_INVOICE_RELATIONSHIP", indexName: "ACR_INVOICE_RELATIONSHIP_N1") {
            column(name: "invoice_ln_id", type: "bigint(20)")
        }
        createIndex(tableName: "ACR_INVOICE_RELATIONSHIP", indexName: "ACR_INVOICE_RELATIONSHIP_N2") {
            column(name: "source_document_type", type: "varchar(100)")
            column(name: "source_document_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACP_INVOICE_HD") {
        createTable(tableName: "ACP_INVOICE_HD", remarks: "进项发票头表") {
            column(name: "invoice_hd_id", type: "bigint(20)", remarks: "发票头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACP_INVOICE_HD_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "document_number", type: "varchar(100)", remarks: "系统发票编号")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "billing_method", type: "varchar(100)", remarks: "开票方式")
            column(name: "invoice_kind", type: "varchar(100)", remarks: "发票种类（0-专用增票 / 2-普通增票 / RECEIPT-收据）（syscode：VAT.INVOICE_KIND)")
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴")
            column(name: "bp_name", type: "varchar(255)", remarks: "发票抬头/伙伴名称")
            column(name: "bp_tax_registry_num", type: "varchar(100)", remarks: "纳税人登记号")
            column(name: "bp_address_phone_num", type: "varchar(255)", remarks: "地址及电话")
            column(name: "bp_bank_account", type: "varchar(100)", remarks: "开户行及账号 ")
            column(name: "description", type: "varchar(2000)", remarks: "备注")
            column(name: "total_amount", type: "double", remarks: "价税合计")
            column(name: "net_amount", type: "double", remarks: "不含税金额")
            column(name: "tax_amount", type: "double", remarks: "税金")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "invoice_date", type: "datetime", remarks: "发票日期")
            column(name: "invoice_number", type: "varchar(100)", remarks: "发票号")
            column(name: "invoice_status", type: "varchar(100)", remarks: "发票状态")
            column(name: "reversed_flag", type: "varchar(1)", remarks: "反冲标志")
            column(name: "reverse_date", type: "datetime", remarks: "反冲日期")
            column(name: "source_invoice_header_id", type: "bigint(20)", remarks: "来源发票头ID")
            column(name: "confirmed_date", type: "datetime", remarks: "复核日期")
            column(name: "confirmed_by", type: "bigint(20)", remarks: "复核人ID")
            column(name: "posted_date", type: "datetime", remarks: "确认日期")
            column(name: "posted_by", type: "bigint(20)", remarks: "确认人ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "ACP_INVOICE_HD", indexName: "ACP_INVOICE_HD_N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "document_number", type: "varchar(100)")
        }
        createIndex(tableName: "ACP_INVOICE_HD", indexName: "ACP_INVOICE_HD_N3") {
            column(name: "billing_method", type: "varchar(100)")
        }
        createIndex(tableName: "ACP_INVOICE_HD", indexName: "ACP_INVOICE_HD_N2") {
            column(name: "invoice_kind", type: "varchar(100)")
            column(name: "bp_id", type: "bigint(20)")
            column(name: "bp_name", type: "varchar(255)")
            column(name: "bp_tax_registry_num", type: "varchar(100)")
            column(name: "bp_address_phone_num", type: "varchar(255)")
            column(name: "bp_bank_account", type: "varchar(100)")
        }
        createIndex(tableName: "ACP_INVOICE_HD", indexName: "ACP_INVOICE_HD_N4") {
            column(name: "invoice_date", type: "datetime")
        }
        createIndex(tableName: "ACP_INVOICE_HD", indexName: "ACP_INVOICE_HD_N5") {
            column(name: "invoice_number", type: "varchar(100)")
        }
        createIndex(tableName: "ACP_INVOICE_HD", indexName: "ACP_INVOICE_HD_N6") {
            column(name: "invoice_status", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACP_INVOICE_LN") {
        createTable(tableName: "ACP_INVOICE_LN", remarks: "进项发票行表") {
            column(name: "invoice_ln_id", type: "bigint(20)", remarks: "发票行id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACP_INVOICE_LN_PK")
            }
            column(name: "invoice_hd_id", type: "bigint(20)", remarks: "发票头id") { constraints(nullable: "false") }
            column(name: "line_type", type: "varchar(100)", remarks: "行类型（syscode：VAT.INVOICE_LINE_TYPE）")
            column(name: "line_number", type: "bigint(20)", remarks: "行号")
            column(name: "source_document_category", type: "varchar(100)", remarks: "开票来源单据（缺省CON_CONTRACT)")
            column(name: "contract_id", type: "bigint(20)", remarks: "开票合同-合同id")
            column(name: "cashflow_id", type: "bigint(20)", remarks: "开票合同-现金流id")
            column(name: "cf_item", type: "varchar(100)", remarks: "开票合同-现金流项目")
            column(name: "cf_type", type: "varchar(100)", remarks: "开票合同-现金流类型")
            column(name: "times", type: "bigint(20)", remarks: "开票合同-期数")
            column(name: "product_name", type: "varchar(2000)", remarks: "商品名称")
            column(name: "specification", type: "varchar(2000)", remarks: "规格型号")
            column(name: "quantity", type: "double", remarks: "数量")
            column(name: "uom", type: "varchar(100)", remarks: "计量单位")
            column(name: "price", type: "double", remarks: "单价")
            column(name: "net_price", type: "double", remarks: "税前单价")
            column(name: "tax_type_rate", type: "double", remarks: "税率")
            column(name: "tax_included_flag", type: "varchar(1)", remarks: "含税标志")
            column(name: "tax_amount", type: "double", remarks: "税额")
            column(name: "net_amount", type: "double", remarks: "税前金额")
            column(name: "total_amount", type: "double", remarks: "含税金额")
            column(name: "description", type: "varchar(2000)", remarks: "行备注/行摘要")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "ACP_INVOICE_LN", indexName: "ACP_INVOICE_LN_N1") {
            column(name: "invoice_hd_id", type: "bigint(20)")
        }
        createIndex(tableName: "ACP_INVOICE_LN", indexName: "ACP_INVOICE_LN_N3") {
            column(name: "line_type", type: "varchar(100)")
            column(name: "line_number", type: "bigint(20)")
        }
        createIndex(tableName: "ACP_INVOICE_LN", indexName: "ACP_INVOICE_LN_N2") {
            column(name: "source_document_category", type: "varchar(100)")
            column(name: "contract_id", type: "bigint(20)")
            column(name: "cashflow_id", type: "bigint(20)")
            column(name: "cf_item", type: "varchar(100)")
            column(name: "cf_type", type: "varchar(100)")
            column(name: "times", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_FILE_TEMPLET_TYPE") {
        createTable(tableName: "HLS_DOC_FILE_TEMPLET_TYPE", remarks: "文档模板") {
            column(name: "templet_type", type: "varchar(100)", remarks: "模板类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_TEMPLET_TYPE_PK")
            }
            column(name: "description", type: "varchar(100)", remarks: "模板类型描述") { constraints(nullable: "false") }
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统级标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_FILE_TEMPLET") {
        createTable(tableName: "HLS_DOC_FILE_TEMPLET", remarks: "文档模板") {
            column(name: "templet_id", type: "bigint(20)", remarks: "模板ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_TEMPLET_PK")
            }
            column(name: "templet_code", type: "varchar(100)", remarks: "模板代码") { constraints(nullable: "false") }
            column(name: "templet_name", type: "varchar(2000)", remarks: "模板名称")
            column(name: "templet_type", type: "varchar(100)", remarks: "模板类型")
            column(name: "usage_code", type: "varchar(100)", remarks: "用途类别（syscode:HLS.DOC_FILE_TEMPLET_USAGE_CODE)(租赁合同/抵质押合同/….)")
            column(name: "usage_category", type: "varchar(100)", remarks: "签约BP类别(从hls_bp_category取值，暂只能选取承租人/担保人/供应商）")
            column(name: "note", type: "varchar(2000)", remarks: "说明")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DOC_FILE_TEMPLET", columnNames: "templet_code", constraintName: "HLS_DOC_FILE_TEMPLET_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_FILE_TEMPLET_PARA") {
        createTable(tableName: "HLS_DOC_FILE_TEMPLET_PARA", remarks: "文档模板参数") {
            column(name: "templet_para_id", type: "bigint(20)", remarks: "参数ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_TEMPLET_PARA_PK")
            }
            column(name: "bookmark", type: "varchar(100)", remarks: "书签代码") { constraints(nullable: "false") }
            column(name: "bookmark_description", type: "varchar(2000)", remarks: "书签描述")
            column(name: "bookmark_type", type: "varchar(100)", remarks: "书签类型(syscode:HLS.DOC_FILE_TEMPLET_BOOKMARK_TYPE)（文本/表单/表单域/横向表单)")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "data_source_id", type: "bigint(20)", remarks: "数据源id")
            column(name: "font_family", type: "varchar(100)", remarks: "字体类型")
            column(name: "font_size", type: "double", remarks: "字体大小")
            column(name: "table_width", type: "double", remarks: "表单宽度")
            column(name: "underline", type: "varchar(100)", remarks: "下划线类型(syscode：HLS.DOC_FILE_TEMPLET_UNDERLINE_TYPE)（单线/双线）")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DOC_FILE_TEMPLET_PARA", columnNames: "bookmark", constraintName: "HLS_DOC_FILE_TEMPLET_PARA_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_FILE_TMP_PARA_LINK") {
        createTable(tableName: "HLS_DOC_FILE_TMP_PARA_LINK", remarks: "文档模板参数匹配") {
            column(name: "link_id", type: "bigint(20)", remarks: "匹配ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_TMP_PARA_LINK_PK")
            }
            column(name: "templet_para_id", type: "bigint(20)", remarks: "参数ID") { constraints(nullable: "false") }
            column(name: "templet_id", type: "bigint(20)", remarks: "模板ID") { constraints(nullable: "false") }
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DOC_FILE_TMP_PARA_LINK", columnNames: "templet_para_id,templet_id", constraintName: "HLS_DOC_FILE_TMP_PARA_LINK_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_FILE_PARA_TABLE") {
        createTable(tableName: "HLS_DOC_FILE_PARA_TABLE", remarks: "文档模板参数_表格") {
            column(name: "para_table_id", type: "bigint(20)", remarks: "参数表格ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_PARA_TABLE_PK")
            }
            column(name: "templet_para_id", type: "bigint(20)", remarks: "参数ID") { constraints(nullable: "false") }
            column(name: "column_name", type: "varchar(100)", remarks: "字段名") { constraints(nullable: "false") }
            column(name: "column_desc", type: "varchar(2000)", remarks: "字段描述")
            column(name: "column_num", type: "bigint(20)", remarks: "字段顺序")
            column(name: "column_width", type: "double", remarks: "字段宽度")
            column(name: "alignment", type: "varchar(100)", remarks: "对齐方式(HLS.DOC_FILE_TEMPLET_ALIGNMENT_TYPE)（左对齐/居中/右对齐）")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_DOC_FILE_PARA_TABLE", indexName: "HLS_DOC_FILE_PARA_TABLE_N1") {
            column(name: "para_table_id", type: "bigint(20)")
            column(name: "column_name", type: "varchar(100)")
        }
        createIndex(tableName: "HLS_DOC_FILE_PARA_TABLE", indexName: "HLS_DOC_FILE_PARA_TABLE_N2") {
            column(name: "templet_para_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_FILE_TEMPLET_RULE") {
        createTable(tableName: "HLS_DOC_FILE_TEMPLET_RULE", remarks: "文档模板参数_表格") {
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_TEMPLET_RULE_PK")
            }
            column(name: "templet_type", type: "varchar(100)", remarks: "模板类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_FILE_TEMPLET_RULE_PK")
            }
            column(name: "DATA_SOURCE_ID", type: "bigint(20)", remarks: "数据源ID")
            column(name: "RULE_ENGINE_ID", type: "bigint(20)", remarks: "规则树ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DB_DATA_SOURCE") {
        createTable(tableName: "HLS_DB_DATA_SOURCE", remarks: "通用数据源头表") {
            column(name: "data_source_id", type: "bigint(20)", remarks: "数据来源ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DB_DATA_SOURCE_PK")
            }
            column(name: "data_source_code", type: "varchar(100)", remarks: "数据来源代码") { constraints(nullable: "false") }
            column(name: "usage_type", type: "varchar(100)", remarks: "用途类别（syscode：HLS.DB_DATA_SOURCE_USAGE_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "sql_context", type: "text", remarks: "拼接后sql语句")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DB_DATA_SOURCE", columnNames: "data_source_code,company_id", constraintName: "HLS_DB_DATA_SOURCE_U1")

        createIndex(tableName: "HLS_DB_DATA_SOURCE", indexName: "HLS_DB_DATA_SOURCE_N1") {
            column(name: "usage_type", type: "varchar(100)")
            column(name: "company_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DB_DATA_SOURCE_PARA") {
        createTable(tableName: "HLS_DB_DATA_SOURCE_PARA", remarks: "通用数据源_输入参数表") {
            column(name: "data_source_para_id", type: "bigint(20)", remarks: "数据来源参数ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DB_DATA_SOURCE_PARA_PK")
            }
            column(name: "data_source_id", type: "bigint(20)", remarks: "数据来源ID") { constraints(nullable: "false") }
            column(name: "parameter_name", type: "varchar(100)", remarks: "参数名称") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "参数说明")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DB_DATA_SOURCE_PARA", columnNames: "data_source_id,parameter_name", constraintName: "HLS_DB_DATA_SOURCE_PARA_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DB_DATA_SOURCE_TB") {
        createTable(tableName: "HLS_DB_DATA_SOURCE_TB", remarks: "通用数据源_查询表") {
            column(name: "data_source_tb_id", type: "bigint(20)", remarks: "数据来源表ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DB_DATA_SOURCE_TB_PK")
            }
            column(name: "data_source_id", type: "bigint(20)", remarks: "数据来源ID") { constraints(nullable: "false") }
            column(name: "db_object_name", type: "varchar(100)", remarks: "数据库对象名") { constraints(nullable: "false") }
            column(name: "alias_name", type: "varchar(100)", remarks: "别名")
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "base_table_flag", type: "varchar(1)", remarks: "是否基表标志", defaultValue: "N")
            column(name: "join_type", type: "varchar(100)", remarks: "数据库关联方式(syscode:HLS.DB_DATA_SOURCE_JOIN_TYPE)")
            column(name: "join_data_source_tb_id", type: "bigint(20)", remarks: "数据库关联表ID")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_DB_DATA_SOURCE_TB", indexName: "HLS_DB_DATA_SOURCE_TB_N1") {
            column(name: "data_source_id", type: "bigint(20)")
        }
        createIndex(tableName: "HLS_DB_DATA_SOURCE_TB", indexName: "HLS_DB_DATA_SOURCE_TB_N2") {
            column(name: "join_data_source_tb_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DB_DATA_SOURCE_TB_WH") {
        createTable(tableName: "HLS_DB_DATA_SOURCE_TB_WH", remarks: "通用数据源_查询关联条件表") {
            column(name: "data_source_tb_wh_id", type: "bigint(20)", remarks: "数据来源关联条件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DB_DATA_SOURCE_TB_WH_PK")
            }
            column(name: "data_source_tb_id", type: "bigint(20)", remarks: "数据来源表ID") { constraints(nullable: "false") }
            column(name: "manual_flag", type: "varchar(1)", remarks: "手工标志")
            column(name: "x_condition_type", type: "varchar(100)", remarks: "左边条件数据源类别(syscode:HLS.DB_DATA_SOURCE_CONDITION_TYPE)")
            column(name: "x_condition_source_tb_id", type: "bigint(20)", remarks: "左边条件数据源表名")
            column(name: "x_condition_column", type: "varchar(100)", remarks: "左边条件数据源对象字段名")
            column(name: "x_condition_value", type: "varchar(100)", remarks: "左边条件数据值")
            column(name: "calulate_symbol", type: "varchar(100)", remarks: "逻辑判断标识")
            column(name: "y_condition_type", type: "varchar(100)", remarks: "右边条件数据源类别(syscode:HLS.DB_DATA_SOURCE_CONDITION_TYPE)")
            column(name: "y_condition_source_tb_id", type: "bigint(20)", remarks: "右边条件数据源表名")
            column(name: "y_condition_column", type: "varchar(100)", remarks: "右边条件数据源对象字段名")
            column(name: "y_condition_value", type: "varchar(100)", remarks: "右边条件数据值")
            column(name: "where_context", type: "varchar(2000)", remarks: "条件字符串")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_DB_DATA_SOURCE_TB_WH", indexName: "HLS_DB_DATA_SOURCE_TB_WH_N1") {
            column(name: "data_source_tb_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DB_DATA_SOURCE_COLUMN") {
        createTable(tableName: "HLS_DB_DATA_SOURCE_COLUMN", remarks: "通用数据源_字段表") {
            column(name: "data_source_column_id", type: "bigint(20)", remarks: "数据来源表字段ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DB_DATA_SOURCE_COLUMN_PK")
            }
            column(name: "data_source_id", type: "bigint(20)", remarks: "数据来源ID") { constraints(nullable: "false") }
            column(name: "data_source_tb_id", type: "bigint(20)", remarks: "数据来源表ID")
            column(name: "column_name", type: "varchar(100)", remarks: "数据库对象字段名") { constraints(nullable: "false") }
            column(name: "column_type", type: "varchar(100)", remarks: "数据库对象字段类型")
            column(name: "alias_name", type: "varchar(100)", remarks: "别名")
            column(name: "description", type: "varchar(2000)", remarks: "描述")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DB_DATA_SOURCE_COLUMN", columnNames: "data_source_id,column_name", constraintName: "HLS_DB_DATA_SOURCE_COLUMN_U1")
        addUniqueConstraint(tableName: "HLS_DB_DATA_SOURCE_COLUMN", columnNames: "data_source_id,alias_name", constraintName: "HLS_DB_DATA_SOURCE_COLUMN_U2")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_RULE_ENGINE_TYPE") {
        createTable(tableName: "HLS_RULE_ENGINE_TYPE", remarks: "规则引擎类型") {
            column(name: "rule_engine_type", type: "varchar(100)", remarks: "规则引擎类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RULE_ENGINE_TYPE_PK")
            }
            column(name: "description", type: "varchar(2000)", remarks: "描述") { constraints(nullable: "false") }
            column(name: "rule_result_sql", type: "varchar(2000)", remarks: "规则匹配结果sql")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "system_flag", type: "varchar(1)", remarks: "系统级标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_RULE_ENGINE") {
        createTable(tableName: "HLS_RULE_ENGINE", remarks: "规则引擎") {
            column(name: "rule_engine_id", type: "bigint(20)", remarks: "规则引擎ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RULE_ENGINE_PK")
            }
            column(name: "rule_engine_code", type: "varchar(100)", remarks: "规则引擎代码") { constraints(nullable: "false") }
            column(name: "rule_engine_name", type: "varchar(2000)", remarks: "规则引擎名称")
            column(name: "rule_engine_type", type: "varchar(100)", remarks: "规则引擎类型")
            column(name: "data_source_id", type: "bigint(20)", remarks: "数据源ID")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_RULE_ENGINE", columnNames: "rule_engine_code", constraintName: "HLS_RULE_ENGINE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_RULE_ENGINE_ROUTE") {
        createTable(tableName: "HLS_RULE_ENGINE_ROUTE", remarks: "规则引擎_规则路径") {
            column(name: "rule_engine_id", type: "bigint(20)", remarks: "规则引擎ID") { constraints(nullable: "false") }
            column(name: "route_id", type: "bigint(20)", remarks: "规则路径ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RULE_ENGINE_ROUTE_PK")
            }
            column(name: "parent_route_id", type: "bigint(20)", remarks: "上级规则路径ID")
            column(name: "finnal_flag", type: "varchar(1)", remarks: "最终节点标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_RULE_ENGINE_RESULT") {
        createTable(tableName: "HLS_RULE_ENGINE_RESULT", remarks: "规则引擎_规则结果") {
            column(name: "route_result_id", type: "bigint(20)", remarks: "规则结果ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RULE_ENGINE_RESULT_PK")
            }
            column(name: "route_id", type: "bigint(20)", remarks: "规则路径ID") { constraints(nullable: "false") }
            column(name: "route_result_value", type: "varchar(1000)", remarks: "规则结果值")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_RULE_ENGINE_RESULT", indexName: "HLS_RULE_ENGINE_RESULT_N1") {
            column(name: "route_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_RULE_ENGINE_CONDITION") {
        createTable(tableName: "HLS_RULE_ENGINE_CONDITION", remarks: "规则引擎_规则条件") {
            column(name: "condition_id", type: "bigint(20)", remarks: "规则条件ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RULE_ENGINE_CONDITION_PK")
            }
            column(name: "route_id", type: "bigint(20)", remarks: "规则路径ID") { constraints(nullable: "false") }
            column(name: "x_condition_type", type: "varchar(100)", remarks: "左边条件类型（syscode：HLS.RULE_ENGINE_CONDITION_TYPE)(字段/值)")
            column(name: "x_condition_value", type: "varchar(1000)", remarks: "左边条件值（如“字段”则从HLS_RULE_ENGINE_DATA选取；如“值”则手工输入）")
            column(name: "calulate_symbol", type: "varchar(100)", remarks: "逻辑判断标识(syscode:HLS.RULE_ENGINE_CALULATE_SYMBOL)(等于/不等于/大于/小于/大于等于/小于等于/介于之间）")
            column(name: "y_condition_type", type: "varchar(100)", remarks: "右边条件类型")
            column(name: "y_condition_value_1", type: "varchar(1000)", remarks: "左边条件值1")
            column(name: "y_condition_value_2", type: "varchar(1000)", remarks: "左边条件值2（介于之间时可输入)")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_RULE_ENGINE_CONDITION", indexName: "HLS_RULE_ENGINE_CONDITION_N1") {
            column(name: "route_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SYSTEM_EVENT_MASTER") {
        createTable(tableName: "HLS_SYSTEM_EVENT_MASTER", remarks: "事件表定义") {
            column(name: "EVENT_CODE", type: "bigint(100)", remarks: "事件代码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SYSTEM_EVENT_MASTER_PK")
            }
            column(name: "EVENT_NAME", type: "bigint(2000)", remarks: "事件名称") { constraints(nullable: "false") }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SYSTEM_EVENT") {
        createTable(tableName: "HLS_SYSTEM_EVENT", remarks: "事件表") {
            column(name: "EVENT_ID", type: "bigint(20)", remarks: "事件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SYSTEM_EVENT_PK")
            }
            column(name: "EVENT_CODE", type: "varchar(100)", remarks: "事件代码") { constraints(nullable: "false") }
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "触发单据类别")
            column(name: "SOURCE_DOCUMENT_ID", type: "bigint(20)", remarks: "触发单据ID")
            column(name: "EVENT_USER_ID", type: "bigint(20)", remarks: "触发用户ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_SYSTEM_EVENT", indexName: "HLS_SYSTEM_EVENT_N1") {
            column(name: "EVENT_CODE", type: "varchar(100)")
        }
        createIndex(tableName: "HLS_SYSTEM_EVENT", indexName: "HLS_SYSTEM_EVENT_N2") {
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)")
            column(name: "SOURCE_DOCUMENT_ID", type: "bigint(20)")
        }
        createIndex(tableName: "HLS_SYSTEM_EVENT", indexName: "HLS_SYSTEM_EVENT_N3") {
            column(name: "EVENT_USER_ID", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_RELATIONSHIP") {
        createTable(tableName: "HLS_DOC_RELATIONSHIP", remarks: "单据关系表") {
            column(name: "RELATION_ID", type: "bigint(20)", remarks: "关系ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_RELATIONSHIP_PK")
            }
            column(name: "DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "单据类别")
            column(name: "DOCUMENT_ID", type: "bigint(20)", remarks: "单据ID")
            column(name: "RELATION_TYPE", type: "varchar(100)", remarks: "关系类型：D2D，单据对单据")
            column(name: "RELEATION_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "关联单据类别")
            column(name: "RELEATION_DOCUMENT_ID", type: "bigint(20)", remarks: "关联单据ID")
            column(name: "SOURCE_MODULE", type: "varchar(100)", remarks: "来源模块")
            column(name: "SOURCE_EVENT", type: "varchar(100)", remarks: "来源事件")
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "SOURCE_DOCUMENT_ID", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "SOURCE_USER_ID", type: "bigint(20)", remarks: "来源用户ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_DOC_RELATIONSHIP", columnNames: "DOCUMENT_CATEGORY,DOCUMENT_ID,RELATION_TYPE,RELEATION_DOCUMENT_CATEGORY,RELEATION_DOCUMENT_ID", constraintName: "HLS_DOC_RELATIONSHIP_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_USER_RELATIONSHIP") {
        createTable(tableName: "HLS_USER_RELATIONSHIP", remarks: "用户关系表") {
            column(name: "RELATION_ID", type: "bigint(20)", remarks: "关系ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_USER_RELATIONSHIP_PK")
            }
            column(name: "USER_ID", type: "bigint(20)", remarks: "用户ID")
            column(name: "RELATION_TYPE", type: "varchar(100)", remarks: "关系类型：P2P,人对人；P2D，人对单据")
            column(name: "RELATION_USER_ID", type: "bigint(20)", remarks: "关联用户ID")
            column(name: "RELATION_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "关联单据类别")
            column(name: "RELATION_DOCUMENT_ID", type: "bigint(20)", remarks: "关联单据ID")
            column(name: "SOURCE_MODULE", type: "varchar(100)", remarks: "来源模块")
            column(name: "SOURCE_EVENT", type: "varchar(100)", remarks: "来源事件")
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "SOURCE_DOCUMENT_ID", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "SOURCE_USER_ID", type: "bigint(20)", remarks: "来源用户ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_USER_RELATIONSHIP", columnNames: "USER_ID,RELATION_TYPE,RELATION_USER_ID", constraintName: "HLS_USER_RELATIONSHIP_U1")
        addUniqueConstraint(tableName: "HLS_USER_RELATIONSHIP", columnNames: "USER_ID,RELATION_TYPE,RELATION_DOCUMENT_CATEGORY,RELATION_DOCUMENT_ID", constraintName: "HLS_USER_RELATIONSHIP_U2")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SYSTEM_NOTICE") {
        createTable(tableName: "HLS_SYSTEM_NOTICE", remarks: "通知消息表") {
            column(name: "notice_id", type: "bigint(20)", remarks: "通知ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SYSTEM_NOTICE_PK")
            }
            column(name: "notice_title", type: "varchar(2000)", remarks: "通知标题")
            column(name: "notice_message", type: "varchar(2000)", remarks: "通知文本")
            column(name: "notice_datetime", type: "datetime", remarks: "通知发布时间")
            column(name: "notice_type", type: "varchar(100)", remarks: "通知类型(NOTICE:通知/ EARLY_WARNING：预警 / TODO ：待办事项）")
            column(name: "notice_url", type: "varchar(1000)", remarks: "通知来源链接")
            column(name: "notice_level", type: "varchar(100)", remarks: "通知等级(1:仅自己/2:仅好友/3：所有人）")
            column(name: "source_module", type: "varchar(100)", remarks: "来源模块")
            column(name: "source_event", type: "varchar(100)", remarks: "来源事件")
            column(name: "source_document_category", type: "varchar(100)", remarks: "来源单据")
            column(name: "source_document_id", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "source_user_id", type: "bigint(20)", remarks: "发布人")
            column(name: "source_event_id", type: "bigint(20)", remarks: "来源事件id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_SYSTEM_NOTICE", indexName: "HLS_SYSTEM_NOTICE_N1") {
            column(name: "notice_type", type: "varchar(100)")
            column(name: "notice_level", type: "varchar(100)")
        }
        createIndex(tableName: "HLS_SYSTEM_NOTICE", indexName: "HLS_SYSTEM_NOTICE_N2") {
            column(name: "source_module", type: "varchar(100)")
            column(name: "source_event", type: "varchar(100)")
            column(name: "source_document_category", type: "varchar(100)")
            column(name: "source_document_id", type: "bigint(20)")
            column(name: "source_user_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SYSTEM_NOTICE_OWNER") {
        createTable(tableName: "HLS_SYSTEM_NOTICE_OWNER", remarks: "通知消息_权限表") {
            column(name: "notice_id", type: "bigint(20)", remarks: "通知ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SYSTEM_NOTICE_OWNER_PK")
            }
            column(name: "owner_user_id", type: "bigint(20)", remarks: "消息所属用户ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SYSTEM_NOTICE_OWNER_PK")
            }
            column(name: "read_flag", type: "varchar(1)", remarks: "已阅状态")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "done_flag", type: "varchar(1)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SYSTEM_NOTICE_REPLY") {
        createTable(tableName: "HLS_SYSTEM_NOTICE_REPLY", remarks: "通知消息_回复表") {
            column(name: "notice_reply_id", type: "bigint(20)", remarks: "回复ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SYSTEM_NOTICE_REPLY_PK")
            }
            column(name: "notice_id", type: "bigint(20)", remarks: "通知ID") { constraints(nullable: "false") }
            column(name: "notice_reply_message", type: "varchar(2000)", remarks: "回复文本")
            column(name: "reply_user_id", type: "bigint(20)", remarks: "回复人")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "HLS_SYSTEM_NOTICE_REPLY", indexName: "HLS_SYSTEM_NOTICE_REPLY_N1") {
            column(name: "notice_id", type: "bigint(20)")
        }
        createIndex(tableName: "HLS_SYSTEM_NOTICE_REPLY", indexName: "HLS_SYSTEM_NOTICE_REPLY_N2") {
            column(name: "reply_user_id", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-JOB_TASK") {
        createTable(tableName: "JOB_TASK", remarks: "执行任务") {
            column(name: "task_id", type: "bigint(20)", remarks: "任务ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "JOB_TASK_PK")
            }
            column(name: "task_code", type: "varchar(100)", remarks: "任务代码") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(2000)", remarks: "任务名称")
            column(name: "class_name", type: "varchar(1000)", remarks: "java 类名")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "JOB_TASK", columnNames: "task_code", constraintName: "JOB_TASK_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-JOB_TASK_AUTHORIZE") {
        createTable(tableName: "JOB_TASK_AUTHORIZE", remarks: "执行任务_权限") {
            column(name: "task_authorize_id", type: "bigint(20)", remarks: "任务权限ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "JOB_TASK_AUTHORIZE_PK")
            }
            column(name: "task_id", type: "bigint(20)", remarks: "任务ID") { constraints(nullable: "false") }
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID") { constraints(nullable: "false") }
            column(name: "valid_date_from", type: "datetime", remarks: "有效日期从")
            column(name: "valid_date_to", type: "datetime", remarks: "有效日期至")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "JOB_TASK_AUTHORIZE", columnNames: "task_id,role_id", constraintName: "JOB_TASK_AUTHORIZE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-JOB_TASK_PARAMETER") {
        createTable(tableName: "JOB_TASK_PARAMETER", remarks: "执行任务_参数") {
            column(name: "task_parameter_id", type: "bigint(20)", remarks: "任务参数ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "JOB_TASK_PARAMETER_PK")
            }
            column(name: "task_id", type: "bigint(20)", remarks: "任务ID") { constraints(nullable: "false") }
            column(name: "parameter_name", type: "varchar(100)", remarks: "参数名称") { constraints(nullable: "false") }
            column(name: "parameter_desc", type: "varchar(2000)", remarks: "参数说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "JOB_TASK_PARAMETER", columnNames: "task_id,parameter_name", constraintName: "JOB_TASK_PARAMETER_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-JOB_SCHEDULE") {
        createTable(tableName: "JOB_SCHEDULE", remarks: "执行周期频率") {
            column(name: "schedule_name", type: "varchar(255)", remarks: "周期频率名称") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "JOB_SCHEDULE_PK")
            }
            column(name: "short_desc", type: "varchar(2000)", remarks: "周期频率代码")
            column(name: "full_desc", type: "bigint(2000)", remarks: "周期频率描述")
            column(name: "start_date", type: "datetime", remarks: "起始日期")
            column(name: "end_date", type: "datetime", remarks: "结束日期")
            column(name: "repeat_interval", type: "varchar(1000)", remarks: "重复间隔")
            column(name: "para_freq", type: "varchar(1000)", remarks: "频率(SYSCODE:JOB.SCHEDULE_FREQUENCY)")
            column(name: "para_interval", type: "varchar(1000)", remarks: "间隔")
            column(name: "para_bymonth", type: "varchar(1000)", remarks: "第几月")
            column(name: "para_bymonthday", type: "varchar(1000)", remarks: "月的第几天")
            column(name: "para_byweekno", type: "varchar(1000)", remarks: "第几周")
            column(name: "para_byyearday", type: "varchar(1000)", remarks: "年的第几天")
            column(name: "para_byday", type: "varchar(1000)", remarks: "周的周几")
            column(name: "para_bydate", type: "varchar(1000)", remarks: "日期")
            column(name: "para_byhour", type: "varchar(1000)", remarks: "第几时")
            column(name: "para_byminute", type: "varchar(1000)", remarks: "第几分")
            column(name: "para_bysecond", type: "varchar(1000)", remarks: "第几秒")
            column(name: "para_include", type: "varchar(1000)", remarks: "包含")
            column(name: "para_exclude", type: "varchar(1000)", remarks: "排除")
            column(name: "para_intersect", type: "varchar(1000)", remarks: "交集")
            column(name: "cron_expression", type: "varchar(1000)", remarks: "cron表达式")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-JOB_INFORMATION") {
        createTable(tableName: "JOB_INFORMATION", remarks: "计划任务详细") {
            column(name: "job_id", type: "bigint(20)", remarks: "JOB ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "JOB_INFORMATION_PK")
            }
            column(name: "job_name", type: "varchar(100)", remarks: "任务名称") { constraints(nullable: "false") }
            column(name: "job_group", type: "varchar(100)", remarks: "任务组") { constraints(nullable: "false") }
            column(name: "task_id", type: "bigint(20)", remarks: "任务id")
            column(name: "task_class_name", type: "varchar(1000)", remarks: "java 类名")
            column(name: "schedule_name", type: "varchar(1000)", remarks: "周期频率名称")
            column(name: "cron_expression", type: "varchar(1000)", remarks: "cron表达式")
            column(name: "submit_type", type: "varchar(100)", remarks: "提交方式(syscode:JOB.SUBMIT_TYPE)")
            column(name: "run_times", type: "bigint(20)", remarks: "运行次数")
            column(name: "error_times", type: "bigint(20)", remarks: "失败次数")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "JOB_INFORMATION", columnNames: "job_name,job_group", constraintName: "JOB_INFORMATION_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-JOB_INFORMATION_PARA") {
        createTable(tableName: "JOB_INFORMATION_PARA", remarks: "计划任务详细_参数") {
            column(name: "job_para_id", type: "bigint(20)", remarks: "JOB执行参数ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "JOB_INFORMATION_PARA_PK")
            }
            column(name: "job_id", type: "bigint(20)", remarks: "JOB ID") { constraints(nullable: "false") }
            column(name: "task_parameter_id", type: "bigint(20)", remarks: "任务参数ID") { constraints(nullable: "false") }
            column(name: "parameter_name", type: "varchar(255)", remarks: "执行参数名称")
            column(name: "parameter_desc", type: "varchar(1000)", remarks: "执行参数说明")
            column(name: "parameter_value", type: "varchar(1000)", remarks: "执行参数值")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "JOB_INFORMATION_PARA", columnNames: "job_id,task_parameter_id", constraintName: "JOB_INFORMATION_PARA_U1")
        addUniqueConstraint(tableName: "JOB_INFORMATION_PARA", columnNames: "job_id,parameter_name", constraintName: "JOB_INFORMATION_PARA_U2")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_REPORT_HD") {
        createTable(tableName: "RPT_REPORT_HD", remarks: "报表定义") {
            column(name: "report_id", type: "bigint(20)", remarks: "报表ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_HD_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "report_code", type: "varchar(100)", remarks: "报表代码") { constraints(nullable: "false") }
            column(name: "report_name", type: "varchar(2000)", remarks: "报表名称")
            column(name: "report_description", type: "varchar(2000)", remarks: "报表简介")
            column(name: "report_type", type: "varchar(100)", remarks: "报表类型（syscode：RPT.REPORT_TYPE)")
            column(name: "report_logo", type: "text", remarks: "报表logo")
            column(name: "authority_type", type: "varchar(100)", remarks: "阅读权限（syscode：RPT.REPORT_AUTHORITY_TYPE)")
            column(name: "release_frequency", type: "varchar(100)", remarks: "发布频率（syscode：RPT.REPORT_RELEASE_FREQUENCY)")
            column(name: "start_date", type: "datetime", remarks: "上加日期")
            column(name: "end_date", type: "datetime", remarks: "下架日期")
            column(name: "release_by", type: "varchar(2000)", remarks: "发布人")
            column(name: "rpt_program", type: "varchar(2000)", remarks: "报表执行程序名")
            column(name: "rpt_html", type: "varchar(2000)", remarks: "报表显示页面名")
            column(name: "job_name", type: "varchar(100)", remarks: "job发布名称（JOB_公司ID_报表代码)")
            column(name: "job_id", type: "bigint(20)", remarks: "job发布ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "RPT_REPORT_HD", columnNames: "company_id,report_code", constraintName: "RPT_REPORT_HD_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_REPORT_KEYWORD") {
        createTable(tableName: "RPT_REPORT_KEYWORD", remarks: "报表关键字") {
            column(name: "report_keyword_id", type: "bigint(20)", remarks: "关键字ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_KEYWORD_PK")
            }
            column(name: "report_id", type: "bigint(20)", remarks: "报表ID") { constraints(nullable: "false") }
            column(name: "key_word", type: "varchar(100)", remarks: "关键字") { constraints(nullable: "false") }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "RPT_REPORT_KEYWORD", columnNames: "report_id,key_word", constraintName: "RPT_REPORT_KEYWORD_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_REPORT_AUTHORITY") {
        createTable(tableName: "RPT_REPORT_AUTHORITY", remarks: "报表权限明细") {
            column(name: "report_authority_id", type: "bigint(20)", remarks: "报表授权ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_AUTHORITY_PK")
            }
            column(name: "report_id", type: "bigint(20)", remarks: "报表ID") { constraints(nullable: "false") }
            column(name: "company_id", type: "bigint(20)", remarks: "授权公司") { constraints(nullable: "false") }
            column(name: "unit_id", type: "bigint(20)", remarks: "授权部门")
            column(name: "position_id", type: "bigint(20)", remarks: "授权岗位")
            column(name: "start_date", type: "datetime", remarks: "生效日期从")
            column(name: "end_date", type: "datetime", remarks: "生效日期到")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "RPT_REPORT_AUTHORITY", columnNames: "report_id,company_id,unit_id,position_id", constraintName: "RPT_REPORT_AUTHORITY_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_REPORT_DTL") {
        createTable(tableName: "RPT_REPORT_DTL", remarks: "报表明细") {
            column(name: "report_dtl_id", type: "bigint(20)", remarks: "报表明细ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_DTL_PK")
            }
            column(name: "report_id", type: "bigint(20)", remarks: "报表ID") { constraints(nullable: "false") }
            column(name: "release_date", type: "datetime", remarks: "发布日期") { constraints(nullable: "false") }
            column(name: "release_user_id", type: "bigint(20)", remarks: "发布人")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "RPT_REPORT_DTL", indexName: "RPT_REPORT_DTL_N1") {
            column(name: "report_id", type: "bigint(20)")
        }
        createIndex(tableName: "RPT_REPORT_DTL", indexName: "RPT_REPORT_DTL_N2") {
            column(name: "release_date", type: "datetime")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_REPORT_DTL_OWNER") {
        createTable(tableName: "RPT_REPORT_DTL_OWNER", remarks: "报表明细权限表") {
            column(name: "report_dtl_owner_id", type: "bigint(20)", remarks: "报表所有者ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_DTL_OWNER_PK")
            }
            column(name: "report_dtl_id", type: "bigint(20)", remarks: "报表明细ID") { constraints(nullable: "false") }
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID") { constraints(nullable: "false") }
            column(name: "read_flag", type: "varchar(1)", remarks: "已读标志")
            column(name: "grade", type: "varchar(100)", remarks: "评分")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "RPT_REPORT_DTL_OWNER", columnNames: "report_dtl_id,user_id", constraintName: "RPT_REPORT_DTL_OWNER_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_REPORT_GRADE") {
        createTable(tableName: "RPT_REPORT_GRADE", remarks: "报表明细权限表") {
            column(name: "report_id", type: "bigint(20)", remarks: "报表ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_GRADE_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_REPORT_GRADE_PK")
            }
            column(name: "grade", type: "varchar(100)", remarks: "评分")
            column(name: "description", type: "varchar(2000)", remarks: "说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_CONTACT") {
        createTable(tableName: "HLS_CONTACT", remarks: "问题反馈表") {
            column(name: "CONTACT_ID", type: "bigint(20)", remarks: "id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CONTACT_PK")
            }
            column(name: "CONTACT_TYPE", type: "varchar(100)", remarks: "反馈类型(syscode：CONTACT_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "CONTACT_SUBJECT", type: "varchar(1000)", remarks: "反馈主题")
            column(name: "CONTACT_DESCRIPTION", type: "varchar(2000)", remarks: "反馈内容")
            column(name: "CONTACT_USER_ID", type: "bigint(20)", remarks: "反馈用户id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_SET_OF_BOOKS") {
        createTable(tableName: "GLD_SET_OF_BOOKS", remarks: "帐套") {
            column(name: "SET_OF_BOOKS_ID", type: "bigint(20)", remarks: "帐套ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_SET_OF_BOOKS_PK")
            }
            column(name: "SET_OF_BOOKS_CODE", type: "varchar(100)", remarks: "帐套代码") { constraints(nullable: "false") }
            column(name: "SET_OF_BOOKS_NAME", type: "varchar(1000)", remarks: "帐套名称")
            column(name: "PERIOD_SET_ID", type: "bigint(20)", remarks: "期间表ID")
            column(name: "ACCOUNT_SET_ID", type: "bigint(20)", remarks: "科目表ID")
            column(name: "FUNCTIONAL_CURRENCY", type: "varchar(100)", remarks: "本位币")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_SET_OF_BOOKS", columnNames: "SET_OF_BOOKS_CODE", constraintName: "GLD_SET_OF_BOOKS_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_PERIOD_SET") {
        createTable(tableName: "GLD_PERIOD_SET", remarks: "期间表") {
            column(name: "PERIOD_SET_ID", type: "bigint(20)", remarks: "期间表ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_PERIOD_SET_PK")
            }
            column(name: "PERIOD_SET_CODE", type: "varchar(100)", remarks: "期间表代码") { constraints(nullable: "false") }
            column(name: "PERIOD_SET_NAME", type: "varchar(1000)", remarks: "期间表名称")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_PERIOD_SET", columnNames: "PERIOD_SET_CODE", constraintName: "GLD_PERIOD_SET_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_PERIOD") {
        createTable(tableName: "GLD_PERIOD", remarks: "期间明细") {
            column(name: "PERIOD_SET_ID", type: "bigint(20)", remarks: "期间表ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_PERIOD_PK")
            }
            column(name: "PERIOD_NAME", type: "varchar(100)", remarks: "期间名") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_PERIOD_PK")
            }
            column(name: "PERIOD_YEAR", type: "bigint(20)", remarks: "期间年度") { constraints(nullable: "false") }
            column(name: "PERIOD_MONTH", type: "bigint(20)", remarks: "期间月度") { constraints(nullable: "false") }
            column(name: "START_DATE", type: "datetime", remarks: "期间开始日")
            column(name: "END_DATE", type: "datetime", remarks: "期间结束日")
            column(name: "ADJUSTMENT_FLAG", type: "varchar(1)", remarks: "是否调整期间", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_PERIOD", columnNames: "PERIOD_SET_ID,PERIOD_YEAR,PERIOD_MONTH", constraintName: "GLD_PERIOD_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_ACCOUNT_SET") {
        createTable(tableName: "GLD_ACCOUNT_SET", remarks: "帐套") {
            column(name: "ACCOUNT_SET_ID", type: "bigint(20)", remarks: "科目表ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_ACCOUNT_SET_PK")
            }
            column(name: "ACCOUNT_SET_CODE", type: "varchar(100)", remarks: "科目表代码") { constraints(nullable: "false") }
            column(name: "ACCOUNT_SET_NAME", type: "varchar(1000)", remarks: "科目表名称")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_ACCOUNT_SET", columnNames: "ACCOUNT_SET_CODE", constraintName: "GLD_ACCOUNT_SET_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_ACCOUNT") {
        createTable(tableName: "GLD_ACCOUNT", remarks: "科目明细") {
            column(name: "ACCOUNT_SET_ID", type: "bigint(20)", remarks: "科目表ID") { constraints(nullable: "false") }
            column(name: "ACCOUNT_ID", type: "bigint(20)", remarks: "科目ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_ACCOUNT_PK")
            }
            column(name: "ACCOUNT_CODE", type: "varchar(100)", remarks: "科目代码") { constraints(nullable: "false") }
            column(name: "ACCOUNT_NAME", type: "varchar(2000)", remarks: "科目名称")
            column(name: "ACCOUNT_TYPE", type: "varchar(100)", remarks: "科目类型（syscode：GLD.ACCOUNT_TYPE)")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "SUMMARY_FLAG", type: "varchar(1)", remarks: "汇总科目标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_ACCOUNT_HIERARCHY") {
        createTable(tableName: "GLD_ACCOUNT_HIERARCHY", remarks: "期间层次") {
            column(name: "ACCOUNT_HIERARCHY_ID", type: "bigint(20)", remarks: "科目层次ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_ACCOUNT_HIERARCHY_PK")
            }
            column(name: "ACCOUNT_ID", type: "bigint(20)", remarks: "科目ID") { constraints(nullable: "false") }
            column(name: "SUB_ACCOUNT_CODE", type: "varchar(100)", remarks: "子科目代码表达式") {
                constraints(nullable: "false")
            }
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_ACCOUNT_HIERARCHY", columnNames: "ACCOUNT_ID,SUB_ACCOUNT_CODE", constraintName: "GLD_ACCOUNT_HIERARCHY_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_ACCOUNT_HIERARCHY_DTL") {
        createTable(tableName: "GLD_ACCOUNT_HIERARCHY_DTL", remarks: "期间层次详细") {
            column(name: "ACCOUNT_HIERARCHY_DTL_ID", type: "bigint(20)", remarks: "科目层次详细ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_ACCOUNT_HIERARCHY_DTL_PK")
            }
            column(name: "ACCOUNT_ID", type: "bigint(20)", remarks: "科目ID") { constraints(nullable: "false") }
            column(name: "PARENT_ACCOUNT_ID", type: "bigint(20)", remarks: "汇总科目ID") { constraints(nullable: "false") }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_ACCOUNT_HIERARCHY_DTL", columnNames: "ACCOUNT_ID,PARENT_ACCOUNT_ID", constraintName: "GLD_ACCOUNT_HIERARCHY_DTL_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_TRX") {
        createTable(tableName: "GLD_JE_TRX", remarks: "凭证事务表") {
            column(name: "JE_TRX", type: "varchar(100)", remarks: "凭证事务") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_TRX_PK")
            }
            column(name: "DESCRIPTION", type: "varchar(2000)", remarks: "描述")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "SYSTEM_FLAG", type: "varchar(1)", remarks: "系统级标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_SEGMENT_VALUE") {
        createTable(tableName: "GLD_JE_SEGMENT_VALUE", remarks: "凭证参考段值") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "SEGMENT_VALUE_ID", type: "bigint(100)", remarks: "段值ID") {
                constraints(primaryKey: "true", primaryKeyName: "GLD_JE_SEGMENT_VALUE_PK")
            }
            column(name: "SEGMENT_N", type: "varchar(100)", remarks: "段值编号")
            column(name: "SEGMENT_CODE", type: "varchar(100)", remarks: "段值代码")
            column(name: "SEGMENT_VALUE", type: "varchar(1000)", remarks: "段值描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_JE_SEGMENT_VALUE", columnNames: "COMPANY_ID,SEGMENT_N,SEGMENT_CODE", constraintName: "GLD_JE_SEGMENT_VALUE_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_FINANCIAL_ATTRIBUTE") {
        createTable(tableName: "GLD_FINANCIAL_ATTRIBUTE", remarks: "公司财务属性表") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_FINANCIAL_ATTRIBUTE_PK")
            }
            column(name: "SET_OF_BOOKS_ID", type: "bigint(20)", remarks: "帐套ID")
            column(name: "CON_INCOME_RULE", type: "varchar(100)", remarks: "租息分摊规则(SYSCODE:GLD.CON_INCOME_RULE)")
            column(name: "JE_AUTO_REVERSE_RULE", type: "varchar(100)", remarks: "凭证自动反冲规则(SYSCODE:GLD.JE_AUTO_REVERSE_RULE)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_SEGMENT") {
        createTable(tableName: "GLD_JE_SEGMENT", remarks: "凭证参考段") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_SEGMENT_PK")
            }
            column(name: "SEGMENT_1", type: "varchar(100)", remarks: "段1(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_2", type: "varchar(100)", remarks: "段2(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_3", type: "varchar(100)", remarks: "段3(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_4", type: "varchar(100)", remarks: "段4(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_5", type: "varchar(100)", remarks: "段5(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_6", type: "varchar(100)", remarks: "段6(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_7", type: "varchar(100)", remarks: "段7(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_8", type: "varchar(100)", remarks: "段8(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_9", type: "varchar(100)", remarks: "段9(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_10", type: "varchar(100)", remarks: "段10(syscode:GLD.JE_SEGMENT_TYPE)")
            column(name: "SEGMENT_1_NAME", type: "varchar(100)", remarks: "段1名称")
            column(name: "SEGMENT_2_NAME", type: "varchar(100)", remarks: "段2名称")
            column(name: "SEGMENT_3_NAME", type: "varchar(100)", remarks: "段3名称")
            column(name: "SEGMENT_4_NAME", type: "varchar(100)", remarks: "段4名称")
            column(name: "SEGMENT_5_NAME", type: "varchar(100)", remarks: "段5名称")
            column(name: "SEGMENT_6_NAME", type: "varchar(100)", remarks: "段6名称")
            column(name: "SEGMENT_7_NAME", type: "varchar(100)", remarks: "段7名称")
            column(name: "SEGMENT_8_NAME", type: "varchar(100)", remarks: "段8名称")
            column(name: "SEGMENT_9_NAME", type: "varchar(100)", remarks: "段9名称")
            column(name: "SEGMENT_10_NAME", type: "varchar(100)", remarks: "段10名称")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_ACCOUNT_SEGMENT") {
        createTable(tableName: "GLD_ACCOUNT_SEGMENT", remarks: "科目参考段设置") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_ACCOUNT_SEGMENT_PK")
            }
            column(name: "ACCOUNT_ID", type: "bigint(20)", remarks: "科目ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_ACCOUNT_SEGMENT_PK")
            }
            column(name: "SEGMENT_1", type: "varchar(1)", remarks: "段1启用标志", defaultValue: "N")
            column(name: "SEGMENT_2", type: "varchar(1)", remarks: "段2启用标志", defaultValue: "N")
            column(name: "SEGMENT_3", type: "varchar(1)", remarks: "段3启用标志", defaultValue: "N")
            column(name: "SEGMENT_4", type: "varchar(1)", remarks: "段4启用标志", defaultValue: "N")
            column(name: "SEGMENT_5", type: "varchar(1)", remarks: "段5启用标志", defaultValue: "N")
            column(name: "SEGMENT_6", type: "varchar(1)", remarks: "段6启用标志", defaultValue: "N")
            column(name: "SEGMENT_7", type: "varchar(1)", remarks: "段7启用标志", defaultValue: "N")
            column(name: "SEGMENT_8", type: "varchar(1)", remarks: "段8启用标志", defaultValue: "N")
            column(name: "SEGMENT_9", type: "varchar(1)", remarks: "段9启用标志", defaultValue: "N")
            column(name: "SEGMENT_10", type: "varchar(1)", remarks: "段10启用标志", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_COST_CENTER") {
        createTable(tableName: "GLD_COST_CENTER", remarks: "成本中心") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "COST_CENTER_ID", type: "bigint(20)", remarks: "成本中心ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_COST_CENTER_PK")
            }
            column(name: "COST_CENTER_CODE", type: "varchar(100)", remarks: "成本中心代码") { constraints(nullable: "false") }
            column(name: "DESCRIPTION", type: "varchar(2000)", remarks: "成本中心名称")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_COST_CENTER", columnNames: "COMPANY_ID,COST_CENTER_CODE", constraintName: "GLD_COST_CENTER_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_COST_CENTER_ORG") {
        createTable(tableName: "GLD_COST_CENTER_ORG", remarks: "成本中心-组织架构匹配") {
            column(name: "COST_CENTER_ORG_ID", type: "bigint(20)", remarks: "匹配ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_COST_CENTER_ORG_PK")
            }
            column(name: "COST_CENTER_ID", type: "bigint(20)", remarks: "成本中心ID") { constraints(nullable: "false") }
            column(name: "ORG_UNIT_ID", type: "bigint(100)", remarks: "部门ID") { constraints(nullable: "false") }
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_COST_CENTER_ORG", columnNames: "COST_CENTER_ID,ORG_UNIT_ID", constraintName: "GLD_COST_CENTER_ORG_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_TEMPLATE") {
        createTable(tableName: "GLD_JE_TEMPLATE", remarks: "凭证模板") {
            column(name: "JE_TEMPLATE_ID", type: "bigint(20)", remarks: "凭证模板ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_TEMPLATE_PK")
            }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "JE_TEMPLATE_NAME", type: "varchar(2000)", remarks: "凭证模板说明") {
                constraints(nullable: "false")
            }
            column(name: "DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "单据类别") { constraints(nullable: "false") }
            column(name: "DOCUMENT_TYPE", type: "varchar(100)", remarks: "单据类型") { constraints(nullable: "false") }
            column(name: "BUSINESS_TYPE", type: "varchar(100)", remarks: "业务类型") { constraints(nullable: "false") }
            column(name: "JE_TRX", type: "varchar(100)", remarks: "凭证事务") { constraints(nullable: "false") }
            column(name: "JE_COMPANY_ID", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "JE_DATE", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "JE_ACCOUNT_ID", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "JE_COST_CENTER_ID", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "JE_CURRENCY", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "DR_CR", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "DR_AMOUNT", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "CR_AMOUNT", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "DR_FUNCTIONAL_AMOUNT", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "CR_FUNCTIONAL_AMOUNT", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "EXCHANGE_RATE", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "JE_DESCRIPTION", type: "varchar(1000)")
            column(name: "SEGMENT_1", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_2", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_3", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_4", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_5", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_6", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_7", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_8", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_9", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "SEGMENT_10", type: "varchar(500)", remarks: "(TYPE---VALUE：例SEGMENT---76表示取段值表中code=76的记录；例TRX---DOC_ID表示业务流水视图中字段为DOC_ID的值）")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标志")
            column(name: "JE_HD_RULE_FLAG", type: "varchar(1)", remarks: "凭证头汇总标志", defaultValue: "N")
            column(name: "JE_HD_RULE", type: "varchar(1000)", remarks: "凭证头汇总规则")
            column(name: "JE_REVERSE_RULE", type: "varchar(1000)", remarks: "凭证行反冲规则（SYSCODE:GLD.JE_REVERSE_RULE）")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "GLD_JE_TEMPLATE", indexName: "GLD_JE_TEMPLATE_N1") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_TRX", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_RULE_ENGINE") {
        createTable(tableName: "GLD_JE_RULE_ENGINE", remarks: "凭证规则树") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_RULE_ENGINE_PK")
            }
            column(name: "JE_TRX", type: "varchar(100)", remarks: "凭证事务") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_RULE_ENGINE_PK")
            }
            column(name: "DATA_SOURCE_ID", type: "bigint(20)", remarks: "数据源ID") { constraints(nullable: "false") }
            column(name: "RULE_ENGINE_ID", type: "bigint(20)", remarks: "规则树ID") { constraints(nullable: "false") }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_TRX_DTL") {
        createTable(tableName: "GLD_JE_TRX_DTL", remarks: "凭证事务流水表") {
            column(name: "JE_TRX_DTL_ID", type: "bigint(20)", remarks: "凭证流水ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_TRX_DTL_PK")
            }
            column(name: "JE_TRX_ID", type: "bigint(20)", remarks: "凭证事务-业务单据ID") { constraints(nullable: "false") }
            column(name: "JE_TRX", type: "varchar(100)", remarks: "凭证事务") { constraints(nullable: "false") }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "OPERATE_TYPE", type: "varchar(100)", remarks: "凭证流水方式(syscode:GLD.JE_TRX_DTL_OPERATE_TYPE)") {
                constraints(nullable: "false")
            }
            column(name: "STATUS", type: "bigint(20)", remarks: "制证状态(syscode:GLD.JE_TRX_DTL_STATUS)") {
                constraints(nullable: "false")
            }
            column(name: "REVERSE_JE_TRX_ID", type: "bigint(20)", remarks: "反冲凭证事务-业务单据ID")
            column(name: "MSG_LOG", type: "varchar(1000)", remarks: "消息日志")
            column(name: "JE_SOURCE_DOC", type: "varchar(100)", remarks: "凭证来源单据（CON_CONTRACT)")
            column(name: "JE_SOURCE_ID", type: "bigint(20)", remarks: "凭证来源单据ID(CONTRACT_ID)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "GLD_JE_TRX_DTL", indexName: "GLD_JE_TRX_DTL_N1") {
            column(name: "JE_TRX_ID", type: "bigint(20)")
            column(name: "JE_TRX", type: "varchar(100)")
            column(name: "COMPANY_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_TRX_DTL", indexName: "GLD_JE_TRX_DTL_N2") {
            column(name: "JE_SOURCE_DOC", type: "varchar(100)")
            column(name: "JE_SOURCE_ID", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_TRX_JSON_DTL") {
        createTable(tableName: "GLD_JE_TRX_JSON_DTL", remarks: "凭证事务流水数据表") {
            column(name: "JE_TRX_DTL_ID", type: "bigint(20)", remarks: "凭证流水ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_TRX_JSON_DTL_PK")
            }
            column(name: "JSON_DATA", type: "text", remarks: "制证数据源json")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_HEAD") {
        createTable(tableName: "GLD_JE_HEAD", remarks: "凭证头") {
            column(name: "JE_HEAD_ID", type: "bigint(20)", remarks: "凭证头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_HEAD_PK")
            }
            column(name: "DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "单据类别") { constraints(nullable: "false") }
            column(name: "DOCUMENT_TYPE", type: "varchar(100)", remarks: "单据类型") { constraints(nullable: "false") }
            column(name: "BUSINESS_TYPE", type: "varchar(100)", remarks: "业务类型") { constraints(nullable: "false") }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID")
            column(name: "JE_NUMBER", type: "varchar(100)", remarks: "凭证编号")
            column(name: "JE_HEAD_STR", type: "varchar(255)", remarks: "凭证头汇总规则")
            column(name: "JE_DATE", type: "datetime", remarks: "记账日期")
            column(name: "PERIOD_NAME", type: "varchar(100)", remarks: "期间")
            column(name: "CURRENCY", type: "varchar(100)", remarks: "币种")
            column(name: "DESCRIPTION", type: "varchar(1000)", remarks: "行摘要")
            column(name: "JE_STATUS", type: "varchar(100)", remarks: "凭证状态")
            column(name: "JE_CREATED_BY", type: "bigint(20)", remarks: "凭证制证人")
            column(name: "JE_CREATION_DATE", type: "datetime", remarks: "凭证制证时间")
            column(name: "JE_CONFIRMED_BY", type: "bigint(20)", remarks: "凭证确认人")
            column(name: "JE_CONFIRM_DATE", type: "datetime", remarks: "凭证确认时间")
            column(name: "GL_STATUS", type: "varchar(100)", remarks: "总账状态")
            column(name: "GL_MSG", type: "varchar(2000)", remarks: "总账消息")
            column(name: "REVERSE_FLAG", type: "varchar(1)", remarks: "反冲标志", defaultValue: "N")
            column(name: "REVERSE_JE_HEAD_ID", type: "bigint(20)", remarks: "反冲凭证头ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addColumn(tableName: "GLD_JE_HEAD") {
            column(name: "ROUTE_RESULT_DESCRIPTION", type: "varchar(1000)")
        }


        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N1") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_NUMBER", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N2") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_HEAD_STR", type: "varchar(255)")
        }
        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N3") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_DATE", type: "datetime")
        }
        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N4") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "PERIOD_NAME", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N5") {
            column(name: "COMPANY_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N6") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_STATUS", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_HEAD", indexName: "GLD_JE_HEAD_N7") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "GL_STATUS", type: "varchar(100)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_JE_LINE") {
        createTable(tableName: "GLD_JE_LINE", remarks: "凭证行") {
            column(name: "JE_LINE_ID", type: "bigint(20)", remarks: "凭证行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_JE_LINE_PK")
            }
            column(name: "JE_HEAD_ID", type: "bigint(20)", remarks: "凭证头ID") { constraints(nullable: "false") }
            column(name: "DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "单据类别") { constraints(nullable: "false") }
            column(name: "DOCUMENT_TYPE", type: "varchar(100)", remarks: "单据类型") { constraints(nullable: "false") }
            column(name: "BUSINESS_TYPE", type: "varchar(100)", remarks: "业务类型") { constraints(nullable: "false") }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID")
            column(name: "SOURCE_TYPE", type: "varchar(100)", remarks: "来源类型(syscode:GLD.JE_SOURCE_TYPE)(流水/手工)")
            column(name: "SOURCE_ID", type: "bigint(20)", remarks: "来源ID(JE_TRX_DTL_ID/空)")
            column(name: "JE_TEMPLATE_ID", type: "bigint(20)", remarks: "凭证模板ID")
            column(name: "JE_TRX", type: "varchar(100)", remarks: "凭证事务")
            column(name: "SET_OF_BOOKS_ID", type: "bigint(20)", remarks: "帐套ID")
            column(name: "JE_DATE", type: "datetime", remarks: "记账日期")
            column(name: "PERIOD_NAME", type: "varchar(100)", remarks: "期间")
            column(name: "ACCOUNT_ID", type: "bigint(20)", remarks: "科目ID")
            column(name: "COST_CENTER_ID", type: "bigint(20)", remarks: "成本中心ID")
            column(name: "CURRENCY", type: "varchar(100)", remarks: "币种")
            column(name: "DR_CR", type: "varchar(100)", remarks: "借/贷（syscode：GLD.JE_DR_CR)")
            column(name: "DR_AMOUNT", type: "double", remarks: "借方金额")
            column(name: "CR_AMOUNT", type: "double", remarks: "贷方金额")
            column(name: "DR_FUNCTIONAL_AMOUNT", type: "double", remarks: "借方本币金额")
            column(name: "CR_FUNCTIONAL_AMOUNT", type: "double", remarks: "贷方本币金额")
            column(name: "EXCHANGE_RATE", type: "double", remarks: "汇率")
            column(name: "JE_DESCRIPTION", type: "varchar(1000)", remarks: "行摘要")
            column(name: "SEGMENT_1", type: "varchar(255)", remarks: "段1")
            column(name: "SEGMENT_2", type: "varchar(255)", remarks: "段2")
            column(name: "SEGMENT_3", type: "varchar(255)", remarks: "段3")
            column(name: "SEGMENT_4", type: "varchar(255)", remarks: "段4")
            column(name: "SEGMENT_5", type: "varchar(255)", remarks: "段5")
            column(name: "SEGMENT_6", type: "varchar(255)", remarks: "段6")
            column(name: "SEGMENT_7", type: "varchar(255)", remarks: "段7")
            column(name: "SEGMENT_8", type: "varchar(255)", remarks: "段8")
            column(name: "SEGMENT_9", type: "varchar(255)", remarks: "段9")
            column(name: "SEGMENT_10", type: "varchar(255)", remarks: "段10")
            column(name: "JE_STATUS", type: "varchar(100)", remarks: "凭证状态")
            column(name: "JE_CREATED_BY", type: "bigint(20)", remarks: "凭证制证人")
            column(name: "JE_CREATION_DATE", type: "datetime", remarks: "凭证制证时间")
            column(name: "JE_CONFIRMED_BY", type: "bigint(20)", remarks: "凭证确认人")
            column(name: "JE_CONFIRM_DATE", type: "datetime", remarks: "凭证确认时间")
            column(name: "GL_STATUS", type: "varchar(100)", remarks: "总账状态")
            column(name: "GL_MSG", type: "varchar(2000)", remarks: "总账消息")
            column(name: "REVERSE_FLAG", type: "varchar(1)", remarks: "反冲标志", defaultValue: "N")
            column(name: "REVERSE_JE_LINE_ID", type: "bigint(20)", remarks: "反冲凭证行id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N12") {
            column(name: "JE_HEAD_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N1") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_DATE", type: "datetime")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N2") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "PERIOD_NAME", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N3") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "ACCOUNT_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N4") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "COST_CENTER_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N6") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_STATUS", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N7") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "GL_STATUS", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N8") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_TEMPLATE_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N9") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "JE_TRX", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N10") {
            column(name: "COMPANY_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N11") {
            column(name: "COMPANY_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_JE_LINE", indexName: "GLD_JE_LINE_N5") {
            column(name: "SOURCE_TYPE", type: "varchar(100)")
            column(name: "SOURCE_ID", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_PERIOD_STATUS") {
        createTable(tableName: "GLD_PERIOD_STATUS", remarks: "期间控制") {
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_PERIOD_STATUS_PK")
            }
            column(name: "PERIOD_NAME", type: "varchar(100)", remarks: "期间") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_PERIOD_STATUS_PK")
            }
            column(name: "STATUS", type: "varchar(100)", remarks: "状态(syscode:GLD.PERIOD_STATUS）")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_CONTRACT_TRX") {
        createTable(tableName: "GLD_CONTRACT_TRX", remarks: "租赁合同收入事务表") {
            column(name: "CONTRACT_TRX_ID", type: "bigint(20)", remarks: "事务ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_CONTRACT_TRX_PK")
            }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID")
            column(name: "CONTRACT_ID", type: "bigint(20)", remarks: "合同ID")
            column(name: "SOURCE_TYPE", type: "varchar(100)", remarks: "来源类型(syscode:GLD.GLD_CONTRACT_SOURCE_TYPE)")
            column(name: "SOURCE_ID", type: "bigint(20)", remarks: "来源ID")
            column(name: "STATUS", type: "varchar(100)", remarks: "状态（syscode：GLD.CONTRACT_FI_TRX_STATUS）")
            column(name: "MSG_LOG", type: "varchar(1000)", remarks: "消息日志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_CONTRACT_TRX", columnNames: "COMPANY_ID,CONTRACT_ID,SOURCE_TYPE,SOURCE_ID", constraintName: "GLD_CONTRACT_TRX_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_CONTRACT_HD") {
        createTable(tableName: "GLD_CONTRACT_HD", remarks: "租赁合同收入头表") {
            column(name: "CONTRACT_ID", type: "bigint(20)", remarks: "合同ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_CONTRACT_HD_PK")
            }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID")
            column(name: "STATUS", type: "varchar(100)", remarks: "状态(syscode:GLD.CONTRACT_FINANCE_INCOME_STATUS)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "GLD_CONTRACT_HD", indexName: "GLD_CONTRACT_HD_N1") {
            column(name: "COMPANY_ID", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_CONTRACT_CASHFLOW") {
        createTable(tableName: "GLD_CONTRACT_CASHFLOW", remarks: "租赁合同现金流表") {
            column(name: "CASHFLOW_ID", type: "bigint(20)", remarks: "现金流ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_CONTRACT_CASHFLOW_PK")
            }
            column(name: "CONTRACT_ID", type: "bigint(20)", remarks: "合同ID")
            column(name: "TIMES", type: "bigint(20)", remarks: "期数")
            column(name: "FIN_INCOME_DATE", type: "datetime", remarks: "收入确认日")
            column(name: "FINANCE_INCOME", type: "double", remarks: "收入金额")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "GLD_CONTRACT_CASHFLOW", columnNames: "CONTRACT_ID,TIMES", constraintName: "GLD_CONTRACT_CASHFLOW_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-GLD_CONTRACT_FINANCE_INCOME") {
        createTable(tableName: "GLD_CONTRACT_FINANCE_INCOME", remarks: "租赁合同收入分摊表") {
            column(name: "FINANCE_INCOME_ID", type: "bigint(20)", remarks: "收入分摊ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "GLD_CONTRACT_FINANCE_INCOME_PK")
            }
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID")
            column(name: "CONTRACT_ID", type: "bigint(20)", remarks: "合同ID")
            column(name: "CASHFLOW_ID", type: "bigint(20)", remarks: "现金流ID")
            column(name: "PERIOD_NAME", type: "varchar(100)", remarks: "期间")
            column(name: "START_DATE", type: "datetime", remarks: "起始日")
            column(name: "END_DATE", type: "datetime", remarks: "截止日")
            column(name: "DAYS", type: "bigint(20)", remarks: "天数")
            column(name: "FINANCE_INCOME", type: "double", remarks: "收入金额")
            column(name: "SOURCE_TYPE", type: "varchar(100)", remarks: "数据来源")
            column(name: "SOURCE_ID", type: "bigint(20)", remarks: "来源ID")
            column(name: "POST_FLAG", type: "varchar(1)", remarks: "确认标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "GLD_CONTRACT_FINANCE_INCOME", indexName: "GLD_CONTRACT_FINANCE_INCOME_N1") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "CONTRACT_ID", type: "bigint(20)")
            column(name: "CASHFLOW_ID", type: "bigint(20)")
        }
        createIndex(tableName: "GLD_CONTRACT_FINANCE_INCOME", indexName: "GLD_CONTRACT_FINANCE_INCOME_N2") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "PERIOD_NAME", type: "varchar(100)")
        }
        createIndex(tableName: "GLD_CONTRACT_FINANCE_INCOME", indexName: "GLD_CONTRACT_FINANCE_INCOME_N3") {
            column(name: "COMPANY_ID", type: "bigint(20)")
            column(name: "START_DATE", type: "datetime")
            column(name: "END_DATE", type: "datetime")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACT_DEMO_VACATION") {
        createTable(tableName: "ACT_DEMO_VACATION", remarks: "") {
            column(name: "ID", type: "bigint(20)", remarks: "", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACT_DEMO_VACATION_PK")
            }
            column(name: "USER_CODE", type: "varchar(225)", remarks: "用户编码") { constraints(nullable: "false") }
            column(name: "START_DATE", type: "datetime", remarks: "") { constraints(nullable: "false") }
            column(name: "NEED_DAYS", type: "decimal(4,1)", remarks: "请假天数") { constraints(nullable: "false") }
            column(name: "LEAVE_REASON", type: "varchar(255)", remarks: "请假理由")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-ACT_EXCEPTION") {
        createTable(tableName: "ACT_EXCEPTION", remarks: "") {
            column(name: "ID", type: "bigint(20)", remarks: "", autoIncrement: "true", startWith: "10061") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "ACT_EXCEPTIONN_PK")
            }
            column(name: "PROC_ID", type: "varchar(225)", remarks: "流程id") { constraints(nullable: "false") }
            column(name: "MESSAGE", type: "longblob", remarks: "异常信息") { constraints(nullable: "false") }
            column(name: "DUEDATE", type: "datetime", remarks: "") { constraints(nullable: "false") }
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_ATTACHMENT_TEMP") {
        createTable(tableName: "CON_CONTRACT_ATTACHMENT_TEMP", remarks: "") {
            column(name: "contract_attachment_id", type: "bigint(20)", remarks: "合同附件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_ATTACHMENT_TEMP_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "contract_attachment_category", type: "varchar(200)", remarks: "合同附件类别") {
                constraints(nullable: "false")
            }
            column(name: "document_name", type: "varchar(300)", remarks: "文档名称") { constraints(nullable: "false") }
            column(name: "description", type: "varchar(300)", remarks: "说明备注") { constraints(nullable: "false") }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "CON_CONTRACT_ATTACHMENT_TEMP", indexName: "con_contract_attachment_n") {
            column(name: "contract_id", type: "bigint(20)")
            column(name: "contract_attachment_category", type: "varchar(200)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_CASHFLOW_H") {
        createTable(tableName: "CON_CONTRACT_CASHFLOW_H", remarks: "") {
            column(name: "cashflow_id", type: "bigint(20)", remarks: "现金流ID", autoIncrement: "true", startWith: "5021") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_CASHFLOW_H_PK")
            }
            column(name: "change_req_id", type: "bigint(20)", remarks: "合同变更ID") {
                constraints(nullable: "false")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "cf_item", type: "bigint(20)", remarks: "现金流项目")
            column(name: "cf_type", type: "bigint(20)", remarks: "现金流类型")
            column(name: "cf_direction", type: "varchar(100)", remarks: "现金流方向(INFLOW/OUTFLOW")
            column(name: "cf_status", type: "varchar(100)", remarks: "现金流状态(BLOCK/冻结 、RELEASE/下达、CANCEL/取消)")
            column(name: "times", type: "bigint(20)", remarks: "期数")
            column(name: "due_date", type: "date", remarks: "支付日/到期日")
            column(name: "fin_income_date", type: "date", remarks: "收入确认日")
            column(name: "due_amount", type: "double(20,2)", remarks: "应收金额")
            column(name: "net_due_amount", type: "double(23,2)", remarks: "不含税应收金额")
            column(name: "vat_due_amount", type: "double(23,2)", remarks: "增值税额")
            column(name: "principal", type: "double(23,2)", remarks: "应收本金")
            column(name: "net_principal", type: "double(23,2)", remarks: "不含税应收本金")
            column(name: "vat_principal", type: "double(23,2)", remarks: "本金增值税额")
            column(name: "interest", type: "double(23,2)", remarks: "应收利息")
            column(name: "net_interest", type: "double(23,2)", remarks: "不含税应收利息")
            column(name: "vat_interest", type: "double(23,2)", remarks: "利息增值税额")
            column(name: "write_off_flag", type: "varchar(100)", remarks: "核销标志(NOT/PARTIAL/FULL)")
            column(name: "received_amount", type: "double(23,2)", remarks: "已收金额")
            column(name: "received_principal", type: "double(23,2)", remarks: "已收本金")
            column(name: "received_interest", type: "double(23,2)", remarks: "已收利息")
            column(name: "last_received_date", type: "date", remarks: "最后收款日")
            column(name: "full_write_off_date", type: "date", remarks: "完全核销日")
            column(name: "penalty_process_status", type: "varchar(100)", remarks: "罚金处理状态(NORMAL 正常/SUSPEND 暂停计算/EXEMPT 豁免)")
            column(name: "billing_status", type: "varchar(100)", remarks: "开票状态(NOT/PARTIAL/FULL)")
            column(name: "billing_amount", type: "double(23,2)", remarks: "开票金额")
            column(name: "billing_principal", type: "double(23,2)", remarks: "开票本金")
            column(name: "billing_interest", type: "double(23,2)", remarks: "开票利息")
            column(name: "payment_bp_id", type: "bigint(20)", remarks: "付款商业伙伴ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")

        }

        createIndex(tableName: "CON_CONTRACT_CASHFLOW_H", indexName: "N1") {
            column(name: "change_req_id", type: "bigint(20)")
            column(name: "contract_id", type: "bigint(20)")
            column(name: "cf_item", type: "bigint(20)")
            column(name: "cf_type", type: "bigint(20)")
            column(name: "times", type: "bigint(20)")

        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_CONTENT") {
        createTable(tableName: "CON_CONTRACT_CONTENT", remarks: "") {
            column(name: "contract_content_id", type: "bigint(20)", remarks: "合同文本ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_CONTENT_PK")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "content_name", type: "varchar(100)", remarks: "合同文本名") { constraints(nullable: "false") }
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "CON_CONTRACT_CONTENT", indexName: "con_contract_content_n1") {
            column(name: "contract_id", type: "bigint(20)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_GUARANTOR_H") {
        createTable(tableName: "CON_CONTRACT_GUARANTOR_H", remarks: "") {
            column(name: "contract_guarantor_id", type: "bigint(20)", remarks: "合同担保人ID", autoIncrement: "true", startWith: "44569") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_GUARANTOR_H_PK")
            }
            column(name: "change_req_id", type: "bigint(20)", remarks: "合同变更ID") {
                constraints(nullable: "false")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID")
            column(name: "guarantor_bp_id", type: "bigint(20)", remarks: "担保人商业伙伴ID")
            column(name: "guarantee_type", type: "varchar(100)", remarks: "担保类型")
            column(name: "description", type: "varchar(500)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_GUARANTOR_H", columnNames: "change_req_id,contract_id,guarantor_bp_id", constraintName: "U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_H") {
        createTable(tableName: "CON_CONTRACT_H", remarks: "") {
            column(name: "change_req_id", type: "bigint(20)", remarks: "") {
                constraints(nullable: "false")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID", autoIncrement: "true", startWith: "1308") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_H_PK")
            }
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") { constraints(nullable: "false") }
            column(name: "project_id", type: "bigint(20)", remarks: "项目ID")
            column(name: "quotation_id", type: "bigint(20)", remarks: "报价ID")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型") { constraints(nullable: "false") }
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别") {
                constraints(nullable: "false")
            }
            column(name: "business_type", type: "varchar(100)", remarks: "业务模式") { constraints(nullable: "false") }
            column(name: "contract_number", type: "varchar(100)", remarks: "合同编号")
            column(name: "contract_name", type: "varchar(200)", remarks: "合同名称")
            column(name: "business_contract_number", type: "varchar(100)", remarks: "业务合同号")
            column(name: "bp_account_id", type: "bigint(20)", remarks: "代扣银行")
            column(name: "contract_status", type: "varchar(100)", remarks: "合同状态")
            column(name: "lease_channel", type: "varchar(100)", remarks: "商业模式")
            column(name: "division", type: "varchar(100)", remarks: "产品线")
            column(name: "sign_date", type: "date", remarks: "签约日")
            column(name: "inception_of_lease", type: "date", remarks: "起租日")
            column(name: "employee_id", type: "bigint(20)", remarks: "业务员(用户id)")
            column(name: "unit_id", type: "bigint(20)", remarks: "部门id")
            column(name: "lease_start_date", type: "date", remarks: "租赁期开始日")
            column(name: "first_pay_date", type: "date", remarks: "首次支付日")
            column(name: "last_pay_date", type: "date", remarks: "末次支付日")
            column(name: "lease_end_date", type: "date", remarks: "租赁到期日(租赁期结束日)")
            column(name: "original_recall_date", type: "date", remarks: "合同正本回收日")
            column(name: "lease_card_recall_date", type: "date", remarks: "承租证回收日")
            column(name: "early_termination_date", type: "date", remarks: "提起结清日")
            column(name: "termination_date", type: "date", remarks: "合同结清日")
            column(name: "assignment_date", type: "date", remarks: "所有权转让日")
            column(name: "lease_times", type: "bigint(20)", remarks: "租赁期数")
            column(name: "annual_pay_times", type: "bigint(20)", remarks: "支付频率(年)")
            column(name: "lease_term", type: "bigint(20)", remarks: "租赁期限")
            column(name: "pay_type", type: "bigint(20)", remarks: "支付类型(1/先付;0/后付)")
            column(name: "currency", type: "varchar(10)", remarks: "币种")
            column(name: "tax_type_id", type: "bigint(20)", remarks: "税种id")
            column(name: "vat_flag", type: "varchar(1)", remarks: "增值税标志")
            column(name: "vat_rate", type: "double(23,2)", remarks: "增值税率")
            column(name: "lease_item_amount", type: "double(23,2)", remarks: "租赁资产总价款")
            column(name: "vat_input", type: "double(23,2)", remarks: "进项增值税额")
            column(name: "vat_input_tax_type_id", type: "double(23,2)", remarks: "进项税税种")
            column(name: "vat_input_tax_type_rate", type: "double(23,2)", remarks: "进项税税率")
            column(name: "down_payment_ratio", type: "double(23,2)", remarks: "首期租金比例/首付比例")
            column(name: "down_payment", type: "double(23,2)", remarks: "首期租金/首付金额")
            column(name: "net_down_payment", type: "double(23,2)", remarks: "不含税首付金额")
            column(name: "finance_amount", type: "double(23,2)", remarks: "融资额 (租赁资产总价款 - 首付款，即租赁本金)")
            column(name: "net_finance_amount", type: "double(23,2)", remarks: "不含税融资额")
            column(name: "vat_finance_amount", type: "double(23,2)", remarks: "融资额增值税")
            column(name: "total_rental", type: "double(23,2)", remarks: "租金总额")
            column(name: "net_total_rental", type: "double(23,2)", remarks: "不含税租金")
            column(name: "vat_total_rental", type: "double(23,2)", remarks: "租金增值税额")
            column(name: "total_interest", type: "double(23,2)", remarks: "利息总额")
            column(name: "net_total_interest", type: "double(23,2)", remarks: "不含税利息")
            column(name: "vat_total_interest", type: "double(23,2)", remarks: "利息增值税额")
            column(name: "lease_charge_ratio", type: "double(23,2)", remarks: "手续费比例")
            column(name: "lease_charge", type: "double(23,2)", remarks: "手续费")
            column(name: "net_lease_charge", type: "double(23,2)", remarks: "不含税手续费")
            column(name: "vat_lease_charge", type: "double(23,2)", remarks: "手续费税额")
            column(name: "lease_mgt_fee_ratio", type: "double(23,2)", remarks: "管理费比例")
            column(name: "lease_mgt_fee", type: "double(23,2)", remarks: "管理费")
            column(name: "net_lease_mgt_fee", type: "double(23,2)", remarks: "不含税管理费")
            column(name: "vat_lease_mgt_fee", type: "double(23,2)", remarks: "管理费税额")
            column(name: "lease_mgt_fee_rule", type: "varchar(30)", remarks: "管理费计算方式")
            column(name: "deposit_ratio", type: "double(23,2)", remarks: "保证金比例")
            column(name: "deposit", type: "double(23,2)", remarks: "保证金")
            column(name: "deposit_deduction", type: "varchar(30)", remarks: "保证金抵扣方式")
            column(name: "residual_ratio", type: "double(23,2)", remarks: "留购价款")
            column(name: "residual_value", type: "double(23,2)", remarks: "留购价款")
            column(name: "net_residual_value", type: "double(23,2)", remarks: "不含税留购金")
            column(name: "vat_residual_value", type: "double(23,2)", remarks: "留购金税额")
            column(name: "balloon_ratio", type: "double(23,2)", remarks: "末期租金比例")
            column(name: "balloon", type: "double(23,2)", remarks: "末期租金")
            column(name: "net_balloon", type: "double(23,2)", remarks: "不含税末期租金")
            column(name: "vat_balloon", type: "double(23,2)", remarks: "末期租金税额")
            column(name: "base_rate_type", type: "double(23,2)", remarks: "基准利率类别：pboc央行基准、libor伦敦同业")
            column(name: "base_rate", type: "double(23,2)", remarks: "基准利率")
            column(name: "int_rate", type: "double(23,2)", remarks: "租赁利率")
            column(name: "int_rate_implicit", type: "double(23,2)", remarks: "租赁利率(实际)")
            column(name: "int_rate_type", type: "varchar(30)", remarks: "利率类型：浮动/floating; 固定/fixed")
            column(name: "irr", type: "double(23,2)", remarks: "内部收益率")
            column(name: "irr_after_tax", type: "double(23,2)", remarks: "税后内部收益率")
            column(name: "pmt", type: "double(23,2)", remarks: "等额本息租金")
            column(name: "pmt_first", type: "double(23,2)", remarks: "等额本息租金(首期)")
            column(name: "annual_mean_rate", type: "double(23,2)", remarks: "表面利率、平息率")
            column(name: "received_status", type: "varchar(30)", remarks: "回款状态(not/partial/full)")
            column(name: "overdue_status", type: "varchar(30)", remarks: "逾期状态(n 未逾期、y 已逾期)")
            column(name: "billing_method", type: "varchar(30)", remarks: "开票方式")
            column(name: "billing_status", type: "varchar(30)", remarks: "开票状态(not/partial/full)")
            column(name: "biz_day_convention", type: "varchar(30)", remarks: "非工作日调整")
            column(name: "penalty_profile", type: "varchar(30)", remarks: "迟延履行金规则")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "CON_CONTRACT_H", indexName: "N0") {
            column(name: "contract_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_CONTRACT_H", indexName: "N1") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "project_id", type: "bigint(20)")
            column(name: "quotation_id", type: "bigint(20)")
        }
        createIndex(tableName: "CON_CONTRACT_H", indexName: "N2") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "contract_number", type: "varchar(100)")
            column(name: "contract_name", type: "varchar(200)")
            column(name: "business_contract_number", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_H", indexName: "N3") {
            column(name: "company_id", type: "bigint(20)")
            column(name: "contract_status", type: "varchar(100)")
        }
        createIndex(tableName: "CON_CONTRACT_H", indexName: "N4") {
            column(name: "document_type", type: "varchar(100)")
            column(name: "document_category", type: "varchar(100)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_LEASE_ITEM_H") {
        createTable(tableName: "CON_CONTRACT_LEASE_ITEM_H", remarks: "") {
            column(name: "contract_lease_item_id", type: "bigint(20)", remarks: "合同租赁物ID", autoIncrement: "true", startWith: "566") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_LEASE_ITEM_H_PK")
            }
            column(name: "change_req_id", type: "bigint(20)", remarks: "合同变更ID") {
                constraints(nullable: "false")
            }
            column(name: "seq_number", type: "bigint(100)", remarks: "合同租赁物序号") { constraints(nullable: "false") }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "lease_item_name", type: "varchar(100)", remarks: "租赁物名称")
            column(name: "serial_number", type: "varchar(100)", remarks: "租赁物序列号")
            column(name: "pattern", type: "varchar(100)", remarks: "型号")
            column(name: "specification", type: "varchar(100)", remarks: "规格")
            column(name: "colour", type: "varchar(100)", remarks: "颜色")
            column(name: "quantity", type: "bigint(20)", remarks: "数量")
            column(name: "uom", type: "varchar(100)", remarks: "单位")
            column(name: "price", type: "double(20,2)", remarks: "单价")
            column(name: "lease_item_amount", type: "double(20,2)", remarks: "租赁物金额")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "vender_bp_id", type: "bigint(20)", remarks: "供应商商业伙伴ID")
            column(name: "description", type: "varchar(300)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_LEASE_ITEM_H", columnNames: "seq_number,change_req_id,contract_id", constraintName: "U1")

        createIndex(tableName: "CON_CONTRACT_LEASE_ITEM_H", indexName: "con_contract_lease_item_n1") {
            column(name: "contract_id", type: "bigint(20)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_MORTGAGE_H") {
        createTable(tableName: "CON_CONTRACT_MORTGAGE_H", remarks: "") {
            column(name: "contract_mortgage_id", type: "bigint(20)", remarks: "合同抵质押ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_MORTGAGE_H_PK")
            }
            column(name: "change_req_id", type: "bigint(20)", remarks: "合同变更ID") {
                constraints(nullable: "false")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "seq_number", type: "bigint(20)", remarks: "合同抵质押物序号") { constraints(nullable: "false") }
            column(name: "mortgage_name", type: "varchar(500)", remarks: "抵押物名称")
            column(name: "mortgage_type", type: "varchar(100)", remarks: "抵押类型(抵押mortgage /质押 pledge)")
            column(name: "mortgage_ast_classfication", type: "varchar(500)", remarks: "抵押物分类(动产(质押)/动产(抵押)/权利/不动产)")
            column(name: "mortgage_ast_detail", type: "varchar(500)", remarks: "明细分类(汇票/债券/基金份额/股权/一般动产/特殊动产-车辆/特殊动产-船舶/特殊动产-航天器/土地/房屋)")
            column(name: "mortgage_contract_no", type: "varchar(500)", remarks: "抵押合同编号")
            column(name: "mortgage_register_no", type: "varchar(500)", remarks: "抵押物登记证号")
            column(name: "mortgage_registed_dept", type: "varchar(500)", remarks: "抵押登记部门")
            column(name: "mortgagor_bp_id", type: "bigint(20)", remarks: "抵押人商业伙伴ID")
            column(name: "mortgage_value", type: "double(20,2)", remarks: "抵押物价值")
            column(name: "currency", type: "varchar(100)", remarks: "币种")
            column(name: "uom", type: "varchar(100)", remarks: "单位")
            column(name: "quantity", type: "bigint(20)", remarks: "数量")
            column(name: "start_date", type: "date", remarks: "抵押开始日期")
            column(name: "end_date", type: "date", remarks: "抵押结束日期")
            column(name: "description", type: "varchar(500)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_MORTGAGE_H", columnNames: "change_req_id,contract_id,seq_number", constraintName: "U1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-CON_CONTRACT_TENANT_H") {
        createTable(tableName: "CON_CONTRACT_TENANT_H", remarks: "") {
            column(name: "contract_tenant_id", type: "bigint(20)", remarks: "合同承租人ID", autoIncrement: "true", startWith: "10425") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "CON_CONTRACT_TENANT_H_PK")
            }
            column(name: "change_req_id", type: "bigint(20)", remarks: "合同变更ID") {
                constraints(nullable: "false")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同ID") { constraints(nullable: "false") }
            column(name: "tenant_bp_id", type: "bigint(20)", remarks: "承租人商业伙伴ID") {
                constraints(nullable: "false")
            }
            column(name: "tenant_bp_type", type: "varchar(100)", remarks: "承租人商业伙伴类型")
            column(name: "description", type: "varchar(200)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "CON_CONTRACT_TENANT_H", columnNames: "change_req_id,contract_id,tenant_bp_id", constraintName: "U1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-EXCEL_EXPORT_INFO") {
        createTable(tableName: "EXCEL_EXPORT_INFO", remarks: "") {
            column(name: "id", type: "bigint(20)", remarks: "文件导出信息ID", autoIncrement: "true", startWith: "4") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "EXCEL_EXPORT_INFO_PK")
            }
            column(name: "deal_date", type: "datetime", remarks: "开始处理文件时间")
            column(name: "done_date", type: "datetime", remarks: "导出完成时间")
            column(name: "enable", type: "varchar(255)", remarks: "启动flag")
            column(name: "export_json_config", type: "varchar(4000)", remarks: "配置信息，json格式")
            column(name: "file_name", type: "varchar(255)", remarks: "excel的文件名")
            column(name: "file_path", type: "varchar(255)", remarks: "保存在服务器上的路径")
            column(name: "in_date", type: "datetime", remarks: "开始等待文件生成的时间")
            column(name: "max_row_number", type: "int(11)", remarks: "excel文件最多的行数")
            column(name: "sql_id", type: "varchar(4000)", remarks: "sql的id")
            column(name: "status", type: "varchar(255)", remarks: "状态,newgeneratingfinished")
            column(name: "userId", type: "bigint(20)", remarks: "")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_COMPANY_TL") {
        createTable(tableName: "FND_COMPANY_TL", remarks: "") {
            column(name: "company_id", type: "bigint(20)", remarks: "") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_COMPANY_TL_PK")
            }
            column(name: "LANG", type: "varchar(10)", remarks: "") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_COMPANY_TL_PK")
            }
            column(name: "company_short_name", type: "varchar(300)", remarks: "")
            column(name: "company_full_name", type: "varchar(300)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_COMPANY_VAT_ATTRIBUTE") {
        createTable(tableName: "FND_COMPANY_VAT_ATTRIBUTE", remarks: "公司税务属性表") {
            column(name: "company_id", type: "bigint(20)", remarks: "公司ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_COMPANY_VAT_ATTRIBUTE_PK")
            }
            column(name: "special_invoice_limit", type: "double", remarks: "增值税专票限额")
            column(name: "normal_invoice_limit", type: "double", remarks: "增值税普票限额")
            column(name: "line_limit", type: "double", remarks: "最大发票行数")
            column(name: "invoice_title", type: "varchar(300)", remarks: "开票公司名称")
            column(name: "tax_registry_num", type: "varchar(300)", remarks: "纳税人识别号")
            column(name: "invoice_address", type: "varchar(300)", remarks: "地址")
            column(name: "invoice_phone", type: "varchar(300)", remarks: "电话")
            column(name: "invoice_bank", type: "varchar(300)", remarks: "开户行")
            column(name: "invoice_bank_account", type: "varchar(300)", remarks: "银行账号")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")

        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_INTERFACE_HEADERS") {
        createTable(tableName: "FND_INTERFACE_HEADERS", remarks: "") {
            column(name: "header_id", type: "bigint(20)", remarks: "头ID", autoIncrement: "true", startWith: "410") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_INTERFACE_HEADERS_PK")
            }
            column(name: "template_code", type: "varchar(30)", remarks: "模板号")
            column(name: "job_id", type: "bigint(20)", remarks: "任务ID")
            column(name: "status", type: "varchar(30)", remarks: "导入状态SYSCODE:FND_INTERFACE_STATUS,NEW-新建 LOADING-正在导入 SUCESS-导入成功 ERROR-导入出错")
            column(name: "file_name", type: "varchar(200)", remarks: "导入文件名称")
            column(name: "attributes_1", type: "varchar(30)", remarks: "")
            column(name: "attributes_2", type: "varchar(30)", remarks: "")
            column(name: "attributes_3", type: "varchar(30)", remarks: "")
            column(name: "attributes_4", type: "varchar(30)", remarks: "")
            column(name: "attributes_5", type: "varchar(30)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-FND_INTERFACE_LINES") {
        createTable(tableName: "FND_INTERFACE_LINES", remarks: "") {
            column(name: "line_id", type: "bigint(20)", remarks: "头ID", autoIncrement: "true", startWith: "23666") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "FND_INTERFACE_LINES_PK")
            }
            column(name: "header_id", type: "bigint(20)", remarks: "模板号")
            column(name: "line_number", type: "bigint(20)", remarks: "行号")
            column(name: "status", type: "varchar(30)", remarks: "导入状态SYSCODE:FND_INTERFACE_STATUS,NEW-新建 LOADING-正在导入 SUCESS-导入成功 ERROR-导入出错")
            column(name: "error_message", type: "varchar(200)", remarks: "错误消息")
            column(name: "sheet_name", type: "varchar(255)", remarks: "")
            column(name: "attributes_1", type: "text", remarks: "")
            column(name: "attributes_2", type: "text", remarks: "")
            column(name: "attributes_3", type: "text", remarks: "")
            column(name: "attributes_4", type: "text", remarks: "")
            column(name: "attributes_5", type: "text", remarks: "")
            column(name: "attributes_6", type: "text", remarks: "")
            column(name: "attributes_7", type: "text", remarks: "")
            column(name: "attributes_8", type: "text", remarks: "")
            column(name: "attributes_9", type: "text", remarks: "")
            column(name: "attributes_10", type: "text", remarks: "")
            column(name: "attributes_11", type: "text", remarks: "")
            column(name: "attributes_12", type: "text", remarks: "")
            column(name: "attributes_13", type: "text", remarks: "")
            column(name: "attributes_14", type: "text", remarks: "")
            column(name: "attributes_15", type: "text", remarks: "")
            column(name: "attributes_16", type: "text", remarks: "")
            column(name: "attributes_17", type: "text", remarks: "")
            column(name: "attributes_18", type: "text", remarks: "")
            column(name: "attributes_19", type: "text", remarks: "")
            column(name: "attributes_20", type: "text", remarks: "")
            column(name: "attributes_21", type: "text", remarks: "")
            column(name: "attributes_22", type: "text", remarks: "")
            column(name: "attributes_23", type: "text", remarks: "")
            column(name: "attributes_24", type: "text", remarks: "")
//                column(name: "attributes_25", type: "text", remarks: "")
//                column(name: "attributes_26", type: "text", remarks: "")
//                column(name: "attributes_27", type: "text", remarks: "")
//                column(name: "attributes_28", type: "text", remarks: "")
//                column(name: "attributes_29", type: "text", remarks: "")
//                column(name: "attributes_30", type: "text", remarks: "")
//                column(name: "attributes_31", type: "text", remarks: "")
//                column(name: "attributes_32", type: "text", remarks: "")
//                column(name: "attributes_33", type: "text", remarks: "")
//                column(name: "attributes_34", type: "text", remarks: "")
//                column(name: "attributes_35", type: "text", remarks: "")
//                column(name: "attributes_36", type: "text", remarks: "")
//                column(name: "attributes_37", type: "text", remarks: "")
//                column(name: "attributes_38", type: "text", remarks: "")
//                column(name: "attributes_39", type: "text", remarks: "")
//                column(name: "attributes_40", type: "text", remarks: "")
//                column(name: "attributes_41", type: "text", remarks: "")
//                column(name: "attributes_42", type: "text", remarks: "")
//                column(name: "attributes_43", type: "text", remarks: "")
//                column(name: "attributes_44", type: "text", remarks: "")
//                column(name: "attributes_45", type: "text", remarks: "")
//                column(name: "attributes_46", type: "text", remarks: "")
//                column(name: "attributes_47", type: "text", remarks: "")
//                column(name: "attributes_48", type: "text", remarks: "")
//                column(name: "attributes_49", type: "text", remarks: "")
//                column(name: "attributes_50", type: "text", remarks: "")
//                column(name: "attributes_51", type: "text", remarks: "")
//                column(name: "attributes_52", type: "text", remarks: "")
//                column(name: "attributes_53", type: "text", remarks: "")
//                column(name: "attributes_54", type: "text", remarks: "")
//                column(name: "attributes_55", type: "text", remarks: "")
//                column(name: "attributes_56", type: "text", remarks: "")
//                column(name: "attributes_57", type: "text", remarks: "")
//                column(name: "attributes_58", type: "text", remarks: "")
//                column(name: "attributes_59", type: "text", remarks: "")
//                column(name: "attributes_60", type: "text", remarks: "")
//                column(name: "attributes_61", type: "text", remarks: "")
//                column(name: "attributes_62", type: "text", remarks: "")
//                column(name: "attributes_63", type: "text", remarks: "")
//                column(name: "attributes_64", type: "text", remarks: "")
//                column(name: "attributes_65", type: "text", remarks: "")
//                column(name: "attributes_66", type: "text", remarks: "")
//                column(name: "attributes_67", type: "text", remarks: "")
//                column(name: "attributes_68", type: "text", remarks: "")
//                column(name: "attributes_69", type: "text", remarks: "")
//                column(name: "attributes_70", type: "text", remarks: "")
//                column(name: "attributes_71", type: "text", remarks: "")
//                column(name: "attributes_72", type: "text", remarks: "")
//                column(name: "attributes_73", type: "text", remarks: "")
//                column(name: "attributes_74", type: "text", remarks: "")
//                column(name: "attributes_75", type: "text", remarks: "")
//                column(name: "attributes_76", type: "text", remarks: "")
//                column(name: "attributes_77", type: "text", remarks: "")
//                column(name: "attributes_78", type: "text", remarks: "")
//                column(name: "attributes_79", type: "text", remarks: "")
//                column(name: "attributes_80", type: "text", remarks: "")
//                column(name: "attributes_81", type: "text", remarks: "")
//                column(name: "attributes_82", type: "text", remarks: "")
//                column(name: "attributes_83", type: "text", remarks: "")
//                column(name: "attributes_84", type: "text", remarks: "")
//                column(name: "attributes_85", type: "text", remarks: "")
//                column(name: "attributes_86", type: "text", remarks: "")
//                column(name: "attributes_87", type: "text", remarks: "")
//                column(name: "attributes_88", type: "text", remarks: "")
//                column(name: "attributes_89", type: "text", remarks: "")
//                column(name: "attributes_90", type: "text", remarks: "")
//                column(name: "attributes_91", type: "text", remarks: "")
//                column(name: "attributes_92", type: "text", remarks: "")
//                column(name: "attributes_93", type: "text", remarks: "")
//                column(name: "attributes_94", type: "text", remarks: "")
//                column(name: "attributes_95", type: "text", remarks: "")
//                column(name: "attributes_96", type: "text", remarks: "")
//                column(name: "attributes_97", type: "text", remarks: "")
//                column(name: "attributes_98", type: "text", remarks: "")
//                column(name: "attributes_99", type: "text", remarks: "")
//                column(name: "attributes_100", type: "text", remarks: "")
//                column(name: "attributes_101", type: "text", remarks: "")
//                column(name: "attributes_102", type: "text", remarks: "")
//                column(name: "attributes_103", type: "text", remarks: "")
//                column(name: "attributes_104", type: "text", remarks: "")
//                column(name: "attributes_105", type: "text", remarks: "")
//                column(name: "attributes_106", type: "text", remarks: "")
//                column(name: "attributes_107", type: "text", remarks: "")
//                column(name: "attributes_108", type: "text", remarks: "")
//                column(name: "attributes_109", type: "text", remarks: "")
//                column(name: "attributes_110", type: "text", remarks: "")
//                column(name: "attributes_111", type: "text", remarks: "")
//                column(name: "attributes_112", type: "text", remarks: "")
//                column(name: "attributes_113", type: "text", remarks: "")
//                column(name: "attributes_114", type: "text", remarks: "")
//                column(name: "attributes_115", type: "text", remarks: "")
//                column(name: "attributes_116", type: "text", remarks: "")
//                column(name: "attributes_117", type: "text", remarks: "")
//                column(name: "attributes_118", type: "text", remarks: "")
//                column(name: "attributes_119", type: "text", remarks: "")
//                column(name: "attributes_120", type: "text", remarks: "")
//                column(name: "attributes_121", type: "text", remarks: "")
//                column(name: "attributes_122", type: "text", remarks: "")
//                column(name: "attributes_123", type: "text", remarks: "")
//                column(name: "attributes_124", type: "text", remarks: "")
//                column(name: "attributes_125", type: "text", remarks: "")
//                column(name: "attributes_126", type: "text", remarks: "")
//                column(name: "attributes_127", type: "text", remarks: "")
//                column(name: "attributes_128", type: "text", remarks: "")
//                column(name: "attributes_129", type: "text", remarks: "")
//                column(name: "attributes_130", type: "text", remarks: "")
//                column(name: "attributes_131", type: "text", remarks: "")
//                column(name: "attributes_132", type: "text", remarks: "")
//                column(name: "attributes_133", type: "text", remarks: "")
//                column(name: "attributes_134", type: "text", remarks: "")
//                column(name: "attributes_135", type: "text", remarks: "")
//                column(name: "attributes_136", type: "text", remarks: "")
//                column(name: "attributes_137", type: "text", remarks: "")
//                column(name: "attributes_138", type: "text", remarks: "")
//                column(name: "attributes_139", type: "text", remarks: "")
//                column(name: "attributes_140", type: "text", remarks: "")
//                column(name: "attributes_141", type: "text", remarks: "")
//                column(name: "attributes_142", type: "text", remarks: "")
//                column(name: "attributes_143", type: "text", remarks: "")
//                column(name: "attributes_144", type: "text", remarks: "")
//                column(name: "attributes_145", type: "text", remarks: "")
//                column(name: "attributes_146", type: "text", remarks: "")
//                column(name: "attributes_147", type: "text", remarks: "")
//                column(name: "attributes_148", type: "text", remarks: "")
//                column(name: "attributes_149", type: "text", remarks: "")
//                column(name: "attributes_150", type: "text", remarks: "")
//                column(name: "attributes_151", type: "text", remarks: "")
//                column(name: "attributes_152", type: "text", remarks: "")
//                column(name: "attributes_153", type: "text", remarks: "")
//                column(name: "attributes_154", type: "text", remarks: "")
//                column(name: "attributes_155", type: "text", remarks: "")
//                column(name: "attributes_156", type: "text", remarks: "")
//                column(name: "attributes_157", type: "text", remarks: "")
//                column(name: "attributes_158", type: "text", remarks: "")
//                column(name: "attributes_159", type: "text", remarks: "")
//                column(name: "attributes_160", type: "text", remarks: "")
//                column(name: "attributes_161", type: "text", remarks: "")
//                column(name: "attributes_162", type: "text", remarks: "")
//                column(name: "attributes_163", type: "text", remarks: "")
//                column(name: "attributes_164", type: "text", remarks: "")
//                column(name: "attributes_165", type: "text", remarks: "")
//                column(name: "attributes_166", type: "text", remarks: "")
//                column(name: "attributes_167", type: "text", remarks: "")
//                column(name: "attributes_168", type: "text", remarks: "")
//                column(name: "attributes_169", type: "text", remarks: "")
//                column(name: "attributes_170", type: "text", remarks: "")
//                column(name: "attributes_171", type: "text", remarks: "")
//                column(name: "attributes_172", type: "text", remarks: "")
//                column(name: "attributes_173", type: "text", remarks: "")
//                column(name: "attributes_174", type: "text", remarks: "")
//                column(name: "attributes_175", type: "text", remarks: "")
//                column(name: "attributes_176", type: "text", remarks: "")
//                column(name: "attributes_177", type: "text", remarks: "")
//                column(name: "attributes_178", type: "text", remarks: "")
//                column(name: "attributes_179", type: "text", remarks: "")
//                column(name: "attributes_180", type: "text", remarks: "")
//                column(name: "attributes_181", type: "text", remarks: "")
//                column(name: "attributes_182", type: "text", remarks: "")
//                column(name: "attributes_183", type: "text", remarks: "")
//                column(name: "attributes_184", type: "text", remarks: "")
//                column(name: "attributes_185", type: "text", remarks: "")
//                column(name: "attributes_186", type: "text", remarks: "")
//                column(name: "attributes_187", type: "text", remarks: "")
//                column(name: "attributes_188", type: "text", remarks: "")
//                column(name: "attributes_189", type: "text", remarks: "")
//                column(name: "attributes_190", type: "text", remarks: "")
//                column(name: "attributes_191", type: "text", remarks: "")
//                column(name: "attributes_192", type: "text", remarks: "")
//                column(name: "attributes_193", type: "text", remarks: "")
//                column(name: "attributes_194", type: "text", remarks: "")
//                column(name: "attributes_195", type: "text", remarks: "")
//                column(name: "attributes_196", type: "text", remarks: "")
//                column(name: "attributes_197", type: "text", remarks: "")
//                column(name: "attributes_198", type: "text", remarks: "")
//                column(name: "attributes_199", type: "text", remarks: "")
//                column(name: "attributes_200", type: "text", remarks: "")
//                column(name: "attributes_201", type: "text", remarks: "")
//                column(name: "attributes_202", type: "text", remarks: "")
//                column(name: "attributes_203", type: "text", remarks: "")
//                column(name: "attributes_204", type: "text", remarks: "")
//                column(name: "attributes_205", type: "text", remarks: "")
//                column(name: "attributes_206", type: "text", remarks: "")
//                column(name: "attributes_207", type: "text", remarks: "")
//                column(name: "attributes_208", type: "text", remarks: "")
//                column(name: "attributes_209", type: "text", remarks: "")
//                column(name: "attributes_210", type: "text", remarks: "")
//                column(name: "attributes_211", type: "text", remarks: "")
//                column(name: "attributes_212", type: "text", remarks: "")
//                column(name: "attributes_213", type: "text", remarks: "")
//                column(name: "attributes_214", type: "text", remarks: "")
//                column(name: "attributes_215", type: "text", remarks: "")
//                column(name: "attributes_216", type: "text", remarks: "")
//                column(name: "attributes_217", type: "text", remarks: "")
//                column(name: "attributes_218", type: "text", remarks: "")
//                column(name: "attributes_219", type: "text", remarks: "")
//                column(name: "attributes_220", type: "text", remarks: "")
//                column(name: "attributes_221", type: "text", remarks: "")
//                column(name: "attributes_222", type: "text", remarks: "")
//                column(name: "attributes_223", type: "text", remarks: "")
//                column(name: "attributes_224", type: "text", remarks: "")
//                column(name: "attributes_225", type: "text", remarks: "")
//                column(name: "attributes_226", type: "text", remarks: "")
//                column(name: "attributes_227", type: "text", remarks: "")
//                column(name: "attributes_228", type: "text", remarks: "")
//                column(name: "attributes_229", type: "text", remarks: "")
//                column(name: "attributes_230", type: "text", remarks: "")
//                column(name: "attributes_231", type: "text", remarks: "")
//                column(name: "attributes_232", type: "text", remarks: "")
//                column(name: "attributes_233", type: "text", remarks: "")
//                column(name: "attributes_234", type: "text", remarks: "")
//                column(name: "attributes_235", type: "text", remarks: "")
//                column(name: "attributes_236", type: "text", remarks: "")
//                column(name: "attributes_237", type: "text", remarks: "")
//                column(name: "attributes_238", type: "text", remarks: "")
//                column(name: "attributes_239", type: "text", remarks: "")
//                column(name: "attributes_240", type: "text", remarks: "")
//                column(name: "attributes_241", type: "text", remarks: "")
//                column(name: "attributes_242", type: "text", remarks: "")
//                column(name: "attributes_243", type: "text", remarks: "")
//                column(name: "attributes_244", type: "text", remarks: "")
//                column(name: "attributes_245", type: "text", remarks: "")
//                column(name: "attributes_246", type: "text", remarks: "")
//                column(name: "attributes_247", type: "text", remarks: "")
//                column(name: "attributes_248", type: "text", remarks: "")
//                column(name: "attributes_249", type: "text", remarks: "")
//                column(name: "attributes_250", type: "text", remarks: "")
//                column(name: "attributes_251", type: "text", remarks: "")
//                column(name: "attributes_252", type: "text", remarks: "")
//                column(name: "attributes_253", type: "text", remarks: "")
//                column(name: "attributes_254", type: "text", remarks: "")
//                column(name: "attributes_255", type: "text", remarks: "")
//                column(name: "attributes_256", type: "text", remarks: "")
//                column(name: "attributes_257", type: "text", remarks: "")
//                column(name: "attributes_258", type: "text", remarks: "")
//                column(name: "attributes_259", type: "text", remarks: "")
//                column(name: "attributes_260", type: "text", remarks: "")
//                column(name: "attributes_261", type: "text", remarks: "")
//                column(name: "attributes_262", type: "text", remarks: "")
//                column(name: "attributes_263", type: "text", remarks: "")
//                column(name: "attributes_264", type: "text", remarks: "")
//                column(name: "attributes_265", type: "text", remarks: "")
//                column(name: "attributes_266", type: "text", remarks: "")
//                column(name: "attributes_267", type: "text", remarks: "")
//                column(name: "attributes_268", type: "text", remarks: "")
//                column(name: "attributes_269", type: "text", remarks: "")
//                column(name: "attributes_270", type: "text", remarks: "")
//                column(name: "attributes_271", type: "text", remarks: "")
//                column(name: "attributes_272", type: "text", remarks: "")
//                column(name: "attributes_273", type: "text", remarks: "")
//                column(name: "attributes_274", type: "text", remarks: "")
//                column(name: "attributes_275", type: "text", remarks: "")
//                column(name: "attributes_276", type: "text", remarks: "")
//                column(name: "attributes_277", type: "text", remarks: "")
//                column(name: "attributes_278", type: "text", remarks: "")
//                column(name: "attributes_279", type: "text", remarks: "")
//                column(name: "attributes_280", type: "text", remarks: "")
//                column(name: "attributes_281", type: "text", remarks: "")
//                column(name: "attributes_282", type: "text", remarks: "")
//                column(name: "attributes_283", type: "text", remarks: "")
//                column(name: "attributes_284", type: "text", remarks: "")
//                column(name: "attributes_285", type: "text", remarks: "")
//                column(name: "attributes_286", type: "text", remarks: "")
//                column(name: "attributes_287", type: "text", remarks: "")
//                column(name: "attributes_288", type: "text", remarks: "")
//                column(name: "attributes_289", type: "text", remarks: "")
//                column(name: "attributes_290", type: "text", remarks: "")
//                column(name: "attributes_291", type: "text", remarks: "")
//                column(name: "attributes_292", type: "text", remarks: "")
//                column(name: "attributes_293", type: "text", remarks: "")
//                column(name: "attributes_294", type: "text", remarks: "")
//                column(name: "attributes_295", type: "text", remarks: "")
//                column(name: "attributes_296", type: "text", remarks: "")
//                column(name: "attributes_297", type: "text", remarks: "")
//                column(name: "attributes_298", type: "text", remarks: "")
//                column(name: "attributes_299", type: "text", remarks: "")
//                column(name: "attributes_300", type: "text", remarks: "")
//                column(name: "attributes_301", type: "text", remarks: "")
//                column(name: "attributes_302", type: "text", remarks: "")
//                column(name: "attributes_303", type: "text", remarks: "")
//                column(name: "attributes_304", type: "text", remarks: "")
//                column(name: "attributes_305", type: "text", remarks: "")
//                column(name: "attributes_306", type: "text", remarks: "")
//                column(name: "attributes_307", type: "text", remarks: "")
//                column(name: "attributes_308", type: "text", remarks: "")
//                column(name: "attributes_309", type: "text", remarks: "")
//                column(name: "attributes_310", type: "text", remarks: "")
//                column(name: "attributes_311", type: "text", remarks: "")
//                column(name: "attributes_312", type: "text", remarks: "")
//                column(name: "attributes_313", type: "text", remarks: "")
//                column(name: "attributes_314", type: "text", remarks: "")
//                column(name: "attributes_315", type: "text", remarks: "")
//                column(name: "attributes_316", type: "text", remarks: "")
//                column(name: "attributes_317", type: "text", remarks: "")
//                column(name: "attributes_318", type: "text", remarks: "")
//                column(name: "attributes_319", type: "text", remarks: "")
//                column(name: "attributes_320", type: "text", remarks: "")
//                column(name: "attributes_321", type: "text", remarks: "")
//                column(name: "attributes_322", type: "text", remarks: "")
//                column(name: "attributes_323", type: "text", remarks: "")
//                column(name: "attributes_324", type: "text", remarks: "")
//                column(name: "attributes_325", type: "text", remarks: "")
//                column(name: "attributes_326", type: "text", remarks: "")
//                column(name: "attributes_327", type: "text", remarks: "")
//                column(name: "attributes_328", type: "text", remarks: "")
//                column(name: "attributes_329", type: "text", remarks: "")
//                column(name: "attributes_330", type: "text", remarks: "")
//                column(name: "attributes_331", type: "text", remarks: "")
//                column(name: "attributes_332", type: "text", remarks: "")
//                column(name: "attributes_333", type: "text", remarks: "")
//                column(name: "attributes_334", type: "text", remarks: "")
//                column(name: "attributes_335", type: "text", remarks: "")
//                column(name: "attributes_336", type: "text", remarks: "")
//                column(name: "attributes_337", type: "text", remarks: "")
//                column(name: "attributes_338", type: "text", remarks: "")
//                column(name: "attributes_339", type: "text", remarks: "")
//                column(name: "attributes_340", type: "text", remarks: "")
//                column(name: "attributes_341", type: "text", remarks: "")
//                column(name: "attributes_342", type: "text", remarks: "")
//                column(name: "attributes_343", type: "text", remarks: "")
//                column(name: "attributes_344", type: "text", remarks: "")
//                column(name: "attributes_345", type: "text", remarks: "")
//                column(name: "attributes_346", type: "text", remarks: "")
//                column(name: "attributes_347", type: "text", remarks: "")
//                column(name: "attributes_348", type: "text", remarks: "")
//                column(name: "attributes_349", type: "text", remarks: "")
//                column(name: "attributes_350", type: "text", remarks: "")
//                column(name: "attributes_351", type: "text", remarks: "")
//                column(name: "attributes_352", type: "text", remarks: "")
//                column(name: "attributes_353", type: "text", remarks: "")
//                column(name: "attributes_354", type: "text", remarks: "")
//                column(name: "attributes_355", type: "text", remarks: "")
//                column(name: "attributes_356", type: "text", remarks: "")
//                column(name: "attributes_357", type: "text", remarks: "")
//                column(name: "attributes_358", type: "text", remarks: "")
//                column(name: "attributes_359", type: "text", remarks: "")
//                column(name: "attributes_360", type: "text", remarks: "")
//                column(name: "attributes_361", type: "text", remarks: "")
//                column(name: "attributes_362", type: "text", remarks: "")
//                column(name: "attributes_363", type: "text", remarks: "")
//                column(name: "attributes_364", type: "text", remarks: "")
//                column(name: "attributes_365", type: "text", remarks: "")
//                column(name: "attributes_366", type: "text", remarks: "")
//                column(name: "attributes_367", type: "text", remarks: "")
//                column(name: "attributes_368", type: "text", remarks: "")
//                column(name: "attributes_369", type: "text", remarks: "")
//                column(name: "attributes_370", type: "text", remarks: "")
//                column(name: "attributes_371", type: "text", remarks: "")
//                column(name: "attributes_372", type: "text", remarks: "")
//                column(name: "attributes_373", type: "text", remarks: "")
//                column(name: "attributes_374", type: "text", remarks: "")
//                column(name: "attributes_375", type: "text", remarks: "")
//                column(name: "attributes_376", type: "text", remarks: "")
//                column(name: "attributes_377", type: "text", remarks: "")
//                column(name: "attributes_378", type: "text", remarks: "")
//                column(name: "attributes_379", type: "text", remarks: "")
//                column(name: "attributes_380", type: "text", remarks: "")
//                column(name: "attributes_381", type: "text", remarks: "")
//                column(name: "attributes_382", type: "text", remarks: "")
//                column(name: "attributes_383", type: "text", remarks: "")
//                column(name: "attributes_384", type: "text", remarks: "")
//                column(name: "attributes_385", type: "text", remarks: "")
//                column(name: "attributes_386", type: "text", remarks: "")
//                column(name: "attributes_387", type: "text", remarks: "")
//                column(name: "attributes_388", type: "text", remarks: "")
//                column(name: "attributes_389", type: "text", remarks: "")
//                column(name: "attributes_390", type: "text", remarks: "")
//                column(name: "attributes_391", type: "text", remarks: "")
//                column(name: "attributes_392", type: "text", remarks: "")
//                column(name: "attributes_393", type: "text", remarks: "")
//                column(name: "attributes_394", type: "text", remarks: "")
//                column(name: "attributes_395", type: "text", remarks: "")
//                column(name: "attributes_396", type: "text", remarks: "")
//                column(name: "attributes_397", type: "text", remarks: "")
//                column(name: "attributes_398", type: "text", remarks: "")
//                column(name: "attributes_399", type: "text", remarks: "")
//                column(name: "attributes_400", type: "text", remarks: "")
//                column(name: "attributes_401", type: "text", remarks: "")
//                column(name: "attributes_402", type: "text", remarks: "")
//                column(name: "attributes_403", type: "text", remarks: "")
//                column(name: "attributes_404", type: "text", remarks: "")
//                column(name: "attributes_405", type: "text", remarks: "")
//                column(name: "attributes_406", type: "text", remarks: "")
//                column(name: "attributes_407", type: "text", remarks: "")
//                column(name: "attributes_408", type: "text", remarks: "")
//                column(name: "attributes_409", type: "text", remarks: "")
//                column(name: "attributes_410", type: "text", remarks: "")
//                column(name: "attributes_411", type: "text", remarks: "")
//                column(name: "attributes_412", type: "text", remarks: "")
//                column(name: "attributes_413", type: "text", remarks: "")
//                column(name: "attributes_414", type: "text", remarks: "")
//                column(name: "attributes_415", type: "text", remarks: "")
//                column(name: "attributes_416", type: "text", remarks: "")
//                column(name: "attributes_417", type: "text", remarks: "")
//                column(name: "attributes_418", type: "text", remarks: "")
//                column(name: "attributes_419", type: "text", remarks: "")
//                column(name: "attributes_420", type: "text", remarks: "")
//                column(name: "attributes_421", type: "text", remarks: "")
//                column(name: "attributes_422", type: "text", remarks: "")
//                column(name: "attributes_423", type: "text", remarks: "")
//                column(name: "attributes_424", type: "text", remarks: "")
//                column(name: "attributes_425", type: "text", remarks: "")
//                column(name: "attributes_426", type: "text", remarks: "")
//                column(name: "attributes_427", type: "text", remarks: "")
//                column(name: "attributes_428", type: "text", remarks: "")
//                column(name: "attributes_429", type: "text", remarks: "")
//                column(name: "attributes_430", type: "text", remarks: "")
//                column(name: "attributes_431", type: "text", remarks: "")
//                column(name: "attributes_432", type: "text", remarks: "")
//                column(name: "attributes_433", type: "text", remarks: "")
//                column(name: "attributes_434", type: "text", remarks: "")
//                column(name: "attributes_435", type: "text", remarks: "")
//                column(name: "attributes_436", type: "text", remarks: "")
//                column(name: "attributes_437", type: "text", remarks: "")
//                column(name: "attributes_438", type: "text", remarks: "")
//                column(name: "attributes_439", type: "text", remarks: "")
//                column(name: "attributes_440", type: "text", remarks: "")
//                column(name: "attributes_441", type: "text", remarks: "")
//                column(name: "attributes_442", type: "text", remarks: "")
//                column(name: "attributes_443", type: "text", remarks: "")
//                column(name: "attributes_444", type: "text", remarks: "")
//                column(name: "attributes_445", type: "text", remarks: "")
//                column(name: "attributes_446", type: "text", remarks: "")
//                column(name: "attributes_447", type: "text", remarks: "")
//                column(name: "attributes_448", type: "text", remarks: "")
//                column(name: "attributes_449", type: "text", remarks: "")
//                column(name: "attributes_450", type: "text", remarks: "")
//                column(name: "attributes_451", type: "text", remarks: "")
//                column(name: "attributes_452", type: "text", remarks: "")
//                column(name: "attributes_453", type: "text", remarks: "")
//                column(name: "attributes_454", type: "text", remarks: "")
//                column(name: "attributes_455", type: "text", remarks: "")
//                column(name: "attributes_456", type: "text", remarks: "")
//                column(name: "attributes_457", type: "text", remarks: "")
//                column(name: "attributes_458", type: "text", remarks: "")
//                column(name: "attributes_459", type: "text", remarks: "")
//                column(name: "attributes_460", type: "text", remarks: "")
//                column(name: "attributes_461", type: "text", remarks: "")
//                column(name: "attributes_462", type: "text", remarks: "")
//                column(name: "attributes_463", type: "text", remarks: "")
//                column(name: "attributes_464", type: "text", remarks: "")
//                column(name: "attributes_465", type: "text", remarks: "")
//                column(name: "attributes_466", type: "text", remarks: "")
//                column(name: "attributes_467", type: "text", remarks: "")
//                column(name: "attributes_468", type: "text", remarks: "")
//                column(name: "attributes_469", type: "text", remarks: "")
//                column(name: "attributes_470", type: "text", remarks: "")
//                column(name: "attributes_471", type: "text", remarks: "")
//                column(name: "attributes_472", type: "text", remarks: "")
//                column(name: "attributes_473", type: "text", remarks: "")
//                column(name: "attributes_474", type: "text", remarks: "")
//                column(name: "attributes_475", type: "text", remarks: "")
//                column(name: "attributes_476", type: "text", remarks: "")
//                column(name: "attributes_477", type: "text", remarks: "")
//                column(name: "attributes_478", type: "text", remarks: "")
//                column(name: "attributes_479", type: "text", remarks: "")
//                column(name: "attributes_480", type: "text", remarks: "")
//                column(name: "attributes_481", type: "text", remarks: "")
//                column(name: "attributes_482", type: "text", remarks: "")
//                column(name: "attributes_483", type: "text", remarks: "")
//                column(name: "attributes_484", type: "text", remarks: "")
//                column(name: "attributes_485", type: "text", remarks: "")
//                column(name: "attributes_486", type: "text", remarks: "")
//                column(name: "attributes_487", type: "text", remarks: "")
//                column(name: "attributes_488", type: "text", remarks: "")
//                column(name: "attributes_489", type: "text", remarks: "")
//                column(name: "attributes_490", type: "text", remarks: "")
//                column(name: "attributes_491", type: "text", remarks: "")
//                column(name: "attributes_492", type: "text", remarks: "")
//                column(name: "attributes_493", type: "text", remarks: "")
//                column(name: "attributes_494", type: "text", remarks: "")
//                column(name: "attributes_495", type: "text", remarks: "")
//                column(name: "attributes_496", type: "text", remarks: "")
//                column(name: "attributes_497", type: "text", remarks: "")
//                column(name: "attributes_498", type: "text", remarks: "")
//                column(name: "attributes_499", type: "text", remarks: "")
//                column(name: "attributes_500", type: "text", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_SCORE_TARGET_VALUES") {
        createTable(tableName: "HLS_SCORE_TARGET_VALUES", remarks: "") {
            column(name: "score_target_value_id", type: "bigint(20)", remarks: "", autoIncrement: "true", startWith: "95") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_SCORE_TARGET_VALUES_PK")
            }
            column(name: "score_target_id", type: "bigint(20)", remarks: "")
            column(name: "line_number", type: "bigint(20)", remarks: "")
            column(name: "left_bracket", type: "varchar(100)", remarks: "")
            column(name: "from_value", type: "varchar(100)", remarks: "")
            column(name: "to_value", type: "varchar(100)", remarks: "")
            column(name: "right_bracket", type: "varchar(100)", remarks: "")
            column(name: "fixed_target_value", type: "varchar(200)", remarks: "")
            column(name: "description", type: "varchar(300)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_SCORE_TARGET_VALUES", columnNames: "score_target_id,line_number", constraintName: "uni_HLS_SCORE_TARGET_VALUES")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_MASTER_BAD_RECORD") {
        createTable(tableName: "HLS_BP_MASTER_BAD_RECORD", remarks: "") {
            column(name: "record_order", type: "varchar(255)", remarks: "") {
                constraints(primaryKey: "true", primaryKeyName: "HLS_BP_MASTER_BAD_RECORD_PK")
            }
            column(name: "doc_number", type: "varchar(255)", remarks: "")
            column(name: "company_Name", type: "varchar(255)", remarks: "")
            column(name: "represent_Name", type: "varchar(255)", remarks: "")
            column(name: "code", type: "varchar(255)", remarks: "")
            column(name: "case_Reason", type: "varchar(255)", remarks: "")
            column(name: "punish_Basis", type: "varchar(255)", remarks: "")
            column(name: "punish_Result", type: "varchar(255)", remarks: "")
            column(name: "police_Depart", type: "varchar(255)", remarks: "")
            column(name: "date", type: "varchar(255)", remarks: "")
            column(name: "detail_Url", type: "varchar(255)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_BP_REPORT_H") {
        createTable(tableName: "HLS_BP_REPORT_H", remarks: "") {
            column(name: "version_id", type: "bigint(20)", remarks: "版本ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_REPORT_H_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "BP报告ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_BP_REPORT_H_PK")
            }
            column(name: "bp_id", type: "bigint(20)", remarks: "商业伙伴ID")
            column(name: "report_number", type: "varchar(100)", remarks: "报告编号")
            column(name: "report_name", type: "varchar(300)", remarks: "报告名称")
            column(name: "document_type", type: "varchar(100)", remarks: "单据类型")
            column(name: "document_category", type: "varchar(100)", remarks: "单据类别")
            column(name: "business_type", type: "varchar(100)", remarks: "业务类型")
            column(name: "source_document_category", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "source_document_id", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "status", type: "varchar(100)", remarks: "状态")
            column(name: "report_by", type: "bigint(20)", remarks: "报告人")
            column(name: "report_date", type: "datetime", remarks: "报告时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_BP_REPORT_H", columnNames: "bp_id,report_number,version_id", constraintName: "HLS_BP_REPORT_H_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_CON_FILE_TEMPLET") {
        createTable(tableName: "HLS_CON_FILE_TEMPLET", remarks: "") {
            column(name: "con_templet_id", type: "bigint(20)", remarks: "主键", autoIncrement: "true", startWith: "15") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_CON_FILE_TEMPLET_PK")
            }
            column(name: "seq_id", type: "bigint(20)", remarks: "")
            column(name: "con_templet_code", type: "varchar(100)", remarks: "")
            column(name: "con_templet_name", type: "varchar(300)", remarks: "")
            column(name: "company_id", type: "bigint(20)", remarks: "")
            column(name: "con_templet_usage", type: "varchar(100)", remarks: "")
            column(name: "templet_id", type: "bigint(100)", remarks: "")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_CON_FILE_TEMPLET", columnNames: "seq_id,con_templet_code", constraintName: "UK_HLS_CON_FILE_TEMPLET")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DEBT_DEDUCTION_BANK") {
        createTable(tableName: "HLS_DEBT_DEDUCTION_BANK", remarks: "") {
            column(name: "BANK_ID", type: "bigint(20)", remarks: "银行ID", autoIncrement: "true", startWith: "2") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DEBT_DEDUCTION_BANK_PK")
            }
            column(name: "BANK_CODE", type: "varchar(100)", remarks: "银行代码")
            column(name: "BANK_NAME", type: "varchar(100)", remarks: "银行名称")
            column(name: "BANK_IMAGE", type: "varchar(200)", remarks: "银行图标")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "是否启用")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DEBT_DEDUCTION_DETAIL") {
        createTable(tableName: "HLS_DEBT_DEDUCTION_DETAIL", remarks: "") {
            column(name: "DETAIL_ID", type: "bigint(20)", remarks: "明细ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DEBT_DEDUCTION_DETAIL_PK")
            }
            column(name: "LINE_ID", type: "bigint(20)", remarks: "外键：hls_debt_deduction_line.line_id")
            column(name: "SOURCE_TABLE", type: "varchar(100)", remarks: "来源数据表")
            column(name: "SOURCE_ID", type: "bigint(20)", remarks: "来源数据id")
            column(name: "ALLOCATE_AMOUNT", type: "double(20,2)", remarks: "核销金额")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "WRITE_OFF_AMOUNT", type: "double", remarks: "")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DEBT_DEDUCTION_HEADER") {
        createTable(tableName: "HLS_DEBT_DEDUCTION_HEADER", remarks: "") {
            column(name: "HEADER_ID", type: "bigint(20)", remarks: "头ID", autoIncrement: "true", startWith: "2") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DEBT_DEDUCTION_HEADER_PK")
            }
            column(name: "DEDUCTION_NUMBER", type: "varchar(100)", remarks: "编号") { constraints(nullable: "false") }
            column(name: "BANK_ID", type: "bigint(20)", remarks: "代扣银行") { constraints(nullable: "false") }
            column(name: "STATUS", type: "varchar(100)", remarks: "状态：NEW/DEDUCTING/WRITEOFFING/FINISH  新建/扣款中/核销中/完成") {
                constraints(nullable: "false")
            }
            column(name: "LOG_FILE_PATH", type: "varchar(200)", remarks: "日志文件路径")
            column(name: "LOG_FILE_NAME", type: "varchar(100)", remarks: "日志文件名")
            column(name: "SEND_DATE", type: "datetime", remarks: "发送时间")
            column(name: "BACK_DATE", type: "datetime", remarks: "结果回传时间")
            column(name: "FINISH_DATE", type: "datetime", remarks: "处理结束时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DEBT_DEDUCTION_LINE") {
        createTable(tableName: "HLS_DEBT_DEDUCTION_LINE", remarks: "") {
            column(name: "LINE_ID", type: "bigint(20)", remarks: "行ID", autoIncrement: "true", startWith: "2") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DEBT_DEDUCTION_LINE_PK")
            }
            column(name: "HEADER_ID", type: "bigint(20)", remarks: "外键：hls_debt_deduction_header.header_id") {
                constraints(nullable: "false")
            }
            column(name: "ACCOUNT_NAME", type: "varchar(100)", remarks: "账户名") { constraints(nullable: "false") }
            column(name: "ACCOUNT_NUM", type: "varchar(100)", remarks: "账号") { constraints(nullable: "false") }
            column(name: "DUE_AMOUNT", type: "double(20,2)", remarks: "应扣款金额") { constraints(nullable: "false") }
            column(name: "ADJUST_AMOUNT", type: "double(20,2)", remarks: "调整扣款金额") {
                constraints(nullable: "false")
            }
            column(name: "ACTUAL_AMOUNT", type: "double(20,2)", remarks: "实际扣款金额")
            column(name: "STATUS", type: "varchar(100)", remarks: "状态：NEW/DEDUCTING/WRITEOFFING/FINISH  新建/扣款中/核销中/完成")
            column(name: "MESSAGE", type: "varchar(300)", remarks: "代扣返回信息")
            column(name: "CONTRACT_ID", type: "bigint(20)", remarks: "")
            column(name: "TRANSACTION_ID", type: "bigint(20)", remarks: "")
            column(name: "BANK_ACCOUNT_ID", type: "bigint(20)", remarks: "")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-HLS_DOC_AUTHORITY") {
        createTable(tableName: "HLS_DOC_AUTHORITY", remarks: "") {
            column(name: "USER_ID", type: "bigint(20)", remarks: "用户ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOC_AUTHORITY_PK")
            }
            column(name: "DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "单据类别") {
                constraints(nullable: "false")
            }
            column(name: "DOCUMENT_ID", type: "bigint(20)", remarks: "单据ID")
            column(name: "AUTHORITY_TYPE", type: "varchar(100)", remarks: "权限类型")
            column(name: "SOURCE_MODULE", type: "varchar(100)", remarks: "来源模块")
            column(name: "SOURCE_EVENT", type: "varchar(100)", remarks: "来源事件")
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "来源单据")
            column(name: "SOURCE_DOCUMENT_ID", type: "bigint(20)", remarks: "来源单据ID")
            column(name: "SOURCE_USER_ID", type: "bigint(20)", remarks: "发布人")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_DOCUMENT_VERSION") {
        createTable(tableName: "HLS_DOCUMENT_VERSION", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_DOCUMENT_VERSION_PK")
            }
            column(name: "VERSION_DATE", type: "DATETIME", remarks: "版本日期")
            column(name: "DESCRIPTION", type: "varchar(300)", remarks: "说明")
            column(name: "SOURCE_EVENT", type: "varchar(300)", remarks: "来源事件")
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(200)", remarks: "来源单据类型")
            column(name: "SOURCE_DOCUMENT_ID", type: "bigint(20)", remarks: "来源单据id")
            column(name: "SOURCE_USER_ID", type: "bigint(20)", remarks: "来源用户id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_FIN_CALC_CONFIG") {
        createTable(tableName: "HLS_FIN_CALC_CONFIG", remarks: "") {
            column(name: "CONFIG_ID", type: "bigint(20)", remarks: "主键ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_FIN_CALC_CONFIG_PK")
            }
            column(name: "COLUMN_CODE", type: "varchar(20)", remarks: "")
            column(name: "COLUMN_NAME", type: "varchar(20)", remarks: "")
            column(name: "PRICE_LIST", type: "varchar(20)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_FIN_CALC_CONFIG", columnNames: "COLUMN_NAME,PRICE_LIST", constraintName: "HLS_FIN_CALC_CONFIG_U1")
        addUniqueConstraint(tableName: "HLS_FIN_CALC_CONFIG", columnNames: "COLUMN_CODE,PRICE_LIST", constraintName: "HLS_FIN_CALC_CONFIG_U2")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_PRICE_LIST") {
        createTable(tableName: "HLS_PRICE_LIST", remarks: "") {
            column(name: "PRICE_LIST", type: "VARCHAR(100)", remarks: "主键ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_PRICE_LIST_PK")
            }
            column(name: "SHEETS", type: "LONGTEXT", remarks: "")
            column(name: "DESCRIPTION", type: "varchar(200)", remarks: "")
            column(name: "ENABLED_FLAG", type: "varchar(10)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_RABBIT_EXCHANGE") {
        createTable(tableName: "HLS_RABBIT_EXCHANGE", remarks: "") {
            column(name: "EXCHANGE_ID", type: "bigint(20)", remarks: "交换机ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RABBIT_EXCHANGE_PK")
            }
            column(name: "EXCHANGE_CODE", type: "VARCHAR(200)", remarks: "交换机代码")
            column(name: "EXCHANGE_NAME", type: "varchar(200)", remarks: "交换机名称")
            column(name: "EXCHANGE_TYPE", type: "varchar(200)", remarks: "交换机类型(SYSCODE:TOPIC/主题模式,DIRECT/唯一模式,FANOUT/广播模式)")
            column(name: "DURABLE", type: "varchar(1)", remarks: "持久化")
            column(name: "AUTO_DETELE", type: "VARCHAR(1)", remarks: "自动删除")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_RABBIT_EXCHANGE_QUEUE") {
        createTable(tableName: "HLS_RABBIT_EXCHANGE_QUEUE", remarks: "") {
            column(name: "QUEUE_ID", type: "bigint(20)", remarks: "队列ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RABBIT_EXCHANGE_QUEUE_PK")
            }
            column(name: "EXCHANGE_ID", type: "VARCHAR(20)", remarks: "交换机ID")
            column(name: "QUEUE_CODE", type: "varchar(200)", remarks: "交换机代码")
            column(name: "QUEUE_NAME", type: "varchar(200)", remarks: "交换机名称")
            column(name: "ROUTING_KEY", type: "varchar(200)", remarks: "匹配式")
            column(name: "DURABLE", type: "varchar(1)", remarks: "持久化")
            column(name: "AUTO_DELETE", type: "VARCHAR(1)", remarks: "自动删除")
            column(name: "EXCLUSIVE", type: "varchar(1)", remarks: "私有队列")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_RULE_ENGINE_DATA") {
        createTable(tableName: "HLS_RULE_ENGINE_DATA", remarks: "") {
            column(name: "DATA_ID", type: "bigint(20)", remarks: "", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HLS_RULE_ENGINE_DATA_PK")
            }
            column(name: "RULE_ENGINE_ID", type: "BIGINT(20)", remarks: "")
            column(name: "DATA_NAME", type: "varchar(200)", remarks: "")
            column(name: "DATA_DESCRIPTION", type: "varchar(200)", remarks: "")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HLS_RULE_ENGINE_DATA", columnNames: "RULE_ENGINE_ID,DATA_NAME", constraintName: "HLS_RULE_ENGINE_DATA_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HLS_USER_RELATIONSHIP_B") {
        createTable(tableName: "HLS_USER_RELATIONSHIP_B", remarks: "") {
            column(name: "USER_ID", type: "bigint(20)", remarks: "用户id")
            column(name: "RELATION_USER_ID", type: "BIGINT(20)", remarks: "关联用户id")
            column(name: "RELATION_DOCUMENT_ID", type: "BIGINT(20)", remarks: "关系单据id")
            column(name: "RELATION_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "关系单据类别")
            column(name: "RELATION_TYPE", type: "varchar(100)", remarks: "关系类型")
            column(name: "SOURCE_MODULE", type: "varchar(100)", remarks: "来源模块")
            column(name: "SOURCE_EVENT", type: "varchar(100)", remarks: "来源事件")
            column(name: "SOURCE_USER_ID", type: "BIGINT(20)", remarks: "发布人")
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "来源单据")
            column(name: "SOURCE_DOCUMENT_ID", type: "BIGINT(20)", remarks: "来源单据id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HR_EMPLOYEE") {
        createTable(tableName: "HR_EMPLOYEE", remarks: "") {
            column(name: "EMPLOYEE_ID", type: "bigint(20)", remarks: "员工id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_EMPLOYEE_PK")
            }
            column(name: "EMPLOYEE_CODE", type: "VARCHAR(30)", remarks: "员工编码")
            column(name: "NAME", type: "VARCHAR(50)", remarks: "员工姓名")
            column(name: "BORN_DATE", type: "DATE", remarks: "出生日期")
            column(name: "EMAIL", type: "varchar(50)", remarks: "电子邮件")
            column(name: "MOBILE", type: "varchar(50)", remarks: "移动电话")
            column(name: "JOIN_DATE", type: "DATE", remarks: "入职日期")
            column(name: "GENDER", type: "varchar(1)", remarks: "性别")
            column(name: "CERTIFICATE_ID", type: "VARCHAR(100)", remarks: "ID")
            column(name: "STATUS", type: "varchar(50)", remarks: "状态")
            column(name: "ENABLED_FLAG", type: "VARCHAR(1)", remarks: "启用状态")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "CERTIFICATE_TYPE", type: "BIGINT(20)", remarks: "证件类型")
            column(name: "EFFECTIVE_START_DATE", type: "BIGINT(20)", remarks: "有效期从")
            column(name: "EFFECTIVE_END_DATE", type: "BIGINT(20)", remarks: "有效期至")
            column(name: "ATTRIBUTE1", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE2", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE3", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE4", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE5", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE6", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE7", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE8", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE9", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE10", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE11", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE12", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE13", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE14", type: "VARCHAR(240)", remarks: "")
            column(name: "ATTRIBUTE15", type: "VARCHAR(240)", remarks: "")
        }

        addUniqueConstraint(tableName: "HR_EMPLOYEE", columnNames: "CERTIFICATE_ID", constraintName: "HR_EMPLOYEE_U2")
        addUniqueConstraint(tableName: "HR_EMPLOYEE", columnNames: "EMPLOYEE_CODE", constraintName: "HR_EMPLOYEE_U1")
    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HR_EMPLOYEE_ASSIGN") {
        createTable(tableName: "HR_EMPLOYEE_ASSIGN", remarks: "") {
            column(name: "ASSIGN_ID", type: "bigint(20)", remarks: "", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_EMPLOYEE_ASSIGN_PK")
            }
            column(name: "EMPLOYEE_ID", type: "BIGINT(20)", remarks: "员工id")
            column(name: "POSITION_ID", type: "BIGINT(20)", remarks: "岗位id")
            column(name: "PRIMARY_POSITION_FLAG", type: "varchar(1)", remarks: "主岗位标识")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用状态")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "HR_EMPLOYEE_ASSIGN", columnNames: "EMPLOYEE_ID,POSITION_ID", constraintName: "HR_EMPLOYEE_ASSIGN_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HR_ORG_POSITION_B") {
        createTable(tableName: "HR_ORG_POSITION_B", remarks: "") {
            column(name: "POSITION_ID", type: "bigint(20)", remarks: "", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_ORG_POSITION_B_PK")
            }
            column(name: "UNIT_ID", type: "BIGINT(20)", remarks: "组织id")
            column(name: "POSITION_CODE", type: "VARCHAR(50)", remarks: "岗位编码")
            column(name: "NAME", type: "varchar(100)", remarks: "岗位名称")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "岗位描述")
            column(name: "PARENT_POSITION_ID", type: "BIGINT(20)", remarks: "父岗位id")
            column(name: "ENABLED_FLAG", type: "VARCHAR(1)", remarks: "启用状态")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HR_ORG_POSITION_TL") {
        createTable(tableName: "HR_ORG_POSITION_TL", remarks: "") {
            column(name: "POSITION_ID", type: "BIGINT(20)", remarks: "岗位id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_ORG_POSITION_TL_PK")
            }
            column(name: "LANG", type: "VARCHAR(50)", remarks: "语言") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_ORG_POSITION_TL_PK")
            }
            column(name: "NAME", type: "VARCHAR(100)", remarks: "岗位名称")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "岗位描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HR_ORG_UNIT_B") {
        createTable(tableName: "HR_ORG_UNIT_B", remarks: "") {
            column(name: "UNIT_ID", type: "bigint(20)", remarks: "组织id", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_ORG_UNIT_B_PK")
            }
            column(name: "PARENT_ID", type: "BIGINT(20)", remarks: "父组织id")
            column(name: "UNIT_CODE", type: "VARCHAR(50)", remarks: "组织编码")
            column(name: "NAME", type: "varchar(100)", remarks: "组织名称")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "组织描述")
            column(name: "MANAGER_POSITION", type: "BIGINT(20)", remarks: "组织管理岗位")
            column(name: "COMPANY_ID", type: "BIGINT(20)", remarks: "公司id")
            column(name: "ENABLED_FLAG", type: "VARCHAR(1)", remarks: "启用状态")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "UNIT_CATEGORY", type: "VARCHAR(50)", remarks: "组织类别")
            column(name: "UNIT_TYPE", type: "VARCHAR(50)", remarks: "组织分类")
        }
        addUniqueConstraint(tableName: "HR_ORG_UNIT_B", columnNames: "UNIT_CODE", constraintName: "HR_ORG_UNIT_BU1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-HR_ORG_UNIT_TL") {
        createTable(tableName: "HR_ORG_UNIT_TL", remarks: "") {
            column(name: "UNIT_ID", type: "BIGINT(20)", remarks: "组织id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_ORG_UNIT_TL_PK")
            }
            column(name: "LANG", type: "VARCHAR(50)", remarks: "语言") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "HR_ORG_UNIT_TL_PK")
            }
            column(name: "NAME", type: "VARCHAR(100)", remarks: "组织名称")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "组织描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_GUARANTOR_H") {
        createTable(tableName: "PRJ_PROJECT_GUARANTOR_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_GUARANTOR_H_PK")
            }
            column(name: "PROJECT_GUARANTOR_ID", type: "BIGINT(20)", remarks: "项目担保人id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_GUARANTOR_H_PK")
            }
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "项目id")
            column(name: "GUARANTOR_BP_ID", type: "BIGINT(20)", remarks: "担保人商业伙伴id")
            column(name: "GURANTEE_TYPE", type: "varchar(100)", remarks: "担保类型")
            column(name: "DESCRIPTION", type: "VARCHAR(300)", remarks: "说明备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "PRJ_PROJECT_GUARANTOR_H", columnNames: "VERSION_ID,PROJECT_ID,GUARANTOR_BP_ID", constraintName: "PRJ_PROJECT_GUARANTOR_H_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_H") {
        createTable(tableName: "PRJ_PROJECT_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_H_PK")
            }
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "项目id")
            column(name: "COMPANY_ID", type: "BIGINT(20)", remarks: "公司id")
            column(name: "DOCUMENT_TYPE", type: "VARCHAR(100)", remarks: "单据类型")
            column(name: "DOCUMENT_CATEGORY", type: "VARCHAR(10)", remarks: "单据类别")
            column(name: "BUSINESS_TYPE", type: "VARCHAR(100)", remarks: "业务类型")
            column(name: "PROJECT_NUMBER", type: "VARCHAR(100)", remarks: "项目编号")
            column(name: "PROJECT_NAME", type: "VARCHAR(300)", remarks: "项目名称")
            column(name: "PROJECT_STATUS", type: "VARCHAR(100)", remarks: "项目状态")
            column(name: "LEASE_CHANNEL", type: "VARCHAR(100)", remarks: "商业模式")
            column(name: "DIVISION", type: "VARCHAR(100)", remarks: "产品线")
            column(name: "EMPLOYEE_ID", type: "BIGINT(20)", remarks: "业务员(用户id)")
            column(name: "UNIT_ID", type: "BIGINT(20)", remarks: "部门id")
            column(name: "FINANCE_AMOUNT", type: "BIGINT(20)", remarks: "融资额")
            column(name: "LEASE_START_DATE", type: "DATETIME", remarks: "租赁期开始日")
            column(name: "FINANCING_PURPOSE", type: "VARCHAR(300)", remarks: "融资目的")
            column(name: "CURRENCY", type: "VARCHAR(200)", remarks: "币种")
            column(name: "DESCRIPTION", type: "VARCHAR(300)", remarks: "备注")
            column(name: "COMPREHENSIVE_OPINION", type: "VARCHAR(4000)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_LEASE_ITEM_H") {
        createTable(tableName: "PRJ_PROJECT_LEASE_ITEM_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_LEASE_ITEM_H_PK")
            }
            column(name: "PROJECT_LEASE_ITEM_ID", type: "BIGINT(20)", remarks: "") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_LEASE_ITEM_H_PK")
            }
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "项目id")
            column(name: "SEQ_NUMBER", type: "BIGINT(20)", remarks: "")
            column(name: "LEASE_ITEM_NAME", type: "VARCHAR(300)", remarks: "")
            column(name: "SERIAL_NUMBER", type: "VARCHAR(300)", remarks: "")
            column(name: "PATTERN", type: "VARCHAR(300)", remarks: "")
            column(name: "SPECIFICATION", type: "VARCHAR(300)", remarks: "")
            column(name: "COLOUR", type: "VARCHAR(300)", remarks: "")
            column(name: "QUANTITY", type: "BIGINT(20)", remarks: "")
            column(name: "UOM", type: "VARCHAR(300)", remarks: "")
            column(name: "PRICE", type: "DOUBLE", remarks: "")
            column(name: "LEASE_ITEM_AMOUNT", type: "DOUBLE", remarks: "")
            column(name: "CURRENCY", type: "VARCHAR(100)", remarks: "")
            column(name: "VENDER_BP_ID", type: "BIGINT(20)", remarks: "")
            column(name: "DESCRIPTION", type: "VARCHAR(300)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "PRJ_PROJECT_LEASE_ITEM_H", columnNames: "VERSION_ID,PROJECT_ID,SEQ_NUMBER", constraintName: "PRJ_PROJECT_LEASE_ITEM_H_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_MEETING_H") {
        createTable(tableName: "PRJ_PROJECT_MEETING_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MEETING_H_PK")
            }
            column(name: "PROJECT_MEETING_ID", type: "BIGINT(20)", remarks: "项目上会id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MEETING_H_PK")
            }
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "项目id")
            column(name: "MEETING_NAME", type: "varchar(300)", remarks: "会议名称")
            column(name: "MEETING_LOCATION", type: "varchar(300)", remarks: "会议地点")
            column(name: "MEETING_DATE", type: "DATETIME", remarks: "会议时间")
            column(name: "MEETING_STATUS", type: "VARCHAR(100)", remarks: "状态")
            column(name: "MEETING_RESULT", type: "VARCHAR(100)", remarks: "会议结论")
            column(name: "MEETING_COMMENTS", type: "VARCHAR(300)", remarks: "会议摘要")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "PRJ_PROJECT_MEETING_H", columnNames: "VERSION_ID", constraintName: "PRJ_PROJECT_MEETING_H_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_MEETING_JUDGE_H") {
        createTable(tableName: "PRJ_PROJECT_MEETING_JUDGE_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MEETING_JUDGE_H_PK")
            }
            column(name: "PROJECT_MEETING_JUDGE_ID", type: "BIGINT(20)", remarks: "项目上会评审id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MEETING_JUDGE_H_PK")
            }
            column(name: "PROJECT_MEETING_ID", type: "BIGINT(20)", remarks: "项目上会id")
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "项目id")
            column(name: "JUDGE_EMPLOYEE_ID", type: "BIGINT(20)", remarks: "评审员工id")
            column(name: "JUDGE_APPROVE_RESULT", type: "varchar(100)", remarks: "评审结论")
            column(name: "JUDGE_APPROVE_COMMENTS", type: "VARCHAR(300)", remarks: "评审意见摘要")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "PRJ_PROJECT_MEETING_JUDGE_H", columnNames: "PROJECT_MEETING_ID,PROJECT_ID,JUDGE_EMPLOYEE_ID,VERSION_ID", constraintName: "PRJ_PROJECT_MEETING_JUDGE_H_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_MORTGAGE_H") {
        createTable(tableName: "PRJ_PROJECT_MORTGAGE_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MORTGAGE_H_PK")
            }
            column(name: "PROJECT_MORTGAGE_ID", type: "BIGINT(20)", remarks: "") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_MORTGAGE_H_PK")
            }
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "")
            column(name: "SEQ_NUMBER", type: "BIGINT(20)", remarks: "")
            column(name: "MORTGAGE_NAME", type: "varchar(300)", remarks: "")
            column(name: "MORTGAGE_TYPE", type: "VARCHAR(100)", remarks: "")
            column(name: "MORTGAGE_AST_CLASSFICATION", type: "varchar(300)", remarks: "")
            column(name: "MORTGAGE_AST_DETAIL", type: "varchar(300)", remarks: "")
            column(name: "MORTGAGE_CONTRACT_NO", type: "varchar(300)", remarks: "")
            column(name: "MORTGAGE_REGISTER_NO", type: "varchar(300)", remarks: "")
            column(name: "MORTGAGE_REGISTED_DEPT", type: "varchar(300)", remarks: "")
            column(name: "MORTGAGE_BP_ID", type: "BIGINT(20)", remarks: "")
            column(name: "MORTGAGE_VALUE", type: "DOUBLE", remarks: "")
            column(name: "CURRENCY", type: "varchar(100)", remarks: "")
            column(name: "UOM", type: "varchar(100)", remarks: "")
            column(name: "QUANTITY", type: "BIGINT(20)", remarks: "")
            column(name: "START_DATE", type: "DATETIME", remarks: "")
            column(name: "END_DATE", type: "DATETIME", remarks: "")
            column(name: "DESCRIPTION", type: "varchar(300)", remarks: "")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "PRJ_PROJECT_MORTGAGE_H", columnNames: "PROJECT_ID,SEQ_NUMBER,VERSION_ID", constraintName: "PRJ_PROJECT_MORTGAGE_H_U1")

    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_PROJECT_TENANT_H") {
        createTable(tableName: "PRJ_PROJECT_TENANT_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "项目承租人ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_TENANT_H_PK")
            }
            column(name: "PROJECT_TENANT_ID", type: "BIGINT(20)", remarks: "项目承租人ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_PROJECT_TENANT_H_PK")
            }
            column(name: "PROJECT_ID", type: "BIGINT(20)", remarks: "项目id")
            column(name: "TENANT_BP_ID", type: "BIGINT(20)", remarks: "承租人商业伙伴ID")
            column(name: "TENANT_BP_TYPE", type: "varchar(100)", remarks: "承租人商业伙伴类型")
            column(name: "DESCRIPTION", type: "VARCHAR(300)", remarks: "说明备注")
            column(name: "DESCRIPTION_STOCK_STRU", type: "TEXT", remarks: "承租人与主要股东、下属控股公司等关联企业关联交易情况简介")
            column(name: "INVESTMENT_SITUATION", type: "TEXT", remarks: "承租人对外投资情况简介")
            column(name: "INDUSTRY_STATUS", type: "TEXT", remarks: "行业现状(简要)")
            column(name: "PRODUCT_SUPPLY_DEMAND", type: "TEXT", remarks: "承租人产品及其上、下游市场供需状况")
            column(name: "MAKE_COMPETITION_ANALYSIS", type: "TEXT", remarks: "承租人的市场竞争能力分析")
            column(name: "PROFIT_MODEL", type: "TEXT", remarks: "承租人盈利模式(或经营特点)及上下游客户")
            column(name: "ENVIRONMENTAL_STATUS", type: "TEXT", remarks: "承租人经营情况-承租人的环保状况")
            column(name: "DEVELOPMENT_RESOURCE", type: "TEXT", remarks: "企业可持续发展的资源因素")
            column(name: "RESEARCH_DEVELOPMENT_ABILITY", type: "TEXT", remarks: "承租人经营情况-企业的研发能力和可持续发展能力")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_QUOTATION_CASHFLOW_H") {
        createTable(tableName: "PRJ_QUOTATION_CASHFLOW_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_CASHFLOW_H_PK")
            }
            column(name: "QUOTATION_CASHFLOW_ID", type: "BIGINT(20)", remarks: "现金流id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_CASHFLOW_H_PK")
            }
            column(name: "QUOTATION_ID", type: "BIGINT(20)", remarks: "项目报价ID")
            column(name: "CF_ITEM", type: "BIGINT(4)", remarks: "现金流项目")
            column(name: "CF_TYPE", type: "BIGINT(4)", remarks: "现金流类型")
            column(name: "CF_DIRECTION", type: "VARCHAR(100)", remarks: "现金流方向(INFLOW/OUTFLOW)")
            column(name: "CF_STATUS", type: "varchar(100)", remarks: "现金流状态(BLOCK/冻结 、RELEASE/下达、CANCEL/取消) (syscode：HLS.CASHFLOW_STATUS)")
            column(name: "TIMES", type: "BIGINT(4)", remarks: "期数")
            column(name: "DUE_DATE", type: "DATETIME", remarks: "支付日/到期日")
            column(name: "FIN_INCOME_DATE", type: "DOUBLE", remarks: "收入确认日")
            column(name: "DUE_AMOUNT", type: "DOUBLE", remarks: "应收金额")
            column(name: "NET_DUE_AMOUNT", type: "DOUBLE", remarks: "不含税应收金额")
            column(name: "VAT_DUE_AMOUNT", type: "DOUBLE", remarks: "增值税额")
            column(name: "PRINCIPAL", type: "DOUBLE", remarks: "应收本金")
            column(name: "NET_PRINCIPAL", type: "DOUBLE", remarks: "不含税应收本金")
            column(name: "VAT_PRINCIPAL", type: "DOUBLE", remarks: "本金增值税额")
            column(name: "INTEREST", type: "DOUBLE", remarks: "应收利息")
            column(name: "NET_INTEREST", type: "DOUBLE", remarks: "不含税应收利息")
            column(name: "VAT_INTEREST", type: "DOUBLE", remarks: "利息增值税额")
            column(name: "OUTSTANDING_RENTAL", type: "DOUBLE", remarks: "当期剩余租金")
            column(name: "OUTSTANDING_PRINCIPLE", type: "DOUBLE", remarks: "当期剩余本金")
            column(name: "OUTSTANDING_INTEREST", type: "DOUBLE", remarks: "当期剩余利息'")
            column(name: "INTEREST_ACCRUAL_BALANCE", type: "DOUBLE", remarks: "当期计息余额")
            column(name: "ACCUMULATED_UNPAID_INTEREST", type: "DOUBLE", remarks: "累计未偿还利息")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_QUOTATION_DETAILS") {
        createTable(tableName: "PRJ_QUOTATION_DETAILS", remarks: "") {
            column(name: "QUOTATION_DETAIL_ID", type: "bigint(20)", remarks: "明细ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_DETAILS_PK")
            }
            column(name: "QUOTATION_ID", type: "BIGINT(20)", remarks: "报价表id")
            column(name: "SHEETS", type: "LONGTEXT", remarks: "报价明细")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_QUOTATION_DETAILS", columnNames: "QUOTATION_ID", constraintName: "PRJ_QUOTATION_DETAILS_U1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_QUOTATION_H") {
        createTable(tableName: "PRJ_QUOTATION_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_H_PK")
            }
            column(name: "QUOTATION_ID", type: "BIGINT(20)", remarks: "报价id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_QUOTATION_H_PK")
            }
            column(name: "SOURCE_DOCUMENT_CATEGORY", type: "varchar(100)", remarks: "来源单据类别")
            column(name: "SOURCE_DOCUMENT_ID", type: "BIGINT(20)", remarks: "来源单据id")
            column(name: "DESCRIPTION", type: "varchar(200)", remarks: "备注")
            column(name: "STATUS", type: "VARCHAR(100)", remarks: "状态")
            column(name: "PRICE_LIST", type: "varchar(100)", remarks: "报价方案")
            column(name: "LEASE_START_DATE", type: "DATETIME", remarks: "租赁起始日期")
            column(name: "LEASE_TIMES", type: "int(11)", remarks: "租赁期数")
            column(name: "ANNUAL_PAY_TIMES", type: "int(11)", remarks: "支付频率(年)")
            column(name: "LEASE_TERM", type: "int(11)", remarks: "租赁期限")
            column(name: "PAY_TYPE", type: "int(11)", remarks: "支付类型(1/先付;0/后付)")
            column(name: "CURRENCY", type: "varchar(10)", remarks: "币种")
            column(name: "TAX_TYPE_ID", type: "BIGINT(20)", remarks: "税种id")
            column(name: "VAT_FLAG", type: "varchar(1)", remarks: "增值税标识")
            column(name: "VAT_RATE", type: "DOUBLE", remarks: "增值税率")
            column(name: "LEASE_ITEM_AMOUNT", type: "DOUBLE", remarks: "租赁资产总价款")
            column(name: "VAT_INPUT", type: "DOUBLE", remarks: "进项增值税额")
            column(name: "VAT_INPUT_TAX_TYPE_ID", type: "DOUBLE", remarks: "进项税税种")
            column(name: "VAT_INPUT_TAX_TYPE_RATE", type: "DOUBLE", remarks: "进项税税率")
            column(name: "DOWN_PAYMENT_RATIO", type: "DOUBLE", remarks: "首期租金比例/首付比例")
            column(name: "DOWN_PAYMENT", type: "DOUBLE", remarks: "首期租金/首付金额'")
            column(name: "NET_DOWN_PAYMENT", type: "DOUBLE", remarks: "不含税首付金额")
            column(name: "VAT_DOWN_PAYMENT", type: "DOUBLE", remarks: "首付款税额")
            column(name: "FINANCE_AMOUNT", type: "DOUBLE", remarks: "融资额 (租赁资产总价款 - 首付款，即租赁本金)")
            column(name: "NET_FINANCE_AMOUNT", type: "DOUBLE", remarks: "不含税融资额")
            column(name: "VAT_FINANCE_AMOUNT", type: "DOUBLE", remarks: "融资额增值税")
            column(name: "TOTAL_RENTAL", type: "DOUBLE", remarks: "租金总额")
            column(name: "NET_TOTAL_RENTAL", type: "DOUBLE", remarks: "不含税租金")
            column(name: "VAT_TOTAL_RENTAL", type: "DOUBLE", remarks: "租金增值税额")
            column(name: "TOTAL_INTEREST", type: "DOUBLE", remarks: "利息总额")
            column(name: "NET_TOTAL_INTEREST", type: "DOUBLE", remarks: "不含税利息")
            column(name: "VAT_TOTAL_INTEREST", type: "DOUBLE", remarks: "利息增值税额")
            column(name: "LEASE_CHARGE_RATIO", type: "DOUBLE", remarks: "手续费比例")
            column(name: "LEASE_CHARGE", type: "DOUBLE", remarks: "手续费")
            column(name: "NET_LEASE_CHARGE", type: "DOUBLE", remarks: "不含税手续费")
            column(name: "VAT_LEASE_CHARGE", type: "DOUBLE", remarks: "手续费税额")
            column(name: "LEASE_MGT_FEE_RATIO", type: "DOUBLE", remarks: "管理费比例")
            column(name: "LEASE_MGT_FEE", type: "DOUBLE", remarks: "管理费")
            column(name: "NET_LEASE_MGT_FEE", type: "DOUBLE", remarks: "不含税管理费")
            column(name: "VAT_LEASE_MGT_FEE", type: "DOUBLE", remarks: "管理费税额")
            column(name: "LEASE_MGT_FEE_RULE", type: "varchar(30)", remarks: "管理费计算方式")
            column(name: "DEPOSIT_RATIO", type: "DOUBLE", remarks: "保证金比例")
            column(name: "DEPOSIT", type: "DOUBLE", remarks: "保证金")
            column(name: "DEPOSIT_DEDUCTION", type: "varchar(30)", remarks: "保证金抵扣方式")
            column(name: "RESIDUAL_RATIO", type: "DOUBLE", remarks: "留购价款")
            column(name: "RESIDUAL_VALUE", type: "DOUBLE", remarks: "留购价款")
            column(name: "NET_RESIDUAL_VALUE", type: "DOUBLE", remarks: "不含税留购金")
            column(name: "VAT_RESIDUAL_VALUE", type: "DOUBLE", remarks: "留购金税额")
            column(name: "BALLOON_RATIO", type: "DOUBLE", remarks: "末期租金比例")
            column(name: "BALLOON", type: "DOUBLE", remarks: "末期租金")
            column(name: "NET_BALLOON", type: "DOUBLE", remarks: "不含税末期租金")
            column(name: "VAT_BALLOON", type: "DOUBLE", remarks: "末期租金税额")
            column(name: "BASE_RATE_TYPE", type: "varchar(30)", remarks: "基准利率类别：pboc央行基准、libor伦敦同业")
            column(name: "BASE_RATE", type: "DOUBLE", remarks: "基准利率")
            column(name: "INT_RATE", type: "DOUBLE", remarks: "租赁利率")
            column(name: "INT_RATE_IMPLICIT", type: "DOUBLE", remarks: "租赁利率(实际)")
            column(name: "INT_RATE_TYPE", type: "varchar(30)", remarks: "利率类型：浮动/floating; 固定/fixed(syscode:CON.INT_RATE_TYPE)")
            column(name: "IRR", type: "DOUBLE", remarks: "内部收益率")
            column(name: "IRR_AFTER_TAX", type: "DOUBLE", remarks: "税后内部收益率")
            column(name: "PMT", type: "DOUBLE", remarks: "等额本息租金")
            column(name: "PMT_FIRST", type: "DOUBLE", remarks: "等额本息租金(首期)")
            column(name: "ANNUAL_MEAN_RATE", type: "DOUBLE", remarks: "表面利率、平息率")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-21-init-table-migration-PRJ_TENANT_HIST_EVOLUTION_H") {
        createTable(tableName: "PRJ_TENANT_HIST_EVOLUTION_H", remarks: "") {
            column(name: "VERSION_ID", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_HIST_EVOLUTION_H_PK")
            }
            column(name: "EVOLUTION_ID", type: "BIGINT(20)", remarks: "沿革id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_HIST_EVOLUTION_H_PK")
            }
            column(name: "BP_REPORT_ID", type: "BIGINT(20)", remarks: "bp报告id")
            column(name: "EVOLUTION_SEQ", type: "BIGINT(20)", remarks: "序号")
            column(name: "CHANGE_DATE", type: "DATETIME", remarks: "变更日期")
            column(name: "CHANGE_AFFAIRS", type: "varchar(300)", remarks: "变更事宜")
            column(name: "DESCRIPTION", type: "varchar(300)", remarks: "备注")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_TENANT_HIST_EVOLUTION_H", columnNames: "EVOLUTION_SEQ,BP_REPORT_ID,VERSION_ID", constraintName: "PRJ_TENANT_HIST_EVOLUTION_H_U1")
    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_SALES_CUSTOMER_H") {
        createTable(tableName: "PRJ_TENANT_SALES_CUSTOMER_H", remarks: "承租人销售客户定义表") {
            column(name: "version_id", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_SALES_CUSTOMER_H_PK")
            }
            column(name: "customer_id", type: "bigint(20)", remarks: "客户ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_SALES_CUSTOMER_H_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "BP报告ID")
            column(name: "sale_customer_name", type: "varchar(300)", remarks: "销售客户名称")
            column(name: "sale_quantity", type: "double", remarks: "销售量(万元)")
            column(name: "sale_percentage", type: "varchar(300)", remarks: "占总销售量比例%")
            column(name: "sale_payment_way", type: "varchar(300)", remarks: "结算方式")
            column(name: "sale_relation", type: "varchar(300)", remarks: "关联关系")
            column(name: "OBJECT_VERSION_NUMBER", type: "bigint(20)", defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint(20)", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_TENANT_SALES_CUSTOMER_H", columnNames: "version_id", constraintName: "PRJ_TENANT_SALES_CUSTOMER_H_U1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_STOCK_HOLDING_H") {
        createTable(tableName: "PRJ_TENANT_STOCK_HOLDING_H", remarks: "承租人股份持有定义表") {
            column(name: "version_id", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_STOCK_HOLDING_H_PK")
            }
            column(name: "holding_id", type: "bigint(20)", remarks: "控股ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_STOCK_HOLDING_H_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "BP报告ID")
            column(name: "holding_company", type: "varchar(300)", remarks: "控股公司名称")
            column(name: "industry", type: "varchar(200)", remarks: "所属行业")
            column(name: "registered_capital", type: "double(20,2)", remarks: "注册资本(万元)")
            column(name: "stockholding_ratio", type: "double(20,2)", remarks: "承租人控股比例(%)")
            column(name: "asset_size", type: "double(20,2)", remarks: "最近年度资产规模(万元)")
            column(name: "total_profit", type: "double(20,2)", remarks: "利润总额(万元)")
            column(name: "OBJECT_VERSION_NUMBER", type: "bigint(20)", defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint(20)", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_TENANT_STOCK_HOLDING_H", columnNames: "version_id", constraintName: "prj_tenant_stock_holding_h_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_STOCK_STRU_H") {
        createTable(tableName: "PRJ_TENANT_STOCK_STRU_H", remarks: "承租人股份结构定义表") {
            column(name: "version_id", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_STOCK_STRU_H_PK")
            }
            column(name: "holding_id", type: "bigint(20)", remarks: "控股ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_STOCK_STRU_H_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "BP报告ID")
            column(name: "structure_name", type: "varchar(200)", remarks: "结构名")
            column(name: "industry", type: "varchar(200)", remarks: "所属行业")
            column(name: "capital_contribution", type: "double(20,2)", remarks: "出资金额(万元)")
            column(name: "stockholding_type", type: "varchar(300)", remarks: "出资方式")
            column(name: "stockholding_ratio", type: "double(20,2)", remarks: "股权比例(%)")
            column(name: "description", type: "varchar(300)", remarks: "说明")
            column(name: "OBJECT_VERSION_NUMBER", type: "bigint(20)", defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint(20)", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_TENANT_STOCK_STRU_H", columnNames: "version_id", constraintName: "prj_tenant_stock_structure_h_U1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-PRJ_TENANT_SUPPLIER_H") {
        createTable(tableName: "PRJ_TENANT_SUPPLIER_H", remarks: "承租人供应商定义表") {
            column(name: "version_id", type: "bigint(20)", remarks: "版本id") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_SUPPLIER_H_PK")
            }
            column(name: "supplier_id", type: "bigint(20)", remarks: "供应商ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "PRJ_TENANT_SUPPLIER_H_PK")
            }
            column(name: "bp_report_id", type: "bigint(20)", remarks: "BP报告ID")
            column(name: "vender_name", type: "varchar(300)", remarks: "厂商名")
            column(name: "purchase_amount", type: "double", remarks: "采购数量")
            column(name: "purchase_percentage", type: "double", remarks: "采购比例(%)")
            column(name: "payment_way", type: "varchar(300)", remarks: "付款方式")
            column(name: "relation", type: "varchar(300)", remarks: "关系类型")
            column(name: "OBJECT_VERSION_NUMBER", type: "bigint(20)", defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint(20)", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "PRJ_TENANT_SUPPLIER_H", columnNames: "version_id", constraintName: "prj_tenant_supplier_h_u1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT310_AGING") {
        createTable(tableName: "RPT310_AGING", remarks: "应收账款逾期账款账龄报表明细表") {
            column(name: "PRT_AGING_ID", type: "bigint(20)", remarks: "主键", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT310_AGING_PK")
            }
            column(name: "REPORT_DTL_ID", type: "bigint(20)", remarks: "报表明细id")
            column(name: "CONTRACT_ID", type: "bigint(20)", remarks: "合同ID")
            column(name: "COMPANY_ID", type: "bigint(20)", remarks: "公司ID")
            column(name: "ONE_MONTH_DUE_AMOUNT", type: "double(20,2)", remarks: "30天内应收金额")
            column(name: "TWO_MONTH_DUE_AMOUNT", type: "double(20,2)", remarks: "30-60天内应收金额")
            column(name: "THREE_MONTH_DUE_AMOUNT", type: "double(20,2)", remarks: "60-90天内应收金额")
            column(name: "HALF_YEAR_DUE_AMOUNT", type: "double(20,2)", remarks: "90-180天内应收金额")
            column(name: "ONE_YEAR_DUE_AMOUNT", type: "double(20,2)", remarks: "180-360天内应收金额")
            column(name: "OVER_ONE_YEAR_DUE_AMOUNT", type: "double(20,2)", remarks: "一年以上应收金额")
            column(name: "ONE_MONTH_AMOUNT", type: "double(20,2)", remarks: "30天内逾期金额")
            column(name: "TWO_MONTH_AMOUNT", type: "double(20,2)", remarks: "30-60天内逾期金额")
            column(name: "THREE_MONTH_AMOUNT", type: "double(20,2)", remarks: "60-90天内逾期金额")
            column(name: "HALF_YEAR_AMOUNT", type: "double(20,2)", remarks: "90-180天内逾期金额")
            column(name: "ONE_YEAR_AMOUNT", type: "double(20,2)", remarks: "一年以内逾期金额")
            column(name: "OVER_ONE_YEAR_AMOUNT", type: "double(20,2)", remarks: "一年以上逾期金额")
            column(name: "OBJECT_VERSION_NUMBER", type: "bigint(20)", defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint(20)", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-RPT_CON_EXECUTE") {
        createTable(tableName: "RPT_CON_EXECUTE", remarks: "合同执行明细表") {
            column(name: "rpt_con_execute_id", type: "bigint(20)", remarks: "主键", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "RPT_CON_EXECUTE_PK")
            }
            column(name: "write_off_id", type: "bigint(20)", remarks: "核销id")
            column(name: "reversed_flag", type: "varchar(100)", remarks: "核销标志")
            column(name: "cashflow_id", type: "bigint(20)", remarks: "现金流id")
            column(name: "report_dtl_id", type: "bigint(20)", remarks: "报表")
            column(name: "contract_id", type: "bigint(20)", remarks: "合同id")
            column(name: "contract_number", type: "varchar(100)", remarks: "合同编号")
            column(name: "contract_name", type: "varchar(200)", remarks: "合同名称")
            column(name: "contract_status", type: "varchar(100)", remarks: "合同状态")
            column(name: "document_type", type: "varchar(100)", remarks: "合同类型")
            column(name: "sign_date", type: "datetime", remarks: "签约日")
            column(name: "inception_of_lease", type: "datetime", remarks: "起租日")
            column(name: "lease_term", type: "bigint(20)", remarks: "签约期限")
            column(name: "irr", type: "double(20,2)", remarks: "内部收益率")
            column(name: "int_rate", type: "double(20,2)", remarks: "租赁利率")
            column(name: "cf_item", type: "bigint(20)", remarks: "现金流项目")
            column(name: "cf_type", type: "bigint(20)", remarks: "现金流类型")
            column(name: "write_off_due_amount", type: "double(20,2)", remarks: "核销金额")
            column(name: "cf_direction", type: "varchar(100)", remarks: "现金流方向")
            column(name: "cf_status", type: "varchar(100)", remarks: "现金流状态")
            column(name: "overdue_status", type: "varchar(100)", remarks: "逾期状态")
            column(name: "write_off_date", type: "datetime", remarks: "核销时间")
            column(name: "times", type: "bigint(20)", remarks: "期数")
            column(name: "due_amount", type: "double(20,2)", remarks: "应收金额")
            column(name: "received_amount", type: "double(20,2)", remarks: "已收金额")
            column(name: "due_date", type: "datetime", remarks: "应收日期")
            column(name: "last_received_date", type: "datetime", remarks: "最后收款日")
            column(name: "cc_creation_date", type: "datetime", remarks: "合同创建日期")
            column(name: "lease_times", type: "bigint(20)", remarks: "租赁期数")
            column(name: "employee_id", type: "bigint(20)", remarks: "项目经理id")
            column(name: "prj_count", type: "bigint(20)", remarks: "业务员某段时间项目数")
            column(name: "user_name", type: "varchar(100)", remarks: "员工名")
            column(name: "bp_name", type: "varchar(200)", remarks: "承租人")
            column(name: "tenant_bp_id", type: "bigint(20)", remarks: "承租人id")
            column(name: "project_id", type: "bigint(20)", remarks: "项目id")
            column(name: "prj_finance_amount", type: "double(20,2)", remarks: "项目融资额")
            column(name: "project_name", type: "varchar(100)", remarks: "项目名")
            column(name: "unit_id", type: "bigint(20)", remarks: "项目部门id")
            column(name: "unit_name", type: "varchar(100)", remarks: "项目名")
            column(name: "finance_amount", type: "double(20,2)", defaultValue: "0.00", remarks: "合同融资额")
            column(name: "release_date", type: "datetime", remarks: "报表发布时间")
            column(name: "company_id", type: "bigint(20)", remarks: "公司id") { constraints(nullable: "false") }
            column(name: "change_count", type: "bigint(20)", remarks: "合同变更数量")
            column(name: "OBJECT_VERSION_NUMBER", type: "bigint(20)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint(20)", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint(20)", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-rpt_gathering") {
        createTable(tableName: "rpt_gathering", remarks: "报表统计信息表") {
            column(name: "prt_gathering_id", type: "bigint(20)", remarks: "主键自增", autoIncrement: "true", startWith: "1001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "rpt_gathering_pk")
            }
            column(name: "contract_id", type: "bigint(20)", remarks: "合同id")
            column(name: "company_id", type: "bigint(20)", remarks: "公司id")
            column(name: "tran_time", type: "datetime", remarks: "事务日期")
            column(name: "rent", type: "double(20,2)", defaultValue: "0.00", remarks: "租金")
            column(name: "margin", type: "double(20,2)", defaultValue: "0.00", remarks: "保证金")
            column(name: "hand_charge", type: "double(20,2)", defaultValue: "0.00", remarks: "手续费")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-rpt_temp_receivables") {
        createTable(tableName: "rpt_temp_receivables", remarks: "暂存收款数据表") {
            column(name: "temp_data_id", type: "bigint(20)", remarks: "暂存数据id", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "rpt_temp_receivables_pk")
            }
            column(name: "receivables_new", type: "bigint(255)", remarks: "收款新增")
            column(name: "receivables_recoil", type: "bigint(255)", remarks: "收款反冲")
            column(name: "receivables_write_off", type: "bigint(255)", remarks: "收款核销")
            column(name: "receivables_refund", type: "bigint(255)", remarks: "收款退款")
            column(name: "write_off_recoil", type: "bigint(255)", remarks: "核销反冲")
            column(name: "refund_recoil", type: "bigint(255)", remarks: "退款反冲")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT")
            column(name: "REQUEST_ID", type: "BIGINT")
            column(name: "PROGRAM_ID", type: "BIGINT")
            column(name: "CREATED_BY", type: "BIGINT")
            column(name: "CREATION_DATE", type: "DATETIME")
            column(name: "LAST_UPDATED_BY", type: "BIGINT")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT")
            column(name: "report_dtl_id", type: "bigint(20)", remarks: "详细报表id")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_account_retrieve") {
        createTable(tableName: "sys_account_retrieve", remarks: "账户回收表") {
            column(name: "USER_ID", type: "bigint(20)", remarks: "用户ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_account_retrieve_pk")
            }
            column(name: "RETRIEVE_TYPE", type: "varchar(30)", remarks: "类型:NAME/PWD")
            column(name: "RETRIEVE_DATE", type: "datetime", remarks: "时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "decimal(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_attach_category_b") {
        createTable(tableName: "sys_attach_category_b", remarks: "连接类别") {
            column(name: "CATEGORY_ID", type: "bigint(20)", remarks: "ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_attach_category_b_pk")
            }
            column(name: "CATEGORY_NAME", type: "varchar(40)", remarks: "分类名称")
            column(name: "LEAF_FLAG", type: "varchar(1)", remarks: "标记")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "STATUS", type: "varchar(1)", remarks: "状态")
            column(name: "PARENT_CATEGORY_ID", type: "bigint(20)", remarks: "父级类别ID")
            column(name: "PATH", type: "varchar(200)", remarks: "层级路径")
            column(name: "SOURCE_TYPE", type: "varchar(30)", remarks: "来源类型")
            column(name: "ALLOWED_FILE_TYPE", type: "varchar(300)", remarks: "允许文件类型")
            column(name: "ALLOWED_FILE_SIZE", type: "decimal(20,0)", remarks: "允许文件大小")
            column(name: "IS_UNIQUE", type: "varchar(1)", remarks: "IS_UNIQUE")
            column(name: "CATEGORY_PATH", type: "varchar(255)", remarks: "类别路径")
            column(name: "OBJECT_VERSION_NUMBER", type: "decimal(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_attach_category_tl") {
        createTable(tableName: "sys_attach_category_tl", remarks: "连接类别多语言表") {
            column(name: "CATEGORY_ID", type: "bigint(20)", remarks: "ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_attach_category_tl_pk")
            }
            column(name: "LANG", type: "varchar(10)", remarks: "语言类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_attach_category_tl_pk")
            }
            column(name: "CATEGORY_NAME", type: "varchar(40)", remarks: "类别名称")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "角色描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_attachment") {
        createTable(tableName: "sys_attachment", remarks: "附件表") {
            column(name: "ATTACHMENT_ID", type: "bigint(20)", remarks: "附件ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_attachment_pk")
            }
            column(name: "CATEGORY_ID", type: "bigint(20)", remarks: "分类ID")
            column(name: "NAME", type: "varchar(40)", remarks: "附件名称")
            column(name: "SOURCE_TYPE", type: "varchar(30)", remarks: "对应业务类型")
            column(name: "SOURCE_KEY", type: "varchar(40)", remarks: "业务主键")
            column(name: "STATUS", type: "varchar(1)", remarks: "状态")
            column(name: "START_ACTIVE_DATE", type: "datetime", remarks: "开始生效日期")
            column(name: "END_ACTIVE_DATE", type: "datetime", remarks: "失效时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "filedescription", type: "varchar(255)", remarks: "頁面多了一個字段\"備注\",表中新添此字段于201704271011@Jeffery")
        }
        createIndex(tableName: "sys_attachment", indexName: "SYS_ATTACHMENT_N1") {
            column(name: "CATEGORY_ID", type: "bigint(20)")
        }
        createIndex(tableName: "sys_attachment", indexName: "SYS_ATTACHMENT_N2") {
            column(name: "SOURCE_TYPE", type: "varchar(30)")
            column(name: "SOURCE_KEY", type: "varchar(40)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_code_b") {
        createTable(tableName: "sys_code_b", remarks: "快码类型") {
            column(name: "CODE_ID", type: "bigint(20)", remarks: "快码ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_code_b_pk")
            }
            column(name: "CODE", type: "varchar(100)", remarks: "快码类型") { constraints(nullable: "false") }
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "快码类型描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "TYPE", type: "varchar(200)", remarks: "类型")
            column(name: "PARENT_CODE_ID", type: "bigint(20)", remarks: "父级快码")
            column(name: "enabled_flag", type: "varchar(1)", remarks: "启用标记")
        }
        addUniqueConstraint(tableName: "sys_code_b", columnNames: "CODE_ID", constraintName: "SYS_CODE_B_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_code_tl") {
        createTable(tableName: "sys_code_tl", remarks: "快码类型多语言") {
            column(name: "CODE_ID", type: "bigint(20)", remarks: "快码ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_code_tl_pk")
            }
            column(name: "LANG", type: "varchar(10)", remarks: "语言类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_code_tl_pk")
            }
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "快码描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_code_value_b") {
        createTable(tableName: "sys_code_value_b", remarks: "快码值") {
            column(name: "CODE_VALUE_ID", type: "bigint(20)", remarks: "快码值ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_code_value_b_pk")
            }
            column(name: "CODE_ID", type: "bigint(20)", remarks: "快码ID")
            column(name: "VALUE", type: "varchar(150)", remarks: "快码值")
            column(name: "MEANING", type: "varchar(150)", remarks: "快码意思")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "快码描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "ORDER_SEQ", type: "int(11)", defaultValue: "10")
            column(name: "TAG", type: "varchar(255)", remarks: "标记")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "是否启用", defaultValue: "Y")
            column(name: "PARENT_CODE_VALUE_ID", type: "bigint(20)", remarks: "父级快码值")
        }

        addUniqueConstraint(tableName: "sys_code_value_b", columnNames: "CODE_ID,VALUE", constraintName: "SYS_CODE_VALUE_B_U1")
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_code_value_tl") {
        createTable(tableName: "sys_code_value_tl", remarks: "快码值多语言") {
            column(name: "CODE_VALUE_ID", type: "bigint(20)", remarks: "快码值ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_code_value_tl_pk")
            }
            column(name: "LANG", type: "varchar(10)", remarks: "语言类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_code_value_tl_pk")
            }
            column(name: "MEANING", type: "varchar(150)", remarks: "快码意思")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "快码描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")

        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_config") {
        createTable(tableName: "sys_config", remarks: "配置") {
            column(name: "CONFIG_ID", type: "bigint(20)", remarks: "配置ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_config_pk")
            }
            column(name: "CONFIG_CODE", type: "varchar(240)", remarks: "配置编码") { constraints(nullable: "false") }
            column(name: "CONFIG_VALUE", type: "varchar(240)", remarks: "配置值")
            column(name: "CATEGORY", type: "varchar(240)", remarks: "配置分类")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用标记", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "sys_config", columnNames: "CONFIG_CODE", constraintName: "SYS_CONFIG_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_dashboard_b") {
        createTable(tableName: "sys_dashboard_b", remarks: "仪表盘") {
            column(name: "DASHBOARD_ID", type: "bigint(20)", remarks: "仪表盘编码", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_dashboard_b_pk")
            }
            column(name: "DASHBOARD_CODE", type: "varchar(100)", remarks: "仪表盘编码") {
                constraints(nullable: "false")
            }
            column(name: "TITLE", type: "varchar(100)", remarks: "仪表盘标题")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "仪表盘描述")
            column(name: "RESOURCE_ID", type: "bigint(20)", remarks: "资源ID") { constraints(nullable: "false") }
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "启用状态", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "sys_dashboard_b", columnNames: "DASHBOARD_CODE", constraintName: "SYS_DASHBOARD_B_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_dashboard_tl") {
        createTable(tableName: "sys_dashboard_tl", remarks: "仪表盘多语言") {
            column(name: "DASHBOARD_ID", type: "bigint(20)", remarks: "仪表盘编码") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_dashboard_tl_pk")
            }
            column(name: "LANG", type: "varchar(50)", remarks: "语言类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_dashboard_tl_pk")
            }
            column(name: "TITLE", type: "varchar(100)", remarks: "仪表盘标题")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "仪表盘描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_demo_b") {
        createTable(tableName: "sys_demo_b", remarks: "个人信息") {
            column(name: "USER_ID", type: "bigint(20)", remarks: "ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_demo_b_pk")
            }
            column(name: "USER_CODE", type: "varchar(255)", remarks: "编码") { constraints(nullable: "false") }
            column(name: "USER_NAME", type: "varchar(255)", remarks: "姓名") { constraints(nullable: "false") }
            column(name: "USER_AGE", type: "varchar(20)", remarks: "年龄")
            column(name: "USER_SEX", type: "varchar(50)", remarks: "性别")
            column(name: "USER_BIRTH", type: "date", remarks: "生日")
            column(name: "USER_EMAIL", type: "varchar(255)", remarks: "邮箱")
            column(name: "USER_PHONE", type: "bigint(20)", remarks: "电话")
            column(name: "ENABLE_FLAG", type: "varchar(1)", remarks: "是否有效")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "描述")
            column(name: "ROLE_NAME", type: "varchar(255)", remarks: "角色名称")
            column(name: "START_ACTIVE_TIME", type: "datetime", remarks: "开始时间")
            column(name: "END_ACTIVE_TIME", type: "datetime", remarks: "结束时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_demo_tl") {
        createTable(tableName: "sys_demo_tl", remarks: "个人信息多语言") {
            column(name: "USER_ID", type: "bigint(20)", remarks: "ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_demo_tl_pk")
            }
            column(name: "LANG", type: "varchar(50)", remarks: "语言类型") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_demo_tl_pk")
            }
            column(name: "USER_NAME", type: "varchar(255)", remarks: "姓名")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_file") {
        createTable(tableName: "sys_file", remarks: "文件") {
            column(name: "FILE_ID", type: "bigint(20)", remarks: "文件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_file_pk")
            }
            column(name: "ATTACHMENT_ID", type: "bigint(20)", remarks: "附件ID")
            column(name: "FILE_NAME", type: "varchar(255)", remarks: "文件名")
            column(name: "FILE_PATH", type: "varchar(255)", remarks: "文件虚拟路径")
            column(name: "FILE_SIZE", type: "decimal(20,0)", remarks: "文件大小")
            column(name: "FILE_TYPE", type: "varchar(240)", remarks: "文件类型")
            column(name: "UPLOAD_DATE", type: "datetime", remarks: "文件类型")
            column(name: "OBJECT_VERSION_NUMBER", type: "decimal(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }
        createIndex(tableName: "sys_file", indexName: "SYS_FILE_N1") {
            column(name: "ATTACHMENT_ID", type: "bigint(20)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_function") {
        createTable(tableName: "sys_function", remarks: "功能模块定义表") {
            column(name: "FUNCTION_ID", type: "bigint(20)", remarks: "功能模块ID", autoIncrement: "true") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "sys_function_pk")
            }
            column(name: "MODULE_CODE", type: "varchar(30)", remarks: "模块编码")
            column(name: "FUNCTION_ICON", type: "varchar(100)", remarks: "功能图标")
            column(name: "FUNCTION_CODE", type: "varchar(30)", remarks: "功能编码") { constraints(nullable: "false") }
            column(name: "FUNCTION_NAME", type: "varchar(150)", remarks: "功能名称")
            column(name: "FUNCTION_DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "RESOURCE_ID", type: "bigint(20)", remarks: "功能入口")
            column(name: "homepage_resource_id", type: "bigint(20)", remarks: "模块首页面(小)")
            column(name: "TYPE", type: "varchar(30)", remarks: "功能类型")
            column(name: "PARENT_FUNCTION_ID", type: "bigint(20)", remarks: "父功能")
            column(name: "ENABLED_FLAG", type: "varchar(1)", remarks: "是否启用", defaultValue: "Y")
            column(name: "FUNCTION_SEQUENCE", type: "decimal(20,0)", remarks: "排序号", defaultValue: "1")
            column(name: "OBJECT_VERSION_NUMBER", type: "decimal(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }
    }


    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_function_resource") {
        createTable(tableName: "sys_function_resource") {
            column(name: "FUNC_SRC_ID", type: "bigint(20)", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_FUNCTION_RESOURCE_PK")
            }
            column(name: "FUNCTION_ID", type: "bigint(20)", remarks: "外键，功能 ID")
            column(name: "RESOURCE_ID", type: "bigint(20)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "sys_function_resource", columnNames: "FUNCTION_ID, RESOURCE_ID", constraintName: "SYS_FUNCTION_RESOURCE_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_function_tl") {
        createTable(tableName: "sys_function_tl") {
            column(name: "FUNCTION_ID", type: "bigint(20)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_FUNCTION_TL_PK")
            }
            column(name: "LANG", type: "varchar(10)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_FUNCTION_TL_PK")
            }
            column(name: "FUNCTION_NAME", type: "varchar(150)", remarks: "功能名")
            column(name: "FUNCTION_DESCRIPTION", type: "varchar(240)", remarks: "功能描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_if_config_header_b") {
        createTable(tableName: "sys_if_config_header_b") {
            column(name: "HEADER_ID", type: "varchar(255)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_CONFIG_HEADER_B_PK")
            }
            column(name: "INTERFACE_CODE", type: "varchar(30)", remarks: "系统代码") {
                constraints(nullable: "false")
            }
            column(name: "INTERFACE_TYPE", type: "varchar(10)", remarks: "接口类型") {
                constraints(nullable: "false")
            }
            column(name: "DOMAIN_URL", type: "varchar(200)", remarks: "系统地址") {
                constraints(nullable: "false")
            }
            column(name: "BODY_HEADER", type: "varchar(300)", remarks: "SOAP报文前缀")
            column(name: "BODY_TAIL", type: "varchar(300)", remarks: "SOAP报文后缀")
            column(name: "NAMESPACE", type: "varchar(30)", remarks: "SOAP命名空间")
            column(name: "REQUEST_METHOD", type: "varchar(10)", remarks: "请求方法") {
                constraints(nullable: "false")
            }
            column(name: "REQUEST_FORMAT", type: "varchar(30)", remarks: "请求形式") {
                constraints(nullable: "false")
            }
            column(name: "REQUEST_CONTENTTYPE", type: "varchar(80)", remarks: "请求报文格式")
            column(name: "REQUEST_ACCEPT", type: "varchar(80)", remarks: "请求接收类型")
            column(name: "AUTH_FLAG", type: "varchar(1)", remarks: "是否需要验证") {
                constraints(nullable: "false")
            }
            column(name: "AUTH_USERNAME", type: "varchar(80)", remarks: "校验用户名")
            column(name: "AUTH_PASSWORD", type: "varchar(80)", remarks: "校验密码")
            column(name: "ENABLE_FLAG", type: "varchar(1)", remarks: "是否有效") {
                constraints(nullable: "false")
            }
            column(name: "NAME", type: "varchar(200)", remarks: "系统名称") {
                constraints(nullable: "false")
            }
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "系统描述") {
                constraints(nullable: "false")
            }
            column(name: "SYSTEM_TYPE", type: "varchar(10)", remarks: "系统类型")
            column(name: "MAPPER_CLASS", type: "varchar(255)", remarks: "包装类")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "AUTH_TYPE", type: "varchar(50)", remarks: "校验模式", defaultValue: "BASIC_AUTH")
            column(name: "AUTH_URL", type: "varchar(255)", remarks: "取授权码的url")
            column(name: "ACCESS_TOKEN_URL", type: "varchar(255)", remarks: "获取token的url")
            column(name: "CLIENT_ID", type: "varchar(255)", remarks: "应用id")
            column(name: "CLIENT_SECRET", type: "varchar(255)", remarks: "应用secret")
            column(name: "GRANT_TYPE", type: "varchar(50)", remarks: "授权模式")
            column(name: "SCOPE", type: "varchar(100)", remarks: "权限范围")
            column(name: "SOAP_ACTION", type: "varchar(255)")

        }

        addUniqueConstraint(tableName: "sys_if_config_header_b", columnNames: "INTERFACE_CODE", constraintName: "SYS_IF_CONFIG_HEADER_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_if_config_header_tl") {
        createTable(tableName: "sys_if_config_header_tl") {
            column(name: "HEADER_ID", type: "varchar(255)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_CONFIG_HEADER_TL_PK")
            }
            column(name: "LANG", type: "varchar(50)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_CONFIG_HEADER_TL_PK")
            }
            column(name: "NAME", type: "varchar(200)", remarks: "系统名称")
            column(name: "DESCRIPTION", type: "varchar(255)", remarks: "系统描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_if_config_line_b") {
        createTable(tableName: "sys_if_config_line_b") {
            column(name: "LINE_ID", type: "varchar(255)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_CONFIG_LINE_B_PK")
            }
            column(name: "HEADER_ID", type: "varchar(255)", remarks: "行Id") {
                constraints(nullable: "false")
            }
            column(name: "LINE_CODE", type: "varchar(30)", remarks: "接口代码") {
                constraints(nullable: "false")
            }
            column(name: "IFT_URL", type: "varchar(200)", remarks: "接口地址") {
                constraints(nullable: "false")
            }
            column(name: "ENABLE_FLAG", type: "varchar(1)", remarks: "是否有效") {
                constraints(nullable: "false")
            }
            column(name: "LINE_NAME", type: "varchar(50)", remarks: "接口名称")
            column(name: "LINE_DESCRIPTION", type: "varchar(255)", remarks: "接口描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }



    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_if_config_line_tl") {
        createTable(tableName: "sys_if_config_line_tl") {
            column(name: "LINE_ID", type: "varchar(255)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_CONFIG_LINE_TL_PK")
            }
            column(name: "LANG", type: "varchar(50)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_CONFIG_LINE_TL_PK")
            }
            column(name: "LINE_NAME", type: "varchar(50)", remarks: "接口名称")
            column(name: "LINE_DESCRIPTION", type: "varchar(255)", remarks: "接口描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_if_invoke_inbound") {
        createTable(tableName: "sys_if_invoke_inbound") {
            column(name: "INBOUND_ID", type: "bigint(20)", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_INVOKE_INBOUND_PK")
            }
            column(name: "INTERFACE_NAME", type: "varchar(255)", remarks: "接口名称") {
                constraints(nullable: "false")
            }
            column(name: "INTERFACE_URL", type: "varchar(200)", remarks: "接口地址") {
                constraints(nullable: "false")
            }
            column(name: "REQUEST_TIME", type: "DATETIME", remarks: "请求时间") {
                constraints(nullable: "false")
            }
            column(name: "REQUEST_HEADER_PARAMETER", type: "varchar(300)", remarks: "请求header参数")
            column(name: "REQUEST_BODY_PARAMETER", type: "longtext", remarks: "请求body参数")
            column(name: "REQUEST_METHOD", type: "varchar(10)", remarks: "请求方式")
            column(name: "REQUEST_STATUS", type: "varchar(10)", remarks: "请求状态")
            column(name: "RESPONSE_CONTENT", type: "longtext", remarks: "响应内容")
            column(name: "RESPONSE_TIME", type: "bigint(20)", remarks: "响应时间")
            column(name: "STACKTRACE", type: "longtext", remarks: "错误堆栈")
            column(name: "IP", type: "varchar(40)", remarks: "ip地址")
            column(name: "REFERER", type: "varchar(240)")
            column(name: "USER_AGENT", type: "varchar(240)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


        createIndex(tableName: "sys_if_invoke_inbound", indexName: "SYS_IF_INVOKE_INBOUND_N1") {
            column(name: "INTERFACE_NAME", type: "varchar(255)")
        }
        createIndex(tableName: "sys_if_invoke_inbound", indexName: "SYS_IF_INVOKE_INBOUND_N2") {
            column(name: "INTERFACE_URL", type: "varchar(200)")
        }
        createIndex(tableName: "sys_if_invoke_inbound", indexName: "SYS_IF_INVOKE_INBOUND_N3") {
            column(name: "REQUEST_TIME", type: "DATETIME")
        }
        createIndex(tableName: "sys_if_invoke_inbound", indexName: "SYS_IF_INVOKE_INBOUND_N4") {
            column(name: "REQUEST_STATUS", type: "varchar(10)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_if_invoke_outbound") {
        createTable(tableName: "sys_if_invoke_outbound") {
            column(name: "OUTBOUND_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_IF_INVOKE_OUTBOUND_PK")
            }
            column(name: "INTERFACE_NAME", type: "varchar(255)", remarks: "接口名称") {
                constraints(nullable: "false")
            }
            column(name: "INTERFACE_URL", type: "varchar(200)", remarks: "接口地址") {
                constraints(nullable: "false")
            }
            column(name: "REQUEST_TIME", type: "DATETIME", remarks: "请求时间") {
                constraints(nullable: "false")
            }

            column(name: "REQUEST_PARAMETER", type: "longtext", remarks: "请求参数")
            column(name: "REQUEST_STATUS", type: "varchar(10)", remarks: "请求状态")
            column(name: "RESPONSE_CONTENT", type: "longtext", remarks: "响应内容")
            column(name: "RESPONSE_TIME", type: "bigint(20)", remarks: "响应时间")
            column(name: "RESPONSE_CODE", type: "varchar(30)", remarks: "httpCode")
            column(name: "STACKTRACE", type: "longtext", remarks: "错误堆栈")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "sys_if_invoke_outbound", indexName: "SYS_IF_INVOKE_OUTBOUND_N1") {
            column(name: "INTERFACE_NAME", type: "varchar(255)")
        }
        createIndex(tableName: "sys_if_invoke_outbound", indexName: "SYS_IF_INVOKE_OUTBOUND_N2") {
            column(name: "INTERFACE_URL", type: "varchar(200)")
        }
        createIndex(tableName: "sys_if_invoke_outbound", indexName: "SYS_IF_INVOKE_OUTBOUND_N3") {
            column(name: "REQUEST_TIME", type: "DATETIME")
        }
        createIndex(tableName: "sys_if_invoke_outbound", indexName: "SYS_IF_INVOKE_OUTBOUND_N4") {
            column(name: "REQUEST_STATUS", type: "varchar(10)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_job_running_info") {
        createTable(tableName: "sys_job_running_info") {
            column(name: "JOB_RUNNING_INFO_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_JOB_RUNNING_INFO_PK")
            }
            column(name: "JOB_NAME", type: "varchar(225)")
            column(name: "JOB_GROUP", type: "varchar(225)")
            column(name: "JOB_RESULT", type: "varchar(225)")
            column(name: "JOB_STATUS", type: "varchar(225)")
            column(name: "JOB_STATUS_MESSAGE", type: "varchar(225)")
            column(name: "TRIGGER_NAME", type: "varchar(225)")
            column(name: "TRIGGER_GROUP", type: "varchar(225)")
            column(name: "PREVIOUS_FIRE_TIME", type: "DATETIME")
            column(name: "FIRE_TIME", type: "DATETIME")
            column(name: "NEXT_FIRE_TIME", type: "DATETIME")
            column(name: "REFIRE_COUNT", type: "bigint(20)", defaultValue: "0")
            column(name: "FIRE_INSTANCE_ID", type: "varchar(225)")
            column(name: "SCHEDULER_INSTANCE_ID", type: "varchar(225)")
            column(name: "SCHEDULED_FIRE_TIME", type: "DATETIME")
            column(name: "EXECUTION_SUMMARY", type: "varchar(225)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "IP_ADDRESS", type: "varchar(255)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_lang_b") {
        createTable(tableName: "sys_lang_b") {
            column(name: "LANG_CODE", type: "varchar(10)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_LANG_B_PK")
            }
            column(name: "BASE_LANG", type: "varchar(10)", remarks: "基语言")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "JOB_RESULT", type: "varchar(225)")
            column(name: "JOB_STATUS", type: "varchar(225)")
            column(name: "JOB_STATUS_MESSAGE", type: "varchar(225)")
            column(name: "TRIGGER_NAME", type: "varchar(225)")
            column(name: "TRIGGER_GROUP", type: "varchar(225)")
            column(name: "PREVIOUS_FIRE_TIME", type: "DATETIME")
            column(name: "FIRE_TIME", type: "DATETIME")
            column(name: "NEXT_FIRE_TIME", type: "DATETIME")
            column(name: "REFIRE_COUNT", type: "bigint(20)", defaultValue: "0")
            column(name: "FIRE_INSTANCE_ID", type: "varchar(225)")
            column(name: "SCHEDULER_INSTANCE_ID", type: "varchar(225)")
            column(name: "SCHEDULED_FIRE_TIME", type: "DATETIME")
            column(name: "EXECUTION_SUMMARY", type: "varchar(225)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")

        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_lov") {
        createTable(tableName: "sys_lov") {
            column(name: "LOV_ID", type: "bigint(20)", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_LOV_PK")
            }
            column(name: "CODE", type: "varchar(80)", remarks: "LOV的code") {
                constraints(nullable: "false")
            }
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "SQL_ID", type: "varchar(225)", remarks: "SQL ID")
            column(name: "VALUE_FIELD", type: "varchar(80)", remarks: "VALUE_FIELD")
            column(name: "TEXT_FIELD", type: "varchar(80)", remarks: "TEXT_FIELD")
            column(name: "TITLE", type: "varchar(225)", remarks: "标题")
            column(name: "WIDTH", type: "decimal(20)", remarks: "宽度")
            column(name: "HEIGHT", type: "decimal(20)", remarks: "高度")
            column(name: "PLACEHOLDER", type: "varchar(80)", remarks: "提示")
            column(name: "DELAY_LOAD", type: "varchar(1)", remarks: "是否延迟加载", defaultValue: "N")
            column(name: "NEED_QUERY_PARAM", type: "varchar(1)", remarks: "是否需要查询条件", defaultValue: "N")
            column(name: "EDITABLE", type: "varchar(1)", remarks: "是否可编辑", defaultValue: "N")
            column(name: "CAN_POPUP", type: "varchar(1)", remarks: "是否可弹出", defaultValue: "Y")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "CUSTOM_SQL", type: "longtext", remarks: "自定义sql")
            column(name: "QUERY_COLUMNS", type: "int(11)", remarks: "查询框列数", defaultValue: "1")
            column(name: "CUSTOM_URL", type: "varchar(255)", remarks: "自定义URL")
        }

        addUniqueConstraint(tableName: "sys_lov", columnNames: "CODE", constraintName: "SYS_LOV_U1")


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_lov_item") {
        createTable(tableName: "sys_lov_item") {
            column(name: "LOV_ITEM_ID", type: "bigint(20)", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_LOV_ITEM_PK")
            }
            column(name: "LOV_ID", type: "bigint(20)", remarks: "头表ID")
            column(name: "DISPLAY", type: "varchar(255)", remarks: "描述字段")
            column(name: "IS_AUTOCOMPLETE", type: "varchar(1)", remarks: "是否autocomplete", defaultValue: "N")
            column(name: "CONDITION_FIELD", type: "varchar(80)", remarks: "是否查询字段")
            column(name: "CONDITION_FIELD_WIDTH", type: "decimal(20)", remarks: "查询字段宽度")
            column(name: "CONDITION_FIELD_TYPE", type: "varchar(30)", remarks: "查询字段组件类型")
            column(name: "CONDITION_FIELD_NAME", type: "varchar(80)", remarks: "查询字段名")
            column(name: "CONDITION_FIELD_NEWLINE", type: "varchar(1)", remarks: "查询字段新一行")
            column(name: "CONDITION_FIELD_SELECT_CODE", type: "varchar(80)", remarks: "查询字段combobox对应的快码值")
            column(name: "CONDITION_FIELD_LOV_CODE", type: "varchar(80)", remarks: "查询字段lov对应的通用lov编码")
            column(name: "CONDITION_FIELD_SEQUENCE", type: "decimal(20)", remarks: "查询字段排序号")
            column(name: "CONDITION_FIELD_SELECT_URL", type: "varchar(255)", remarks: "查询字段combobox对应的URL")
            column(name: "CONDITION_FIELD_SELECT_VF", type: "varchar(80)", remarks: "查询字段combobox对应的valueField")
            column(name: "CONDITION_FIELD_SELECT_TF", type: "varchar(80)", remarks: "查询字段combobox对应的textField")
            column(name: "CONDITION_FIELD_TEXTFIELD", type: "varchar(80)", remarks: "查询字段对应的textField")
            column(name: "AUTOCOMPLETE_FIELD", type: "varchar(1)", remarks: "autocomplete显示列", defaultValue: "Y")
            column(name: "GRID_FIELD", type: "varchar(1)", remarks: "是否显示表格列", defaultValue: "Y")
            column(name: "GRID_FIELD_NAME", type: "varchar(80)", remarks: "表格列字段名")
            column(name: "GRID_FIELD_SEQUENCE", type: "decimal(20)", remarks: "表格列排序号", defaultValue: "1")
            column(name: "GRID_FIELD_WIDTH", type: "decimal(20)", remarks: "表格列宽")
            column(name: "GRID_FIELD_ALIGN", type: "varchar(10)", remarks: "表格列布局", defaultValue: "center")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "CONDITION_FIELD_LABEL_WIDTH", type: "decimal(10)")
        }

        createIndex(tableName: "sys_lov_item", indexName: "SYS_LOV_ITEM_N1") {
            column(name: "LOV_ID", type: "bigint(20)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_mailing_list") {
        createTable(tableName: "sys_mailing_list") {
            column(name: "MAILING_LIST_ID", type: "int(11)") {
                constraints(nullable: "false")
            }
            column(name: "MAIL_SERVER_ID", type: "int(11)")
            column(name: "MAIL_TO", type: "varchar(300)")
            column(name: "MAIL_CC", type: "varchar(300)")
            column(name: "SUBJECT", type: "varchar(300)")
            column(name: "BODY", type: "mediumtext")
            column(name: "NOTE", type: "varchar(300)")
            column(name: "SENT_FLAG", type: "varchar(1)")
            column(name: "ERROR_TIMES", type: "int(11)", defaultValue: "0")
            column(name: "CREATED_BY", type: "int(11)") {
                constraints(nullable: "false")
            }
            column(name: "CREATION_DATE", type: "date") {
                constraints(nullable: "false")
            }
            column(name: "LAST_UPDATED_BY", type: "int(11)") {
                constraints(nullable: "false")
            }
            column(name: "LAST_UPDATE_DATE", type: "date") {
                constraints(nullable: "false")
            }
            column(name: "RECEIVERS", type: "varchar(255)", remarks: "收件邮箱")
            column(name: "TEMPLATE_CODE", type: "varchar(255)", remarks: "模板代码")
            column(name: "MODE", type: "varchar(255)", remarks: "模板")
            column(name: "ATTACHMENTS", type: "varchar(255)", remarks: "附件")
            column(name: "REQUEST_ID", type: "int(11)")
            column(name: "PROGRAM_ID", type: "int(11)")
            column(name: "OBJECT_VERSION_NUMBER", type: "int(11)")
            column(name: "LAST_UPDATE_LOGIN", type: "date")
            column(name: "ATTRIBUTE1", type: "varchar(255)")
            column(name: "ATTRIBUTE2", type: "varchar(255)")
            column(name: "ATTRIBUTE3", type: "varchar(255)")
            column(name: "ATTRIBUTE4", type: "varchar(255)")
            column(name: "ATTRIBUTE5", type: "varchar(255)")
            column(name: "ATTRIBUTE6", type: "varchar(255)")
            column(name: "ATTRIBUTE7", type: "varchar(255)")
            column(name: "ATTRIBUTE8", type: "varchar(255)")
            column(name: "ATTRIBUTE9", type: "varchar(255)")
            column(name: "ATTRIBUTE10", type: "varchar(255)")
            column(name: "ATTRIBUTE11", type: "varchar(255)")
            column(name: "ATTRIBUTE12", type: "varchar(255)")
            column(name: "ATTRIBUTE13", type: "varchar(255)")
            column(name: "ATTRIBUTE14", type: "varchar(255)")
            column(name: "ATTRIBUTE15", type: "varchar(255)")

        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message") {
        createTable(tableName: "sys_message") {
            column(name: "MESSAGE_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_PK")
            }
            column(name: "MESSAGE_TYPE", type: "varchar(10)", remarks: "信息类型,email/sms")
            column(name: "MESSAGE_HOST", type: "varchar(255)", remarks: "消息服务器")
            column(name: "MESSAGE_FROM", type: "varchar(255)", remarks: "消息发出人")
            column(name: "SUBJECT", type: "varchar(255)", remarks: "标题")
            column(name: "CONTENT", type: "longtext", remarks: "内容")
            column(name: "PRIORITY_LEVEL", type: "varchar(25)", remarks: "优先级")
            column(name: "SEND_FLAG", type: "varchar(1)", remarks: "发送标记", defaultValue: "N")
            column(name: "MESSAGE_SOURCE", type: "varchar(255)", remarks: "消息来源")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        createIndex(tableName: "sys_message", indexName: "SYS_MESSAGE_N1") {
            column(name: "MESSAGE_TYPE", type: "varchar(10)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_account") {
        createTable(tableName: "sys_message_account") {
            column(name: "ACCOUNT_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_ACCOUNT_PK")
            }
            column(name: "ACCOUNT_TYPE", type: "varchar(50)", remarks: "账号类型")
            column(name: "ACCOUNT_CODE", type: "varchar(50)", remarks: "编号")
            column(name: "USER_NAME", type: "varchar(240)", remarks: "用户名")
            column(name: "PASSWORD", type: "varchar(240)", remarks: "密码")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_attachment") {
        createTable(tableName: "sys_message_attachment") {
            column(name: "ATTACHMENT_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_ATTACHMENT_PK")
            }
            column(name: "MESSAGE_ID", type: "bigint(20)", remarks: "消息id")
            column(name: "FILE_ID", type: "bigint(20)", remarks: "附件id")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        createIndex(tableName: "sys_message_attachment", indexName: "SYS_MESSAGE_ATTACHMENT_N1") {
            column(name: "FILE_ID", type: "bigint(20)")
        }
        createIndex(tableName: "sys_message_attachment", indexName: "SYS_MESSAGE_ATTACHMENT_N2") {
            column(name: "MESSAGE_ID", type: "bigint(20)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_email_account") {
        createTable(tableName: "sys_message_email_account") {
            column(name: "ACCOUNT_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_EMAIL_ACCOUNT_PK")
            }
            column(name: "ACCOUNT_CODE", type: "varchar(50)") {
                constraints(nullable: "false")
            }
            column(name: "CONFIG_ID", type: "bigint(20)")
            column(name: "USER_NAME", type: "varchar(240)")
            column(name: "PASSWORD", type: "varchar(240)")
            column(name: "DESCRIPTION", type: "varchar(240)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "sys_message_email_account", columnNames: "ACCOUNT_CODE", constraintName: "SYS_MESSAGE_EMAIL_ACCOUNT_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_email_config") {
        createTable(tableName: "sys_message_email_config") {
            column(name: "CONFIG_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_EMAIL_CONFIG_PK")
            }
            column(name: "CONFIG_CODE", type: "varchar(50)", remarks: "编号") {
                constraints(nullable: "false")
            }
            column(name: "HOST", type: "varchar(50)", remarks: "服务器")
            column(name: "PORT", type: "varchar(10)", remarks: "端口")
            column(name: "TRY_TIMES", type: "decimal(20)", remarks: "重试次数", defaultValue: "3")
            column(name: "DESCRIPTION", type: "varchar(20)", remarks: "描述")
            column(name: "USE_WHITE_LIST", type: "varchar(1)", remarks: "是否使用白名单", defaultValue: "N")
            column(name: "USER_NAME", type: "varchar(240)", remarks: "用户名")
            column(name: "PASSWORD", type: "varchar(240)", remarks: "密码")
            column(name: "ENABLE", type: "varchar(1)", defaultValue: "N")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "SERVER_ENABLE", type: "varchar(255)")

        }

        addUniqueConstraint(tableName: "sys_message_email_config", columnNames: "CONFIG_CODE", constraintName: "SYS_MESSAGE_EMAIL_CONFIG_U1")


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_email_property") {
        createTable(tableName: "sys_message_email_property") {
            column(name: "PROPERTY_ID", type: "bigint(20)") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_EMAIL_PROPERTY_PK")
            }
            column(name: "PROPERTY_NAME", type: "varchar(255)")
            column(name: "PROPERTY_CODE", type: "varchar(255)")
            column(name: "CONFIG_ID", type: "bigint(20)")
            column(name: "ATTRIBUTE1", type: "varchar(255)")
            column(name: "ATTRIBUTE2", type: "varchar(255)")
            column(name: "ATTRIBUTE3", type: "varchar(255)")
            column(name: "ATTRIBUTE4", type: "varchar(255)")
            column(name: "ATTRIBUTE5", type: "varchar(255)")
            column(name: "ATTRIBUTE6", type: "varchar(255)")
            column(name: "ATTRIBUTE7", type: "varchar(255)")
            column(name: "ATTRIBUTE8", type: "varchar(255)")
            column(name: "ATTRIBUTE9", type: "varchar(255)")
            column(name: "ATTRIBUTE10", type: "varchar(255)")
            column(name: "ATTRIBUTE11", type: "varchar(255)")
            column(name: "ATTRIBUTE12", type: "varchar(255)")
            column(name: "ATTRIBUTE13", type: "varchar(255)")
            column(name: "ATTRIBUTE14", type: "varchar(255)")
            column(name: "ATTRIBUTE15", type: "varchar(255)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_email_white_lt") {
        createTable(tableName: "sys_message_email_white_lt") {
            column(name: "ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_EMAIL_WHITE_LT_PK")
            }
            column(name: "ADDRESS", type: "varchar(240)", remarks: "白名单地址")
            column(name: "CONFIG_ID", type: "bigint(20)", remarks: "邮箱配置id")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_receiver") {
        createTable(tableName: "sys_message_receiver") {
            column(name: "RECEIVER_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_RECEIVER_PK")
            }
            column(name: "MESSAGE_ID", type: "bigint(20)", remarks: "消息id")
            column(name: "MESSAGE_TYPE", type: "varchar(25)", remarks: "消息类型,抄送/普通")
            column(name: "MESSAGE_ADDRESS", type: "varchar(255)", remarks: "消息地址,邮箱/手机号")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        createIndex(tableName: "sys_message_receiver", indexName: "SYS_MESSAGE_RECEIVER_N1") {
            column(name: "MESSAGE_ID", type: "bigint(20)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_template") {
        createTable(tableName: "sys_message_template") {
            column(name: "TEMPLATE_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_TEMPLATE_PK")
            }
            column(name: "SUBJECT", type: "longtext", remarks: "模板标题")
            column(name: "CONTENT", type: "longtext", remarks: "模板内容")
            column(name: "ACCOUNT_ID", type: "bigint(20)", remarks: "账号id")
            column(name: "TEMPLATE_CODE", type: "varchar(50)", remarks: "模板编号") {
                constraints(nullable: "false")
            }
            column(name: "TEMPLATE_TYPE", type: "varchar(50)", remarks: "模板类型,邮件/SMS")
            column(name: "PRIORITY_LEVEL", type: "varchar(50)", remarks: "优先级")
            column(name: "DESCRIPTION", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
            column(name: "SEND_TYPE", type: "varchar(255)")
        }

        addUniqueConstraint(tableName: "sys_message_template", columnNames: "TEMPLATE_CODE", constraintName: "SYS_MESSAGE_TEMPLATE_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_message_transaction") {
        createTable(tableName: "sys_message_transaction") {
            column(name: "TRANSACTION_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_MESSAGE_TRANSACTION_PK")
            }
            column(name: "MESSAGE_ID", type: "bigint(20)", remarks: "消息id")
            column(name: "TRANSACTION_STATUS", type: "varchar(25)", remarks: "发送状态")
            column(name: "TRANSACTION_MESSAGE", type: "longtext", remarks: "返回信息")
            column(name: "MESSAGE_ADDRESS", type: "varchar(255)", remarks: "消息地址,邮箱/手机号/会员/用户")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        createIndex(tableName: "sys_message_transaction", indexName: "SYS_MESSAGE_TRANSACTION_N1") {
            column(name: "MESSAGE_ID", type: "bigint(20)")
        }

        createIndex(tableName: "sys_message_transaction", indexName: "SYS_MESSAGE_TRANSACTION_N2") {
            column(name: "TRANSACTION_STATUS", type: "varchar(25)")
        }


    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_oauth_client_details") {
        createTable(tableName: "sys_oauth_client_details") {
            column(name: "ID", type: "bigint(20)", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_OAUTH_CLIENT_DETAILS_PK")
            }
            column(name: "CLIENT_ID", type: "varchar(100)", remarks: "客户端id") {
                constraints(nullable: "false")
            }
            column(name: "CLIENT_SECRET", type: "varchar(256)", remarks: "客户端密码")
            column(name: "AUTHORIZED_GRANT_TYPES", type: "varchar(256)", remarks: "授权模式") {
                constraints(nullable: "false")
            }
            column(name: "RESOURCE_IDS", type: "varchar(256)", remarks: "资源ID", defaultValue: "api-resource")
            column(name: "AUTHORITIES", type: "varchar(256)", remarks: "角色信息")
            column(name: "AUTO_APPROVE", type: "varchar(256)", remarks: "自动授权")
            column(name: "SCOPE", type: "varchar(256)", remarks: "scope")
            column(name: "ACCESS_TOKEN_VALIDITY", type: "bigint(20)", remarks: "accessToken 失效时间")
            column(name: "REFRESH_TOKEN_VALIDITY", type: "bigint(20)", remarks: "refreshToken 失效时间")
            column(name: "WEB_SERVER_REDIRECT_URI", type: "varchar(300)", remarks: "授权码模式下的重定向URI")
            column(name: "ADDITIONAL_INFORMATION", type: "varchar(4000)", remarks: "自定义信息")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "sys_oauth_client_details", columnNames: "CLIENT_ID", constraintName: "SYS_OAUTH_CLIENT_U1")

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-20-init-table-migration-sys_preferences") {
        createTable(tableName: "sys_preferences") {
            column(name: "PREFERENCES_ID", type: "bigint(20)", autoIncrement: "true", startWith: "1") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_PREFERENCES_PK")
            }
            column(name: "PREFERENCES", type: "varchar(30)", remarks: "首选项名")
            column(name: "PREFERENCES_VALUE", type: "varchar(80)", remarks: "首选项值")
            column(name: "USER_ID", type: "bigint(20)", remarks: "账号ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "sys_preferences", columnNames: "PREFERENCES, USER_ID", constraintName: "SYS_PREFERENCES_U1")


    }
    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_PROFILE") {
        createTable(tableName: "SYS_PROFILE", remarks: "") {
            column(name: "profile_id", type: "bigint(20)", remarks: "配置文件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_PROFILE_PK")
            }
            column(name: "profile_name", type: "varchar(40)", remarks: "配置文件描述")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_PROFILE", columnNames: "profile_name", constraintName: "SYS_PROFILE_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_PROFILE_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_PROFILE_VALUE") {
        createTable(tableName: "SYS_PROFILE_VALUE", remarks: "") {
            column(name: "profile_value_id", type: "bigint(20)", remarks: "配置文件值ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_PROFILE_VALUE_PK")
            }
            column(name: "profile_id", type: "varchar(32)", remarks: "配置文件ID")
            column(name: "level_id", type: "varchar(32)", remarks: "层次ID")
            column(name: "level_value", type: "varchar(40)", remarks: "层次值")
            column(name: "profile_value", type: "varchar(80)", remarks: "配置文件值")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_PROFILE_VALUE", columnNames: "profile_id, level_id, level_value", constraintName: "SYS_PROFILE_VALUE_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_PROFILE_VALUE_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_PROMPTS") {
        createTable(tableName: "SYS_PROMPTS", remarks: "") {
            column(name: "prompt_id", type: "bigint(20)", remarks: "文本ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_PROMPTS_PK")
            }
            column(name: "prompt_code", type: "varchar(255)", remarks: "文本编码")
            column(name: "lang", type: "varchar(10)", remarks: "语言")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_PROMPTS", columnNames: "prompt_code,lang", constraintName: "SYS_PROMPTS_U1")

        createIndex(tableName: "SYS_PROMPTS", indexName: "SYS_PROMPTS_N1") {
            column(name: "description", type: "varchar(240)")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_PROMPTS_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_RESOURCE_B") {
        createTable(tableName: "SYS_RESOURCE_B", remarks: "") {
            column(name: "resource_id", type: "bigint(20)", remarks: "资源ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_B_PK")
            }
            column(name: "url", type: "varchar(255)", remarks: "URL")
            column(name: "type", type: "varchar(15)", remarks: "资源类型")
            column(name: "name", type: "varchar(40)", remarks: "资源名称")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "login_require", type: "varchar(1)", defaultValue: "Y", remarks: "是否需要登录")
            column(name: "access_check", type: "varchar(1)", defaultValue: "Y", remarks: "是否权限校验")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_RESOURCE_B", columnNames: "url", constraintName: "SYS_RESOURCE_B_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_RESOURCE_B_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_RESOURCE_CUSTOMIZATION") {
        createTable(tableName: "SYS_RESOURCE_CUSTOMIZATION", remarks: "") {
            column(name: "resource_customization_id", type: "bigint(20)", remarks: "资源用户化ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_CUSTOMIZATION_PK")
            }
            column(name: "resource_id", type: "bigint(20)", remarks: "外键，资源ID")
            column(name: "url", type: "varchar(255)", remarks: "URL")
            column(name: "sequence", type: "int(11)", remarks: "序列号")
            column(name: "enable_flag", type: "varchar(1)", remarks: "是否激活")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        createIndex(tableName: "SYS_RESOURCE_CUSTOMIZATION", indexName: "SYS_RESOURCE_CUSTOMIZATION_N1") {
            column(name: "resource_id", type: "bigint(20)")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_RESOURCE_CUSTOMIZATION_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_RESOURCE_ITEM_B") {
        createTable(tableName: "SYS_RESOURCE_ITEM_B", remarks: "") {
            column(name: "resource_item_id", type: "bigint(20)", remarks: "资源控件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_ITEM_B_PK")
            }
            column(name: "owner_resource_id", type: "bigint(20)", remarks: "功能资源ID")
            column(name: "target_resource_id", type: "bigint(20)", remarks: "目标资源ID")
            column(name: "item_id", type: "varchar(50)", remarks: "HTML中控件ID")
            column(name: "item_name", type: "varchar(50)", remarks: "控件名称")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "item_type", type: "varchar(10)", remarks: "控件类型")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_RESOURCE_ITEM_B", columnNames: "item_id,owner_resource_id", constraintName: "SYS_RESOURCE_ITEM_B_U1")

        createIndex(tableName: "SYS_RESOURCE_ITEM_B", indexName: "SYS_RESOURCE_ITEM_B_N1") {
            column(name: "owner_resource_id", type: "bigint(20)")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_RESOURCE_ITEM_B_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_RESOURCE_ITEM_TL") {
        createTable(tableName: "SYS_RESOURCE_ITEM_TL", remarks: "") {
            column(name: "resource_item_id", type: "bigint(20)", remarks: "资源控件ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_ITEM_TL_PK")
            }
            column(name: "lang", type: "varchar(10)", remarks: "语言") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_ITEM_TL_PK")
            }
            column(name: "item_name", type: "varchar(150)", remarks: "控件名称")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_RESOURCE_TL") {
        createTable(tableName: "SYS_RESOURCE_TL", remarks: "") {
            column(name: "resource_id", type: "bigint(20)", remarks: "外键，资源ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_TL_PK")
            }
            column(name: "lang", type: "varchar(10)", remarks: "语言") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_TL_PK")
            }
            column(name: "name", type: "varchar(40)", remarks: "资源名称")
            column(name: "description", type: "varchar(240)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_ROLE") {
        createTable(tableName: "SYS_ROLE", remarks: "") {
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_PK")
            }
            column(name: "role_code", type: "varchar(100)", remarks: "角色编码")
            column(name: "role_name", type: "varchar(300)", remarks: "角色名称")
            column(name: "Valid_date_from", type: "datetime", remarks: "有效期从")
            column(name: "Valid_date_to", type: "datetime", remarks: "有效期到")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT")
            column(name: "REQUEST_ID", type: "BIGINT")
            column(name: "PROGRAM_ID", type: "BIGINT")
            column(name: "CREATED_BY", type: "BIGINT")
            column(name: "CREATION_DATE", type: "DATETIME")
            column(name: "LAST_UPDATED_BY", type: "BIGINT")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_ROLE", columnNames: "role_code", constraintName: "role_code")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_ROLE_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_ROLE_FUNCTION") {
        createTable(tableName: "SYS_ROLE_FUNCTION", remarks: "") {
            column(name: "srf_id", type: "bigint(20)", remarks: "系统角色功能ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_FUNCTION_PK")
            }
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID")
            column(name: "function_id", type: "bigint(20)", remarks: "功能ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_ROLE_FUNCTION", columnNames: "role_id,function_id", constraintName: "SYS_ROLE_FUNCTION_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_ROLE_FUNCTION_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_ROLE_RESOURCE_ITEM") {
        createTable(tableName: "SYS_ROLE_RESOURCE_ITEM", remarks: "") {
            column(name: "rsi_id", type: "bigint(20)", remarks: "系统角色控件ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_RESOURCE_ITEM_PK")
            }
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID")
            column(name: "resource_item_id", type: "bigint(20)", remarks: "功能控件ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "SYS_ROLE_RESOURCE_ITEM", columnNames: "role_id,resource_item_id", constraintName: "SYS_ROLE_RESOURCE_ITEM_U1")

        createIndex(tableName: "SYS_ROLE_RESOURCE_ITEM", indexName: "SYS_ROLE_RESOURCE_ITEM_N1") {
            column(name: "role_id", type: "bigint(20)")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_ROLE_RESOURCE_ITEM_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_ROLE_TL") {
        createTable(tableName: "SYS_ROLE_TL", remarks: "") {
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_TL_PK")
            }
            column(name: "lang", type: "varchar(10)", remarks: "语言") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_ROLE_TL_PK")
            }
            column(name: "role_name", type: "varchar(150)", remarks: "角色名称")
            column(name: "role_description", type: "varchar(240)", remarks: "角色描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_TOKEN_LOGS") {
        createTable(tableName: "SYS_TOKEN_LOGS", remarks: "") {
            column(name: "id", type: "bigint(20)", remarks: "ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_TOKEN_LOGS_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID")
            column(name: "client_id", type: "varchar(100)", remarks: "客户端ID")
            column(name: "token", type: "varchar(1024)", remarks: "token")
            column(name: "token_access_time", type: "datetime", remarks: "token获取日期")
            column(name: "token_access_type", type: "varchar(32)", remarks: "token获取方式")
            column(name: "token_expires_time", type: "datetime", remarks: "token失效日期")
            column(name: "revoke_flag", type: "varchar(5)", defaultValue: "Y", remarks: "是否有效")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        createIndex(tableName: "SYS_TOKEN_LOGS", indexName: "SYS_TOKEN_LOGS_N1") {
            column(name: "user_id", type: "bigint(20)")
        }

        createIndex(tableName: "SYS_TOKEN_LOGS", indexName: "SYS_TOKEN_LOGS_N2") {
            column(name: "client_id", type: "varchar(100)")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_TOKEN_LOGS_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_USER_DASHBOARD") {
        createTable(tableName: "SYS_USER_DASHBOARD", remarks: "") {
            column(name: "user_dashboard_id", type: "bigint(20)", remarks: "用户仪表盘ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_DASHBOARD_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID")
            column(name: "dashboard_id", type: "bigint(20)", remarks: "仪表盘ID")
            column(name: "dashboard_sequence", type: "decimal(20,0)", defaultValue: "1", remarks: "仪表盘排序号")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_USER_DASHBOARD_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_USER_DEMO_B") {
        createTable(tableName: "SYS_USER_DEMO_B", remarks: "") {
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_DEMO_B_PK")
            }
            column(name: "user_code", type: "varchar(255)", remarks: "编码")
            column(name: "user_name", type: "varchar(255)", remarks: "姓名")
            column(name: "user_age", type: "bigint(20)", remarks: "年龄")
            column(name: "user_sex", type: "varchar(50)", remarks: "性别")
            column(name: "user_birth", type: "date", remarks: "生日")
            column(name: "user_email", type: "varchar(255)", remarks: "邮箱")
            column(name: "user_phone", type: "bigint(20)", remarks: "电话")
            column(name: "enable_flag", type: "varchar(1)", remarks: "是否启用")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "ROLE_ID", type: "bigint(20)", remarks: "角色ID")
            column(name: "ROLE_NAME", type: "varchar(255)", remarks: "角色名称")
            column(name: "START_ACTIVE_TIME", type: "datetime", remarks: "开始时间")
            column(name: "END_ACTIVE_TIME", type: "datetime", remarks: "结束时间")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "SYS_USER_DEMO_B", columnNames: "user_code", constraintName: "SYS_USER_DEMO_B_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_USER_DEMO_B_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_USER_DEMO_TL") {
        createTable(tableName: "SYS_USER_DEMO_TL", remarks: "") {
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_DEMO_TL_PK")
            }
            column(name: "lang", type: "varchar(10)", remarks: "语言") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_DEMO_TL_PK")
            }
            column(name: "user_name", type: "varchar(255)", remarks: "姓名")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_USER_LOGIN") {
        createTable(tableName: "SYS_USER_LOGIN", remarks: "") {
            column(name: "login_id", type: "bigint(20)", remarks: "登录ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_CUSTOMIZATION_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "用户id")
            column(name: "login_time", type: "datetime", remarks: "登录时间")
            column(name: "ip", type: "varchar(40)", remarks: "ip地址")
            column(name: "referer", type: "varchar(240)")
            column(name: "user_agent", type: "varchar(240)")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_USER_LOGIN_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_USER_ROLE") {
        createTable(tableName: "SYS_USER_ROLE", remarks: "") {
            column(name: "sur_id", type: "bigint(20)", remarks: "系统用户角色ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_ROLE_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "用户ID")
            column(name: "role_id", type: "bigint(20)", remarks: "角色ID")
            column(name: "OBJECT_VERSION_NUMBER", type: "DECIMAL(20,0)", defaultValue: "-1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
            column(name: "ATTRIBUTE_CATEGORY", type: "varchar(30)")
            column(name: "ATTRIBUTE1", type: "varchar(240)")
            column(name: "ATTRIBUTE2", type: "varchar(240)")
            column(name: "ATTRIBUTE3", type: "varchar(240)")
            column(name: "ATTRIBUTE4", type: "varchar(240)")
            column(name: "ATTRIBUTE5", type: "varchar(240)")
            column(name: "ATTRIBUTE6", type: "varchar(240)")
            column(name: "ATTRIBUTE7", type: "varchar(240)")
            column(name: "ATTRIBUTE8", type: "varchar(240)")
            column(name: "ATTRIBUTE9", type: "varchar(240)")
            column(name: "ATTRIBUTE10", type: "varchar(240)")
            column(name: "ATTRIBUTE11", type: "varchar(240)")
            column(name: "ATTRIBUTE12", type: "varchar(240)")
            column(name: "ATTRIBUTE13", type: "varchar(240)")
            column(name: "ATTRIBUTE14", type: "varchar(240)")
            column(name: "ATTRIBUTE15", type: "varchar(240)")
        }

        addUniqueConstraint(tableName: "SYS_USER_ROLE", columnNames: "role_id,user_id", constraintName: "SYS_USER_ROLE_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_USER_ROLE_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-SYS_USER_SHORTCUT") {
        createTable(tableName: "SYS_USER_SHORTCUT", remarks: "主页快捷方式") {
            column(name: "shortcut_id", type: "bigint(20)", remarks: "快捷方式ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_USER_SHORTCUT_PK")
            }
            column(name: "user_id", type: "bigint(20)", remarks: "用户id")
            column(name: "function_code", type: "varchar(50)", remarks: "功能CODE")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'SYS_USER_SHORTCUT_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-WFL_APPROVE_CANDIDATE_RULE") {
        createTable(tableName: "WFL_APPROVE_CANDIDATE_RULE", remarks: "候选人审批规则") {
            column(name: "candidate_rule_id", type: "bigint(20)", remarks: "主键ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "WFL_APPROVE_CANDIDATE_RULE_PK")
            }
            column(name: "code", type: "varchar(50)", remarks: "选人规则的唯一标示")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "expression", type: "varchar(100)", remarks: "activiti表达式")
            column(name: "enable_flag", type: "varchar(5)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "WFL_APPROVE_CANDIDATE_RULE", columnNames: "code", constraintName: "WFL_APPROVE_CANDIDATE_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'WFL_APPROVE_CANDIDATE_RULE_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-WFL_APPROVE_CHAIN_HEADER") {
        createTable(tableName: "WFL_APPROVE_CHAIN_HEADER", remarks: "审批链定义 头表") {
            column(name: "approve_chain_id", type: "bigint(20)", remarks: "头ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "WFL_APPROVE_CHAIN_HEADER_PK")
            }
            column(name: "process_key", type: "varchar(255)", remarks: "业务key")
            column(name: "usertask_id", type: "varchar(255)", remarks: "任务ID")
            column(name: "enable_flag", type: "varchar(1)", defaultValue: "Y", remarks: "是否启用")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "WFL_APPROVE_CHAIN_HEADER", columnNames: "process_key,usertask_id", constraintName: "WFL_APPROVE_CHAIN_HEADER_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'WFL_APPROVE_CHAIN_HEADER_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-WFL_APPROVE_CHAIN_LINE") {
        createTable(tableName: "WFL_APPROVE_CHAIN_LINE", remarks: "审批链定义 行表") {
            column(name: "APPROVE_CHAIN_LINE_ID", type: "bigint(20)", remarks: "行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "WFL_APPROVE_CHAIN_LINE_PK")
            }
            column(name: "approve_chain_id", type: "bigint(20)", remarks: "头ID")
            column(name: "name", type: "varchar(255)", remarks: "名称")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "approve_type", type: "varchar(40)", defaultValue: "NONE", remarks: "审批类型")
            column(name: "assignee", type: "varchar(200)", remarks: "审批人")
            column(name: "assign_group", type: "varchar(200)", remarks: "审批组")
            column(name: "form_key", type: "varchar(255)", remarks: "审批页面")
            column(name: "sequence", type: "decimal(18,2)", defaultValue: "10.00", remarks: "排序号，可以为小数")
            column(name: "skip_expression", type: "varchar(255)", remarks: "跳过条件,留空表示不跳过 (false)")
            column(name: "break_on_skip", type: "varchar(1)", defaultValue: "N", remarks: "该规则被跳过时,停止继续走其他规则")
            column(name: "enable_flag", type: "varchar(1)", defaultValue: "Y", remarks: "是否启用")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        addUniqueConstraint(tableName: "wfl_approve_chain_line", columnNames: "name", constraintName: "NAME")

        createIndex(tableName: "wfl_approve_chain_line", indexName: "WFL_APPROVE_CHAIN_LINE_N1") {
            column(name: "approve_chain_id", type: "bigint(20)")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'WFL_APPROVE_CHAIN_LINE_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-WFL_APPROVE_STRATEGY") {
        createTable(tableName: "WFL_APPROVE_STRATEGY", remarks: "审批策略") {
            column(name: "approve_strategy_id", type: "bigint(20)", remarks: "策略ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "WFL_APPROVE_STRATEGY_PK")
            }
            column(name: "code", type: "varchar(50)", remarks: "策略的唯一标识")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "conditions", type: "varchar(500)", remarks: "审批通过条件")
            column(name: "enable_flag", type: "varchar(5)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "WFL_APPROVE_STRATEGY", columnNames: "code", constraintName: "WFL_APPROVE_STRATEGY_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'WFL_APPROVE_STRATEGY_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-WFL_BUSINESS_RULE_HEADER") {
        createTable(tableName: "WFL_BUSINESS_RULE_HEADER", remarks: "审批权限规则 头表") {
            column(name: "business_rule_id", type: "bigint(20)", remarks: "审批规则ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "WFL_BUSINESS_RULE_HEADER_PK")
            }
            column(name: "code", type: "varchar(50)", remarks: "审批规则的唯一标识")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "WFL_TYPE", type: "varchar(50)", remarks: "工作流类型")
            column(name: "enable_flag", type: "varchar(5)", remarks: "启用标志")
            column(name: "start_active_date", type: "datetime", remarks: "有效期从")
            column(name: "end_active_date", type: "datetime", remarks: "有效期至")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }
        addUniqueConstraint(tableName: "WFL_BUSINESS_RULE_HEADER", columnNames: "code", constraintName: "WFL_BUSINESS_RULE_HEADER_U1")

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'WFL_BUSINESS_RULE_HEADER_S', startValue: "10001")
        }
    }

    changeSet(author: "neil", id: "HLS_DB_SCRIPT_2017-9-19-init-data-migration-WFL_BUSINESS_RULE_LINE") {
        createTable(tableName: "WFL_BUSINESS_RULE_LINE", remarks: "审批权限规则 行表") {
            column(name: "business_rule_line_id", type: "bigint(20)", remarks: "行ID", autoIncrement: "true", startWith: "10001") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "WFL_BUSINESS_RULE_LINE_PK")
            }
            column(name: "business_rule_id", type: "bigint(20)", remarks: "头ID")
            column(name: "description", type: "varchar(255)", remarks: "描述")
            column(name: "conditions", type: "varchar(500)", remarks: "审批权限表达式")
            column(name: "enable_flag", type: "varchar(5)", remarks: "启用标志")
            column(name: "OBJECT_VERSION_NUMBER", type: "BIGINT", defaultValue: "1")
            column(name: "REQUEST_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "PROGRAM_ID", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "CREATION_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "BIGINT", defaultValue: "-1")
            column(name: "LAST_UPDATE_DATE", type: "DATETIME", defaultValueComputed: "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "BIGINT", defaultValue: "-1")
        }

        if (mhi.isDbType('oracle') || mhi.isDbType('hana')) {
            createSequence(sequenceName: 'WFL_BUSINESS_RULE_LINE_S', startValue: "10001")
        }
    }

    changeSet(author: "qiangzeng", id: "20170904-sys-resource-item-element-1") {
        if (mhi.isDbType('oracle') || mhi.isDbType('hana')){
            createSequence(sequenceName: 'SYS_RESOURCE_ITEM_ELEMENT_S',startValue:"10001")
        }
        createTable (tableName: "SYS_RESOURCE_ITEM_ELEMENT", remarks: "资源组件元素") {
            column(name: "ELEMENT_ID", type: "BIGINT", autoIncrement: "true", startWith: "10001", remarks: "PK") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_ITEM_ELEMENT_PK")
            }
            column(name: "TYPE", type:"VARCHAR(20)",remarks: "类型"){
                constraints(nullable: "false")
            }
            column(name: "PROPERTY", type:"VARCHAR(20)",remarks: "属性"){
                constraints(nullable: "false")
            }
            column(name: "PROPERTY_VALUE", type:"VARCHAR(20)",remarks: "属性值"){
                constraints(nullable: "false")
            }
            column(name: "NAME", type:"VARCHAR(20)",remarks: "名称")
            column(name: "RESOURCE_ITEM_ID", type:"BIGINT",remarks: "资源组件ID")
            column(name:"OBJECT_VERSION_NUMBER",type:"BIGINT",defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "bigint", defaultValue : "-1")
            column(name: "CREATED_BY", type: "bigint", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint", defaultValue : "-1")
            column(name:"ATTRIBUTE_CATEGORY",type:"varchar(30)")
            column(name:"ATTRIBUTE1",type:"varchar(240)")
            column(name:"ATTRIBUTE2",type:"varchar(240)")
            column(name:"ATTRIBUTE3",type:"varchar(240)")
            column(name:"ATTRIBUTE4",type:"varchar(240)")
            column(name:"ATTRIBUTE5",type:"varchar(240)")
            column(name:"ATTRIBUTE6",type:"varchar(240)")
            column(name:"ATTRIBUTE7",type:"varchar(240)")
            column(name:"ATTRIBUTE8",type:"varchar(240)")
            column(name:"ATTRIBUTE9",type:"varchar(240)")
            column(name:"ATTRIBUTE10",type:"varchar(240)")
            column(name:"ATTRIBUTE11",type:"varchar(240)")
            column(name:"ATTRIBUTE12",type:"varchar(240)")
            column(name:"ATTRIBUTE13",type:"varchar(240)")
            column(name:"ATTRIBUTE14",type:"varchar(240)")
            column(name:"ATTRIBUTE15",type:"varchar(240)")
        }
    }
    changeSet(author: "qiangzeng", id: "20170904-sys-resource-item-assign-1") {
        if (mhi.isDbType('oracle') || mhi.isDbType('hana')){
            createSequence(sequenceName: 'SYS_RESOURCE_ITEM_ASSIGN_S',startValue:"10001")
        }
        createTable (tableName: "SYS_RESOURCE_ITEM_ASSIGN", remarks: "资源组件分配") {
            column(name: "ASSIGN_ID", type: "BIGINT", autoIncrement: "true", startWith: "10001", remarks: "PK") {
                constraints(nullable: "false", primaryKey: "true", primaryKeyName: "SYS_RESOURCE_ITEM_ASSIGN_PK")
            }
            column(name: "ASSIGN_TYPE", type:"VARCHAR(50)",remarks: "分配类型")
            column(name: "TYPE_ID", type:"BIGINT",remarks: "类型ID")
            column(name: "ELEMENT_ID", type:"BIGINT",remarks: "组件元素ID")
            column(name: "FUNCTION_ID", type:"BIGINT",remarks: "功能ID")
            column(name: "ENABLE", type:"VARCHAR(50)",remarks: "是否启用")
            column(name:"OBJECT_VERSION_NUMBER",type:"BIGINT",defaultValue: "1")
            column(name: "REQUEST_ID", type: "bigint", defaultValue : "-1")
            column(name: "PROGRAM_ID", type: "bigint", defaultValue : "-1")
            column(name: "CREATED_BY", type: "bigint", defaultValue : "-1")
            column(name: "CREATION_DATE", type: "datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATED_BY", type: "bigint", defaultValue : "-1")
            column(name: "LAST_UPDATE_DATE", type: "datetime", defaultValueComputed : "CURRENT_TIMESTAMP")
            column(name: "LAST_UPDATE_LOGIN", type: "bigint", defaultValue : "-1")
            column(name:"ATTRIBUTE_CATEGORY",type:"varchar(30)")
            column(name:"ATTRIBUTE1",type:"varchar(240)")
            column(name:"ATTRIBUTE2",type:"varchar(240)")
            column(name:"ATTRIBUTE3",type:"varchar(240)")
            column(name:"ATTRIBUTE4",type:"varchar(240)")
            column(name:"ATTRIBUTE5",type:"varchar(240)")
            column(name:"ATTRIBUTE6",type:"varchar(240)")
            column(name:"ATTRIBUTE7",type:"varchar(240)")
            column(name:"ATTRIBUTE8",type:"varchar(240)")
            column(name:"ATTRIBUTE9",type:"varchar(240)")
            column(name:"ATTRIBUTE10",type:"varchar(240)")
            column(name:"ATTRIBUTE11",type:"varchar(240)")
            column(name:"ATTRIBUTE12",type:"varchar(240)")
            column(name:"ATTRIBUTE13",type:"varchar(240)")
            column(name:"ATTRIBUTE14",type:"varchar(240)")
            column(name:"ATTRIBUTE15",type:"varchar(240)")
        }
    }

}
